/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(wb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(){throw new Error("abort")}function q(m){h[2]=m}function r(){return h[2]}function ub(vb){var s=vb.a;var t=s.a;var u=t.buffer;t.grow=sb;var v=new Int8Array(u);var w=new Int16Array(u);var x=new Int32Array(u);var y=new Uint8Array(u);var z=new Uint16Array(u);var A=new Uint32Array(u);var B=new Float32Array(u);var C=new Float64Array(u);var D=Math.imul;var E=Math.fround;var F=Math.abs;var G=Math.clz32;var H=Math.min;var I=Math.max;var J=Math.floor;var K=Math.ceil;var L=Math.trunc;var M=Math.sqrt;var N=s.b;var O=s.c;var P=s.d;var Q=s.e;var R=s.f;var S=s.g;var T=s.h;var U=s.i;var V=s.j;var W=s.k;var X=s.l;var Y=s.m;var Z=s.n;var _=s.o;var $=s.p;var aa=s.q;var ba=s.r;var ca=s.s;var da=s.t;var ea=s.u;var fa=s.v;var ga=s.w;var ha=s.x;var ia=s.y;var ja=s.z;var ka=s.A;var la=s.B;var ma=s.C;var na=s.D;var oa=s.E;var pa=s.F;var qa=s.G;var ra=s.H;var sa=s.I;var ta=s.J;var ua=s.K;var va=s.L;var wa=s.M;var xa=s.N;var ya=s.O;var za=s.P;var Aa=s.Q;var Ba=s.R;var Ca=s.S;var Da=s.T;var Ea=s.U;var Fa=s.V;var Ga=s.W;var Ha=s.X;var Ia=s.Y;var Ja=s.Z;var Ka=s._;var La=s.$;var Ma=s.aa;var Na=s.ba;var Oa=s.ca;var Pa=s.da;var Qa=s.ea;var Ra=s.fa;var Sa=s.ga;var Ta=s.ha;var Ua=s.ia;var Va=s.ja;var Wa=s.ka;var Xa=s.la;var Ya=s.ma;var Za=s.na;var _a=s.oa;var $a=s.pa;var ab=s.qa;var bb=s.ra;var cb=s.sa;var db=s.ta;var eb=s.ua;var fb=s.va;var gb=s.wa;var hb=528464;var ib=0;var jb=0;var kb=0;var lb=0;
// EMSCRIPTEN_START_FUNCS
function cba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,P=0,R=0,S=0,U=0,V=0,W=0,X=E(0),Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=E(0),ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=E(0),La=0;Y=hb-32|0;hb=Y;ja=a+24604|0;f=ja;a:{if(!x[f+16>>2]){break a}g=x[f+20>>2];if(g>>>0>4|!(1<<g&22)){break a}f=x[f+28>>2];if(f>>>0>4){break a}e=23>>>f&1}if(!e){g=Y+16|0;fM(g,5104,8871,207);e=hb-160|0;hb=e;f=Ub(e+120|0,13608);x[114414]=0;T(6,e+104|0,1,13200);h=x[114414];x[114414]=0;b:{c:{d:{e:{f:{if((h|0)!=1){x[114414]=0;T(3,e+136|0,f|0,e+104|0);h=x[114414];x[114414]=0;if((h|0)==1){break f}x[114414]=0;ba(2150,e+88|0,g|0,1,9458,e+136|0);g=x[114414];x[114414]=0;if((g|0)==1){break e}xb(e+136|0);xb(e+104|0);break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;xb(e+136|0)}xb(e+104|0)}xb(f);Q(a|0);p()}xb(f);hb=e+160|0}e=x[a+480208>>2];g:{if(!b|e&512){break g}ka=a+8204|0;ua=a+1074332|0;L=a+393352|0;Z=a+12|0;la=a+1304392|0;f=x[a+1074380>>2];while(1){h:{if(f){break h}f=e|512;i:{if(e&256){break i}s=hb-32|0;hb=s;U=hb-16|0;hb=U;f=a+1074392|0;e=x[f>>2]+1|0;x[f>>2]=e;j:{k:{if(Ol(a)>>>0>e>>>0){break k}i=a+1074984|0;o=a+1074312|0;g=a+1304360|0;j=a+484344|0;k=a+484360|0;n=a+1074438|0;m=a+1074424|0;q=a+480210|0;while(1){l=0;l:{if(!x[a+1074396>>2]){break l}l=0;if(!(y[q|0]&8)){break l}l=x[a+480180>>2]==1}m:{if(x[a+480180>>2]!=2|(y[q|0]&8?0:x[a+1074428>>2])){break m}f=0;if(!z[a+480188>>1]){break m}while(1){x[(D(f,896)+a|0)+1075788>>2]=0;f=f+1|0;if(f>>>0<z[a+480188>>1]){continue}break}}x[a+1074400>>2]=0;x[a+1074392>>2]=0;x[a+1074396>>2]=0;x[a+1074424>>2]=x[a+1074428>>2];f=z[a+1074440>>1];w[a+1074438>>1]=f;n:{o:{p:{if(!(y[a+480208|0]&32)){e=a;q:{if(qc(Vb(k))>>>0>f>>>0){f=z[uc(Vb(k),z[n>>1])>>1];break q}f=65535}w[e+1074436>>1]=f;h=Ae(j);e=z[a+1074436>>1];r:{if(h>>>0<=(f&65535)>>>0){break r}if(xh(Zb(j,e))){e=z[a+1074436>>1];break r}w[a+1074436>>1]=65534;e=65534}if(Ae(j)>>>0<=(e&65535)>>>0){while(1){s:{t:{u:{v:{if(z[a+1074436>>1]!=65535){e=z[n>>1];if(qc(Vb(k))>>>0>e>>>0){break v}}f=z[Vb(k)+28>>1];if(f){break t}e=z[n>>1];if(qc(Vb(k))>>>0<e>>>0){break u}e=z[n>>1];if(!e){break u}h=e;while(1){f=e;h=h-1|0;H=h&65535;if(!H){break u}e=f-1|0;if(z[uc(Vb(k),H)>>1]!=65535){continue}break}break t}f=z[n>>1]+1|0;w[n>>1]=f;break s}f=0}w[a+1074438>>1]=f;x[a+480208>>2]=x[a+480208>>2]&-524289;w:{if(qc(Vb(k))>>>0<=(f&65535)>>>0){break w}while(1){if(z[uc(Vb(k),z[n>>1])>>1]!=65534){break w}e=z[n>>1]+1|0;w[n>>1]=e;if(qc(Vb(k))>>>0>(e&65535)>>>0){continue}break}}e=z[n>>1];x:{if(qc(Vb(k))>>>0<=e>>>0){break x}if(!Rp(Vb(k),z[n>>1])){break x}f=z[n>>1];break s}Hk(g,1);break p}e=a;y:{if(qc(Vb(k))>>>0>(f&65535)>>>0){f=z[uc(Vb(k),z[n>>1])>>1];break y}f=65535}w[e+1074436>>1]=f;h=Ae(j);e=z[a+1074436>>1];z:{if(h>>>0<=(f&65535)>>>0){break z}if(xh(Zb(j,e))){e=z[a+1074436>>1];break z}w[a+1074436>>1]=65534;e=65534}if(Ae(j)>>>0<=(e&65535)>>>0){continue}break}}w[a+1074440>>1]=z[a+1074438>>1]}e=0;if(!kg(j,z[a+1074436>>1])){break j}if(A[a+1074424>>2]>=A[Zb(j,z[a+1074436>>1])+12>>2]){x[m>>2]=0}h=(y[a+480208|0]&32)>>>5&x[a+480272>>2]!=-1;if(l){f=g+12|0;if(od(f)){f=-1}else{f=x[xj(f)>>2]}f=(f|0)==x[m>>2]}else{f=1}if(h|!f){break n}if(!yN(g,z[n>>1],x[m>>2],1)){break n}f=x[a+480272>>2];if(f){if((f|0)>0){x[a+480272>>2]=f-1}Hk(g,1);CL(g,z[n>>1],x[m>>2]);break n}if(!(y[q|0]&64)){break o}if(!xN(g,n,m,1)){x[a+1074424>>2]=0;x[a+1074428>>2]=0;w[a+1074438>>1]=0;w[a+1074440>>1]=0;f=y[k+16|0];if((f|0)>=(Vh(k)-1|0)){Qp(k,0);Hk(g,1);break j}Qp(k,y[k+16|0]+1&255);Hk(g,1)}f=0;while(1){Hn((D(f,896)+a|0)+1074984|0,7,a,f&65535,1024);f=f+1|0;if((f|0)!=256){continue}break}ZL(a);x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];x[a+1074444>>2]=x[a+480200>>2];w[a+1074440>>1]=z[a+1074438>>1];x[a+1074428>>2]=x[a+1074424>>2];f=qc(Vb(k));e=z[a+1074438>>1];if(f>>>0>e>>>0){Ia=a,Ja=z[uc(Vb(k),z[a+1074438>>1])>>1],w[Ia+1074436>>1]=Ja;e=z[a+1074438>>1]}CL(g,e&65535,x[a+1074424>>2]);if(kg(j,z[a+1074436>>1])){break n}}e=0;break j}Hk(g,1);break j}e=x[a+1074424>>2]+1|0;x[a+1074428>>2]=e;A:{if(e>>>0<A[Zb(j,z[a+1074436>>1])+12>>2]){break A}if(!(y[a+480208|0]&32)){w[a+1074440>>1]=z[a+1074438>>1]+1}x[a+1074428>>2]=0;e=U+8|0;Kb(e,o,63);if(!Ib(e)){break A}e=x[a+1074432>>2];x[a+1074432>>2]=0;x[a+1074428>>2]=e}e=Df(Zb(j,z[a+1074436>>1]),x[a+1074424>>2],0);f=z[a+480188>>1];if(f){H=i+D(f,896)|0;f=i;while(1){h=U+8|0;Kb(h,o,82);B:{if(!Ib(h)|y[f+827|0]!=1){break B}h=y[e+3|0];if((h|0)!=2&(h|0)!=3){break B}Ia=f,Ja=eg(a,y[f+822|0],x[f+768>>2],x[f+704>>2]),x[Ia+700>>2]=Ja}h=U+8|0;Kb(h,o,91);C:{if(!Ib(h)){break C}if(Af(e)){break C}if(!Af(f+810|0)|y[f+813|0]!=19){break C}h=y[f+815|0];if((h&240)!=208|A[a+1074416>>2]>(h&15)>>>0){break C}Ia=f,Ja=eg(a,y[f+810|0],x[f+768>>2],0),x[Ia+700>>2]=Ja}h=U+8|0;Kb(h,o,92);D:{if(!Ib(h)){break D}Kb(U,o,5);if(Ib(U)|x[a+1074416>>2]!=1|y[f+813|0]!=17){break D}v[U+8|0]=1;Ia=a,Ja=D(y[Xg(U+8|0,f+815|0)|0],1e4),x[Ia+1074420>>2]=Ja}h=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);v[f+810|0]=h;v[f+811|0]=h>>>8;v[f+812|0]=h>>>16;v[f+813|0]=h>>>24;h=y[e+4|0]|y[e+5|0]<<8;v[f+814|0]=h;v[f+815|0]=h>>>8;h=x[f+676>>2];x[f+20>>2]=x[f+672>>2];x[f+24>>2]=h;x[f+88>>2]=x[f+88>>2]&-393217;h=U+8|0;Kb(h,o,21);if(!Ib(h)){v[f+851|0]=0}x[f+884>>2]=0;v[f+827|0]=0;e=e+6|0;f=f+896|0;if((H|0)!=(f|0)){continue}break}}h=a+1074412|0;E:{F:{e=a+484344|0;if(go(e,z[a+1074436>>1])){if(cN(Zb(e,z[a+1074436>>1]))){break F}}x[a+1074408>>2]=x[a+480216>>2];f=x[a+480220>>2];break E}Ia=a+1074408|0,Ja=x[Zb(e,z[a+1074436>>1])+16>>2],x[Ia>>2]=Ja;f=x[Zb(e,z[a+1074436>>1])+20>>2]}x[h>>2]=f;if(!l){break k}e=x[a+1074416>>2]+1|0;x[a+1074392>>2]=e;if(Ol(a)>>>0<=e>>>0){continue}break}}if(!x[a+1074416>>2]){x[a+1074416>>2]=1}f=x[a+480208>>2];e=a;G:{H:{if(x[a+1074392>>2]){x[a+480208>>2]=f&-4097;if(x[a+480180>>2]&1048580|!(y[a+480210|0]&32)&x[a+480180>>2]==1){break G}if(A[a+1074392>>2]>=Ol(a)>>>0|A[a+1074392>>2]%(x[a+1074400>>2]+x[a+1074416>>2]>>>0)){break G}f=x[a+480208>>2];break H}f=f&-528385}x[e+480208>>2]=f|4096}C=0;u=hb-32|0;hb=u;I:{if(!z[a+480188>>1]){n=-1;J=65535;m=-1;break I}aa=a+1075821|0;R=a+1304392|0;G=a+1074312|0;$=a+1074376|0;S=a+480209|0;ca=a+480210|0;m=-1;n=-1;J=65535;while(1){t=D(C,896)+a|0;k=t+1075799|0;i=y[k|0];j=t+1075797|0;M=y[j|0];q=t+1075798|0;I=y[q|0];W=t+1075796|0;o=y[W|0];V=t+1075795|0;l=y[V|0];f=x[a+1074392>>2];g=x[a+1074400>>2];H=x[a+1074416>>2];O=t+1075794|0;e=it(O);h=t+1075856|0;v[h|0]=x[a+480208>>2]>>>12&1|y[h|0]&254;r=(f>>>0)%(g+H>>>0)|0;f=y[O|0];if((f|0)==252){f=y[V|0];g=Ny(O);H=gt(O);J:{if((f-1&255)>>>0>249){break J}f=x[(D(f,160)+a|0)+906140>>2];if(!f){break J}mb[x[x[f>>2]+44>>2]](f,g,E(E(H>>>0)*E(.0010010009864345193)))}f=y[O|0]}K:{if(B[t+1075868>>2]==E(0)|M?(f&255)!=251:0){break K}H=x[a+480208>>2]&4096;L:{if(!H){g=y[t+1075878|0];break L}g=y[V|0];v[t+1075878|0]=g}if((g-1&255)>>>0>249){break K}f=(D(g&255,160)+a|0)+906140|0;if(!x[f>>2]){break K}M:{if(!H){g=z[t+1075876>>1];break M}g=ct(y[W|0],y[q|0]);w[t+1075876>>1]=g;X=E(E(ct(y[j|0],y[k|0])>>>0)*E(.0010010009864345193));B[t+1075872>>2]=X;k=x[f>>2];Ia=t+1075868|0,Ka=E(E(X-E(mb[x[x[k>>2]+48>>2]](k,g)))/E(Ol(a)>>>0)),B[Ia>>2]=Ka}k=x[a+1074392>>2];j=Ol(a);f=x[f>>2];q=g;g=(j|0)==(k+1|0);mb[x[x[f>>2]+(g?44:100)>>2]](f,q,B[(g?t+1075872|0:t+1075868|0)>>2])}k=t+1074984|0;N:{O:{P:{Q:{R:{if(!_M(y[O|0])){if(y[S|0]&16){break R}break Q}f=hb-16|0;hb=f;w[f+12>>1]=0;x[f+8>>2]=0;e=_h(f+8|0);g=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);v[k+810|0]=g;v[k+811|0]=g>>>8;v[k+812|0]=g>>>16;v[k+813|0]=g>>>24;e=y[e+4|0]|y[e+5|0]<<8;v[k+814|0]=e;v[k+815|0]=e>>>8;hb=f+16|0;l=0;o=0;I=0;M=0;i=0;e=0;if(!(y[S|0]&16)){break Q}g=0;break O}if(!l){l=0;break P}x[t+1075768>>2]=0;break P}SM(a,k)}if((M|0)==33){f=u+24|0;Kb(f,G,30);g=i>>>4|0;Hy(a,C&65535,g+(i&15)|0,Ib(f));M=33;break O}g=0;if((M-19&255)>>>0>1){break O}S:{if(!(!(x[a+480180>>2]&16777250)|i)){i=y[t+1075837|0];break S}v[t+1075837|0]=i}f=i&240;if((f|0)==208){f=i&15;if(!f){if(x[a+480180>>2]&16777248){g=1;break O}if(x[a+480180>>2]!=2){break O}break N}T:{if(f>>>0<x[a+1074400>>2]+x[a+1074416>>2]>>>0){break T}g=u+24|0;Kb(g,G,14);if(!Ib(g)){break T}if(!l){break N}v[t+1075809|0]=l;break N}g=f;break O}if(!(y[S|0]&16)){break O}U:{if((f|0)==96&(M|0)==19|(f|0)==176&(M|0)==20){f=u+24|0;Kb(f,G,77);if(Ia=Ib(f),Ja=0,La=x[((C<<5)+a|0)+480280>>2]&1024,La?Ia:Ja){break O}j=0;q=hb-16|0;hb=q;H=i&15;V:{W:{if(H){f=y[k+861|0];X:{if(f){f=f-1|0;v[k+861|0]=f;if(f&255){break X}f=q+8|0;Kb(f,a+1074312|0,16);if(!Ib(f)){f=-1;if(x[a+480180>>2]!=2){break V}}x[k+804>>2]=x[a+1074424>>2]+1;break W}f=q+8|0;Kb(f,a+1074312|0,17);if(!(Ib(f)|x[a+480180>>2]&3|!z[a+480188>>1])){f=a+1074984|0;while(1){if(y[f+861|0]?(f|0)!=(k|0):0){break W}f=f+896|0;j=j+1|0;if(z[a+480188>>1]>(j&65535)>>>0){continue}break}}v[k+861|0]=H}f=x[k+804>>2];x[a+1074432>>2]=f;break V}x[k+804>>2]=x[a+1074424>>2]}f=-1}hb=q+16|0;Y:{if((f|0)==-1){f=n;break Y}Z:{if((m|0)!=-1){n=u+24|0;Kb(n,G,68);m=Ib(n)?f:m;break Z}m=-1}n=u+24|0;Kb(n,G,103);J=Ib(n)?-1:J}if(!z[a+480188>>1]|x[a+480180>>2]!=2){break U}n=t+1075845|0;q=t+1075788|0;j=0;while(1){H=D(j,896)+a|0;x[H+1075788>>2]=x[q>>2];v[H+1075845|0]=y[n|0];j=j+1|0;if(j>>>0<z[a+480188>>1]){continue}break}break U}if((f|0)!=224|(x[a+1074396>>2]?x[a+480180>>2]&16777250:0)){break O}f=i&15;if(f?0:x[a+480180>>2]&2){break O}x[a+1074396>>2]=f+1;break O}n=f}_=i&15;f=g;g=x[a+480180>>2]==16&(M|0)==19&(i&240)==208;P=g?0:f;_:{if(!P|y[O|0]!=255|y[W|0]!=2){break _}f=u+24|0;Kb(f,G,74);if(!Ib(f)){break _}v[W|0]=0}j=_|144;f=x[a+1074392>>2];q=u+24|0;Kb(q,G,72);$:{if(Ib(q)){H=0;if(P>>>0>=A[a+1074416>>2]){break $}}q=u+24|0;Kb(q,G,88);H=(r|0)==(P|0)|(f|0)==(P|0);if(!(!P|!Ib(q))){break $}H=(f|0)==(P|0)}j=g?j:i;f=u+24|0;Kb(f,G,44);g=Ib(f);i=h;h=y[h|0];v[i|0]=(g?h&252|(r|0)==(P|0):h)&253|(H?2:0);Kb(f,G,66);h=(!P|Ib(f)^1)&e;aa:{ba:{ca:{if(!(x[a+1074392>>2]|(!(y[ca|0]&32)|!l))){x[t+1075644>>2]=0;if(H){i=y[O|0];break ca}if(!Sh(k)){break aa}v[t+1075809|0]=l;if(z[a+480190>>1]<l>>>0){break aa}e=D(l,104)+a|0;x[t+1075672>>2]=z[e+484410>>1];x[t+1075752>>2]=v[e+484417|0];break aa}if(!H){break aa}i=y[O|0];if(!l){break ba}}v[t+1075809|0]=l}da:{ea:{e=i&255;if(!Zd(e)){break ea}f=u+24|0;Kb(f,G,67);if(!Ib(f)){break ea}g=x[t+1075756>>2];fa:{if(!l|h){break fa}ga:{if(z[a+480192>>1]){f=65535;if(z[a+480192>>1]<l>>>0){break ga}q=x[((l<<2)+a|0)+900380>>2];if(!q){break ga}f=z[fd(q+236|0,e-1|0)>>1];break ga}f=l}f=f&65535;if(f>>>0>z[a+480190>>1]){break fa}g=v[Zp(a,f)+36|0]}i=(e+g|0)-132>>>0>=4294967176?i:0;break da}if(!(x[a+480180>>2]&25165856)|!z[a+480192>>1]){break da}if(e){f=Zd(e)}else{f=1}if(!f){break da}e=l;if(!e){e=y[t+1075810|0]}if(!e|(x[((e<<2)+a|0)+900380>>2]?z[a+480192>>1]>=e>>>0:0)){break da}i=0;l=0}if(!((M|0)!=25|j)){e=u+24|0;Kb(e,G,55);e=Ib(e);l=e?0:l;i=e?0:i}g=u+24|0;Kb(g,G,65);f=(l|0)!=0;e=i&255;q=!e;g=Ib(g);K=1;ha:{if(x[a+480180>>2]&16777248){break ha}r=u+24|0;Kb(r,G,107);if(Ib(r)){break ha}r=u+16|0;Kb(r,G,85);K=0;if(!Ib(r)){break ha}if(Sh(k)){break ha}K=1;r=x[t+1075088>>2];if(!r){break ha}K=Be(r)^1}q=f&q;r=f&g;ia:{ja:{ka:{la:{ma:{na:{if(!(x[a+480180>>2]&1048580)){break na}oa:{if((e|0)!=255){break oa}if(!(!((o|0)==1|l)&(M|0)!=13)){f=u+24|0;Kb(f,G,55);if(Ib(f)){break oa}}f=x[t+1075640>>2];if(v[f+60|0]&1?f:0){break oa}x[t+1075672>>2]=0;e=t+1075072|0;x[e>>2]=x[e>>2]|2097152;pa:{if(!(x[a+480208>>2]&4096)){break pa}f=u+24|0;Kb(f,G,86);if(!Ib(f)){break pa}x[e>>2]=x[e>>2]|4096}l=0;i=0;g=0;e=0;f=0;q=1;if(r){break ja}break ia}f=u+24|0;Kb(f,G,59);if(!Ib(f)|x[a+480208>>2]&4096){break na}qa:{if(!e){i=y[t+1075803|0]-y[t+1075756|0]|0;break qa}if(e>>>0>250){K=0;r=1;i=0;break qa}ra:{if(l){break ra}e=u+24|0;Kb(e,G,98);if(!Ib(e)){break ra}l=0;break qa}K=1;r=1}g=i;h=0;break ma}g=0;if(!q){break la}}e=u+24|0;Kb(e,G,65);if(!Ib(e)){break ka}i=g;g=1}e=i;f=g;q=1;if(r){break ja}break ia}i=g;g=1;q=r}sa:{ta:{if(!z[a+480192>>1]){if(z[a+480190>>1]<l>>>0){break sa}e=(D(l,104)+a|0)+484380|0;break ta}e=x[t+1075088>>2];if(!e){break sa}}ua:{if(w[e+34>>1]<0){break ua}if(x[a+480180>>2]==2){if(!Be(e)){break ua}}x[t+1075672>>2]=z[e+30>>1]}if(!q){break sa}Bt(k,z[e+28>>1],a)}e=i;f=g}g=u+24|0;Kb(g,G,71);if(!(!Ib(g)|!l)){v[t+1075843|0]=32}va:{if(!z[a+480192>>1]){break va}g=u+24|0;Kb(g,G,100);if(!Ib(g)|!l){break va}if(Zd(e&255)){break va}g=x[a+480208>>2];wa:{if(h){if(g&8){break wa}break va}if(!(g&4)){break va}}Rl(k);x[t+1075680>>2]=65536;g=t+1075072|0;x[g>>2]=x[g>>2]|2097152}if(f){f=u+24|0;Kb(f,G,11);xa:{if(!Ib(f)&x[a+480180>>2]!=268435456){break xa}f=u+24|0;Kb(f,G,87);i=0;if(Ib(f)){i=Sh(k)^1}ya:{if(z[a+480192>>1]){if(z[a+480192>>1]<l>>>0){break xa}if(x[t+1075640>>2]!=x[((l<<2)+a|0)+900380>>2]|i){break ya}break xa}if((i^-1)&x[t+1075088>>2]==((D(l,104)+a|0)+484380|0)){break xa}}e=y[t+1075803|0]}za:{if(!z[a+480192>>1]|!(x[a+480180>>2]&1048588)){break za}Rl(k);v[t+1075822|0]=0;x[t+1075764>>2]=0;x[t+1075680>>2]=65536;f=t+1075072|0;x[f>>2]=x[f>>2]&-2101249|2097152;g=u+24|0;Kb(g,G,86);if(!Ib(g)){break za}x[f>>2]=x[f>>2]&-2049}l=K?l:0}i=e&255;Aa:{if(i>>>0<251){break Aa}f=u+24|0;Kb(f,G,50);Ba:{if(!Ib(f)|!l){break Ba}if(z[a+480192>>1]){if(z[a+480192>>1]<l>>>0){break Ba}f=((l<<2)+a|0)+900380|0;if(!x[f>>2]){break Ba}g=t+1075805|0;if(!Zd(y[g|0])){break Ba}f=z[fd(x[f>>2]+236|0,y[g|0]-1|0)>>1]}else{f=l}f=f&65535;if(!f|f>>>0>z[a+480190>>1]){break Ba}f=D(f,104)+a|0;if(w[f+484414>>1]<0){break Ba}x[t+1075672>>2]=z[f+484410>>1]}f=u+24|0;Kb(f,G,100);if(Ia=Ib(f),Ja=0,La=x[a+480208>>2]&4,La?Ia:Ja){break Aa}l=0}if(Zd(i)){v[t+1075808|0]=e;v[t+1075805|0]=e;if(!h){VM(a,C&65535,l,i,0)}AO(k)}Ca:{Da:{Ea:{Fa:{Ga:{if(l){f=t+1075088|0;g=x[f>>2];Fp(a,k,l,h,1,1);e=x[f>>2];Ha:{if(!e|!(y[e+35|0]&2)){break Ha}if(!zd(R)){break Ha}_y(x[R>>2],C&65535,x[f>>2]+68|0)}Ia:{Ja:{if(x[a+480180>>2]==1){if(!h){break Ja}e=u+24|0;Kb(e,G,85);if(!Ib(e)){break Ja}break Ia}e=u+24|0;Kb(e,G,50);if(!Ib(e)){break Ja}if(!Zd(i)){break Ia}}v[t+1075809|0]=0}e=u+24|0;Kb(e,G,42);if(Ib(e)){if(!Zd(i)|(g|0)==x[f>>2]){break Fa}break Ga}if(!(!(x[a+480180>>2]&16777248)|(g|0)==x[f>>2])){e=0;if(Zd(i)){break Ea}}e=u+24|0;Kb(e,G,107);Ka:{if(!Ib(e)|(g|0)==x[f>>2]){break Ka}if(!h){if(Zd(i)){break Ka}}e=t+1075060|0;if(A[e>>2]>=A[k+4>>2]){break Ka}x[e>>2]=0;break Fa}e=u+24|0;Kb(e,G,85);if(!Ib(e)){break Fa}if(!Sh(k)){break Ga}break Fa}if(!i){e=h;break Ca}g=0;f=t+1075809|0;La:{if(!y[f|0]){break La}if(!Zd(i)){break La}Fp(a,k,y[f|0],h,!(x[t+1075088>>2]?1:x[t+1075640>>2]),!(x[a+480180>>2]&1048580));v[f|0]=0;g=1}e=h;break Da}x[k>>2]=0;x[k+4>>2]=0}e=h}g=0;if(!i){break Ca}}f=t+1075088|0;h=x[f>>2];Ma:{if(!h|!(y[h+35|0]&2)){break Ma}if(!zd(R)){break Ma}if(!g){if(WM(x[R>>2],C&65535)){break Ma}}_y(x[R>>2],C&65535,x[f>>2]+68|0)}f=C&65535;ft(a,k,i,e,!(x[a+480180>>2]&1048580),0,f);if(!(!e|(!l|!(x[a+480180>>2]&1048580)))){g=t+1075072|0;x[g>>2]=x[g>>2]|2097152;Rl(k);v[t+1075822|0]=0;x[t+1075764>>2]=0}if(!(x[t+1075072>>2]&512)){break Ca}if(!zd(R)){break Ca}if(i>>>0<=253){if((i|0)!=253){break Ca}g=u+24|0;Kb(g,G,99);if(Ib(g)){break Ca}}Ik(x[R>>2],f)}Na:{Oa:{switch(o-1|0){case 0:I=I>>>0>=64?64:I;x[t+1075672>>2]=I<<2;f=t+1075072|0;x[f>>2]=x[f>>2]|2097152;break Na;case 1:break Oa;default:break Na}}Sl(a,k,I,6)}if(z[a+480192>>1]){yL(a,C&65535)}h=e}e=u+24|0;Kb(e,G,77);if(Ia=Ib(e),Ja=0,La=x[((C<<5)+a|0)+480280>>2]&1024,La?Ia:Ja){break N}e=x[a+1074392>>2];f=u+24|0;Kb(f,G,75);g=e>>>0>=P>>>0;Pa:{Qa:{Ra:{if(!P|!Ib(f)){break Ra}f=x[a+1074392>>2];if(!f){break Qa}g=1;if((f|0)!=(P|0)){break Ra}g=!y[V|0]&(o|0)!=11}e=o;if(!g|e>>>0<3){break Qa}if((e|0)==11){e=u+24|0;My(e,a,O,P);f=y[mc(e)|0];tn(a,k,x[e>>2]);if(f){break Pa}o=11;break Qa}f=u+24|0;Kb(f,G,62);Sa:{Ta:{Ua:{Va:{Wa:{Xa:{if(!(!Ib(f)|I)){I=0;o=0;Ya:{switch(e-8|0){case 0:break Xa;case 1:break Ya;default:break Qa}}if(y[S|0]&16){break Qa}x[t+1075676>>2]=0;break Qa}f=u+24|0;Kb(f,G,41);Za:{if(Ib(f)){break Za}if(I){v[t+1075838|0]=I;break Za}I=y[t+1075838|0]}_a:{switch(e-3|0){case 0:case 1:$a:{ab:{if(I){break ab}f=u+24|0;Kb(f,G,41);if(!Ib(f)){break ab}I=y[t+1075838|0];if(I){break $a}I=0;break Qa}v[t+1075838|0]=I}wn(a,k,((e|0)==3?I<<4:I)&255);break Qa;case 2:if((P|0)!=x[a+1074392>>2]){e=u+24|0;Kb(e,G,41);o=5;if(Ib(e)){break Qa}}e=u+24|0;Kb(e,G,41);Dp(a,k,I,Ib(e));o=5;break Qa;case 3:if((P|0)!=x[a+1074392>>2]){e=u+24|0;Kb(e,G,41);o=6;if(Ib(e)){break Qa}}e=u+24|0;Kb(e,G,41);Cp(a,k,I,Ib(e));o=6;break Qa;case 12:break Sa;case 10:break Ta;case 9:break Ua;case 7:break Va;case 6:break Wa;case 5:break Xa;case 4:break _a;default:break Qa}}e=u+24|0;Kb(e,G,53);if(Ib(e)){v[t+1075827|0]=I&15;o=7;break Qa}Ek(k,I<<4);o=7;break Qa}Ek(k,I);o=8;break Qa}e=u+24|0;Kb(e,G,62);Gy(a,k,I,Ib(e)^1);o=9;break Qa}e=u+24|0;Kb(e,G,62);Gy(a,k,I<<4&240,Ib(e)^1);o=10;break Qa}o=12;e=u+24|0;Kb(e,G,12);RM(a,C&65535,I<<2&252,Ib(e));break Qa}e=u+24|0;Kb(e,G,12);QM(a,C&65535,I<<2&252,Ib(e));o=13;break Qa}o=15;if(!H){break Qa}e=x[t+1075088>>2];if(!e|I>>>0>9){break Qa}bb:{if(!I){l=x[t+1075648>>2];break bb}l=x[(e+(I<<2)|0)- -64>>2];x[t+1075648>>2]=l}Ep(a,k,l)}cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{yb:{zb:{Ab:{switch(M-1|0){case 12:if(!(y[a+480209|0]&16)){break Pa}e=D(C,896)+a|0;x[e+1075672>>2]=j>>>0>=64?256:j<<2;e=e+1075072|0;x[e>>2]=x[e>>2]|2097152;break Pa;case 1:if(!j&(x[a+480180>>2]&1)){break zb}RM(a,C&65535,j,0);break Pa;case 2:if(!j&(x[a+480180>>2]&1)){break zb}QM(a,C&65535,j,0);break Pa;case 10:if(!j&x[a+480180>>2]==1){break zb}wn(a,k,j);break Pa;case 3:tn(a,k,j);break Pa;case 5:if(!(!j&x[a+480180>>2]==1)){wn(a,k,j)}tn(a,k,0);break Pa;case 4:Ek(k,j);break Pa;case 6:if(!(!j&x[a+480180>>2]==1)){wn(a,k,j)}Ek(k,0);break Pa;case 15:if(!(y[a+480209|0]&16)){break Pa}break cb;case 16:e=u+24|0;Kb(e,G,5);if(Ib(e)){if(!(y[a+480209|0]&16)){break Pa}if(j){break cb}break Pa}j=Gp(a,z[a+1074436>>1],x[a+1074424>>2],C&65535,0);Bb:{if(!(x[a+480180>>2]&16777250)){break Bb}if(j){v[(D(C,896)+a|0)+1075839|0]=j;break Bb}j=y[(D(C,896)+a|0)+1075839|0]}x[u+24>>2]=D(j,1e4);xc(u+24|0,D(x[x[a+8>>2]+24>>2],1e4));e=hb-16|0;hb=e;g=x[u+24>>2];x[e+8>>2]=g;f=x[a+8>>2];Cb:{if(g>>>0>=(x[a+480180>>2]&16392?1e4:32e4)>>>0){g=x[a+480208>>2];Kb(e,a+1074312|0,92);if((Ib(e)|0)==((g&4096)>>>12|0)){break Cb}x[e>>2]=D(x[f+24>>2],1e4);Ia=a+1074420|0,Ja=x[Mb(e+8|0,e)>>2],x[Ia>>2]=Ja;break Cb}if(y[a+480209|0]&16){break Cb}h=a+1074420|0;g=(g>>>0)/1e4|0;i=D(g&15,1e4);x[h>>2]=x[h>>2]+((g&240)==16?i:0-i|0);g=x[f+20>>2];f=x[f+24>>2];Kb(e,a+1074312|0,8);yo(h,D(g,1e4),Ib(e)?255e4:D(f,1e4))}hb=e+16|0;break Pa;case 9:if(!H|(x[a+480180>>2]==4?h:0)){break Pa}v[u+24|0]=0;e=Gp(a,z[a+1074436>>1],x[a+1074424>>2],C&65535,u+24|0);f=a;if(!y[u+24|0]){g=(D(C,896)+a|0)+1075648|0;l=e<<8;Db:{if(l){x[g>>2]=l;break Db}l=x[g>>2]}e=(y[(D(C,896)+a|0)+1075840|0]<<16)+l|0}Ep(f,k,e);break Pa;case 40:if(!H){break Pa}g=yna(x[(D(C,896)+a|0)+1075060>>2],0,j,0);f=lb;e=f>>>8|0;Ep(a,k,jd((f&255)<<24|g>>>8,e));break Pa;case 0:if(x[a+1074392>>2]){break Pa}e=D(C,896)+a|0;Eb:{if(y[e+1075803|0]?x[e+1075684>>2]:0){break Eb}e=x[e+1075640>>2];if(e){if(Ki(e)){break Eb}}e=u+24|0;Kb(e,G,13);if(Ib(e)){break Eb}if(x[a+480180>>2]&16777248){break Pa}}if(!j){j=0;if(x[a+480180>>2]&5){break Pa}v[(D(C,896)+a|0)+1075811|0]=1;break Pa}e=D(C,896)+a|0;v[e+1075812|0]=j;v[e+1075811|0]=1;break Pa;case 14:if(x[a+480180>>2]&1048580){j=j&240?j:z[(D(C,896)+a|0)+1075784>>1]&240|j;if(!(j&15)){j=z[(D(C,896)+a|0)+1075784>>1]&15|j}j=j|256}e=u+24|0;Kb(e,G,23);if(Ib(e)){Fb:{if(!j){l=z[(D(C,896)+a|0)+1075784>>1];break Fb}l=j&255;w[(D(C,896)+a|0)+1075784>>1]=l}Fy(a,C&65535,l<<16>>16,(o|0)==15?I+1|0:0);break Pa}Gb:{if(j){w[(D(C,896)+a|0)+1075784>>1]=j&255;break Gb}j=w[(D(C,896)+a|0)+1075784>>1]}Fy(a,C&65535,j,(o|0)==15?I+1|0:0);break Pa;case 39:break fb;case 38:break gb;case 34:case 35:case 36:case 37:break hb;case 13:break ib;case 11:break jb;case 29:break kb;case 26:break lb;case 21:break mb;case 20:break nb;case 27:break ob;case 24:break pb;case 19:break qb;case 18:break rb;case 25:break sb;case 7:break tb;case 28:break ub;case 8:break vb;case 23:break wb;case 22:break xb;case 17:break Ab;default:break Pa}}if(!(y[a+480209|0]&16)){break Pa}e=u+24|0;Kb(e,G,22);Hb:{Ib:{if(Ib(e)){if(!j){j=0;break Ib}if(y[a+480208|0]&4){break Ib}e=j&240?j-16|0:j;j=e-((e&15)!=0)|0;v[(D(C,896)+a|0)+1075844|0]=j;break Ib}e=u+24|0;Kb(e,G,71);if(!Ib(e)){break Hb}}e=(D(C,896)+a|0)+1075843|0;v[e|0]=y[e|0]|128}e=D(C,896)+a|0;v[e+1075811|0]=18;if(j){break yb}}j=0;break Pa}v[e+1075844|0]=j;break Pa}if(!(y[a+480209|0]&16)){break Pa}j=j<<!(x[a+480180>>2]&59593760);if(j>>>0<=128){x[a+1074444>>2]=j<<1;break Pa}if(x[a+480180>>2]&16777250){break Pa}x[a+1074444>>2]=256;break Pa}e=u+24|0;Kb(e,G,9);if(Ib(e)){PM(a,j,(D(C,896)+a|0)+1075821|0);break Pa}PM(a,j,aa);break Pa}if(!(y[a+480209|0]&16)){break Pa}Sl(a,k,j,8);break Pa}Gy(a,k,j,1);break Pa}fN(k,j);break Pa}gN(a,k,j);break Pa}e=j&15;f=C&65535;h=D(f,896)+a|0;g=h+1074984|0;Jb:{Kb:{switch(j>>>4|0){case 0:if(!z[a+480188>>1]){break Jb}f=(j&1)<<14;e=0;while(1){g=(D(e,896)+a|0)+1075072|0;x[g>>2]=(f|x[g>>2]&-16385)^16384;e=e+1|0;if(e>>>0<z[a+480188>>1]){continue}break};break Jb;case 1:if(!(e|x[a+480180>>2]&1048580)){break Jb}HM(a,g,e);break Jb;case 2:if(!(e|x[a+480180>>2]&1048580)){break Jb}FM(a,g,e);break Jb;case 3:f=h+1075072|0;x[f>>2]=x[f>>2]&-1048577|((e|0)!=0)<<20;break Jb;case 4:v[h+1075826|0]=j&7;break Jb;case 5:if(!(y[a+480209|0]&16)){break Jb}if(x[a+480180>>2]&69206025){g=D(f,896)+a|0;h=g+1075752|0;x[h>>2]=e<<28>>24;e=g+1075684|0;if(!x[e>>2]){break Jb}if(!Af(g+1075794|0)){break Jb}g=e;e=D(f,896)+a|0;Ia=g,Ja=eg(a,y[e+1075803|0],x[h>>2],x[e+1075688>>2]),x[Ia>>2]=Ja;break Jb}h=x[a+480180>>2];g=Af((D(f,896)+a|0)+1075794|0);if((h|0)==16){if(!g){break Jb}g=D(f,896)+a|0;h=x[g+1075088>>2];if(!h){break Jb}v[h+37|0]=e;x[g+1075752>>2]=e;g=g+1075684|0;if(!x[g>>2]){break Jb}f=D(f,896)+a|0;Ia=g,Ja=eg(a,y[f+1075803|0],e,x[f+1075688>>2]),x[Ia>>2]=Ja;break Jb}if(!g){break Jb}e=D(f,896)+a|0;f=(j<<4^128)<<24>>24;x[e+1075752>>2]=f;g=e+1075684|0;if(!x[g>>2]){break Jb}Ia=g,Ja=eg(a,y[e+1075803|0],f,x[e+1075688>>2]),x[Ia>>2]=Ja;break Jb;case 7:v[h+1075829|0]=j&7;break Jb;case 8:if(!(y[a+480209|0]&16)){break Jb}Sl(a,g,e,4);break Jb;case 9:Fy(a,f,e,0);break Jb;case 10:if(!(e|x[a+480180>>2]&1048580)){break Jb}Dp(a,g,e,0);break Jb;case 11:if(!(e|x[a+480180>>2]&1048580)){break Jb}Cp(a,g,e,0);break Jb;case 12:Hy(a,f,e,0);break Jb;case 15:break Kb;default:break Jb}}if(x[a+480180>>2]==1){v[(D(f,896)+a|0)+1075850|0]=e;if(!(y[a+480209|0]&16)){break Jb}SM(a,g);break Jb}v[(D(f,896)+a|0)+1075848|0]=e}break Pa}OM(a,C&65535,j);break Pa}e=u+24|0;Kb(e,G,55);if(Ib(e)){if(x[a+1074392>>2]!=(j|0)){break Pa}e=x[(D(C,896)+a|0)+1075640>>2];if(v[e+60|0]&1?e:0){break db}if(!(!(y[V|0]|y[W|0])|j)){e=(D(C,896)+a|0)+1075072|0;x[e>>2]=x[e>>2]|4096;break db}e=D(C,896)+a|0;x[e+1075672>>2]=0;e=e+1075072|0;x[e>>2]=x[e>>2]|2097152;break db}if(y[a+480209|0]&16){break db}break Pa}e=(j&240)-16>>>4|0;if(e>>>0>9){break Pa}if(!(1<<e&880)){if(!e){break eb}if((e|0)!=1){break Pa}NM(a,k,j&15);break Pa}e=u+24|0;Kb(e,G,58);if(Ib(e)){break Pa}OM(a,C&65535,j);break Pa}if(!(y[a+480209|0]&16)|j>>>0>64){break Pa}e=D(C,896)+a|0;x[e+1075744>>2]=j;e=e+1075072|0;x[e>>2]=x[e>>2]|2097152;break Pa}e=j;Lb:{if(e){v[k+836|0]=e;break Lb}e=y[k+836|0]}f=e&15;g=e&255;Mb:{Nb:{if(!((f|0)!=15|g>>>0<16)){if(!(y[a+480209|0]&16)){break Mb}f=g>>>4|0;break Nb}h=x[a+480208>>2]&4096;i=g&240;if(!(!f|(i|0)!=240)){if(!h){break Mb}f=0-f|0;break Nb}if(h){break Mb}if(f){f=0-f|0;if(!(x[a+480180>>2]&25690144)|!i){break Nb}break Mb}if((e&255)>>>0<16){break Mb}f=g>>>4|0}Ia=k,Ja=Xb(f+x[k+760>>2]|0,0,64),x[Ia+760>>2]=Ja}break Pa}eN(k,j);break Pa}if(!(y[a+480209|0]&16)){break Pa}e=D(C,896)+a|0;x[e+1075712>>2]=j;f=u+24|0;Kb(f,G,60);if(Ia=0,Ja=Ib(f),La=y[e+1075708|0]&4,La?Ia:Ja){break Pa}e=D(C,896)+a|0;x[e+1075736>>2]=j;x[e+1075724>>2]=j;break Pa}x[a+1074432>>2]=0;J=Gp(a,z[a+1074436>>1],x[a+1074424>>2],C&65535,0);m=x[a+480180>>2]&5?(m|0)==-1?m:0:m;break Pa}e=hN(a,$,C&65535,j);if((e|0)==-1){break Pa}J=y[a+480208|0]&32?z[a+1074438>>1]:J;m=e;break Pa}if(y[a+480209|0]&16){e=j&240;if(e){v[k+869|0]=e>>>4}e=j&15;if(e){v[k+870|0]=e}v[k+868|0]=y[k+869|0]}g=(M|0)==35|(M|0)==37;h=(M-37&255)>>>0<2;Ob:{Pb:{if(x[a+480180>>2]==32768){f=y[k+869|0];e=16;if((f|0)==16){break Pb}e=f;if(y[a+480209|0]&16){break Pb}break Ob}if(y[a+480209|0]&16){break Ob}e=y[k+868|0]-1|0;v[k+868|0]=e;if(e&255){break Ob}e=y[k+869|0]}v[k+868|0]=e;e=y[k+870|0];e=g?e:0-e|0;Qb:{if(Dj(k)){x[k+876>>2]=x[k+876>>2]+D(e,x[x[x[k+656>>2]+44>>2]+36>>2]);break Qb}Ia=k,Ja=eg(a,$s(a,x[k+700>>2],0,x[k+704>>2])+e|0,0,x[k+704>>2]),x[Ia+700>>2]=Ja}if(!h){break Ob}x[k>>2]=0;x[k+4>>2]=0}break Pa}bN(u,k,j);break Pa}if(x[a+1074392>>2]|_>>>0>1|j>>>0>47){break Pa}e=(j&240)==16;l=e?0:C;f=e?z[a+480188>>1]-1|0:C;if((l&65535)>>>0>(f&65535)>>>0){break Pa}e=((_|0)==1)<<26;while(1){g=l&65535;h=((g<<5)+a|0)+480280|0;x[h>>2]=e|x[h>>2]&-67108865;g=(D(g,896)+a|0)+1075072|0;x[g>>2]=e|x[g>>2]&-67108865;l=l+1|0;if((l&65535)>>>0<=(f&65535)>>>0){continue}break}break Pa}MM(a,k,j&15);break Pa}vn(a,k);break Pa}iN(a,$,j)}e=u+24|0;Kb(e,G,78);if(!(!Ib(e)|!j)){dN(k,j&255)}e=y[V|0];if(!e){break N}v[t+1075810|0]=e}C=C+1|0;if(C>>>0<z[a+480188>>1]){continue}break}}Rb:{if(!(y[a+480209|0]&16)){break Rb}Sb:{if(!((m|0)==-1&(J&65535)==65535)){Tb:{if((n|0)==-1){break Tb}f=u+24|0;e=a+1074312|0;Kb(f,e,68);if(Ib(f)){break Tb}f=u+16|0;Kb(f,e,103);if(Ia=Ib(f),Ja=0,La=(J&65535)!=65535,La?Ia:Ja){break Tb}f=u+8|0;Kb(f,e,49);if(!Ib(f)|(J&65535)==65535){break Sb}}x[a+480208>>2]=x[a+480208>>2]|524288;e=(J&65535)!=65535?J:z[a+1074438>>1]+1|0;f=a+484360|0;if(qc(Vb(f))>>>0<=(e&65535)>>>0){e=z[Vb(f)+28>>1]}f=(m|0)!=-1?m:0;Ub:{if(z[a+1074438>>1]==(e&65535)){break Ub}g=u+24|0;h=a+1074312|0;Kb(g,h,26);if(Ib(g)){break Ub}g=u+16|0;Kb(g,h,68);if(Ib(g)|x[a+480180>>2]==1|!z[a+480188>>1]){break Ub}g=0;while(1){v[(D(g,896)+a|0)+1075845|0]=0;g=g+1|0;if(g>>>0<z[a+480188>>1]){continue}break}}x[a+1074428>>2]=f;if(y[a+480208|0]&32){break Rb}w[a+1074440>>1]=e;break Rb}if((n|0)==-1){break Rb}}x[a+1074428>>2]=n;w[a+1074440>>1]=z[a+1074438>>1];Vb:{if(!x[a+1074396>>2]){break Vb}if(x[a+480180>>2]==32){e=u+24|0;Kb(e,a+1074312|0,103);if(Ib(e)){break Vb}}if(x[a+480180>>2]==2){break Vb}x[a+1074428>>2]=x[a+1074428>>2]+1}if(A[Zb(a+484344|0,z[a+1074436>>1])+12>>2]<=n>>>0){x[a+1074428>>2]=0;w[a+1074440>>1]=z[a+1074440>>1]+1}i=z[a+1074438>>1];e=hb-16|0;hb=e;l=a+1304360|0;g=l+12|0;Ia=e,Ja=gO(g),x[Ia+8>>2]=Ja;Ia=e,Ja=Gj(g),x[Ia>>2]=Ja;Wb:{if(!wt(e+8|0,e)|(n|0)==-1){break Wb}while(1){f=hb-16|0;hb=f;h=e+8|0;x[f+8>>2]=x[h>>2];k=x[Jp(f+8|0)>>2];hb=f+16|0;f=x[k>>2];Wy(l,i,f,0);Jp(h);Ia=e,Ja=Gj(g),x[Ia>>2]=Ja;h=wt(h,e);if((f|0)==(n|0)){break Wb}if(h){continue}break}}hb=e+16|0}hb=u+32|0;e=1}hb=U+16|0;V=x[a+1074420>>2]!=0&e;Xb:{if(!V){break Xb}e=UL(a,a+1074376|0);x[a+1074380>>2]=e;x[a+1074404>>2]=e;f=Md(z[a+480188>>1],1,31);J=a+1074332|0;Yb:{if(y[J+37|0]){e=x[a+24628>>2];if((e|0)>=129){e=((D(e-128|0,f+4|0)|0)/16|0)+128|0}o=D(x[a+480228>>2],e)>>>6|0;break Yb}o=x[a+480228>>2]}o=y[J+37|0]?(o<<7>>>0)/y[(f>>>1|0)+25856|0]|0:o;w[a+480212>>1]=0;u=a+1304392|0;t=a+1074312|0;P=a+480210|0;U=a+480209|0;q=0;while(1){m=D(q,896)+a|0;H=m+1075072|0;Zb:{if(!(x[H>>2]&4096)|(x[m+1075008>>2]|(x[m+1075004>>2]|x[m+1075680>>2]))){break Zb}e=s+24|0;Kb(e,t,64);if(Ib(e)){break Zb}x[m+1075060>>2]=0;e=m+1075076|0;x[e>>2]=0;x[e+4>>2]=0}f=z[a+480188>>1];e=x[H>>2];_b:{if(x[m+1075060>>2]|f>>>0>q>>>0?e&1024:1){if(f>>>0>q>>>0){IL(a,q&65535)}w[m+1075846>>1]=0;break _b}l=0;R=m+1075704|0;x[R>>2]=0;G=m+1075664|0;x[G>>2]=0;n=m+1074992|0;g=n;x[g>>2]=0;x[g+4>>2]=0;x[m+1075084>>2]=0;x[s+20>>2]=1065353216;w[s+18>>1]=0;r=0;C=m+1075684|0;r=x[C>>2]?x[m+1075060>>2]!=0:r;k=m+1074984|0;O=m+1075640|0;M=x[O>>2];$b:{ac:{bc:{if(f>>>0<=q>>>0){break bc}if(y[((q<<5)+a|0)+480288|0]){break ac}if(!M){break bc}l=y[M+34|0]!=0}if((l|r)!=1){break $b}}x[s+8>>2]=x[m+1075672>>2];x[s+4>>2]=x[m+1075748>>2];f=s+24|0;Kb(f,t,28);e=s+8|0;f=Ib(f)?s+4|0:e;g=a+1074312|0;cc:{if($b(g,28)){x[f>>2]=x[f>>2]+w[k+788>>1];_d(f,0,64);break cc}h=$b(g,1);g=w[k+788>>1];if(h){x[f>>2]=g+x[f>>2];_d(f,0,256);break cc}x[k+688>>2]=g+x[k+688>>2];_d(k+688|0,0,256);x[f>>2]=x[k+688>>2];w[k+788>>1]=0}dc:{ec:{f=a+1074312|0;if(!$b(f,28)){if(!$b(f,1)){break ec}}x[k+684>>2]=x[k+692>>2]+w[k+790>>1];_d(k+684|0,0,256);break dc}x[k+692>>2]=x[k+692>>2]+w[k+790>>1];_d(k+692|0,0,256);w[k+790>>1]=0;x[k+684>>2]=x[k+692>>2]}fc:{if(!(y[k+90|0]&4)|(x[a+480208>>2]&2101248)==2101248){break fc}gc:{if(x[e>>2]<=0){if(!$b(a+1074312|0,21)){break gc}}h=5;if(!(x[a+480180>>2]&5)){h=$b(a+1074312|0,21)?5:6}g=ky(a,y[k+845|0],y[k+840|0]);hc:{if((y[k+845|0]&3)!=1){break hc}if(!$b(a+1074312|0,89)){break hc}g=y[k+839|0];i=y[k+840|0];f=i<<2&124;f=(!(y[k+90|0]&2)|y[a+480209|0]&16?g:y[k+843|0]+g|0)&32?f^127:f;g=i&32?0-f|0:f}if(x[a+480180>>2]!=131072){f=x[e>>2]+((D(y[k+847|0],g)|0)/(1<<h)|0)|0}else{f=x[e>>2];f=((D(y[k+847|0],D(f,64-g|0))|0)/-8192|0)+f|0}x[e>>2]=f}if(!(x[a+480180>>2]&16777248)|y[a+480208|0]&4?y[a+480209|0]&16:0){break fc}f=$b(a+1074312|0,21);g=y[k+846|0];h=y[k+840|0];v[k+840|0]=(f?g<<2:h)+(f?h:g)}g=q&65535;i=hb-16|0;hb=i;f=i+8|0;h=a+1074312|0;Kb(f,h,71);ic:{if(Ib(f)){f=(D(g,896)+a|0)+1075843|0;h=v[f|0];if((h|0)>=0){break ic}if(!(y[a+480209|0]&16|y[(D(g,896)+a|0)+1075811|0]!=18)){jc:{kc:{if((h&-33)!=-64){h=h&223;if((h|0)!=128){break kc}h=y[(D(g,896)+a|0)+1075844|0]>>>4|-64;break jc}h=y[(D(g,896)+a|0)+1075844|0]&15|-128;break jc}h=h-1|0}v[f|0]=h;f=(D(g,896)+a|0)+1075072|0;x[f>>2]=x[f>>2]|2097152}if((h&224)!=128){break ic}x[e>>2]=0;break ic}if(y[(D(g,896)+a|0)+1075811|0]!=18){break ic}f=i+8|0;Kb(f,h,22);lc:{if(Ib(f)){j=D(g,896)+a|0;f=j+1075843|0;l=y[f|0];h=l<<24>>24;if(!((h|0)>=0|!x[j+1075060>>2])){mc:{nc:{if((l|0)!=192){if((l|0)!=128){break nc}h=y[(D(g,896)+a|0)+1075844|0]>>>4|-64;break mc}h=y[(D(g,896)+a|0)+1075844|0]&15|-128;break mc}h=h-1|0}v[f|0]=h}if((h&192)!=128){break lc}x[e>>2]=0;break lc}f=y[(D(g,896)+a|0)+1075844|0];h=f>>>4|0;l=h+(f&15)|0;if(!(y[a+480208|0]&4?0:x[a+480180>>2]&16777248)){l=l+2|0;h=h+1|0}j=(D(g,896)+a|0)+1075843|0;f=y[j|0];if(!(x[a+480180>>2]&4)){f=(f&255)>>>0<l>>>0?f:0;if((f&255)>>>0>=h>>>0){x[e>>2]=0}v[j|0]=f+1;break lc}oc:{if(y[a+480209|0]&16){f=f&255;j=f-1|0;f=f>>>0>=j>>>0?j:0;break oc}v[j|0]=f+1}if(((f&255)>>>0)%(l>>>0)>>>0<h>>>0){break lc}x[e>>2]=0}f=(D(g,896)+a|0)+1075072|0;x[f>>2]=x[f>>2]|2097152}f=D(g,896)+a|0;pc:{if(y[f+1075811|0]!=18){break pc}l=f+1075640|0;f=x[l>>2];if(!f|!y[f+34|0]|y[f+15|0]&2){break pc}f=D(g,896)+a|0;if(x[f+1075072>>2]&134218752){break pc}h=f+1075805|0;if(!Zd(y[h|0])){break pc}l=x[l>>2];f=x[(D(y[l+34|0],160)+a|0)+906140>>2];if(!f){break pc}j=mb[x[x[f>>2]+96>>2]](f,y[h|0],g)|0;I=x[e>>2];if(!(!j|I)){mb[x[x[f>>2]+88>>2]](f,l,y[h|0]+255|0,0,g);break pc}if(j|!I){break pc}mb[x[x[f>>2]+88>>2]](f,l,y[h|0],z[(D(g,896)+a|0)+1075672>>1],g)}hb=i+16|0;_d(e,0,256);e=x[s+8>>2]<<6;x[s+8>>2]=e;qc:{rc:{if(M){e=s+24|0;Kb(e,t,31);if(Ib(e)){Us(a,k)}f=s+8|0;sc:{if(!jy(a,k,0)){break sc}h=x[k+656>>2];i=a+1074312|0;l=$b(i,31);e=x[k+728>>2];if(e?0:l){break sc}l=h+48|0;K=e-$b(i,31)|0;e=Up(l,K,256,64);I=y[h+65|0];tc:{if((I|0)==255){break tc}j=x[k+732>>2];if((j|0)==-1){break tc}S=y[Pb(l,I)+2|0];I=S<<2;e=(K|0)==z[Pb(l,y[h+65|0])>>1]?I:e;if($b(i,94)){e=j+(e-I<<1)|0;break tc}if(!S){e=0;break tc}e=(D(e,j)|0)/(I|0)|0}Ia=f,Ja=(D(x[f>>2],Xb(e,0,512))|0)/256|0,x[Ia>>2]=Ja}HL(k,f);uc:{if(!jy(a,k,1)){break uc}e=x[k+656>>2];f=a+1074312|0;i=$b(f,31);h=x[k+740>>2];if(h?0:i){break uc}f=Up(e+68|0,h-$b(f,31)|0,64,64)-32|0;e=x[k+684>>2];Ia=k,Ja=Xb(((D(f,(e|0)>127?256-e|0:e)|0)/32|0)+e|0,0,256),x[Ia+684>>2]=Ja}e=x[k+656>>2];f=y[e+26|0];vc:{if(!f){break vc}h=y[k+819|0];if(!h){break vc}Ia=k,Ja=Xb(x[k+684>>2]+((D(f<<24>>24,h+(y[e+27|0]^-1)|0)<<16>>16)/2<<16>>16)|0,0,256),x[Ia+684>>2]=Ja}e=x[s+8>>2];break rc}if(!(y[H+1|0]&16)){break rc}x[m+1075680>>2]=0;x[s+8>>2]=0;break qc}if(!e){break qc}if(y[H+3|0]&8){x[G>>2]=0;break qc}e=x[s+8>>2];if(y[J+36|0]){f=D(x[s+4>>2],x[m+1075744>>2]);e=e<<8;Ia=G,Ja=Cc(zna(yna(f,f>>31,e,e>>31),lb,1048576,0),lb),x[Ia>>2]=Ja;break qc}f=D(x[s+4>>2],x[m+1075744>>2]);e=D(e,x[a+1074444>>2]);Ia=G,Ja=Cc(zna(yna(f,f>>31,e,e>>31),lb,1048576,0),lb),x[Ia>>2]=Ja}x[R>>2]=x[s+8>>2];wc:{if(x[a+480180>>2]==2|x[C>>2]>=x[a+480260>>2]){break wc}if(zp(a)){break wc}x[C>>2]=x[a+480260>>2]}e=s+24|0;Kb(e,t,73);if(Ib(e)){Xb(x[C>>2],1,31999)}e=x[C>>2];x[s+12>>2]=e;xc:{if((x[H>>2]&1572864)!=1572864){break xc}if(y[P|0]&32){if(!it(m+1075794|0)|y[U|0]&16){break xc}e=x[s+12>>2]}f=m+1075696|0;yc:{if(x[f>>2]==(e|0)){e=x[m+1075700>>2];break yc}x[f>>2]=e;h=e;e=m+1075752|0;f=m+1075688|0;e=eg(a,$s(a,h,x[e>>2],x[f>>2]),x[e>>2],x[f>>2]);x[m+1075700>>2]=e}x[s+12>>2]=e}l=hb-16|0;hb=l;e=g;I=D(e,896)+a|0;f=x[I+1075640>>2];zc:{if(!f){break zc}g=y[f+34|0];if(!g|y[f+15|0]&2|(!x[(D(g,160)+a|0)+906140>>2]|x[(D(e,896)+a|0)+1075072>>2]&134218752)){break zc}h=D(e,896)+a|0;S=h+1075797|0;K=y[S|0];g=0;i=h+1075805|0;if(Zd(y[i|0])){g=y[gc(f+108|0,y[i|0]-1|0)|0]}j=h+1075794|0;Ac:{Bc:{if((K|0)==1){f=0;Cc:{Dc:{switch((A[a+1074392>>2]%3|0)-1|0){case 0:f=y[(D(e,896)+a|0)+1075812|0]>>>4|0;break Cc;case 1:break Dc;default:break Cc}}f=y[(D(e,896)+a|0)+1075812|0]&15}h=D(e,896)+a|0;v[h+1075807|0]=g;if(y[h+1075806|0]==(f+g|0)){break Ac}if(!(y[a+480209|0]&16)){break Bc}if(!Af(j)){break Bc}break Ac}f=0;if(y[j|0]|!y[(D(e,896)+a|0)+1075806|0]){break Ac}}h=D(e,896)+a|0;Ql(a,e,y[h+1075807|0]+f|0,z[h+1075672>>1])}i=(D(e,896)+a|0)+1075806|0;h=y[i|0];Ec:{if(!h){if(!(y[a+480209|0]&16)|(K|0)!=1){break Ec}if(Af(j)){break Ec}h=g;if(!Zd(g)){break Ec}}Ql(a,e,(h&255)+255|0,0)}v[i|0]=y[S|0]==1?y[(D(e,896)+a|0)+1075807|0]+f|0:0}Fc:{if(y[I+1075811|0]!=1){break Fc}if(Dj(I+1074984|0)){g=0;Gc:{Hc:{Ic:{switch(A[a+1074392>>2]%3|0){case 1:g=y[(D(e,896)+a|0)+1075812|0]>>>4|0;break Hc;case 0:break Hc;case 2:break Ic;default:break Gc}}g=y[(D(e,896)+a|0)+1075812|0]&15}w[s+18>>1]=g}e=(D(e,896)+a|0)+1075856|0;v[e|0]=y[e|0]|24;break Fc}if(!(!(y[a+480209|0]&16)|x[a+480180>>2]!=1048576)){f=D(e,896)+a|0;g=eg(a,y[f+1075803|0],x[f+1075752>>2],x[f+1075688>>2]);x[s+12>>2]=g;x[f+1075684>>2]=g}f=l+8|0;g=a+1074312|0;Kb(f,g,13);if(Ib(f)){g=y[(D(e,896)+a|0)+1075812|0];if(!g){break Fc}e=65536;Jc:{switch(((A[a+1074392>>2]%(x[a+1074400>>2]+x[a+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:g=g<<4;case 0:e=x[((g&240)<<2)+30400>>2];break;default:break Jc}}h=zp(a);f=x[s+12>>2];g=f>>31;if(h){e=yna(f,g,e,e>>31);f=lb;e=e+32768|0;f=e>>>0<32768?f+1|0:f;e=zna(e,f,65536,0);f=lb}else{h=(e|0)/2|0;j=h>>31;i=g<<16|f>>>16;g=h;h=f<<16;g=g+h|0;f=j+i|0;e=zna(g,g>>>0<h>>>0?f+1|0:f,e,e>>31);f=lb}Ia=s,Ja=Cc(e,f),x[Ia+12>>2]=Ja;break Fc}f=l+8|0;Kb(f,g,51);if(Ib(f)){if(y[a+480209|0]&16){break Fc}Kc:{Lc:{f=x[a+1074416>>2];g=f-(A[a+1074392>>2]%(f>>>0)|0)|0;if((g|0)>16){break Lc}if((g|0)==16){break Fc}f=0;Mc:{switch((g|0)%3|0){case 0:break Fc;case 2:break Lc;case 1:break Mc;default:break Kc}}f=y[(D(e,896)+a|0)+1075812|0]>>>4|0;break Kc}f=y[(D(e,896)+a|0)+1075812|0]&15}g=f;e=D(e,896)+a|0;f=e+1075752|0;e=e+1075688|0;g=g+$s(a,x[s+12>>2],x[f>>2],x[e>>2])|0;f=eg(a,g,x[f>>2],x[e>>2]);x[s+12>>2]=f;if(g>>>0<109){break Fc}x[l+8>>2]=f;Ia=l,Ja=eg(a,109,0,x[e>>2]),x[Ia+4>>2]=Ja;Ia=s,Ja=x[_c(l+8|0,l+4|0)>>2],x[Ia+12>>2]=Ja;break Fc}h=x[a+1074392>>2];if(x[a+480180>>2]!=1){f=y[(D(e,896)+a|0)+1075803|0]}else{f=D(e,896)+a|0;f=$s(a,x[s+12>>2],x[f+1075752>>2],x[f+1075688>>2])}Nc:{Oc:{switch((((x[a+480180>>2]&67633152?h+2|0:h)>>>0)%3|0)-1|0){case 0:f=(y[(D(e,896)+a|0)+1075812|0]>>>4|0)+f|0;break Nc;case 1:break Oc;default:break Nc}}f=(y[(D(e,896)+a|0)+1075812|0]&15)+f|0}if(!(x[a+480180>>2]&67633408|y[(D(e,896)+a|0)+1075803|0]!=(f&255))){h=l+8|0;Kb(h,g,82);if(!Ib(h)){break Fc}}if(y[a+480210|0]&32){h=f&255;if((h|0)==85){x[s+12>>2]=2147483647;break Fc}f=h>>>0>85?f-37|0:f}h=D(e,896)+a|0;Ia=s,Ja=eg(a,f&255,x[h+1075752>>2],x[h+1075688>>2]),x[Ia+12>>2]=Ja;if(x[a+480180>>2]&71827712){x[h+1075684>>2]=x[s+12>>2];break Fc}h=l+8|0;Kb(h,g,82);if(!Ib(h)){break Fc}v[(D(e,896)+a|0)+1075806|0]=f}hb=l+16|0;if(!(!(y[P|0]&33)|x[s+12>>2]==2147483647)){Pc:{if(x[a+480180>>2]==2){e=452;f=3424;break Pc}f=D(x[m+1075752>>2]>>>4&15,24)+26112|0;e=z[f+22>>1]>>>1|0;e=e>>>0<=452?452:e;f=z[f>>1]<<1}_d(s+12|0,e,f);_d(C,e,f)}GL(a,k);e=x[H>>2]}Qc:{if(!(e&256)|y[U|0]&64){break Qc}e=s+24|0;Kb(e,t,37);if(!Ib(e)){break Qc}x[m+1075668>>2]=128}h=q&65535;IL(a,h);Rc:{if(!r){break Rc}e=FL(a,k,s+12|0);if((e|0)<0|!(y[H+1|0]&2)){break Rc}if(!zd(u)){break Rc}Pp(x[u>>2],h,e>>>2&255,1)}Sc:{if(y[m+1075796|0]!=8){break Sc}Tc:{Uc:{e=y[m+1075797|0];switch(e-5|0){case 1:break Sc;case 0:case 2:break Tc;default:break Uc}}if((e|0)!=26){break Sc}}if(x[a+480180>>2]==4){if(y[U|0]&16){break Sc}e=m+1075823|0;v[e|0]=y[e|0]+y[m+1075827|0];break Sc}if(!(x[a+480180>>2]&16777248)){break Sc}Ek(k,y[m+1075798|0]);EL(a,h,s+12|0,s+20|0)}EL(a,h,s+12|0,s+20|0);if(r){x[s+8>>2]=0;g=s+12|0;I=hb-16|0;hb=I;j=x[k+104>>2];Vc:{if(!j|!y[j+40|0]){break Vc}i=Dj(k);r=zp(a);e=r?31424:30400;l=r?30400:31424;if(!(i|!$b(a+1074312|0,21)|x[a+480180>>2]==1048576)){if(!y[j+41|0]){break Vc}f=y[k+838|0];x[I+12>>2]=x[k+780>>2]+y[j+39|0];Ch(I+12|0,y[j+40|0]<<8);i=x[I+12>>2];x[k+780>>2]=i;i=(i|0)/256|0;x[I+12>>2]=i;v[k+838|0]=y[k+838|0]+y[j+41|0];Wc:{Xc:{switch(y[j+38|0]-1|0){case 3:f=AL(un(a))+-64|0;i=x[I+12>>2];break Wc;case 2:f=64-(f+1>>>1|0)|0;break Wc;case 1:f=(f+1>>>1|0)+-64|0;break Wc;case 0:f=(f^-1)>>>1&64;break Wc;default:break Xc}}f=v[f+26704|0]}Ch(g,8388607);j=x[g>>2]<<8;x[g>>2]=j;S=D(f,i);i=(S|0)/64|0;f=i>>31;i=(f^i)-f|0;K=i>>>2|0;f=j;j=f>>31;Yc:{if((S|0)<=-64){e=x[(K<<2)+e>>2];f=Cc(zna(yna(e,e>>31,f,j),lb,65536,0),lb);e=x[g>>2];f=f-e|0;i=i&3;if(!i){break Yc}i=x[(i<<2)+(r?30336:30272)>>2];f=Cc(zna(yna(i,i>>31,e,e>>31),lb,65536,0),lb)+f|0;e=x[g>>2];f=f-e|0;break Yc}e=x[l+(K<<2)>>2];f=Cc(zna(yna(e,e>>31,f,j),lb,65536,0),lb);e=x[g>>2];f=f-e|0;i=i&3;if(!i){break Yc}i=x[(i<<2)+(r?30272:30336)>>2];f=Cc(zna(yna(i,i>>31,e,e>>31),lb,65536,0),lb)+f|0;e=x[g>>2];f=f-e|0}x[g>>2]=(e+f|0)/256;x[s+8>>2]=f&255;break Vc}Zc:{if(!(y[j+39|0]|x[a+480180>>2]&16777248)){x[k+780>>2]=y[j+40|0]<<8;break Zc}_c:{if(x[a+480180>>2]&16777248){x[k+780>>2]=x[k+780>>2]+(y[j+39|0]<<1);r=y[j+40|0];break _c}r=y[j+40|0];if(y[k+89|0]&8){break _c}x[k+780>>2]=x[k+780>>2]+(((r<<8&65280)>>>0)/y[j+39|0]|0)}Ch(k+780|0,r<<8)}f=y[k+838|0]+y[j+41|0]|0;v[k+838|0]=f;f=f<<24>>24;$c:{ad:{switch(y[j+38|0]-1|0){case 3:v[k+838|0]=f+1;r=v[(f&63)+26640|0];break $c;case 2:r=(64-(f>>>1|0)&127)+-64|0;break $c;case 1:r=((f>>>1|0)- -64&127)+-64|0;break $c;case 0:r=(f|0)>=0?-64:64;break $c;default:break ad}}f=y[k+838|0];r=0-v[f+26704|0]|0;if(x[a+480180>>2]!=1048576){break $c}r=(64-v[(f+-64&255)+26704|0]|0)/2<<16>>16}f=r;K=D(f,x[k+780>>2]);r=(K|0)/256|0;if(i){B[s+20>>2]=E(E(E(f|0)*E(1220703143189894e-20))*E(y[j+40|0]))+B[s+20>>2];v[k+872|0]=y[k+872|0]|16;break Vc}if(x[a+480180>>2]!=4){bd:{if((K|0)<=-256){r=0-r|0;f=r>>>8|0;i=(f<<2)+e|0;break bd}e=l;f=r>>>8|0;i=e+(f<<2)|0}l=x[g>>2];f=x[((f<<2)+e|0)+4>>2];e=x[i>>2];e=((D(f-e|0,r>>>2&63)|0)/64|0)+e|0;e=Cc(zna(yna(l,l>>31,e,e>>31),lb,256,0),lb);x[g>>2]=e;x[s+8>>2]=e&255;x[g>>2]=x[g>>2]/256;break Vc}x[g>>2]=x[g>>2]+((K|0)/16384|0)}hb=I+16|0;if(x[s+12>>2]<=x[a+480260>>2]){e=s+24|0;Kb(e,t,81);if(Ib(e)){x[m+1075060>>2]=0}x[s+12>>2]=x[a+480260>>2]}f=Dj(k);cd:{if(!f){break cd}e=m+1075856|0;g=y[e|0];if(!(x[a+1074392>>2]|!(g&8)?g&16:1)){break cd}zO(k,B[s+20>>2],w[s+18>>1],a);g=e;e=y[e|0];v[g|0]=(e&16?-17:-9)&e}dd:{if((x[H>>2]&134219264)!=512){break dd}if(!zd(u)){break dd}e=s+24|0;Kb(e,t,99);if(!(!(Ib(e)|!(y[H+1|0]&16))&x[a+480180>>2]!=2)){if(!(y[H+1|0]&8?x[a+480180>>2]==2:0)){if(f){f=x[C>>2]}else{f=BM(a,x[s+12>>2],x[m+1075688>>2],x[s+8>>2])}f=yna(f,0,261625,0);e=lb;f=f+66904|0;e=f>>>0<66904?e+1|0:e;e=jd(Bna(f,e,133808,0),lb);e=yna(x[a+480240>>2],0,e,0);i=lb;e=e+32768|0;i=e>>>0<32768?i+1|0:i;f=jd((i&65535)<<16|e>>>16,i>>>16|0);g=x[H>>2];e=1;ed:{if(g&2048){break ed}e=0;if(!(g&4096)){break ed}e=!x[m+1075680>>2]}g=e;l=x[u>>2];e=s+24|0;Kb(e,t,95);C=Ib(e);j=hb-16|0;hb=j;r=Jk(l,h);fd:{if((r|0)==255){break fd}if(Aj(l)){break fd}gd:{if(f>>>0>6208431){i=7;e=1023;break gd}i=7;hd:{if(f>>>0>3104215){break hd}i=6;if(f>>>0>1552107){break hd}i=5;if(f>>>0>776053){break hd}i=4;if(f>>>0>388026){break hd}i=3;if(f>>>0>194013){break hd}i=2;if(f>>>0>97006){break hd}i=f>>>0>48503}e=yna(1<<20-i,0,f,0);f=lb;e=e+24858e3|0;f=e>>>0<24858e3?f+1|0:f;e=jd(Bna(e,f,49716e3,0),lb)}if(C){w[j+14>>1]=(h&3)+e;w[j+12>>1]=1023;e=z[Cf(j+14|0,j+12|0)>>1]}f=tt(r);C=l+4|0;Ia=gc(C,r),Ja=(i<<10|e)>>>8|(g?0:32),v[Ia|0]=Ja;ph(x[l>>2],f|160,e&255);ph(x[l>>2],f|176,y[gc(C,r)|0]);v[l+530|0]=1}hb=j+16|0}f=x[u>>2];g=yna(D(x[m+1075748>>2],D(x[m+1075744>>2],x[R>>2])),0,63,0);e=lb;g=g+33554432|0;e=g>>>0<33554432?e+1|0:e;Pp(f,h,jd((e&67108863)<<6|g>>>26,e>>>26|0)&255,0);e=m+1075668|0;l=e;g=x[e>>2];f=0;e=x[u>>2];i=Jk(e,h);id:{if((i|0)==255){break id}if(Aj(e)){break id}f=y[gc(Oi(e+314|0,i),10)|0];j=x[e>>2];e=f&-49;e=(g|0)<171?e|16:e;e=(g|0)>84?e|32:e;ph(j,tt(i)|192,e&255);f=(e>>>5&1)+(e<<27>>31)|0}x[l>>2]=(f<<7)+128}jd:{e=x[O>>2];if(!e|(y[e+60|0]&7)!=1){break jd}e=e+48|0;if(od(e)){break jd}if(A[DL(k,0)+4>>2]<z[xj(e)>>1]){break jd}if(y[xj(e)+2|0]){break jd}Ji(x[u>>2],h,1);e=s+24|0;Kb(e,t,109);e=Ib(e);f=x[H>>2];x[H>>2]=(e?f:f&-4609)|4096;x[m+1075680>>2]=0;break dd}e=s+24|0;Kb(e,t,99);if(!Ib(e)|!(y[H+1|0]&16)|x[m+1075680>>2]){break dd}Ji(x[u>>2],h,1);x[H>>2]=x[H>>2]&-513}e=yna(ly(a,k,x[s+12>>2],x[s+8>>2]),lb,x[a+480240>>2],0);i=lb;f=zna(e,i,65536,0);g=lb;e=e+65535|0;e=!(e>>>0<65535?i+1|0:i)&e>>>0<131071;x[n>>2]=e?1:f;x[n+4>>2]=e?0:g}kd:{if(!M){break kd}e=s+24|0;Kb(e,t,31);if(Ib(e)){break kd}Us(a,k)}f=x[H>>2];e=f&-65537;j=m+1075004|0;C=m+1075008|0;x[H>>2]=x[j>>2]|(x[C>>2]|x[G>>2])?(e|f<<7&65536)^65536:e;f=m+1075656|0;e=f;x[e>>2]=0;x[e+4>>2]=0;h=m+1075846|0;g=y[h|0];e=g-4|0;v[h|0]=e>>>0<=g>>>0?e:0;i=m+1075847|0;g=y[i|0];e=g-4|0;v[i|0]=e>>>0<=g>>>0?e:0;ld:{md:{nd:{od:{pd:{qd:{e=m+1075088|0;g=x[e>>2];rd:{if(!g){break rd}if(!Be(g)|!x[m+1075060>>2]){break rd}if(Sh(k)){break qd}}l=m+1075e3|0;x[l>>2]=0;break pd}l=m+1075e3|0;e=x[x[e>>2]+20>>2];x[l>>2]=e;if(e){break od}}if(!wj(k)|y[H+1|0]&24){break nd}}I=x[G>>2];r=x[m+1075668>>2];e=(D(I,256-r|0)|0)/16384|0;g=e>>>0>=127?127:e;e=v[h|0];if((e|0)<0){v[h|0]=g;K=g}else{K=e}e=g>>>1|0;if((K&255)>>>0<e>>>0){v[h|0]=e}e=(D(r,I)|0)/16384|0;e=e>>>0>=127?127:e;r=e>>>1|0;h=r;g=v[i|0];if((g|0)<0){v[i|0]=e}else{e=g}if((e&255)>>>0<h>>>0){break md}break ld}if(y[h|0]>=129){v[h|0]=0}r=0;if(y[i|0]<129){break ld}}v[i|0]=r}sd:{td:{if(x[l>>2]){e=m+1075660|0;ud:{if(A[a+24624>>2]>=2){x[s+24>>2]=x[m+1075668>>2];_d(s+24|0,0,256);g=D(x[G>>2],o)>>>(y[J+37|0]?7:8)|0;vd:{wd:{xd:{switch(x[J+32>>2]){case 0:if(!(y[a+24616|0]&16)){break wd}case 1:h=x[s+24>>2];if((h|0)<=127){x[f>>2]=g>>>1;g=(D(g,h)|0)/256|0;break vd}x[f>>2]=(D(g,256-h|0)|0)/256;g=g>>>1|0;break vd;case 3:break xd;default:break wd}}Ch(s+24|0,255);h=x[s+24>>2];if((h|0)<=0){i=65536}else{i=z[(0-h<<1)+32960>>1]}x[f>>2]=D(i,g)>>>16;g=D(g,z[(h<<1)+32448>>1])>>>16|0;break vd}h=x[s+24>>2];x[f>>2]=(D(g,256-h|0)|0)/256;g=(D(g,h)|0)/256|0}x[e>>2]=g;break ud}g=D(x[G>>2],o)>>>8|0;x[f>>2]=g;x[e>>2]=g}h=m+1075800|0;yd:{zd:{g=x[O>>2];if(!g){break zd}if(!mo(y[g+14|0])){break zd}g=y[x[O>>2]+14|0];break yd}if(mo(y[a+480268|0])){g=y[a+480268|0];break yd}g=y[a+24648|0];g=y[P|0]&128?x[a+24668>>2]?-1:g:g}v[h|0]=g;if(!(y[H+2|0]&2|(x[n>>2]!=0|x[n+4>>2]!=1)|(x[m+1075764>>2]|(g&255)==255))){v[h|0]=0}g=f;h=x[f>>2];f=1<<x[J+28>>2];x[g>>2]=(h|0)/(f|0);f=x[e>>2]/(f|0)|0;x[e>>2]=f;g=x[H>>2];if(!(!(g&256)|x[a+24624>>2]!=2)){x[e>>2]=0-f}if(g&128){e=x[n>>2];f=0-e|0;e=0-(x[n+4>>2]+((e|0)!=0)|0)|0;x[n>>2]=f;x[n+4>>2]=e}j=0;n=hb-16|0;hb=n;x[k+28>>2]=0;x[k+32>>2]=0;Ch(k+672|0,524287);Ch(k+676|0,524287);e=x[k+676>>2];g=x[k+672>>2];Ad:{Bd:{f=x[k+88>>2];if(!(f&65536)){break Bd}h=x[k+20>>2];i=x[k+24>>2];if((h|0)==(g|0)&(i|0)==(e|0)){break Bd}f=a+24604|0;g=(g|0)<=(h|0)&(e|0)<=(i|0);Cd:{if(!g){e=EO(f);break Cd}e=DO(f)}if(!(!$b(a+1074312|0,4)|!(x[a+480180>>2]&4))){e=x[a+24620>>2];e=yna(e,e>>31,5,0);i=lb;e=e+500|0;i=e>>>0<500?i+1|0:i;e=Cc(zna(e,i,1e3,0),lb)}f=e;h=x[k+656>>2];Dd:{if(g|!h){break Dd}g=z[h+12>>1];j=(g|0)!=0;if(!g){break Dd}f=(D(g,x[a+24620>>2])>>>0)/1e5|0}l=f?f:1;h=x[k+676>>2];g=x[k+24>>2];i=h-g<<12;f=x[k+672>>2];r=x[k+20>>2];G=f-r<<12;if(!(y[k+90|0]&32|(!(f|h)|(!(g|r)|j)))){x[n+12>>2]=x[a+1074380>>2];_d(n+12|0,e,2048);h=x[k+676>>2];l=x[n+12>>2];f=x[k+672>>2]}i=(i|0)/(l|0)|0;x[k+32>>2]=i;j=(G|0)/(l|0)|0;x[k+28>>2]=j;e=((D(i,l)|0)/-4096|0)+h|0;x[k+24>>2]=e;g=((D(j,l)|0)/-4096|0)+f|0;x[k+20>>2]=g;if(j|i){x[k+100>>2]=l;f=x[k+88>>2];break Ad}x[k+24>>2]=h;x[k+20>>2]=f;e=h;g=f;f=x[k+88>>2]&-65537;break Ad}x[k+24>>2]=e;x[k+20>>2]=g;f=f&-65537}x[k+88>>2]=f&-2097153;x[k+40>>2]=e<<12;x[k+36>>2]=g<<12;hb=n+16|0;if(!(y[H+1|0]&2)){break td}break sd}x[j>>2]=0;x[C>>2]=0;x[m+1075060>>2]=0;if(x[m+1075080>>2]){break td}if(!x[m+1075076>>2]){break sd}}e=z[a+480212>>1];w[a+480212>>1]=e+1;w[((e<<1)+a|0)+1074466>>1]=q}x[m+1075652>>2]=x[H>>2]}q=q+1|0;if((q|0)!=256){continue}break}if(A[a+24608>>2]>z[a+480212>>1]){break Xb}e=a+1074466|0;g=e+(x[a+24608>>2]<<1)|0;i=(z[a+480212>>1]<<1)+e|0;o=hb-16|0;hb=o;x[o+8>>2]=a;if((e|0)!=(g|0)){n=o+8|0;h=hb-16|0;hb=h;x[h+12>>2]=e;if((e|0)!=(g|0)){f=g-e|0;if((f|0)>=3){k=f>>1;f=k-2>>>1|0;while(1){l=f;wL(e,n,k,(f<<1)+e|0);f=f-1|0;if(l){continue}break}}x[h+8>>2]=g;if((g|0)!=(i|0)){f=g-e>>1;e=g;while(1){if(Bk(n,z[e>>1],z[x[h+12>>2]>>1])){e=x[h+8>>2];l=z[e>>1];j=e;e=x[h+12>>2];w[j>>1]=z[e>>1];w[e>>1]=l;e=x[h+12>>2];wL(e,n,f,e);e=x[h+8>>2]}e=e+2|0;x[h+8>>2]=e;if((e|0)!=(i|0)){continue}break}e=x[h+12>>2]}f=g-e|0;if((f|0)>=3){r=f>>>1|0;while(1){f=0;l=hb-16|0;hb=l;x[l+12>>2]=e;q=z[x[l+12>>2]>>1];k=x[l+12>>2];j=hb-16|0;hb=j;H=r-2>>>1|0;while(1){f=f<<1;i=f+2|0;m=i+k|0;x[j+12>>2]=m;f=f|1;Ed:{if((i|0)>=(r|0)){break Ed}if(!Bk(n,z[m>>1],z[m+2>>1])){break Ed}x[j+12>>2]=m+2;f=i}w[k>>1]=z[x[j+12>>2]>>1];k=x[j+12>>2];if((f|0)<=(H|0)){continue}break}hb=j+16|0;f=g-2|0;x[l+8>>2]=f;Fd:{if((f|0)==(k|0)){w[k>>1]=q;break Fd}w[k>>1]=z[x[l+8>>2]>>1];w[x[l+8>>2]>>1]=q;f=x[l+12>>2];j=f;i=hb-16|0;hb=i;k=k+2|0;f=k-f>>1;Gd:{if((f|0)<2){break Gd}f=f-2|0;m=j+(f&-2)|0;x[i+8>>2]=m;m=z[m>>1];k=k-2|0;x[i+12>>2]=k;if(!Bk(n,m,z[k>>1])){break Gd}f=f>>>1|0;k=z[x[i+12>>2]>>1];while(1){Hd:{w[x[i+12>>2]>>1]=z[x[i+8>>2]>>1];m=x[i+8>>2];x[i+12>>2]=m;if(!f){break Hd}q=f-1|0;f=q>>>1|0;q=j+(q&-2)|0;x[i+8>>2]=q;if(Bk(n,z[q>>1],k)){continue}}break}w[m>>1]=k}hb=i+16|0}hb=l+16|0;g=g-2|0;f=r>>>0>2;r=r-1|0;if(f){continue}break}}}hb=h+16|0}hb=o+16|0}hb=s+32|0;if(V){e=x[a+480208>>2];break h}f=x[a+480208>>2]|512;if(y[a+1304512|0]){break i}h=0;e=x[a+24620>>2];g=Cc(zna(yna(e,e>>31,100,0),lb,1e3,0),lb);Id:{if(!g){break Id}f=g>>>0>=1048576?1048576:g;x[a+1074380>>2]=f;l=z[a+480212>>1];if(!l){break Id}i=a+1074376|0;while(1){e=i+D(z[(i+(h<<1)|0)+90>>1],896)|0;k=e+1280|0;x[k>>2]=0;x[k+4>>2]=0;x[e+708>>2]=f;k=x[e+632>>2]<<12;x[e+648>>2]=k;n=x[e+628>>2]<<12;x[e+644>>2]=n;x[e+696>>2]=x[e+696>>2]|65536;x[e+636>>2]=(0-n|0)/(f|0);x[e+640>>2]=(0-k|0)/(f|0);h=h+1|0;if((l|0)!=(h|0)){continue}break}}e=x[a+480208>>2];f=e|256;if(g){break i}f=e|512}e=f;x[a+480208>>2]=e}if(e&512){Ia=a+1074392|0,Ja=Ol(a),x[Ia>>2]=Ja;break g}x[Y+16>>2]=512;e=x[a+1074380>>2];x[Y+12>>2]=3;x[Y+24>>2]=b;x[Y+20>>2]=e;x[Y+8>>2]=Y+16;e=x[Y+12>>2];x[Y>>2]=x[Y+8>>2];x[Y+4>>2]=e;k=gT(Y);if(x[a+24632>>2]){g=0;e=hb-16|0;hb=e;f=k<<2;while(1){x[e>>2]=0;h=((g<<11)+a|0)+16396|0;jK(h,f+h|0,e);g=g+1|0;if((g|0)!=4){continue}break}g=0;while(1){x[e+(g<<2)>>2]=((g<<11)+a|0)+16396;g=g+1|0;if((g|0)!=4){continue}break}mb[x[x[d>>2]+8>>2]](d,e,x[a+24632>>2],k);hb=e+16|0}da=0;ea=0;g=hb-112|0;hb=g;if(k){t=a+12|0;u=a+24592|0;G=a+24588|0;Jn(t,k,u,G);if(A[a+24624>>2]>=3){Jn(a+8204|0,k,a+24600|0,a+24596|0)}w[g+30>>1]=0;e=g+8|0;ha=a+1074312|0;Kb(e,ha,33);e=Ib(e);h=z[a+480212>>1];if(h){va=e?2:1;wa=a+24648|0;xa=a+24596|0;ya=a+24600|0;za=a+8204|0;C=a+397460|0;I=a+397456|0;O=a+393352|0;ma=a+1074376|0;while(1){j=ma+(da<<1)|0;e=D(z[j+90>>1],896);i=e+ma|0;U=i;Jd:{Kd:{if(x[i+624>>2]){break Kd}f=a+e|0;if(x[f+1075080>>2]){break Kd}if(!x[f+1075076>>2]){break Jd}}l=a+e|0;e=y[l+1075800|0]+1|0;if((e&255)>>>0<=5){f=x[(e<<24>>24<<2)+24328>>2]}else{f=0}s=l+1075072|0;q=x[s>>2];o=f|q&1;m=q>>>5&2;r=q>>>12|0;Ld:{if(!(!(q&16777216)&y[a+24612|0]>>>5)){f=G;h=u;e=t;if(!(q&8388608)){break Ld}}if(!x[O+4116>>2]){Jn(O+8|0,k,O+4104|0,O+4108|0)}x[O+4116>>2]=1;q=x[s>>2];f=C;h=I;e=O+8|0}n=i+608|0;i=f;f=q>>>8&A[a+24624>>2]>2;W=f?xa:i;_=f?ya:h;h=f?za:e;ia=Pl(a,z[j+90>>1],2,1);na=(ia-1&255)>>>0>249;Md:{if(na){break Md}f=x[(D(ia,160)+a|0)+906140>>2];if(!f){break Md}e=x[f+24>>2];if(!e){break Md}W=f+36|0;_=f+40|0;if(!(v[f+28|0]&1)){Jn(e,k,_,W);x[f+28>>2]=x[f+28>>2]|1}h=e}$=0;H=g+8|0;e=H;x[e>>2]=0;x[e+4>>2]=0;x[e+8>>2]=0;x[e+12>>2]=0;if(x[n+16>>2]){FC(H,n);e=x[n+12>>2];f=e>>31;j=f^x[n+8>>2];e=(e^f)-((f>>>0>j>>>0)+f|0)|0;x[H+12>>2]=e>>>0>8191?2:16384/(e+1>>>0)|0}Aa=r&8|(m|o);Ba=ea&65535;oa=l+1075809|0;Ca=l+1075792|0;Da=l+1075680|0;Ea=l+1075016|0;Fa=l+1075012|0;Ga=l+1075660|0;Ha=l+1075656|0;R=l+1075080|0;K=l+1075076|0;pa=l+1075008|0;qa=l+1075004|0;aa=l+1075088|0;S=l+1075068|0;P=l+1075060|0;M=l+1074992|0;ca=l+1075064|0;V=l+1075084|0;e=k;while(1){Nd:{f=x[V>>2];fa=f?e>>>0>f>>>0?f:e:e;x[g+68>>2]=fa;ga=x[ca>>2];J=x[s>>2];f=x[M+4>>2];m=f;j=x[M>>2];x[g+56>>2]=j;x[g+60>>2]=f;Od:{Pd:{if(!fa|!(f|j)){break Pd}r=x[P>>2];if(!r){break Pd}f=x[H>>2];if(!f){break Pd}x[U+624>>2]=f;f=x[n>>2];Qd:{Rd:{q=ga&J<<30>>31;i=x[n+4>>2];Sd:{if((q|0)>(i|0)){if((m|0)<0){x[g+104>>2]=0;x[g+108>>2]=q<<1;f=qg(g+104|0,n);x[n>>2]=f;i=lb;x[n+4>>2]=i;r=x[P>>2];if(!(i>>>0<r+q>>>1>>>0&(i|0)>=(q|0))){f=0;x[n>>2]=f;i=q;x[n+4>>2]=i}l=0-j|0;x[g+56>>2]=l;o=0-(((j|0)!=0)+m|0)|0;x[g+60>>2]=o;x[M>>2]=l;x[M+4>>2]=o;J=x[s>>2];Td:{if(J&4){j=J&-129;break Td}x[n>>2]=f;i=r-1|0;x[n+4>>2]=i;x[M>>2]=j;x[M+4>>2]=m;j=J|128}x[s>>2]=j;if(i>>>0<r>>>0?j&2:0){break Qd}x[n>>2]=0;x[n+4>>2]=r;break Pd}if((i|0)>0|(i|0)>=0){break Sd}x[n>>2]=f;i=0;x[n+4>>2]=i;break Sd}if(i>>>0>=r>>>0){break Rd}}l=j;o=m;break Qd}if(!(J&2)){break Pd}if(J&4){Ud:{if(!j&(m|0)<=0|(m|0)<0){l=j;o=m;break Ud}l=0-j|0;j=0-(((j|0)!=0)+m|0)|0;o=j;x[g+56>>2]=l;x[g+60>>2]=j;x[M>>2]=l;x[M+4>>2]=j}x[s>>2]=J|128;m=0-f|0;j=(r<<1)-((1-((f|0)!=0)|0)+i|0)|0;i=j;f=m;x[n>>2]=f;x[n+4>>2]=j;if(j>>>0<r>>>0&j>>>0>ga>>>0){break Qd}x[g+104>>2]=va;i=r-x[Mb(P,g+104|0)>>2]|0;f=x[n>>2];x[n>>2]=f;x[n+4>>2]=i;break Qd}Vd:{if((m|0)>0|(m|0)>=0){l=j;o=m;break Vd}f=0-(((j|0)!=0)+m|0)|0;o=f;l=0-j|0;x[g+56>>2]=l;x[g+60>>2]=f;x[M>>2]=l;x[M+4>>2]=f}x[g+104>>2]=0;x[g+108>>2]=q-r;Tb(n,g+104|0);x[s>>2]=x[s>>2]|8192;f=x[n>>2];i=x[n+4>>2]}x[g+48>>2]=f;x[g+52>>2]=i;Wd:{if((i|0)<(q|0)){if((i|0)<0){break Pd}if((o|0)>0|(o|0)>=0){break Wd}break Pd}if((i|0)<0){break Pd}}if(i>>>0>=A[P>>2]){break Pd}x[g+44>>2]=fa;xc(g+68|0,x[g+20>>2]);Ia=g,Ja=Te(g+56|0,x[g+68>>2]-1|0),x[Ia+32>>2]=Ja;x[g+36>>2]=lb;f=o>>31;i=f;m=f;J=f^l;ga=f^o;tf(g+48|0,g+32|0);o=lb;l=x[g+48>>2];f=x[g+52>>2];r=f;j=x[ca>>2];ra=f>>>0<j>>>0|f>>>0>=j+16>>>0;if(ra){x[s>>2]=x[s>>2]&-8193}j=J-m|0;J=ga-((m>>>0>J>>>0)+i|0)|0;Xd:{Yd:{Zd:{if(!x[g+12>>2]){i=x[g+60>>2];break Zd}i=f;f=x[g+16>>2];if(i>>>0>=f>>>0){_d:{if(x[g+60>>2]<0){x[g+96>>2]=l;x[g+100>>2]=r;x[g+104>>2]=0;x[g+108>>2]=f;Ia=g,Ja=qg(g+96|0,g+104|0),x[Ia+80>>2]=Ja;x[g+84>>2]=lb;x[g+72>>2]=1;x[g+76>>2]=0;Ia=g,Ja=qg(g+80|0,g+72|0),x[Ia+88>>2]=Ja;x[g+92>>2]=lb;f=tm(g+88|0,j,J);break _d}f=x[S>>2];x[g+104>>2]=l;x[g+108>>2]=r;x[g+96>>2]=0;x[g+100>>2]=f;Ia=g,Ja=qg(g+96|0,g+104|0),x[Ia+80>>2]=Ja;x[g+84>>2]=lb;x[g+72>>2]=1;x[g+76>>2]=0;Ia=g,Ja=qg(g+80|0,g+72|0),x[Ia+88>>2]=Ja;x[g+92>>2]=lb;f=tm(g+88|0,j,J)}x[g+44>>2]=f+1;x[U+624>>2]=x[g+12>>2];break Xd}if(!(ra|!(y[s+1|0]&32))){x[g+104>>2]=l;x[g+108>>2]=r;x[g+96>>2]=0;x[g+100>>2]=q+16;Ia=g,Ja=qg(g+96|0,g+104|0),x[Ia+80>>2]=Ja;x[g+84>>2]=lb;x[g+72>>2]=1;x[g+76>>2]=0;Ia=g,Ja=qg(g+80|0,g+72|0),x[Ia+88>>2]=Ja;x[g+92>>2]=lb;Ia=g,Ja=tm(g+88|0,j,J)+1|0,x[Ia+44>>2]=Ja;Ia=U,Ja=x[g+12>>2]+D(x[S>>2]-q|0,zo(x[aa>>2]))|0,x[Ia+624>>2]=Ja;break Xd}i=x[g+60>>2];if(!x[g+56>>2]&(i|0)<=0|(i|0)<0){break Zd}if(fa>>>0<2|f>>>0>o>>>0){break Yd}x[g+104>>2]=l;x[g+108>>2]=r;x[g+96>>2]=0;x[g+100>>2]=f;Ia=g,Ja=qg(g+96|0,g+104|0),x[Ia+80>>2]=Ja;x[g+84>>2]=lb;x[g+72>>2]=1;x[g+76>>2]=0;Ia=g,Ja=qg(g+80|0,g+72|0),x[Ia+88>>2]=Ja;x[g+92>>2]=lb;Ia=g,Ja=tm(g+88|0,j,J)+1|0,x[Ia+44>>2]=Ja;break Xd}if((i|0)>0|(i|0)>=0){break Yd}if((o|0)>=(q|0)){break Xd}x[g+96>>2]=l;x[g+100>>2]=r;x[g+104>>2]=0;x[g+108>>2]=q;Ia=g,Ja=qg(g+96|0,g+104|0),x[Ia+80>>2]=Ja;x[g+84>>2]=lb;x[g+72>>2]=1;x[g+76>>2]=0;Ia=g,Ja=qg(g+80|0,g+72|0),x[Ia+88>>2]=Ja;x[g+92>>2]=lb;Ia=g,Ja=tm(g+88|0,j,J)+1|0,x[Ia+44>>2]=Ja;break Xd}i=x[P>>2];if((i|0)>(o|0)){break Xd}x[g+104>>2]=l;x[g+108>>2]=r;x[g+96>>2]=0;x[g+100>>2]=i;Ia=g,Ja=qg(g+96|0,g+104|0),x[Ia+80>>2]=Ja;x[g+84>>2]=lb;x[g+72>>2]=1;x[g+76>>2]=0;Ia=g,Ja=qg(g+80|0,g+72|0),x[Ia+88>>2]=Ja;x[g+92>>2]=lb;Ia=g,Ja=tm(g+88|0,j,J)+1|0,x[Ia+44>>2]=Ja}yo(g+44|0,1,x[g+68>>2]);i=x[g+44>>2];if((i|0)>0){break Od}}x[U+624>>2]=0;x[P>>2]=0;x[n>>2]=0;x[n+4>>2]=0;x[V>>2]=0;q=0;f=x[n+92>>2];r=x[n+96>>2];if(f|r){if(e){while(1){i=(q<<3)+h|0;f=f-(((-2147483648-f>>>31|0)-1&255)+f>>8)|0;x[i>>2]=f+x[i>>2];r=r-(((-2147483648-r>>>31|0)-1&255)+r>>8)|0;x[i+4>>2]=r+x[i+4>>2];q=q+1|0;if((q|0)!=(e|0)){continue}break}}x[n+96>>2]=r;x[n+92>>2]=f}x[_>>2]=x[_>>2]+x[K>>2];x[W>>2]=x[W>>2]+x[R>>2];x[R>>2]=0;x[K>>2]=0;x[s>>2]=x[s>>2]&-129;break Nd}$d:{ae:{if(Ba>>>0<A[a+24608>>2]){q=4;if(x[V>>2]){break ae}q=0;if(x[pa>>2]|x[qa>>2]){break ae}}Ia=g,Ja=yna(x[M>>2],x[M+4>>2],i,i>>31),x[Ia+104>>2]=Ja;x[g+108>>2]=lb;Tb(n,g+104|0);$=0;x[R>>2]=0;x[K>>2]=0;f=(i<<3)+h|0;break $d}f=(i<<3)+h|0;l=f-8|0;x[K>>2]=0-x[l>>2];j=f-4|0;x[R>>2]=0-x[j>>2];mb[x[((q|Aa)<<2)+76368>>2]](n,wa,h,i);x[K>>2]=x[K>>2]+x[l>>2];x[R>>2]=x[R>>2]+x[j>>2];$=1}h=f;f=x[V>>2];be:{if(!f){break be}if(f>>>0<=i>>>0){x[V>>2]=0;x[qa>>2]=x[Ha>>2];x[pa>>2]=x[Ga>>2];x[Fa>>2]=0;x[Ea>>2]=0;if(x[Da>>2]|!(y[s+1|0]&16)){break be}x[P>>2]=0;x[U+624>>2]=0;break be}x[V>>2]=f-i}J=0;f=0;l=x[n+4>>2];f=l>>>0>=A[S>>2]?(y[s|0]&2)>>>1|0:f;j=l;l=x[P>>2];J=j>>>0<l>>>0|(!l|y[s|0]&2)?J:!z[Ca>>1];e=e-i|0;i=g+104|0;Kb(i,ha,85);ce:{de:{ee:{if(!Ib(i)){break ee}i=y[oa|0];if(!i){break ee}if(i>>>0<=z[a+480190>>1]){break de}}q=0;break ce}j=x[aa>>2];i=D(y[oa|0],104)+a|0;l=i+484380|0;q=(j|0)!=(l|0);if((j|0)==(l|0)|(f|J)!=1){break ce}x[aa>>2]=l;x[U+624>>2]=x[i+484400>>2];f=z[i+484414>>1];x[s>>2]=f|x[s>>2]&-768;l=f<<30>>31;f=x[i+484388>>2];x[P>>2]=l&f;i=x[i+484384>>2];x[ca>>2]=i;x[S>>2]=f;x[n+4>>2]=i;FC(H,n);if(!x[U+624>>2]){break Nd}if((e|0)>0){continue}break Nd}fe:{if(!f|q){break fe}f=g+104|0;Kb(f,ha,83);if(!Ib(f)|x[ca>>2]){break fe}x[n>>2]=x[n>>2];x[n+4>>2]=0;f=x[x[aa>>2]+8>>2];x[P>>2]=f;x[S>>2]=f}if((e|0)>0){continue}}break}x[U+624>>2]=x[H>>2];ea=$+ea|0;w[g+30>>1]=ea;ge:{if(na|!$){break ge}e=x[(D(ia,160)+a|0)+906140>>2];if(!e){break ge}mb[x[x[e>>2]+144>>2]](e)}h=z[a+480212>>1]}da=da+1|0;if(da>>>0<h>>>0){continue}break}}Ia=a,Ja=z[aj(a+480214|0,g+30|0)>>1],w[Ia+480214>>1]=Ja}hb=g+112|0;if(zd(la)){e=Z;f=k;g=(D(x[a+480232>>2],x[a+480236>>2])>>>0)/48|0;o=hb-16|0;hb=o;u=x[la>>2];he:{if(!y[u+530|0]){break he}h=yna(g,0,6169,0);g=lb;i=g>>>16|0;H=jd((g&65535)<<16|h>>>16,i);if(!f){break he}while(1){j=x[u>>2];l=x[j>>2];g=x[j+4>>2];if((l|0)<=(g|0)){while(1){x[j+8>>2]=x[j+12>>2];l=0;r=0;i=0;g=hb-16|0;hb=g;while(1){n=j+D(i,44)|0;ie:{if(!y[n+56|0]){w[g+12>>1]=0;w[g+14>>1]=0;break ie}m=x[n+32>>2];h=z[m+3840>>1];if(h&3){m=(z[n+36>>1]>>>7&7)>>>!y[m+3844|0]>>>(h&1)<<z[n+38>>1];h=h&4?0-m|0:m}else{h=0}m=x[n+52>>2];je:{if(m){G=z[m+32>>1];t=z[n+48>>1];h=h<<16>>16;m=Qf(x[n+16>>2],x[n+40>>2],h,0,w[n+46>>1]);q=x[n+40>>2];s=x[n+20>>2];if(!G){if(!t){m=Qf(s,q,h,m,0);m=Qf(x[n+24>>2],x[n+40>>2],h,m,0);h=Qf(x[n+28>>2],x[n+40>>2],h,m,0);break je}q=Qf(s,q,h,0,0);q=Qf(x[n+24>>2],x[n+40>>2],h,q,0);h=Qf(x[n+28>>2],x[n+40>>2],h,q,0)+m|0;break je}if(!t){m=Qf(s,q,h,m,0);q=Qf(x[n+24>>2],x[n+40>>2],h,0,0);h=Qf(x[n+28>>2],x[n+40>>2],h,q,0)+m|0;break je}q=Qf(s,q,h,0,0);h=(Qf(x[n+24>>2],x[n+40>>2],h,q,0)+m|0)+Qf(x[n+28>>2],x[n+40>>2],h,0,0)|0;break je}t=z[n+48>>1];h=h<<16>>16;m=Qf(x[n+16>>2],x[n+40>>2],h,0,w[n+46>>1]);q=x[n+40>>2];s=x[n+20>>2];if(!t){h=Qf(s,q,h,m,0);break je}h=Qf(s,q,h,0,0)+m|0}w[g+14>>1]=y[n+57|0]?h:0;w[g+12>>1]=y[n+58|0]?h:0}l=w[g+12>>1]+l|0;r=w[g+14>>1]+r|0;i=i+1|0;if((i|0)!=18){continue}break}h=(r|0)>=32767?32767:r;w[j+12>>1]=(h|0)<=-32768?-32768:h;h=(l|0)>=32767?32767:l;w[j+14>>1]=(h|0)<=-32768?-32768:h;w[j+3832>>1]=z[j+3832>>1]+1;h=(z[j+3834>>1]+1>>>0)%13440|0;w[j+3834>>1]=h;h=h>>>0<6720?h:13440-h|0;w[j+3836>>1]=h>>>8;if(!y[j+3843|0]){w[j+3836>>1]=h>>>10}h=z[j+3838>>1]+1|0;w[j+3838>>1]=h;if((h&65535)>>>0>=1024){w[j+3838>>1]=0;w[j+3840>>1]=z[j+3840>>1]+1&7}hb=g+16|0;l=x[j>>2];g=x[j+4>>2]-l|0;x[j+4>>2]=g;if((g|0)>=(l|0)){continue}break}}h=l-g|0;w[o+14>>1]=(D(w[j+12>>1],g)+D(h,w[j+8>>1])|0)/(l|0);w[o+12>>1]=(D(w[j+14>>1],g)+D(h,w[j+10>>1])|0)/(l|0);x[j+4>>2]=g+49716;x[e>>2]=x[e>>2]+D(H,w[o+14>>1]);x[e+4>>2]=x[e+4>>2]+D(H,w[o+12>>1]);e=e+8|0;f=f-1|0;if(f){continue}break}}hb=o+16|0}e=x[L+4116>>2];if(e|x[L+4120>>2]){if(!e){Jn(L+8|0,k,L+4104|0,L+4108|0)}e=x[L>>2];f=x[L+4184>>2];g=D(e,f)>>>4|0;g=g>>>0>=32767?32767:g;w[L+4202>>1]=g;w[L+4200>>1]=g;h=x[L+54052>>2];g=D(h,e)>>>4|0;g=g>>>0>=65536?65536:g;i=g+127>>>3|0;w[L+54050>>1]=i;g=g+255>>>4|0;w[L+54048>>1]=g;w[L+54046>>1]=g;w[L+54044>>1]=i;g=L+8|0;f=(f|0)>(h|0)?f:h;e=36-e>>>1|0;e=16-(e>>>0<=8?8:e)|0;f=16-(D((f|0)>=32768?32768:f,e>>>0<=16?e:0)>>15)|0;e=0;if(k){while(1){h=e<<3;i=h+Z|0;x[i>>2]=x[i>>2]+D(f,x[g+h>>2]>>4);h=h|4;i=h+Z|0;x[i>>2]=x[i>>2]+D(f,x[g+h>>2]>>4);e=e+1|0;if((k|0)!=(e|0)){continue}break}}e=0;h=x[L+4144>>2];f=x[L+4140>>2];if(k){l=w[L+4188>>1];while(1){i=(e<<3)+g|0;n=x[i>>2]>>12;f=(D(l,n-f|0)>>15)+n|0;x[i>>2]=f;j=i;i=x[i+4>>2]>>12;h=(D(l,i-h|0)>>15)+i|0;x[j+4>>2]=h;e=e+1|0;if((k|0)!=(e|0)){continue}break}}s=L+4172|0;x[L+4144>>2]=h;x[L+4140>>2]=f;ke:{if(!k){n=x[s>>2]&8191;break ke}e=g;n=z[s+22>>1];h=z[s+20>>1];q=x[s+4>>2];f=k;if(f){i=w[s+26>>1];l=w[s+24>>1];H=w[s+18>>1];t=w[s+16>>1];r=x[s>>2]-1|0;j=s+32928|0;while(1){o=Sc(x[e>>2]);m=Sc(x[e+4>>2]);h=Sc((h<<16>>16)-o|0);n=Sc((n<<16>>16)-m|0);h=Uc(Sc((D(h,t)|0)/65536<<1)+o|0);n=Uc(Sc((D(n,H)|0)/65536<<1)+m|0);m=j+(q<<2)|0;o=w[m+2>>1];u=w[m>>1];m=Uc(((D(u,l)|0)/-65536|0)+h|0);q=q+1&127;G=j+(q<<2)|0;C=Uc(((D(i,o)|0)/-65536|0)+n|0);w[G+2>>1]=C;w[G>>1]=m;r=r+1&8191;G=s+(r<<2)|0;Ia=G,Ja=Uc(u+((D(l,m)|0)/65536|0)|0),w[Ia+160>>1]=Ja;Ia=G,Ja=Uc(o+((D(i,C)|0)/65536|0)|0),w[Ia+162>>1]=Ja;e=e+8|0;f=f-1|0;if(f){continue}break}}m=L+53996|0;w[s+22>>1]=n;w[s+20>>1]=h;x[s+4>>2]=q;h=x[L+4180>>2];M=L+37612|0;e=g;f=k;while(1){i=h&4095;q=M+(i<<2)|0;n=e;i=4096-i|0;G=h-x[L+53996>>2]&4095;h=4096-G|0;h=h>>>0>i>>>0?i:h;h=f>>>0<h>>>0?f:h;l=h>>>0>=64?64:h;j=l;h=0;H=hb-32|0;hb=H;i=x[s>>2];while(1){x[H+(h<<2)>>2]=i+(x[(s+(h<<4)|0)+32>>2]^-1);h=h+1|0;if((h|0)!=7){continue}break}if(j){t=w[s+28>>1]/8<<16>>16;while(1){o=0;i=0;h=0;while(1){r=H+(h<<2)|0;u=x[r>>2]+1&8191;x[r>>2]=u;K=i;i=s+(u<<2)|0;u=w[i+160>>1];r=s+(h<<4)|0;C=w[i+162>>1];i=(K+D(u,w[r+44>>1])|0)+D(C,w[r+46>>1])|0;o=(D(u,w[r+40>>1])+o|0)+D(C,w[r+42>>1])|0;h=h+1|0;if((h|0)!=4){continue}break}r=0;h=4;C=Uc((o|0)/32768|0);I=Uc((i|0)/32768|0);o=0;while(1){i=H+(h<<2)|0;u=x[i>>2]+1&8191;x[i>>2]=u;K=o;o=s+(u<<2)|0;u=w[o+160>>1];i=s+(h<<4)|0;J=w[o+162>>1];o=(K+D(u,w[i+44>>1])|0)+D(J,w[i+46>>1])|0;r=(D(u,w[i+40>>1])+r|0)+D(J,w[i+42>>1])|0;h=h+1|0;if((h|0)!=7){continue}break}h=Uc(C+((r|0)/32768|0)|0);w[q>>1]=h;x[n>>2]=D(h,t);h=Uc(I+((o|0)/32768|0)|0);w[q+2>>1]=h;x[n+4>>2]=D(h,t);n=n+8|0;q=q+4|0;j=j-1|0;if(j){continue}break}}hb=H+32|0;r=M+(G<<2)|0;h=e;q=x[m+4>>2];j=q&2047;o=l;if(l){i=z[m+32>>1];n=m+8256|0;H=m- -64|0;t=m+24640|0;u=m+16448|0;while(1){P=w[n+((q+1206&2047)<<2)>>1];U=w[(n+((q+754&2047)<<2)|0)+2>>1];J=w[(H+((q+1602&2047)<<2)|0)+2>>1];O=w[H+((q+1750&2047)<<2)>>1];C=t+((q+22&2047)<<2)|0;G=w[C+2>>1];C=w[C>>1];R=t+((q+502&2047)<<2)|0;I=w[R+2>>1];K=w[r>>1];V=w[r+2>>1];S=i<<16>>16;i=w[R>>1];R=Sc(S-i|0);S=w[m+24>>1];W=Sc(w[m+34>>1]-I|0);_=w[m+26>>1];$=Sc(w[m+36>>1]-C|0);aa=w[m+28>>1];ca=Sc(w[m+38>>1]-G|0);da=w[m+30>>1];i=Uc(Sc((D(R,S)|0)/65536<<1)+i|0);w[m+32>>1]=i;Ia=m,Ja=Uc(Sc((D(W,_)|0)/65536<<1)+I|0),w[Ia+34>>1]=Ja;Ia=m,Ja=Uc(Sc((D($,aa)|0)/65536<<1)+C|0),w[Ia+36>>1]=Ja;G=Uc(Sc((D(ca,da)|0)/65536<<1)+G|0);w[m+38>>1]=G;C=Sc((D(w[m+16>>1],i)|0)/32768|0);G=Sc((D(G,w[m+22>>1])|0)/32768|0);R=Sc(C+((K|0)/4<<16>>16)|0);K=Sc(G+((V|0)/4<<16>>16)|0);G=w[m+8>>1];V=Sc(R+((D(G,O)|0)/-65536|0)|0);C=j<<2;S=C+H|0;I=w[m+10>>1];W=Sc(K+((D(I,J)|0)/-65536|0)|0);w[S+2>>1]=W;w[S>>1]=V;O=Sc(O+((D(G,V)|0)/65536|0)|0);V=u+C|0;J=Sc(J+((D(I,W)|0)/65536|0)|0);w[V+2>>1]=J;w[V>>1]=O;O=Sc(O+R|0);R=Sc(J+K|0);J=u+((q+426&2047)<<2)|0;K=w[J+2>>1];V=w[J>>1];q=u+((q+682&2047)<<2)|0;S=w[q+2>>1];W=w[q>>1];q=Sc((D(S,w[m+42>>1])+D(W,w[m+40>>1])|0)/32768|0);J=Sc((D(K,w[m+46>>1])+D(V,w[m+44>>1])|0)/32768|0);W=Sc(Sc(O+W|0)-q|0);S=Sc(Sc(R+S|0)-J|0);O=Sc(Sc(O+V|0)-q|0);R=Sc(Sc(K+R|0)-J|0);q=Sc(q+((D(G,P)|0)/-65536|0)|0);K=n+C|0;J=Sc(J+((D(I,U)|0)/-65536|0)|0);w[K+2>>1]=J;w[K>>1]=q;G=(D(q,G)|0)/65536|0;q=Sc(G+P|0);C=t+C|0;I=(D(I,J)|0)/65536|0;J=Sc(I+U|0);w[C+2>>1]=J;w[C>>1]=q;q=Sc(q+W|0);C=w[m+48>>1];J=Sc(J+S|0);x[h>>2]=(x[h>>2]+D(q,C)|0)+D(J,w[m+50>>1]);q=Sc(Sc(G)+O|0);G=w[m+52>>1];C=Sc(Sc(I)+R|0);x[h+4>>2]=(x[h+4>>2]+D(q,G)|0)+D(C,w[m+54>>1]);h=h+8|0;r=r+4|0;q=j+1|0;j=q&2047;o=o-1|0;if(o){continue}break}}x[m+4>>2]=j;h=l+x[L+4180>>2]&4095;x[L+4180>>2]=h;n=l+x[L+4172>>2]&8191;x[L+4172>>2]=n;e=(l<<3)+e|0;f=f-l|0;if(f){continue}break}}x[L+4172>>2]=n;e=Z;f=0;h=0;q=x[L+4160>>2];o=x[L+4156>>2];l=k;if(k){n=x[L+4164>>2];h=x[L+4168>>2];while(1){f=x[g>>2];i=h;h=x[g+4>>2];i=i-h|0;i=(((i|0)/1024|0)-i|0)+q|0;x[e+4>>2]=i+x[e+4>>2];n=n-f|0;n=(((n|0)/1024|0)-n|0)+o|0;x[e>>2]=n+x[e>>2];q=i+((i|0)/-512|0)|0;o=n+((n|0)/-512|0)|0;e=e+8|0;g=g+8|0;n=f;l=l-1|0;if(l){continue}break}}x[L+4168>>2]=h;x[L+4164>>2]=f;x[L+4160>>2]=q;x[L+4156>>2]=o;e=x[L+4124>>2];le:{if(x[L+4116>>2]){break le}e=x[L+4120>>2];if(e>>>0>k>>>0){e=e-k|0;break le}hJ(L);e=0}x[L+4116>>2]=0;x[L+4120>>2]=e}if(x[a+946300>>2]){o=0;s=0;h=k<<2;i=z[a+480214>>1]!=0;e=a+1074332|0;X=B[e>>2];sa=B[e+4>>2];while(1){l=(D(o,160)+a|0)+906300|0;e=x[l>>2];me:{if(!e|!x[e+24>>2]){break me}if(!Bh(e+44|0)){break me}e=x[l>>2];if(!(mb[x[x[e>>2]+108>>2]](e)|0)){mb[x[x[e>>2]+104>>2]](e,1);mb[x[x[e>>2]+116>>2]](e)}g=e+44|0;f=Od(g,0);g=Od(g,1);ne:{if(v[e+28|0]&1){mz(x[e+24>>2],f,g,k,X);break ne}n=e+40|0;if(x[n>>2]|x[e+36>>2]){Jn(x[e+24>>2],k,n,e+36|0);mz(x[e+24>>2],f,g,k,X);break ne}Sb(f,0,h);Sb(g,0,h)}x[e+28>>2]=x[e+28>>2]&-2;if(mv(l)){break me}i=!(y[e+28|0]&4)|i}o=o+1|0;if((o|0)!=250){continue}break}j=a+12|0;l=a+12300|0;n=a+14348|0;mz(j,l,n,k,X);e=a+1074464|0;G=y[e|0];v[e|0]=0;e=l;f=n;while(1){m=(D(s,160)+a|0)+906300|0;g=x[m>>2];oe:{if(!g|!x[g+24>>2]){break oe}if(!Bh(g+44|0)){break oe}H=x[m>>2];pe:{if(mv(m)){break pe}g=x[m>>2];if(mb[x[x[g>>2]+140>>2]](g)|y[x[m>>2]+28|0]&2){break pe}o=0;if(!s){break oe}while(1){if((Sj((D(o,160)+a|0)+906300|0)|0)==(s|0)){break pe}o=o+1|0;if((s|0)!=(o|0)){continue}break}break oe}g=H+44|0;r=Od(g,0);u=Od(g,1);q=x[m>>2];t=(e|0)==(r|0);e=t?l:e;g=e;f=t?n:f;h=f;qe:{if(!(y[m+28|0]|y[m+29|0]<<8|(y[m+30|0]<<16|y[m+31|0]<<24))){break qe}o=Sj(m);h=f;if(o>>>0<=s>>>0){break qe}h=f;if(o>>>0>249){break qe}o=x[(D(o,160)+a|0)+906300>>2];h=f;if(!o){break qe}if(!(y[q+28|0]&4)){mb[x[x[o>>2]+144>>2]](o)}o=o+44|0;h=f;if(!Bh(o)){break qe}g=Od(o,0);h=Od(o,1)}re:{if(!mv(m)){break re}se:{if(t){break se}o=0;if(!k){break se}while(1){t=o<<2;C=t+r|0;K=C;X=B[C>>2];C=e+t|0;B[K>>2]=X+B[C>>2];I=t+u|0;t=f+t|0;B[I>>2]=B[I>>2]+B[t>>2];x[C>>2]=0;x[t>>2]=0;o=o+1|0;if((k|0)!=(o|0)){continue}break}}f=h;e=g;if(!(i&1)){break re}e=x[m>>2];if(e){mb[x[x[e>>2]+144>>2]](e)}e=g;o=Sj(m);if(o>>>0>249|o>>>0<=s>>>0){break re}while(1){f=o&255;e=(D(f,160)+a|0)+906300|0;o=Sj(e);e=x[e>>2];if(e){mb[x[x[e>>2]+144>>2]](e)}if(f>>>0<o>>>0&o>>>0<=249){continue}break}f=h;e=g}te:{ue:{if(!((y[m+24|0]&2)>>>1|0)){if(!DC(m)|!(y[q+28|0]&4)){break ue}}o=0;if(!k){break te}while(1){m=o<<2;H=m+g|0;B[H>>2]=B[H>>2]+B[m+r>>2];H=h+m|0;B[H>>2]=B[H>>2]+B[m+u>>2];o=o+1|0;if((k|0)!=(o|0)){continue}break}break te}if(G){mb[x[x[H>>2]+124>>2]](H)}mb[x[x[H>>2]+60>>2]](H,g,h,k);x[q+32>>2]=k+x[q+32>>2];if(!DC(m)){break te}if((mb[x[x[H>>2]+152>>2]](H)|0)<=0|A[q+32>>2]<x[a+24620>>2]<<2>>>0){break te}o=0;ve:{if(!k){break ve}while(1){we:{m=o<<2;X=B[m+g>>2];if(X>=E(1.1920928955078125e-7)|X<=E(-1.1920928955078125e-7)){break we}X=B[h+m>>2];if(X>=E(1.1920928955078125e-7)|!(X>E(-1.1920928955078125e-7))){break we}o=o+1|0;if((k|0)!=(o|0)){continue}break ve}break}x[q+32>>2]=0;break te}x[q+28>>2]=x[q+28>>2]|4}x[q+28>>2]=x[q+28>>2]&-3}s=s+1|0;if((s|0)!=250){continue}break}g=0;if(k){while(1){X=E(B[e>>2]*sa);xe:{if(E(F(X))<E(2147483648)){h=~~X;break xe}h=-2147483648}x[j>>2]=h;X=E(B[f>>2]*sa);ye:{if(E(F(X))<E(2147483648)){h=~~X;break ye}h=-2147483648}x[j+4>>2]=h;j=j+8|0;f=f+4|0;e=e+4|0;g=g+1|0;if((k|0)!=(g|0)){continue}break}}}if(x[a+24624>>2]==1){e=0;if(k){while(1){f=(e<<3)+Z|0;x[(e<<2)+Z>>2]=(x[f+4>>2]+x[f>>2]|0)/2;e=e+1|0;if((k|0)!=(e|0)){continue}break}}}if(y[ua+36|0]){i=hb-16|0;hb=i;ze:{Ae:{Be:{if(!x[a+1074376>>2]){n=a+1074448|0;e=n;x[e>>2]=0;x[e+4>>2]=0;x[a+1074456>>2]=x[a+1074444>>2];break Be}g=x[a+1074456>>2];e=x[a+1074444>>2];Ce:{if((g|0)==(e|0)){e=x[a+1074448>>2];break Ce}x[a+1074456>>2]=e;f=a+24604|0;h=a+1074448|0;De:{if((e|0)>(g|0)){e=EO(f);break De}e=DO(f)}x[h>>2]=e;x[a+1074452>>2]=e}n=a+1074448|0;if((e|0)>0){break Ae}}h=0;break ze}g=(x[a+1074456>>2]<<12)-x[a+1074460>>2]|0;h=(g|0)/(e|0)|0;if(x[a+1074372>>2]!=2){break ze}x[i+12>>2]=50;x[i+8>>2]=1e4/(x[a+1074452>>2]+1|0);l=x[Bf(i+12|0,i+8|0)>>2];e=h>>31;if((l|0)>=((e^h)-e|0)){break ze}j=x[a+1074452>>2];e=x[a+1074448>>2];while(1){e=e+j|0;h=(g|0)/(e|0)|0;f=h>>31;if((l|0)<((f^h)-f|0)){continue}break}x[n>>2]=e}Ee:{Fe:{switch(x[a+24624>>2]-1|0){case 0:if((k|0)<=0){break Ee}e=a+12|0;f=x[a+1074444>>2];j=f<<12;o=f>>31;g=0;while(1){Ge:{if(x[n>>2]>0){l=x[a+1074460>>2]+h|0;x[a+1074460>>2]=l;m=x[e>>2];Ia=e,Ja=Cc(zna(yna(m,m>>31,l,l>>31),lb,1048576,0),lb),x[Ia>>2]=Ja;x[a+1074448>>2]=x[a+1074448>>2]-1;break Ge}l=x[e>>2];Ia=e,Ja=Cc(zna(yna(l,l>>31,f,o),lb,256,0),lb),x[Ia>>2]=Ja;x[a+1074460>>2]=j}e=e+4|0;g=g+1|0;if((k|0)!=(g|0)){continue}break};break Ee;case 1:if((k|0)<=0){break Ee}e=a+12|0;f=x[a+1074444>>2];o=f<<12;l=f>>31;g=0;while(1){He:{if(x[n>>2]>0){j=x[a+1074460>>2]+h|0;x[a+1074460>>2]=j;m=x[e>>2];Ia=e,Ja=Cc(zna(yna(m,m>>31,j,j>>31),lb,1048576,0),lb),x[Ia>>2]=Ja;j=x[a+1074460>>2];m=j;r=j>>31;j=x[e+4>>2];Ia=e,Ja=Cc(zna(yna(m,r,j,j>>31),lb,1048576,0),lb),x[Ia+4>>2]=Ja;x[a+1074448>>2]=x[a+1074448>>2]-1;break He}j=x[e>>2];Ia=e,Ja=Cc(zna(yna(j,j>>31,f,l),lb,256,0),lb),x[Ia>>2]=Ja;j=x[e+4>>2];Ia=e,Ja=Cc(zna(yna(j,j>>31,f,l),lb,256,0),lb),x[Ia+4>>2]=Ja;x[a+1074460>>2]=o}e=e+8|0;g=g+1|0;if((k|0)!=(g|0)){continue}break};break Ee;case 3:break Fe;default:break Ee}}if((k|0)<=0){break Ee}e=a+12|0;g=a+8204|0;f=x[a+1074444>>2];m=f<<12;j=f>>31;l=0;while(1){Ie:{if(x[n>>2]>0){o=x[a+1074460>>2]+h|0;x[a+1074460>>2]=o;q=x[e>>2];Ia=e,Ja=Cc(zna(yna(q,q>>31,o,o>>31),lb,1048576,0),lb),x[Ia>>2]=Ja;o=x[a+1074460>>2];r=o;q=o>>31;o=x[e+4>>2];Ia=e,Ja=Cc(zna(yna(r,q,o,o>>31),lb,1048576,0),lb),x[Ia+4>>2]=Ja;o=x[a+1074460>>2];r=o;q=o>>31;o=x[g>>2];Ia=g,Ja=Cc(zna(yna(r,q,o,o>>31),lb,1048576,0),lb),x[Ia>>2]=Ja;o=x[a+1074460>>2];r=o;q=o>>31;o=x[g+4>>2];Ia=g,Ja=Cc(zna(yna(r,q,o,o>>31),lb,1048576,0),lb),x[Ia+4>>2]=Ja;x[a+1074448>>2]=x[a+1074448>>2]-1;break Ie}o=x[e>>2];Ia=e,Ja=Cc(zna(yna(o,o>>31,f,j),lb,256,0),lb),x[Ia>>2]=Ja;o=x[e+4>>2];Ia=e,Ja=Cc(zna(yna(o,o>>31,f,j),lb,256,0),lb),x[Ia+4>>2]=Ja;o=x[g>>2];Ia=g,Ja=Cc(zna(yna(o,o>>31,f,j),lb,256,0),lb),x[Ia>>2]=Ja;o=x[g+4>>2];Ia=g,Ja=Cc(zna(yna(o,o>>31,f,j),lb,256,0),lb),x[Ia+4>>2]=Ja;x[a+1074460>>2]=m}g=g+8|0;e=e+8|0;l=l+1|0;if((k|0)!=(l|0)){continue}break}}hb=i+16|0}if(x[ja>>2]!=128){f=a+12|0;g=a+8204|0;e=x[a+24604>>2];h=x[a+24624>>2];Je:{if((e|0)==128|h>>>0<2){break Je}xL(f,k,e);if(h>>>0<4){break Je}xL(g,k,e)}}e=x[a+24624>>2];if((e|0)==4){g=k-1|0;if((g|0)>=0){while(1){e=(g<<4)+Z|0;f=g<<3;h=f|4;x[e+12>>2]=x[h+ka>>2];x[e+8>>2]=x[f+ka>>2];x[e+4>>2]=x[h+Z>>2];x[e>>2]=x[f+Z>>2];e=(g|0)>0;g=g-1|0;if(e){continue}break}}e=x[a+24624>>2]}mb[x[x[c>>2]+8>>2]](c,Z,e,k);f=x[a+1074380>>2]-k|0;x[a+1074380>>2]=f;x[a+1074376>>2]=k+x[a+1074376>>2];ta=k+ta|0;e=x[a+480208>>2];if(e&512){break g}b=b-k|0;if(b){continue}break}}hb=Y+32|0;return ta|0}function Fla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;d=hb-784|0;hb=d;Lc(b);e=hb-16|0;hb=e;i=e+8|0;g=d+592|0;xq(i,g);h=Eb(i);i=nc(b,ac(e,i));if((h|0)==(i|0)){cc(b,Eb(e+8|0))}hb=e+16|0;e=(h|0)==(i|0);if(!e){hS(g)}a:{b:{c:{if(!e){break c}if(!KS(d+592|0)){break c}if(!Qb(b,jd(JS(d+592|0),lb))){break c}if(!c){f=1;break c}Nd(a,32);v[d+591|0]=0;i=hd(d+576|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{if(x[d+592>>2]==778924148){x[114414]=0;P(598,a|0,16777216);e=x[114414];x[114414]=0;if((e|0)==1){break b}x[114414]=0;e=R(223,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}x[114414]=0;O(224,b|0,e-4|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break b}x[114414]=0;s=R(391,b|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){break H}break b}I:{J:{K:{L:{M:{e=y[d+632|0]|y[d+633|0]<<8;N:{if(e>>>0<2185|e>>>0>4095){break N}x[114414]=0;e=R(223,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}x[114414]=0;O(224,b|0,e-4|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break b}x[114414]=0;s=R(391,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break b}if(s>>>0<256){break N}x[114414]=0;e=R(223,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}if(e>>>0<=s>>>0){break N}x[114414]=0;e=O(224,b|0,s|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}if(!e){break N}x[114414]=0;e=O(599,b|0,10285)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}if(!e){break N}x[114414]=0;P(598,a|0,16777216);e=x[114414];x[114414]=0;if((e|0)==1){break b}if((y[d+632|0]|y[d+633|0]<<8)>>>0>=4096){x[114414]=0;b=O(600,d+328|0,12374)|0;c=x[114414];x[114414]=0;if((c|0)==1){break G}x[114414]=0;P(601,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(b);f=0;break d}f=N()|0;xb(b);break a}if((y[d+632|0]|y[d+633|0]<<8)>>>0<2194){break N}x[114414]=0;e=O(600,d+560|0,11926)|0;f=x[114414];x[114414]=0;if((f|0)==1){break M}x[114414]=0;P(601,a|0,e|0);f=x[114414];x[114414]=0;if((f|0)==1){break L}xb(e)}if(x[a+480180>>2]!=32){break H}if(((y[d+632|0]|y[d+633|0]<<8)&61440)!=20480){break I}e=(y[d+632|0]|y[d+633|0]<<8)&4095;f=e<<16;if(x[d+652>>2]!=1414548815){break K}v[d+591|0]=1;break J}f=N()|0;break a}f=N()|0;xb(e);break a}if(e>>>0<297){break J}f=y[d+652|0]|y[d+653|0]<<8|f}x[a+1074308>>2]=f;break H}if(!((y[d+634|0]|y[d+635|0]<<8)!=2184&(y[d+632|0]|y[d+633|0]<<8)!=2184)){v[d+591|0]=1;x[a+1074308>>2]=18284544;break H}if(!((y[d+632|0]|y[d+633|0]<<8)!=535|(y[d+634|0]|y[d+635|0]<<8)!=512|(y[d+652|0]|y[d+653|0]<<8|(y[d+654|0]<<16|y[d+655|0]<<24)))){x[114414]=0;e=U(602,d+656|0,255,64)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}O:{if(e){x[a+1074308>>2]=18219008;x[114414]=0;e=O(2,d+544|0,10342)|0;f=x[114414];x[114414]=0;if((f|0)!=1){break O}f=N()|0;break a}x[a+1074308>>2]=18284544;x[114414]=0;e=O(2,d+544|0,12747)|0;f=x[114414];x[114414]=0;if((f|0)==1){break F}}Db(i,e);xb(e);v[d+591|0]=1;break H}if(!((y[d+632|0]|y[d+633|0]<<8)!=532|(y[d+634|0]|y[d+635|0]<<8)!=514|(y[d+652|0]|y[d+653|0]<<8|(y[d+654|0]<<16|y[d+655|0]<<24)))){x[a+1074308>>2]=17367040;x[114414]=0;e=O(2,d+544|0,10252)|0;f=x[114414];x[114414]=0;if((f|0)!=1){Db(i,e);xb(e);v[d+591|0]=1;break H}f=N()|0;break a}if((y[d+632|0]|y[d+633|0]<<8)!=768|(y[d+634|0]|y[d+635|0]<<8)!=768|(y[d+652|0]|y[d+653|0]<<8|(y[d+654|0]<<16|y[d+655|0]<<24)|(y[d+624|0]|y[d+625|0]<<8)!=256)){break H}if(y[d+645|0]|y[d+644|0]!=128){break H}x[a+1074308>>2]=18285088;v[d+591|0]=1}x[a+480208>>2]=x[a+480208>>2]&-17|(y[d+636|0]|y[d+637|0]<<8)<<1&16;x[a+480208>>2]=x[a+480208>>2]&-5|(y[d+636|0]|y[d+637|0]<<8)>>>2&4;x[a+480208>>2]=x[a+480208>>2]&-9|(y[d+636|0]|y[d+637|0]<<8)>>>2&8;x[a+480208>>2]=x[a+480208>>2]&-32769|(y[d+636|0]|y[d+637|0]<<8)<<3&32768;x[114414]=0;T(603,d+432|0,3,d+592|4);e=x[114414];x[114414]=0;if((e|0)==1){break E}x[114414]=0;P(355,d+328|0,d+432|0);e=x[114414];x[114414]=0;if((e|0)==1){break E}e=d+328|0;Db(a+1304400|0,e);xb(e);if(!(!(y[d+638|0]&4)|(A[a+1074308>>2]<18285314?x[a+1074308>>2]:0))){x[a+480216>>2]=y[d+622|0];x[a+480220>>2]=y[d+623|0]}e=y[d+640|0];x[a+480200>>2]=e>>>0>128?256:e<<1;if(y[d+642|0]){x[a+480196>>2]=y[d+642|0]}v[d+328|0]=31;e=y[d+643|0];x[114414]=0;v[d+432|0]=e;e=O(404,d+328|0,d+432|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break e}x[a+480204>>2]=D(y[e|0],1e4);e=y[d+641|0];x[114414]=0;v[d+328|0]=e;v[d+432|0]=128;e=O(409,d+328|0,d+432|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break f}x[a+480228>>2]=y[e|0];f=0;while(1){j=(d+592|0)+f|0;g=j- -64|0;P:{if(y[g|0]==255){break P}x[114414]=0;h=(f<<5)+a|0;e=h+480280|0;W(381,e|0);l=x[114414];x[114414]=0;if((l|0)==1){break D}C=h+480286|0,E=Md(y[j+128|0],0,64),w[C>>1]=E;if(v[g|0]<0){x[e>>2]=x[e>>2]|1024}g=y[g|0]&127;if(g>>>0<=64){w[h+480284>>1]=g<<2;break P}if((g|0)!=100){break P}x[e>>2]=x[e>>2]|256}f=f+1|0;if((f|0)!=64){continue}break}x[114414]=0;O(224,b|0,192)|0;e=x[114414];x[114414]=0;if((e|0)==1){break b}Q:{if(!(x[a+480180>>2]!=16777216|(y[d+632|0]|y[d+633|0]<<8)>>>0<2187|(y[d+632|0]|y[d+633|0]<<8)>>>0>2189)){f=0;x[114414]=0;e=R(321,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break C}if(e){break d}x[114414]=0;e=R(391,b|0)|0;g=x[114414];x[114414]=0;R:{if((g|0)==1){break R}if(e>>>0>z[x[19563]+12>>1]){break d}g=Vb(a+484360|0);x[114414]=0;e=aa(604,g|0,b|0,e|0,65535,65535)|0;g=x[114414];x[114414]=0;if((g|0)==1){break R}if(!e){break d}break Q}f=N()|0;break a}e=Vb(a+484360|0);f=y[d+624|0]|y[d+625|0]<<8;x[114414]=0;aa(548,e|0,b|0,f|0,255,254)|0;e=x[114414];x[114414]=0;if((e|0)==1){break b}}r=kq(d+528|0);o=kq(d+512|0);l=kq(d+496|0);e=y[d+626|0]|y[d+627|0]<<8;f=0;x[114414]=0;e=U(605,b|0,r|0,e|0)|0;g=x[114414];x[114414]=0;S:{if((g|0)==1){break S}if(!e){break A}e=y[d+628|0]|y[d+629|0]<<8;x[114414]=0;e=U(605,b|0,o|0,e|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break S}if(!e){break A}e=y[d+630|0]|y[d+631|0]<<8;x[114414]=0;e=U(605,b|0,l|0,e|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break S}if(!e){break A}x[d+492>>2]=-1;C=d,E=bc(r),x[C+328>>2]=E;C=d,E=dc(r),x[C+432>>2]=E;if(!Hb(d+328|0,d+432|0)){break B}while(1){e=x[d+328>>2];e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|e>>>0>=A[d+492>>2])){x[d+492>>2]=e}e=d+328|0;fe(e);if(Hb(e,d+432|0)){continue}break}break B}f=N()|0;break g}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}C=d,E=bc(o),x[C+328>>2]=E;C=d,E=dc(o),x[C+432>>2]=E;if(Hb(d+328|0,d+432|0)){while(1){e=x[d+328>>2];e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|e>>>0>=A[d+492>>2])){x[d+492>>2]=e}e=d+328|0;fe(e);if(Hb(e,d+432|0)){continue}break}}C=d,E=bc(l),x[C+328>>2]=E;C=d,E=dc(l),x[C+432>>2]=E;if(Hb(d+328|0,d+432|0)){while(1){e=x[d+328>>2];e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|e>>>0>=A[d+492>>2])){x[d+492>>2]=e}e=d+328|0;fe(e);if(Hb(e,d+432|0)){continue}break}}T:{U:{if(v[d+638|0]&1){e=y[d+648|0]|y[d+649|0]<<8|(y[d+650|0]<<16|y[d+651|0]<<24);x[114414]=0;x[d+328>>2]=e;e=O(297,d+492|0,d+328|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break U}x[d+492>>2]=x[e>>2]}f=0;V:{W:{X:{e=y[d+632|0]|y[d+633|0]<<8;Y:{if((y[d+634|0]|y[d+635|0]<<8)!=532|(e?(e|0)!=532:0)|(y[d+623|0]|y[d+622|0])){break Y}if(y[d+636|0]&192|(y[d+645|0]|(y[d+652|0]|y[d+653|0]<<8|(y[d+654|0]<<16|y[d+655|0]<<24)))){break Y}Z:{if(!(y[d+628|0]|y[d+629|0]<<8)|(y[d+626|0]|y[d+627|0]<<8)){break Z}if((x[b+8>>2]+(Lb(o)<<2)|0)+2>>>0>A[d+492>>2]){break Z}if(y[d+628|0]|y[d+629|0]<<8){e=0;while(1){x[114414]=0;f=R(391,b|0)|0;g=x[114414];x[114414]=0;_:{if((g|0)!=1){if(!f){break _}ng(b,((e&65535)<<2)+4|0);break Z}f=N()|0;break g}e=e+1|0;if((e&65535)>>>0<(y[d+628|0]|y[d+629|0]<<8)>>>0){continue}break}}x[114414]=0;e=O(2,d+480|0,10492)|0;f=x[114414];x[114414]=0;if((f|0)==1){break W}Db(i,e);xb(e)}f=1;if(y[d+632|0]|y[d+633|0]<<8){break Y}x[114414]=0;e=O(2,d+464|0,11248)|0;g=x[114414];x[114414]=0;if((g|0)==1){break X}Db(i,e);xb(e)}$:{aa:{ba:{if(y[d+638|0]&2){x[114414]=0;e=R(321,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break $}x[114414]=0;g=e<<3;h=O(226,b|0,g|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break $}if(!(!h|A[d+492>>2]<g+x[b+8>>2]>>>0)){x[114414]=0;g=a+1304500|0;P(606,g|0,e|0);h=x[114414];x[114414]=0;if((h|0)==1){break $}C=d,E=bc(g),x[C+432>>2]=E;C=d,E=dc(g),x[C+416>>2]=E;if(Hb(d+432|0,d+416|0)){while(1){g=x[d+432>>2];x[114414]=0;O(607,b|0,d+328|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break aa}x[114414]=0;P(608,d+328|0,g|0);g=x[114414];x[114414]=0;if((g|0)==1){break aa}g=d+432|0;x[g>>2]=x[g>>2]+48;if(Hb(g,d+416|0)){continue}break}}if(!(!e&f)){break ba}if(y[d+638|0]&4){x[114414]=0;e=O(2,d+448|0,11281)|0;f=x[114414];x[114414]=0;if((f|0)!=1){Db(i,e);xb(e);break ba}f=N()|0;break g}x[114414]=0;e=O(2,d+448|0,10526)|0;f=x[114414];x[114414]=0;if((f|0)!=1){Db(i,e);xb(e);break ba}f=N()|0;break g}ng(b,2);break ba}if(!f|(y[d+638|0]|y[d+639|0]<<8)>>>0>1){break ba}x[114414]=0;e=R(321,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break V}if(!e){x[114414]=0;e=O(2,d+448|0,10492)|0;f=x[114414];x[114414]=0;if((f|0)!=1){Db(i,e);xb(e);break ba}f=N()|0;break g}ng(b,2)}ca:{if(!(y[d+636|0]&128|y[d+638|0]&8)){break ca}x[114414]=0;e=a+901404|0;f=O(609,b|0,e|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break h}if(!f){break ca}x[114414]=0;W(610,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break h}}if((y[d+632|0]|y[d+633|0]<<8)>>>0<=531){x[114414]=0;W(611,a+901404|0);e=x[114414];x[114414]=0;if((e|0)==1){break h}}x[114414]=0;t=R(239,d+432|0)|0;e=x[114414];x[114414]=0;da:{ea:{fa:{ga:{ha:{ia:{ja:{if((e|0)!=1){x[114414]=0;e=O(595,b|0,9651)|0;f=x[114414];x[114414]=0;if((f|0)==1){break ja}if(e){x[114414]=0;e=R(391,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break ia}x[114414]=0;T(307,d+328|0,b|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break ia}e=d+328|0;Ud(t,e);Ab(e)}w[a+480188>>1]=1;x[114414]=0;e=O(595,b|0,9656)|0;f=x[114414];x[114414]=0;if((f|0)==1){break ja}if(e){x[114414]=0;e=R(391,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break ha}x[114414]=0;T(307,d+328|0,b|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break ha}x[114414]=0;e=R(223,d+328|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break ga}x[114414]=0;w[d+416>>1]=(e>>>0)/20;e=O(433,23700,d+416|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break ga}e=z[e>>1];w[a+480188>>1]=e;if(e){f=0;while(1){x[114414]=0;U(612,d+328|0,((f<<5)+a|0)+480289|0,20)|0;g=x[114414];x[114414]=0;if((g|0)==1){break ga}f=f+1|0;if((e|0)!=(f|0)){continue}break}}Ab(d+328|0)}if(A[b+8>>2]>A[d+492>>2]){break fa}g=x[d+492>>2]-x[b+8>>2]|0;break ea}f=N()|0;break g}f=N()|0;break i}f=N()|0;break i}f=N()|0;break i}f=N()|0;Ab(d+328|0);break i}x[114414]=0;g=R(296,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break da}}x[114414]=0;T(307,d+416|0,b|0,g|0);e=x[114414];x[114414]=0;if((e|0)==1){break da}x[114414]=0;u=O(613,a|0,d+416|0)|0;e=x[114414];x[114414]=0;ka:{la:{if((e|0)==1){break la}if(!(v[d+638|0]&1)|!(y[d+646|0]|y[d+647|0]<<8)){break ka}e=y[d+648|0]|y[d+649|0]<<8|(y[d+650|0]<<16|y[d+651|0]<<24);x[114414]=0;e=O(224,b|0,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break la}if(!e){break ka}e=y[d+646|0]|y[d+647|0]<<8;x[114414]=0;Z(552,a+1304424|0,b|0,e|0,4)|0;e=x[114414];x[114414]=0;if((e|0)!=1){break ka}}f=N()|0;break j}w[a+480192>>1]=0;ma:{if(y[d+636|0]&4){e=y[d+626|0]|y[d+627|0]<<8;x[114414]=0;w[d+328>>1]=e;w[d+312>>1]=255;e=O(433,d+328|0,d+312|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break ma}w[a+480192>>1]=z[e>>1]}na:{oa:{if(z[a+480192>>1]){f=0;while(1){e=Pb(r,f);pa:{if(!(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))){break pa}e=Pb(r,f);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[114414]=0;e=O(224,b|0,e|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break na}if(!e){break pa}x[114414]=0;e=O(226,b|0,554)|0;g=x[114414];x[114414]=0;if((g|0)==1){break na}if(!e){break pa}x[114414]=0;e=U(405,a|0,f+1&65535,0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break oa}if(!e){break pa}g=y[d+634|0]|y[d+635|0]<<8;x[114414]=0;Z(614,a|0,b|0,e|0,g|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break oa}v[e+33|0]=y[d+645|0]}f=f+1|0;if(f>>>0<z[a+480192>>1]){continue}break}}x[d+412>>2]=0;if(y[d+628|0]|y[d+629|0]<<8){e=Pb(o,(y[d+628|0]|y[d+629|0]<<8)-1|0);x[d+412>>2]=(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))+80}e=y[d+628|0]|y[d+629|0]<<8;x[114414]=0;w[d+328>>1]=e;w[d+312>>1]=3999;e=O(433,d+328|0,d+312|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){w[a+480190>>1]=z[e>>1];g=0;qa:{if(z[a+480190>>1]){j=c&2;q=d+348|0;f=0;while(1){e=Pb(o,f);ra:{if(!(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))){break ra}e=Pb(o,f);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[114414]=0;e=O(224,b|0,e|0)|0;h=x[114414];x[114414]=0;sa:{ta:{ua:{va:{wa:{xa:{ya:{if((h|0)==1){break ya}if(!e){break ra}x[114414]=0;e=O(615,b|0,d+328|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break ya}if(!e){break ra}x[114414]=0;k=f+1|0;e=D(k,104)+a|0;h=e+484380|0;n=O(616,d+328|0,h|0)|0;m=x[114414];x[114414]=0;if((m|0)==1){break xa}x[114414]=0;T(603,d+296|0,3,q|0);m=x[114414];x[114414]=0;if((m|0)==1){break wa}x[114414]=0;P(355,d+312|0,d+296|0);m=x[114414];x[114414]=0;if((m|0)==1){break wa}x[114414]=0;O(334,((k<<5)+a|0)+946304|0,d+312|0)|0;m=x[114414];x[114414]=0;if((m|0)==1){break va}xb(d+312|0);x[114414]=0;n=O(224,b|0,n|0)|0;m=x[114414];x[114414]=0;if((m|0)==1){break xa}if(!n){break ra}e=z[e+484414>>1];if(!(e&512)){break ua}x[114414]=0;e=O(617,b|0,d+312|0)|0;k=x[114414];x[114414]=0;if((k|0)!=1){if(!e){break ta}x[114414]=0;x[d+16>>2]=x[d+320>>2];e=x[d+316>>2];x[d+8>>2]=x[d+312>>2];x[d+12>>2]=e;T(618,h|0,1,d+8|0);e=x[114414];x[114414]=0;if((e|0)!=1){break ta}}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;xb(d+312|0);break j}if(!(e&16384)){e=y[d+632|0]|y[d+633|0]<<8;x[114414]=0;T(619,d+312|0,d+328|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break k}za:{if(j){e=0;x[114414]=0;U(361,d+312|0,h|0,b|0)|0;k=x[114414];x[114414]=0;if((k|0)!=1){break za}break k}e=1;k=y[d+315|0];if(k>>>0>18){break za}k=1<<k;Aa:{if(!(k&126991)){if(k&396800){break Aa}break za}if(!y[d+312|0]){break za}}e=x[h>>2];x[114414]=0;k=O(620,d+312|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break k}e=0;x[114414]=0;O(304,b|0,k|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break k}}if(y[d+315|0]!=1){break sa}g=x[h>>2]!=0|g;break sa}x[114414]=0;O(621,b|0,d+200|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break l}e=x[d+200>>2];if(!(!j|!e)){e=Wb(d+312|0);x[114414]=0;U(437,b|0,e|0,x[d+200>>2])|0;h=x[114414];x[114414]=0;Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{if((h|0)!=1){x[114414]=0;h=O(2,d+264|0,12296)|0;n=x[114414];x[114414]=0;if((n|0)==1){break Ja}x[114414]=0;P(187,d+280|0,h|0);n=x[114414];x[114414]=0;if((n|0)==1){break Ia}x[114414]=0;x[d+184>>2]=k;T(13,d+248|0,0,e|0);k=x[114414];x[114414]=0;if((k|0)==1){break Ha}x[114414]=0;X(622,d+296|0,d+280|0,d+184|0,d+248|0);k=x[114414];x[114414]=0;if((k|0)==1){break Ga}x[114414]=0;T(623,a|0,2,d+296|0);k=x[114414];x[114414]=0;if((k|0)==1){break Fa}xb(d+296|0);xb(d+248|0);Gb(d+280|0);xb(h);xb(e);break ta}f=N()|0;break Ba}f=N()|0;break Ba}f=N()|0;break Ca}f=N()|0;break Da}f=N()|0;break Ea}f=N()|0;xb(d+296|0)}xb(d+248|0)}Gb(d+280|0)}xb(h)}xb(e);break j}x[114414]=0;O(304,b|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break l}}e=0}h=x[b+8>>2];x[114414]=0;x[d+312>>2]=h;h=O(624,d+412|0,d+312|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break qa}x[d+412>>2]=x[h>>2];B=(e|0)!=0}f=f+1|0;if(f>>>0<z[a+480190>>1]){continue}break}}w[d+328>>1]=1;e=z[a+480190>>1];x[114414]=0;w[d+312>>1]=e;e=O(402,d+328|0,d+312|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){w[a+480190>>1]=z[e>>1];Ka:{La:{if(!(g&1)|(y[d+632|0]|y[d+633|0]<<8)!=516|(y[d+638|0]|y[d+639|0]<<8|(y[d+634|0]|y[d+635|0]<<8)!=512)){break La}if(y[d+652|0]|y[d+653|0]<<8|(y[d+654|0]<<16|y[d+655|0]<<24)|((y[d+636|0]|y[d+637|0]<<8)&65527)!=21|(y[d+640|0]!=128|y[d+641|0]!=48)){break La}if(y[d+645|0]|y[d+644|0]!=128|(y[d+646|0]|y[d+647|0]<<8)){break La}g=d+720|0;e=d+656|0;f=1;while(1){f=(y[e|0]&127)==32&f;e=e+1|0;if((g|0)!=(e|0)){continue}break}e=d+784|0;while(1){f=y[g|0]==64&f;g=g+1|0;if((e|0)!=(g|0)){continue}break}g=20;while(1){f=!y[(d+g|0)+596|0]&f;g=g+1|0;if(g>>>0<26){continue}break}if(!f){break La}x[114414]=0;e=O(2,d+312|0,5841)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ka}Db(i,e);xb(e)}x[a+480260>>2]=0;x[a+480264>>2]=2147483647;C=d,E=Lb(l),w[C+328>>1]=E;e=x[a+8>>2];x[114414]=0;e=O(433,d+328|0,e+10|0)|0;f=x[114414];x[114414]=0;Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((f|0)!=1){e=z[e>>1];w[d+246>>1]=e;if((Lb(l)|0)!=(e|0)){x[114414]=0;P(465,d+328|0,12072);e=x[114414];x[114414]=0;if((e|0)==1){break Ua}e=Lb(l);x[114414]=0;x[d+280>>2]=e;X(625,d+232|0,d+328|0,d+280|0,d+246|0);e=x[114414];x[114414]=0;if((e|0)==1){break Ta}x[114414]=0;e=O(626,d+296|0,d+232|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Sa}x[114414]=0;P(601,a|0,e|0);f=x[114414];x[114414]=0;if((f|0)==1){break Ra}xb(e);xb(d+232|0);Gb(d+328|0)}if(c&1){break Oa}w[d+246>>1]=0;break Na}f=N()|0;break j}f=N()|0;break j}f=N()|0;break Pa}f=N()|0;break Qa}f=N()|0;xb(e)}xb(d+232|0)}Gb(d+328|0);break j}if(!z[d+246>>1]){break Na}e=0;while(1){c=Pb(l,e);Va:{if(!(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))){break Va}c=Pb(l,e);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[114414]=0;c=O(224,b|0,c|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ma}if(!c){break Va}x[114414]=0;c=R(321,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break m}x[114414]=0;h=R(321,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break n}if((h-1025&65535)>>>0<64512){break Va}x[114414]=0;f=O(304,b|0,4)|0;g=x[114414];x[114414]=0;if((g|0)==1){break n}if(!f){break Va}x[114414]=0;T(307,d+328|0,b|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break o}c=0;f=z[a+480188>>1];x[114414]=0;g=O(627,d+280|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break q}while(1){Wa:{x[114414]=0;f=O(226,d+328|0,1)|0;j=x[114414];x[114414]=0;Xa:{Ya:{if((j|0)!=1){if(!f){break Wa}x[114414]=0;f=R(403,d+328|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break r}j=f<<24>>24;if(j){break Ya}c=c+1|0;break Xa}break r}Za:{f=j&127;k=f?f-1|0:0;f=k&65535;if(wc(g)>>>0>f>>>0){break Za}x[114414]=0;v[d+248|0]=0;T(628,g|0,f+1|0,d+248|0);q=x[114414];x[114414]=0;if((q|0)!=1){break Za}break r}if((j|0)<0){x[114414]=0;j=R(403,d+328|0)|0;q=x[114414];x[114414]=0;if((q|0)==1){break r}C=Bc(g,f),E=j,v[C|0]=E}if(!(!(y[Bc(g,f)|0]&15)|f>>>0<z[a+480188>>1])){w[a+480188>>1]=k+1}if(v[Bc(g,f)|0]&1){x[114414]=0;O(304,d+328|0,1)|0;j=x[114414];x[114414]=0;if((j|0)==1){break r}}if(y[Bc(g,f)|0]&2){x[114414]=0;O(304,d+328|0,1)|0;j=x[114414];x[114414]=0;if((j|0)==1){break r}}if(y[Bc(g,f)|0]&4){x[114414]=0;O(304,d+328|0,1)|0;j=x[114414];x[114414]=0;if((j|0)==1){break r}}if(!(y[Bc(g,f)|0]&8)){break Xa}x[114414]=0;O(304,d+328|0,2)|0;f=x[114414];x[114414]=0;if((f|0)==1){break r}}if(c>>>0<h>>>0){continue}}break}c=x[b+8>>2];x[114414]=0;x[d+248>>2]=c;c=O(624,d+412|0,d+248|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break r}x[d+412>>2]=x[c>>2];$d(g);Ab(d+328|0)}e=e+1|0;if(e>>>0<z[d+246>>1]){continue}break}}_a:{$a:{c=x[d+412>>2];if(!c){break $a}x[114414]=0;O(224,b|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break s}if(!B){break $a}while(1){ab:{x[114414]=0;c=O(226,b|0,4)|0;e=x[114414];x[114414]=0;if((e|0)==1){break ab}if(!c){break $a}x[114414]=0;c=O(595,b|0,9630)|0;e=x[114414];x[114414]=0;if((e|0)==1){break ab}bb:{if(!c){x[114414]=0;c=O(595,b|0,9635)|0;e=x[114414];x[114414]=0;if((e|0)==1){break ab}if(!c){break bb}}x[114414]=0;c=R(391,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break _a}ng(b,8);if(c&-2139062144){break bb}if(c&1616928864){break $a}}x[114414]=0;c=R(321,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break ab}x[114414]=0;O(304,b|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){continue}}break}f=N()|0;break j}x[114414]=0;c=O(629,a|0,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break s}c=c|y[d+591|0];v[d+591|0]=c;if(!(!(c&255)|u)){ju(a+1074312|0);x[a+1074372>>2]=0}x[114414]=0;X(630,a|0,b|0,0,d+591|0);c=x[114414];x[114414]=0;if((c|0)==1){break s}x[114414]=0;k=a+484344|0;P(362,k|0,z[d+246>>1]);c=x[114414];x[114414]=0;if((c|0)==1){break s}w[d+152>>1]=0;if(!z[d+246>>1]){break T}f=0;while(1){cb:{db:{c=Pb(l,f&65535);eb:{if(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)){c=Pb(l,z[d+152>>1]);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[114414]=0;c=O(224,b|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break eb}if(c){break db}}x[114414]=0;c=U(363,k|0,z[d+152>>1],64)|0;e=x[114414];x[114414]=0;if((e|0)==1){break eb}if(!c){x[114414]=0;P(465,d+328|0,11513);c=x[114414];x[114414]=0;fb:{gb:{hb:{ib:{jb:{if((c|0)!=1){x[114414]=0;T(631,d+216|0,d+328|0,d+152|0);c=x[114414];x[114414]=0;if((c|0)==1){break jb}x[114414]=0;c=O(626,d+248|0,d+216|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break ib}x[114414]=0;P(601,a|0,c|0);e=x[114414];x[114414]=0;if((e|0)==1){break hb}xb(c);xb(d+216|0);Gb(d+328|0);break T}f=N()|0;break j}f=N()|0;break fb}f=N()|0;break gb}f=N()|0;xb(c)}xb(d+216|0)}Gb(d+328|0);break j}c=Zb(k,z[d+152>>1]);x[114414]=0;P(632,c|0,t|0);c=x[114414];x[114414]=0;if((c|0)!=1){break cb}}f=N()|0;break j}x[114414]=0;c=R(321,b|0)|0;e=x[114414];x[114414]=0;kb:{lb:{if((e|0)!=1){x[114414]=0;q=R(321,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break lb}x[114414]=0;e=O(304,b|0,4)|0;f=x[114414];x[114414]=0;if((f|0)==1){break lb}if(!e){break cb}x[114414]=0;e=U(363,k|0,z[d+152>>1],q|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break lb}if(e){break kb}break cb}f=N()|0;break j}f=N()|0;break j}x[114414]=0;T(307,d+328|0,b|0,c|0);c=x[114414];x[114414]=0;if((c|0)!=1){c=Zb(k,z[d+152>>1]);x[114414]=0;P(632,c|0,t|0);c=x[114414];x[114414]=0;mb:{if((c|0)!=1){c=z[a+480188>>1];x[114414]=0;j=O(627,d+200|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){c=z[a+480188>>1];e=d+248|0;Zh(e);x[114414]=0;h=U(633,d+184|0,c|0,e|0)|0;c=x[114414];x[114414]=0;nb:{if((c|0)!=1){C=d,E=bc(Zb(k,z[d+152>>1])),x[C+168>>2]=E;n=0;ob:{if(!q){break ob}while(1){x[114414]=0;c=O(226,d+328|0,1)|0;e=x[114414];x[114414]=0;pb:{if((e|0)!=1){qb:{if(!c){break ob}x[114414]=0;c=R(403,d+328|0)|0;e=x[114414];x[114414]=0;rb:{if((e|0)!=1){c=c<<24>>24;if(c){break rb}FS(d+168|0,z[a+480188>>1]);n=n+1|0;break pb}break qb}sb:{e=c&127;g=e?e-1&65535:0;if(wc(j)>>>0>g>>>0){break sb}x[114414]=0;v[d+248|0]=0;e=g+1|0;T(628,j|0,e|0,d+248|0);f=x[114414];x[114414]=0;if((f|0)==1){break qb}f=d+248|0;Zh(f);x[114414]=0;T(634,h|0,e|0,f|0);e=x[114414];x[114414]=0;if((e|0)!=1){break sb}break qb}if((c|0)<0){x[114414]=0;c=R(403,d+328|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break qb}C=Bc(j,g),E=c,v[C|0]=E}e=d+248|0;Zh(e);if(g>>>0<z[a+480188>>1]){e=Qc(d+168|0,g)}if(y[Bc(j,g)|0]&16){C=e,E=y[Qc(h,g)|0],v[C|0]=E}if(y[Bc(j,g)|0]&32){C=e,E=y[Qc(h,g)+1|0],v[C+1|0]=E}if(y[Bc(j,g)|0]&64){C=e,E=y[Qc(h,g)+2|0],v[C+2|0]=E;C=e,E=y[Qc(h,g)+4|0],v[C+4|0]=E}if(v[Bc(j,g)|0]<0){C=e,E=y[Qc(h,g)+3|0],v[C+3|0]=E;C=e,E=y[Qc(h,g)+5|0],v[C+5|0]=E}if(v[Bc(j,g)|0]&1){x[114414]=0;c=R(403,d+328|0)|0;f=x[114414];x[114414]=0;tb:{ub:{if((f|0)!=1){c=c<<24>>24;c=(((c^-1)&128)>>>7|0)+c|0;if(!(x[a+480180>>2]&16777216)){break ub}f=c;break tb}break qb}f=253;if((c-121&255)>>>0<132){break tb}f=(c&255)!=253?c:0}v[e|0]=f;C=Qc(h,g),E=f,v[C|0]=E}if(y[Bc(j,g)|0]&2){x[114414]=0;c=R(403,d+328|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break qb}v[e+1|0]=c;C=Qc(h,g),E=c,v[C+1|0]=E}if(y[Bc(j,g)|0]&4){x[114414]=0;c=R(403,d+328|0)|0;f=x[114414];x[114414]=0;vb:{wb:{if((f|0)!=1){if(c>>>0>64){break wb}v[e+4|0]=c;v[e+2|0]=1;break vb}break qb}if(c<<24>>24<=-64){v[e+2|0]=2;v[e+4|0]=c^128;break vb}if(c>>>0<=74){v[e+2|0]=5;v[e+4|0]=c-65;break vb}if(c>>>0<=84){v[e+2|0]=6;v[e+4|0]=c-75;break vb}if(c>>>0<=94){v[e+2|0]=3;v[e+4|0]=c-85;break vb}if(c>>>0<=104){v[e+2|0]=4;v[e+4|0]=c-95;break vb}if(c>>>0<=114){v[e+2|0]=13;v[e+4|0]=c-105;break vb}if(c>>>0<=124){v[e+2|0]=12;v[e+4|0]=c-115;break vb}f=c+63|0;if((f&255)>>>0<=9){v[e+4|0]=f;v[e+2|0]=11;break vb}f=c+53|0;m=f&255;if(m>>>0<=9){v[e+4|0]=f;v[e+2|0]=8;if(!m|!x[a+1074308>>2]|A[a+1074308>>2]>18285140){break vb}v[e+2|0]=7;break vb}c=c+33|0;if((c&255)>>>0>9){break vb}v[e+4|0]=c;v[e+2|0]=15}c=y[e+2|0];C=Qc(h,g),E=c,v[C+2|0]=E;c=y[e+4|0];C=Qc(h,g),E=c,v[C+4|0]=E}if(!(y[Bc(j,g)|0]&8)){break pb}x[114414]=0;P(428,d+104|0,d+328|0);c=x[114414];x[114414]=0;if((c|0)!=1){xb:{c=ed(d+104|0);v[e+3|0]=y[d+104|0];v[e+5|0]=y[c|0];x[114414]=0;P(635,e|0,1);c=x[114414];x[114414]=0;if((c|0)==1){break xb}c=y[e+3|0];C=Qc(h,g),E=c,v[C+3|0]=E;c=y[e+5|0];C=Qc(h,g),E=c,v[C+5|0]=E;break pb}}}}f=N()|0;bm(h);break nb}if(n>>>0<q>>>0){continue}break}}bm(h);$d(j);Ab(d+328|0);break cb}f=N()|0}$d(j);break mb}f=N()|0;break mb}f=N()|0}Ab(d+328|0);break j}f=N()|0;break j}f=z[d+152>>1]+1|0;w[d+152>>1]=f;if(z[d+246>>1]>(f&65535)>>>0){continue}break}break T}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break i}f=N()|0;break g}f=N()|0;break g}f=N()|0;break g}f=N()|0;break g}f=N()|0;break g}f=N()|0;break g}c=a+1074308|0;yb:{zb:{if(!x[a+1074308>>2]){Ab:{if((y[d+632|0]|y[d+633|0]<<8)==2184){x[c>>2]=18284544;f=18284544;break Ab}f=x[c>>2]}if(!f){break zb}}if(!Wc(i)){break zb}x[114414]=0;e=O(2,d+168|0,13391)|0;f=x[114414];x[114414]=0;Bb:{Cb:{Db:{Eb:{Fb:{Gb:{if((f|0)!=1){x[114414]=0;P(210,d+152|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break Gb}x[114414]=0;T(3,d+328|0,e|0,d+152|0);f=x[114414];x[114414]=0;if((f|0)==1){break Fb}f=d+328|0;Db(i,f);xb(f);xb(d+152|0);xb(e);if(x[d+652>>2]==1414548815|((y[d+632|0]|y[d+633|0]<<8)&61440)!=20480){break Bb}x[114414]=0;c=O(2,d+328|0,12759)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Db}x[114414]=0;O(160,i|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Cb}xb(c);break yb}f=N()|0;break j}f=N()|0;break Eb}f=N()|0;xb(d+152|0)}xb(e);break j}f=N()|0;break j}f=N()|0;xb(c);break j}if(!ED(c)){break yb}x[114414]=0;c=O(2,d+328|0,12995)|0;e=x[114414];x[114414]=0;Hb:{if((e|0)!=1){x[114414]=0;O(160,i|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Hb}xb(c);break yb}f=N()|0;break j}f=N()|0;xb(c);break j}Ib:{Jb:{Kb:{Lb:{switch((y[d+632|0]|y[d+633|0]<<8)>>>12|0){case 0:if(u){x[114414]=0;c=O(2,d+328|0,4545)|0;e=x[114414];x[114414]=0;if((e|0)!=1){Db(i,c);xb(c);break yb}f=N()|0;break j}Mb:{if((y[d+632|0]|y[d+633|0]<<8)!=532|(y[d+634|0]|y[d+635|0]<<8)!=512|(y[d+638|0]|y[d+639|0]<<8|(y[d+636|0]|y[d+637|0]<<8)!=9)){break Mb}if(y[d+623|0]|y[d+622|0]|(y[d+626|0]|y[d+627|0]<<8|((y[d+630|0]|y[d+631|0]<<8)+1|0)!=(y[d+624|0]|y[d+625|0]<<8))){break Mb}if(y[d+640|0]!=128|y[d+641|0]!=100|(y[d+642|0]!=1|y[d+644|0]!=128)){break Mb}if(y[d+645|0]|(y[d+646|0]|y[d+647|0]<<8)|(y[d+648|0]|y[d+649|0]<<8|(y[d+650|0]<<16|y[d+651|0]<<24)|(y[d+652|0]|y[d+653|0]<<8|(y[d+654|0]<<16|y[d+655|0]<<24)))){break Mb}x[114414]=0;c=O(2,d+328|0,5822)|0;e=x[114414];x[114414]=0;if((e|0)!=1){Db(i,c);xb(c);break yb}f=N()|0;break j}Nb:{if((y[d+632|0]|y[d+633|0]<<8)!=532|(y[d+634|0]|y[d+635|0]<<8)!=512|(y[d+623|0]|y[d+622|0])){break Nb}if(y[d+652|0]|y[d+653|0]<<8|(y[d+654|0]<<16|y[d+655|0]<<24)){break Nb}x[c>>2]=16777381;x[114414]=0;c=O(2,d+328|0,10423)|0;e=x[114414];x[114414]=0;if((e|0)!=1){Db(i,c);xb(c);v[d+591|0]=1;break yb}f=N()|0;break j}if(!((y[d+632|0]|y[d+633|0]<<8)!=532|(y[d+634|0]|y[d+635|0]<<8)!=532|x[d+652>>2]!=1229080643)){x[114414]=0;c=O(2,d+328|0,4597)|0;e=x[114414];x[114414]=0;if((e|0)!=1){Db(i,c);xb(c);break Ib}f=N()|0;break j}Ob:{if((y[d+632|0]|y[d+633|0]<<8)!=532|(y[d+634|0]|y[d+635|0]<<8)!=532|(y[d+645|0]|(y[d+638|0]|y[d+639|0]<<8)>>>0>1)){break Ob}if(!z[a+480190>>1]|(y[d+652|0]|y[d+653|0]<<8|(y[d+654|0]<<16|y[d+655|0]<<24)|((y[d+636|0]|y[d+637|0]<<8)&4294)!=4)){break Ob}x[114414]=0;c=O(118,d+168|0,9327)|0;e=x[114414];x[114414]=0;Pb:{Qb:{if((e|0)!=1){x[114414]=0;e=O(636,a+484527|0,c|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Qb}xb(c);if(!e){break Ob}x[114414]=0;c=O(2,d+328|0,4623)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Pb}Db(i,c);xb(c);break yb}f=N()|0;break j}f=N()|0;xb(c);break j}f=N()|0;break j}Rb:{if(y[d+632|0]|y[d+633|0]<<8){break Rb}if(!Wc(i)){break Rb}x[114414]=0;c=O(2,d+328|0,5662)|0;e=x[114414];x[114414]=0;if((e|0)!=1){Db(i,c);xb(c);break yb}f=N()|0;break j}if((y[d+634|0]|y[d+635|0]<<8)>>>0>767){break yb}if(!Wc(i)){break yb}Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{if((y[d+634|0]|y[d+635|0]<<8)>>>0>=533){x[114414]=0;c=O(2,d+152|0,10456)|0;e=x[114414];x[114414]=0;if((e|0)!=1){Db(i,c);break Yb}f=N()|0;break j}if((y[d+632|0]|y[d+633|0]<<8)>>>0>=533){x[114414]=0;c=O(2,d+136|0,11361)|0;e=x[114414];x[114414]=0;Zb:{_b:{$b:{if((e|0)!=1){x[114414]=0;P(187,d+152|0,c|0);e=x[114414];x[114414]=0;if((e|0)==1){break $b}e=y[d+632|0]|y[d+633|0]<<8;x[114414]=0;x[d+104>>2]=e-532;T(213,d+328|0,d+152|0,d+104|0);e=x[114414];x[114414]=0;if((e|0)==1){break _b}e=d+328|0;Db(i,e);xb(e);Gb(d+152|0);break Yb}f=N()|0;break j}f=N()|0;break Zb}f=N()|0;Gb(d+152|0)}xb(c);break j}x[114414]=0;c=O(2,d+120|0,11020)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Xb}x[114414]=0;P(187,d+152|0,c|0);e=x[114414];x[114414]=0;if((e|0)==1){break Wb}x[d+56>>2]=y[d+633|0]&15;e=y[d+632|0];x[114414]=0;x[d+24>>2]=e;P(637,d+104|0,d+24|0);e=x[114414];x[114414]=0;if((e|0)==1){break Vb}x[114414]=0;X(622,d+328|0,d+152|0,d+56|0,d+104|0);e=x[114414];x[114414]=0;if((e|0)==1){break Ub}e=d+328|0;Db(i,e);xb(e);xb(d+104|0);Gb(d+152|0)}xb(c);c=a+1304500|0;if(!od(c)|!(y[d+652|0]|y[d+653|0]<<8|(y[d+654|0]<<16|y[d+655|0]<<24))){break yb}e=y[d+632|0]|y[d+633|0]<<8;f=y[d+652|0]|y[d+653|0]<<8|(y[d+654|0]<<16|y[d+655|0]<<24);x[114414]=0;e=O(638,e|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Jb}f=tq(d+328|0);x[f+44>>2]=e;x[114414]=0;P(639,c|0,f|0);c=x[114414];x[114414]=0;if((c|0)!=1){break yb}f=N()|0;break j}f=N()|0;break j}f=N()|0;break Sb}f=N()|0;break Tb}f=N()|0;xb(d+104|0)}Gb(d+152|0)}xb(c);break j;case 1:c=y[d+632|0]|y[d+633|0]<<8;e=y[d+652|0]|y[d+653|0]<<8|(y[d+654|0]<<16|y[d+655|0]<<24);x[114414]=0;T(640,d+328|0,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)!=1){c=d+328|0;Db(i,c);xb(c);if((y[d+632|0]|y[d+633|0]<<8)>>>0>=6092){break Kb}x[114414]=0;O(435,a+1074312|0,7)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break Kb}break s}f=N()|0;break j;case 4:x[114414]=0;c=O(2,d+88|0,11084)|0;e=x[114414];x[114414]=0;ac:{bc:{cc:{dc:{ec:{if((e|0)!=1){x[114414]=0;P(187,d+168|0,c|0);e=x[114414];x[114414]=0;if((e|0)==1){break ec}x[d+104>>2]=y[d+633|0]&15;e=y[d+632|0];x[114414]=0;x[d+56>>2]=e;P(637,d+152|0,d+56|0);e=x[114414];x[114414]=0;if((e|0)==1){break dc}x[114414]=0;X(622,d+328|0,d+168|0,d+104|0,d+152|0);e=x[114414];x[114414]=0;if((e|0)==1){break cc}e=d+328|0;Db(i,e);xb(e);xb(d+152|0);Gb(d+168|0);xb(c);break yb}f=N()|0;break j}f=N()|0;break ac}f=N()|0;break bc}f=N()|0;xb(d+152|0)}Gb(d+168|0)}xb(c);break j;case 6:x[114414]=0;c=O(2,d+328|0,4545)|0;e=x[114414];x[114414]=0;if((e|0)!=1){Db(i,c);xb(c);break yb}f=N()|0;break j;case 7:if(!((y[d+632|0]|y[d+633|0]<<8)!=32767|(y[d+634|0]|y[d+635|0]<<8)!=533)){x[114414]=0;c=O(2,d+328|0,1549)|0;e=x[114414];x[114414]=0;if((e|0)!=1){Db(i,c);xb(c);break yb}f=N()|0;break j}x[114414]=0;c=O(2,d+72|0,10572)|0;e=x[114414];x[114414]=0;fc:{gc:{hc:{if((e|0)!=1){x[114414]=0;P(187,d+168|0,c|0);e=x[114414];x[114414]=0;if((e|0)==1){break hc}x[d+152>>2]=y[d+633|0]&15;x[d+104>>2]=(y[d+632|0]|y[d+633|0]<<8)>>>4&15;e=y[d+632|0]|y[d+633|0]<<8;x[114414]=0;x[d+56>>2]=e&15;ba(207,d+328|0,d+168|0,d+152|0,d+104|0,d+56|0);e=x[114414];x[114414]=0;if((e|0)==1){break gc}e=d+328|0;Db(i,e);xb(e);Gb(d+168|0);xb(c);break yb}f=N()|0;break j}f=N()|0;break fc}f=N()|0;Gb(d+168|0)}xb(c);break j;case 13:break Lb;default:break yb}}x[114414]=0;c=O(2,d+328|0,2516)|0;e=x[114414];x[114414]=0;if((e|0)!=1){Db(i,c);xb(c);break yb}f=N()|0;break j}c=y[d+632|0]|y[d+633|0]<<8;if((DS(4096)|0)>(c|0)){break Ib}break yb}f=N()|0;break j}x[114414]=0;O(435,a+1074312|0,38)|0;c=x[114414];x[114414]=0;if((c|0)==1){break s}}ic:{if(x[a+480180>>2]!=16777216|(y[d+632|0]|y[d+633|0]<<8)>>>0<2186){break ic}x[114414]=0;c=O(224,b|0,s|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break s}if(!c){break ic}c=y[d+632|0]|y[d+633|0]<<8;x[114414]=0;T(641,a|0,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)==1){break s}}c=x[a+480180>>2];jc:{if((c|0)==16777216){x[114414]=0;O(2,d+104|0,9613)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break jc}f=N()|0;break j}x[114414]=0;b=O(2,d+40|0,11020)|0;e=x[114414];x[114414]=0;if((e|0)==1){break z}x[114414]=0;P(187,d+56|0,b|0);e=x[114414];x[114414]=0;if((e|0)==1){break y}x[d+36>>2]=y[d+635|0];e=y[d+634|0];x[114414]=0;x[d+20>>2]=e;P(637,d+24|0,d+20|0);e=x[114414];x[114414]=0;if((e|0)==1){break x}x[114414]=0;X(622,d+104|0,d+56|0,d+36|0,d+24|0);e=x[114414];x[114414]=0;if((e|0)==1){break w}}b=d+104|0;Db(a+1304436|0,b);xb(b);if((c|0)!=16777216){xb(d+24|0);Gb(d+56|0);xb(d+40|0)}b=x[a+480180>>2];x[114414]=0;b=O(2,d+104|0,((b|0)==16777216?6105:2520)|0)|0;c=x[114414];x[114414]=0;f=1;if((c|0)==1){break t}Db(a+1304448|0,b);xb(b);Db(a+1304460|0,i);x[a+1304496>>2]=x[a+1074308>>2]?7:4;Ab(d+416|0);Ab(t)}Ui(l);Ui(o);Ui(r);break d}f=N()|0;break j}f=N()|0;break u}f=N()|0;break v}f=N()|0;xb(d+24|0)}Gb(d+56|0)}xb(b);break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;$d(g);break p}f=N()|0}Ab(d+328|0);break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0;break j}f=N()|0}Ab(d+416|0)}Ab(t);break g}f=N()|0}Ui(l);Ui(o);Ui(r);break a}f=N()|0;break a}f=N()|0;break a}xb(i)}hb=d+784|0;return f|0}f=N()|0}xb(i);Q(f|0);p()}function Oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=hb-1648|0;hb=e;Lc(b);a:{b:{if(!If(b,e+1640|0)){break b}if(!eR(e+1640|0)){break b}if(!c){g=1;break b}d=y[e+1640|3];v[e+1639|0]=d;x[e+1632>>2]=-1;x[e+1628>>2]=1048576;if(d>>>0>=5){d=Gf(b);x[e+1632>>2]=d;if(!Qb(b,d)){break b}x[e+240>>2]=134217727;L=e,M=x[Mb(e+240|0,e+1632|0)>>2]<<5,x[L+1628>>2]=M}G=Qq(e+1616|0);d=e+1640|4;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[114414]=0;x[e+240>>2]=f;f=O(297,e+1628|0,e+240|0)|0;g=x[114414];x[114414]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((g|0)==1){break x}f=x[f>>2];x[114414]=0;P(810,G|0,f|0);f=x[114414];x[114414]=0;if((f|0)==1){break x}d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);g=0;x[114414]=0;d=U(811,b|0,G|0,d|0)|0;f=x[114414];x[114414]=0;y:{if((f|0)==1){break y}if(!d){break t}if(y[e+1639|0]>=5){x[114414]=0;O(224,b|0,x[e+1632>>2]+12|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break y}}x[114414]=0;P(397,a|0,0);d=x[114414];x[114414]=0;if((d|0)==1){break y}x[114414]=0;W(432,a|0);d=x[114414];x[114414]=0;if((d|0)==1){break y}x[114414]=0;P(812,e+1592|0,G|0);d=x[114414];x[114414]=0;z:{A:{B:{C:{if((d|0)==1){break C}x[114414]=0;l=U(813,e+1600|0,e+1592|0,0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break C}x[114414]=0;U(564,l|0,a+1304400|0,-1)|0;d=x[114414];x[114414]=0;if((d|0)==1){break B}x[114414]=0;U(564,l|0,a+1304424|0,-1)|0;d=x[114414];x[114414]=0;if((d|0)==1){break B}x[114414]=0;d=O(814,l|0,e+1168|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break w}if(!d|!y[e+1168|0]|v[e+1168|0]<0){break u}d=e+1177|0;if((y[d|0]|y[d+1|0]<<8)>>>0>255){break u}f=e+1179|0;if((y[f|0]|y[f+1|0]<<8)>>>0>3999){break u}g=e+1168|0;w[a+480188>>1]=y[g|0];j=a+484360|0;g=g|3;Se(Vb(j),y[g|0]|y[g+1|0]<<8);w[a+480192>>1]=y[d|0]|y[d+1|0]<<8;w[a+480190>>1]=y[f|0]|y[f+1|0]<<8;d=e+1181|0;if(y[d|0]){break A}d=6;break z}d=N()|0;break c}d=N()|0;break d}d=y[d|0]}x[a+480196>>2]=d;d=e+1182|0;if(y[d|0]){d=y[d|0]}else{d=125}x[a+480204>>2]=D(d,1e4);r=e+1183|0;d=32;D:{if(v[r+1|0]&1){break D}d=2;if(y[r|0]&2){break D}d=1;if(y[r|0]&128){break D}d=y[r|0]&8?16:4}x[114414]=0;P(598,a|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break w}x[a+480208>>2]=x[a+480208>>2]|16777216;if(v[r|0]&1){x[a+480208>>2]=x[a+480208>>2]|16}if(!(!(y[r|0]&16)|x[a+480180>>2]!=2)){x[a+480208>>2]=x[a+480208>>2]|65536}if(!(!(y[r|0]&4)|x[a+480180>>2]!=2)){x[a+480208>>2]=x[a+480208>>2]|2}if(!(y[r+1|0]&8|x[a+480180>>2]!=32)){x[a+480208>>2]=x[a+480208>>2]|4}if(!(y[r+1|0]&4|x[a+480180>>2]!=32)){x[a+480208>>2]=x[a+480208>>2]|8}if(y[r+2|0]&32){x[a+480208>>2]=x[a+480208>>2]|32768}if(y[r+2|0]&8){x[114414]=0;U(434,a+1074312|0,5,1)|0;d=x[114414];x[114414]=0;if((d|0)==1){break w}}E:{d=x[a+480180>>2];F:{if((d|0)!=2){if((d|0)!=32){break F}d=y[e+1187|0];x[114414]=0;v[e+240|0]=d;v[e+168|0]=128;d=O(409,e+240|0,e+168|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){x[a+480200>>2]=y[d|0]<<1;break F}d=N()|0;break d}d=y[e+1187|0];x[114414]=0;v[e+240|0]=d;v[e+168|0]=64;d=O(409,e+240|0,e+168|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break E}x[a+480200>>2]=y[d|0]<<2}I=a+480188|0;f=e+1189|0;d=v[f|0];if(v[f|0]<0){d=d+52|0}else{H=gs(+(d|0)*.15500000000000003);G:{if(H<4294967296&H>=0){d=~~H>>>0;break G}d=0}d=d+51|0}x[a+480228>>2]=d;x[114414]=0;w[e+240>>1]=64;d=O(433,I|0,e+240|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){H:{f=z[d>>1];if(f){g=0;while(1){d=x[a+480180>>2];if((d|0)==32){d=y[(e+g|0)+1190|0];x[114414]=0;v[e+240|0]=d;v[e+168|0]=64;d=O(409,e+240|0,e+168|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break H}w[((g<<5)+a|0)+480286>>1]=y[d|0];d=x[a+480180>>2]}I:{if((d|0)==4){break I}d=(e+g|0)+1254|0;if(y[d|0]==127){x[((g<<5)+a|0)+480280>>2]=256;break I}if(y[d|0]==255){w[((g<<5)+a|0)+480284>>1]=256;break I}w[((g<<5)+a|0)+480284>>1]=y[d|0]}g=g+1|0;if((f|0)!=(g|0)){continue}break}}g=0;h=0;while(1){g=y[(e+h|0)+1318|0]!=0|g;h=h+1|0;if((h|0)!=16){continue}break}while(1){g=y[((i<<1)+e|0)+1335|0]!=0|g;i=i+1|0;if((i|0)!=128){continue}break}if(g&1){g=0;while(1){J:{d=(e+g|0)+1318|0;if(y[d|0]){x[114414]=0;P(465,e+168|0,1425);f=x[114414];x[114414]=0;K:{L:{M:{N:{O:{if((f|0)!=1){d=y[d|0];x[114414]=0;x[e+192>>2]=d-1;P(815,e+1120|0,e+192|0);d=x[114414];x[114414]=0;if((d|0)==1){break O}x[114414]=0;T(467,e+240|0,e+168|0,e+1120|0);d=x[114414];x[114414]=0;if((d|0)==1){break N}x[114414]=0;P(468,e+1104|0,((g<<5)+a|0)+901692|0);d=x[114414];x[114414]=0;if((d|0)==1){break M}x[114414]=0;O(426,e+1104|0,e+240|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break M}xb(e+240|0);xb(e+1120|0);Gb(e+168|0);break J}d=N()|0;break d}d=N()|0;break K}d=N()|0;break L}d=N()|0;xb(e+240|0)}xb(e+1120|0)}Gb(e+168|0);break d}x[114414]=0;f=O(118,e+1152|0,17386)|0;d=x[114414];x[114414]=0;P:{if((d|0)!=1){x[114414]=0;P(468,e+240|0,((g<<5)+a|0)+901692|0);d=x[114414];x[114414]=0;if((d|0)==1){break P}x[114414]=0;O(426,e+240|0,f|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break P}xb(f);break J}d=N()|0;break d}d=N()|0;xb(f);break d}g=g+1|0;if((g|0)!=16){continue}break}g=0;while(1){Q:{d=(e+1168|0)+(g<<1)|0;if(y[d+167|0]){x[114414]=0;P(465,e+168|0,10850);f=x[114414];x[114414]=0;R:{S:{T:{U:{V:{W:{X:{if((f|0)!=1){f=y[d+167|0];x[114414]=0;x[e+144>>2]=f-1;P(815,e+1120|0,e+144|0);f=x[114414];x[114414]=0;if((f|0)==1){break X}d=y[d+166|0];x[114414]=0;v[e+1088|0]=d;P(816,e+1104|0,e+1088|0);d=x[114414];x[114414]=0;if((d|0)==1){break W}x[114414]=0;X(817,e+240|0,e+168|0,e+1120|0,e+1104|0);d=x[114414];x[114414]=0;if((d|0)==1){break V}x[114414]=0;P(468,e+192|0,((g<<5)+a|0)+902204|0);d=x[114414];x[114414]=0;if((d|0)==1){break U}x[114414]=0;O(426,e+192|0,e+240|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break U}xb(e+240|0);xb(e+1104|0);xb(e+1120|0);Gb(e+168|0);break Q}d=N()|0;break d}d=N()|0;break R}d=N()|0;break S}d=N()|0;break T}d=N()|0;xb(e+240|0)}xb(e+1104|0)}xb(e+1120|0)}Gb(e+168|0);break d}x[114414]=0;f=O(118,e+1136|0,17386)|0;d=x[114414];x[114414]=0;Y:{if((d|0)!=1){x[114414]=0;P(468,e+240|0,((g<<5)+a|0)+902204|0);d=x[114414];x[114414]=0;if((d|0)==1){break Y}x[114414]=0;O(426,e+240|0,f|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break Y}xb(f);break Q}d=N()|0;break d}d=N()|0;xb(f);break d}g=g+1|0;if((g|0)!=128){continue}break}}d=Vb(j);f=e+1168|1;f=y[f|0]|y[f+1|0]<<8;x[114414]=0;aa(548,d|0,l|0,f|0,255,254)|0;d=x[114414];x[114414]=0;Z:{_:{$:{aa:{ba:{ca:{if((d|0)!=1){d=e+1168|0;n=d|5;f=y[n|0]|y[n+1|0]<<8;d=y[d|0];x[114414]=0;T(307,e+1120|0,l|0,D(d,f)<<1);d=x[114414];x[114414]=0;if((d|0)==1){break ca}d=y[n|0]|y[n+1|0]<<8;x[114414]=0;T(307,e+1104|0,l|0,d<<1);d=x[114414];x[114414]=0;if((d|0)==1){break ba}d=e+1168|7;d=y[d|0]|y[d+1|0]<<8;x[114414]=0;E=O(360,e+1088|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break aa}L=e,M=bc(E),x[L+168>>2]=M;L=e,M=dc(E),x[L+192>>2]=M;if(Hb(e+168|0,e+192|0)){while(1){d=x[e+168>>2];x[114414]=0;f=R(391,l|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break $}x[114414]=0;T(307,e+240|0,l|0,f|0);f=x[114414];x[114414]=0;if((f|0)==1){break _}f=d;d=e+240|0;Ud(f,d);Ab(d);d=e+168|0;of(d);if(Hb(d,e+192|0)){continue}break}}d=x[a+480180>>2];j=1;o=c&1;if(!o){break Z}f=y[n|0]|y[n+1|0]<<8;x[114414]=0;P(362,a+484344|0,f|0);f=x[114414];x[114414]=0;if((f|0)!=1){break Z}d=N()|0;break g}d=N()|0;break d}d=N()|0;break d}d=N()|0;break e}d=N()|0;break f}d=N()|0;break g}d=N()|0;break g}da:{ea:{fa:{ga:{ha:{ia:{if(y[n|0]|y[n+1|0]<<8){C=(d|0)==16?14:(d|0)==32?1:13;t=a+484344|0;while(1){x[114414]=0;d=R(321,e+1104|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break da}x[e+168>>2]=d;ja:{if(!o){break ja}x[114414]=0;d=U(363,t|0,s&65535,d|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break da}if(!d){break ja}q=0;if(!y[e+1168|0]){break ja}while(1){x[114414]=0;d=R(321,e+1120|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break ea}ka:{if(rd(E)>>>0<=d>>>0){break ka}k=vc(E,d);Lc(k);d=Zb(t,s);x[114414]=0;g=U(427,d|0,0,q&65535)|0;d=x[114414];x[114414]=0;if((d|0)==1){break h}f=0;if(!x[e+168>>2]){break ka}while(1){x[114414]=0;m=R(403,k|0)|0;d=x[114414];x[114414]=0;la:{ma:{if((d|0)!=1){if(!m){break ka}Zh(e+240|0);h=0;u=m&15;if(u){break ma}break la}d=N()|0;break g}while(1){na:{x[114414]=0;O(818,k|0,e+192|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break na}oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{d=y[e+192|0];switch(d-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break sa;case 33:break wa;case 30:case 31:break xa;case 29:break ya;case 28:break za;case 26:break Aa;case 19:case 20:break Ba;case 17:break Ca;case 15:break Da;case 14:break Ea;case 10:break Fa;case 6:break Ga;case 5:break Ha;case 1:break Ia;case 0:break Ja;default:break Ka}}switch(d-48|0){case 4:break ta;case 1:case 2:break ua;case 0:break va;default:break sa}}d=y[e+193|0];La:{if(d>>>0<=119){v[e+240|0]=d+C;break La}Ma:{switch(d-254|0){case 1:v[e+240|0]=255;break La;case 0:v[e+240|0]=254;break La;default:break Ma}}v[e+240|0]=253}x[114414]=0;d=R(588,e+240|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break na}j=d&j;break oa}v[e+241|0]=y[e+193|0]+1;break oa}if(y[e+242|0]){d=y[e+193|0];break pa}d=y[e+193|0];i=x[a+480180>>2];if((i|0)!=32){break qa}i=0;while(1){if(y[i+25920|0]==(d&255)){v[e+244|0]=i;v[e+242|0]=11;break oa}i=i+1|0;if((i|0)!=10){continue}break}break pa}d=y[e+193|0];if(!(y[e+242|0]|d>>>0>9|x[a+480180>>2]!=32)){v[e+244|0]=d;v[e+242|0]=8;break oa}v[e+245|0]=d;v[e+243|0]=5;break oa}d=y[e+193|0];if(y[e+242|0]){break ra}i=x[a+480180>>2];B=(i|0)!=32;if(!(B|(d|0)!=255)){v[e+244|0]=64;v[e+242|0]=2;break oa}Na:{if(!B){if(!(d&3)){break Na}break ra}if(d&15|(i|0)!=4){break ra}}v[e+242|0]=2;v[e+244|0]=(d&252)>>>2;break oa}d=y[e+193|0];if(!(y[e+242|0]|d>>>0>64|x[a+480180>>2]==1)){v[e+244|0]=d;v[e+242|0]=1;break oa}v[e+245|0]=d;v[e+243|0]=13;break oa}v[e+243|0]=14;d=y[e+193|0];v[e+245|0]=d;if(x[a+480180>>2]==32){break oa}v[e+245|0]=D((d&240)>>>4|0,10)+(d&15);break oa}d=y[e+193|0];v[e+245|0]=d;if(d>>>0<=31){v[e+243|0]=16;break oa}v[e+243|0]=17;break oa}i=y[e+193|0];if(i>>>0>=16){v[e+244|0]=i>>>4;v[e+242|0]=(d|0)==20?3:5;break oa}v[e+244|0]=i;v[e+242|0]=(d|0)==20?4:6;break oa}d=y[e+193|0];if(d>>>0>=16){v[e+242|0]=10;v[e+244|0]=d>>>4;break oa}v[e+244|0]=d;v[e+242|0]=9;break oa}v[e+243|0]=28;v[e+245|0]=y[e+193|0]|16;break oa}v[e+243|0]=28;v[e+245|0]=y[e+193|0]|32;break oa}v[e+244|0]=y[e+193|0];v[e+242|0]=y[d+23872|0];break oa}v[e+245|0]=y[e+193|0];d=y[e+243|0];v[e+243|0]=(d|0)==4?6:(d|0)==5?7:11;break oa}d=y[e+193|0];v[e+244|0]=(d>>>0)%10;if(d>>>0<=9){v[e+242|0]=5;break oa}if(d>>>0<=19){v[e+242|0]=6;break oa}if(d>>>0<=29){v[e+242|0]=3;break oa}if(d>>>0>39){break oa}v[e+242|0]=4;break oa}v[e+244|0]=y[e+193|0];v[e+242|0]=y[d+23872|0];break oa}d=y[e+193|0]+33|0;if((d&255)>>>0>9){break oa}v[e+244|0]=d;v[e+242|0]=15;break oa}if(d>>>0>55){break oa}v[e+245|0]=y[e+193|0];v[e+243|0]=y[d+23872|0];break oa}v[e+245|0]=d;v[e+243|0]=9;break oa}if(d&15|(i|0)!=4){break pa}v[e+242|0]=11;v[e+244|0]=(d&240)>>>4;break oa}v[e+245|0]=d;v[e+243|0]=4}h=h+1|0;if(u>>>0>(h&255)>>>0){continue}break la}break}d=N()|0;break g}x[114414]=0;x[e+192>>2]=(m>>>4|0)+f;d=O(297,e+192|0,e+168|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break ia}d=x[d>>2];if(d>>>0>f>>>0){while(1){h=x[e+240>>2];v[g|0]=h;v[g+1|0]=h>>>8;v[g+2|0]=h>>>16;v[g+3|0]=h>>>24;h=z[e+244>>1];v[g+4|0]=h;v[g+5|0]=h>>>8;g=D(y[e+1168|0],6)+g|0;f=f+1|0;if((d|0)!=(f|0)){continue}break}f=d}if(A[e+168>>2]>f>>>0){continue}break}}q=q+1|0;if(y[e+1168|0]>(q&65535)>>>0){continue}break}}s=s+1|0;if(s>>>0<(y[n|0]|y[n+1|0]<<8)>>>0){continue}break}}if(!(!(z[a+480188>>1]==4&j)|x[a+480180>>2]!=1)){x[a+480208>>2]=x[a+480208>>2]|8454144}if(x[a+480180>>2]!=4){break ha}h=0;break ga}d=N()|0;break g}h=!((y[r|0]|y[r+1|0]<<8|(y[r+2|0]<<16|y[r+3|0]<<24))&512);d=0;if(x[a+480180>>2]!=4){break fa}}d=z[a+480192>>1]}x[114414]=0;s=O(819,e+1072|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){Oa:{Pa:{Qa:{if(z[a+480192>>1]){f=1;d=1;while(1){Ra:{Sa:{Ta:{if(!h){x[114414]=0;i=U(405,a|0,d&65535,0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Ta}if(i){break Sa}}while(1){x[114414]=0;f=R(403,l|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break j}if(f){continue}break}if(y[e+1639|0]>=5){while(1){x[114414]=0;f=R(403,l|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){d=N()|0;break i}if(f){continue}break}}x[114414]=0;O(304,l|0,826)|0;f=x[114414];x[114414]=0;if((f|0)!=1){break Ra}}d=N()|0;break i}g=Wb(e+168|0);x[114414]=0;U(564,l|0,g|0,-1)|0;j=x[114414];x[114414]=0;if((j|0)==1){break Qa}x[114414]=0;O(334,i+492|0,g|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break Qa}Ua:{if(y[e+1639|0]<5){break Ua}x[114414]=0;U(564,l|0,g|0,-1)|0;j=x[114414];x[114414]=0;if((j|0)==1){break Qa}x[114414]=0;O(334,i+524|0,g|0)|0;j=x[114414];x[114414]=0;if((j|0)!=1){break Ua}break Qa}x[114414]=0;j=O(820,l|0,e+240|0)|0;q=x[114414];x[114414]=0;if((q|0)==1){break Qa}if(!j){break Pa}j=x[a+480180>>2];x[114414]=0;T(821,e+240|0,i|0,j|0);i=x[114414];x[114414]=0;if((i|0)==1){break Qa}if(x[a+480180>>2]==4){f=Pb(s,f-1|0);i=z[e+1042>>1]|z[e+1044>>1]<<16;v[f|0]=i;v[f+1|0]=i>>>8;v[f+2|0]=i>>>16;v[f+3|0]=i>>>24}xb(g)}d=d+1|0;f=d&65535;if(f>>>0<=z[a+480192>>1]){continue}break}}if(!h){break Oa}w[a+480192>>1]=0;break Oa}d=N()|0;xb(g);break i}xb(g)}d=z[a+480190>>1];x[114414]=0;t=O(822,e+224|0,d|0)|0;d=x[114414];x[114414]=0;j=1;if((d|0)!=1){j=y[e+1639|0]<=4?!(v[r|0]&1):j;q=0;d=0;Va:{if(!z[a+480190>>1]){break Va}C=c&2;h=1;f=1;while(1){Wa:{c=d;n=Wb(e+208|0);x[114414]=0;U(564,l|0,n|0,-1)|0;d=x[114414];x[114414]=0;Xa:{Ya:{Za:{_a:{$a:{ab:{if((d|0)==1){break ab}x[114414]=0;O(334,((h<<5)+a|0)+946304|0,n|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break ab}if(y[e+1639|0]<5){break $a}x[114414]=0;U(564,l|0,n|0,-1)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break _a}}d=N()|0;break Za}He(n)}x[114414]=0;d=O(823,l|0,e+240|0)|0;g=x[114414];x[114414]=0;bb:{cb:{db:{eb:{fb:{gb:{hb:{if((g|0)==1){break hb}if(!d){break gb}d=x[a+480180>>2];x[114414]=0;o=D(h,104);m=o+a|0;g=m+484380|0;X(824,e+240|0,g|0,d|0,j|0);d=x[114414];x[114414]=0;if((d|0)==1){break hb}x[114414]=0;O(335,m+484423|0,n|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break hb}i=0;ib:{if(((y[e+260|0]|y[e+261|0]<<8)&61440)!=28672|y[e+1639|0]<5){break ib}x[114414]=0;i=R(825,l|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break ib}d=N()|0;break Za}if(!C){break Ya}u=y[e+260|0]|y[e+261|0]<<8;k=u&61440;if(!(k|(y[e+275|0]|y[e+276|0]<<8|(y[e+277|0]<<16|y[e+278|0]<<24)))){d=y[e+260|0]|y[e+261|0]<<8;d=ad(e+168|0,d&1?16:8,d&1024?3:1,0,0);x[114414]=0;U(361,d|0,g|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break Ya}d=N()|0;break Za}d=y[e+275|0]|y[e+276|0]<<8|(y[e+277|0]<<16|y[e+278|0]<<24);if(!((d|0)>=0|(d+h|0)<=0)){i=a+484380|0;k=D((y[e+275|0]|y[e+276|0]<<8|(y[e+277|0]<<16|y[e+278|0]<<24))+h|0,104);d=i+k|0;xc(g,x[d>>2]);h=i+o|0;i=z[h+34>>1]&-2|w[d+34>>1]&1;w[h+34>>1]=i;w[h+34>>1]=i&65471|z[d+34>>1]&64;if(!Be(d)){break Ya}x[114414]=0;d=R(416,g|0)|0;h=x[114414];x[114414]=0;if((h|0)!=1){if(!d){break Ya}d=x[m+484400>>2];x[114414]=0;d=R(417,d|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}h=x[(a+k|0)+484400>>2];x[114414]=0;h=R(826,h|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break a}sc(d,h,Kj(g));break Ya}d=N()|0;break Za}if((y[e+275|0]|y[e+276|0]<<8|(y[e+277|0]<<16|y[e+278|0]<<24))<=0){break Ya}if(v[e+260|0]&1){d=m+484414|0;w[d>>1]=z[d>>1]|1}if(y[e+261|0]&4){d=m+484414|0;w[d>>1]=z[d>>1]|64}d=y[e+275|0]|y[e+276|0]<<8|(y[e+277|0]<<16|y[e+278|0]<<24);x[114414]=0;T(307,e+192|0,b|0,d|0);d=x[114414];x[114414]=0;jb:{kb:{lb:{mb:{if((d|0)!=1){d=Je(g);B=(k|0)==16384;if(!B&(k|0)!=8192){break kb}x[114414]=0;o=R(223,e+192|0)|0;F=x[114414];x[114414]=0;if((F|0)==1){break jb}x[e+168>>2]=o;F=x[e+168>>2];o=4/(d>>>0)|0;if(F>>>0>4294967295/(o>>>0)>>>0){break mb}o=D(o,F);break lb}d=N()|0;break Za}o=-1}x[e+168>>2]=o;xc(g,o);if(!B){if((k|0)!=8192){break kb}x[114414]=0;h=R(416,g|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break cb}if(!h){break eb}h=x[m+484400>>2];g=x[g>>2];if(v[e+260|0]&1){x[114414]=0;X(827,e+192|0,h|0,g|0,d|0);g=x[114414];x[114414]=0;d=c;if((g|0)!=1){break db}break cb}x[114414]=0;X(828,e+192|0,h|0,g|0,d|0);g=x[114414];x[114414]=0;d=c;if((g|0)==1){break cb}break db}x[114414]=0;h=R(416,g|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break cb}if(!h){break eb}h=x[m+484400>>2];g=x[g>>2];if(v[e+260|0]&1){x[114414]=0;X(829,e+192|0,h|0,g|0,d|0);g=x[114414];x[114414]=0;d=c;if((g|0)==1){break cb}break db}x[114414]=0;X(830,e+192|0,h|0,g|0,d|0);g=x[114414];x[114414]=0;d=c;if((g|0)==1){break cb}break db}if((u&45056)==12288){d=dR(e+168|0,e+192|0,y[e+279|0]|y[e+280|0]<<8,i);g=Uz(t,h-1|0);Ud(g,d);x[g+16>>2]=x[d+16>>2];Ab(d);break eb}if((k|0)!=32768){d=1;if((k|0)!=4096){break db}d=e+192|0;h=df(e+168|0,d);x[114414]=0;d=O(831,e+160|0,d|0)|0;i=x[114414];x[114414]=0;if((i|0)!=1){nb:{if(!y[e+165|0]){break nb}i=z[e+162>>1]<<1;if((i&65535)>>>0>(y[e+279|0]|y[e+280|0]<<8)>>>0){break nb}i=(y[e+279|0]|y[e+280|0]<<8)-i|0;v[e+279|0]=i;v[e+280|0]=i>>>8;d=z[d>>1];x[114414]=0;O(224,e+192|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break fb}x[114414]=0;d=R(296,e+192|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break fb}x[114414]=0;T(307,e+144|0,e+192|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break fb}d=e+144|0;Ud(h,d);Ab(d)}x[114414]=0;d=f&65535;i=aa(832,a|0,d|0,h|0,1,1)|0;k=x[114414];x[114414]=0;if((k|0)==1){break fb}ob:{if(!i){x[114414]=0;i=Z(833,a|0,d|0,h|0,1)|0;d=x[114414];x[114414]=0;if((d|0)==1){break fb}d=1;if(!i){break ob}}pb:{if(!(y[e+279|0]|y[e+280|0]<<8)){break pb}d=y[e+279|0]|y[e+280|0]<<8;if(Kj(g)>>>0<=d>>>0){break pb}d=y[e+279|0]|y[e+280|0]<<8;i=zo(g);m=m+484400|0;k=x[m>>2];x[114414]=0;k=R(417,k|0)|0;o=x[114414];x[114414]=0;if((o|0)==1){break a}m=x[m>>2];x[114414]=0;m=R(417,m|0)|0;o=x[114414];x[114414]=0;if((o|0)==1){break a}Bg(k,m+(y[e+279|0]|y[e+280|0]<<8)|0,Kj(g)-(y[e+279|0]|y[e+280|0]<<8)|0);x[g>>2]=x[g>>2]-((d>>>0)/(i>>>0)|0)}d=x[e+248>>2];x[e+136>>2]=d;x[e+4>>2]=d;d=e+4|0;if(A[g>>2]>(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))>>>0){x[g>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24)}d=c}Ab(h);break db}break fb}x[114414]=0;d=O(617,e+192|0,e+168|0)|0;h=x[114414];x[114414]=0;if((h|0)!=1){if(!d){break eb}x[114414]=0;x[e+16>>2]=x[e+176>>2];d=x[e+172>>2];x[e+8>>2]=x[e+168>>2];x[e+12>>2]=d;T(618,g|0,1,e+8|0);d=x[114414];x[114414]=0;if((d|0)!=1){break eb}}d=N()|0;break bb}d=N()|0;break bb}d=N()|0;break Za}xb(n);g=z[a+480190>>1];d=c;break Wa}d=N()|0;Ab(h);break bb}d=c}Ab(e+192|0);break Xa}d=N()|0}Ab(e+192|0)}xb(n);break k}d=c}xb(n);g=z[a+480190>>1];f=f+1|0;h=f&65535;if(g>>>0>=h>>>0){continue}}break}if(!C|!(g&65535)){break Va}i=1;n=1;while(1){b=Uz(t,i-1|0);x[114414]=0;c=R(303,b|0)|0;f=x[114414];x[114414]=0;qb:{rb:{sb:{if((f|0)!=1){if(!c){break qb}f=z[b+18>>1];c=f+n&65535;tb:{ub:{g=(f|0)!=0&(c|0)!=0&c>>>0<=z[a+480190>>1]&z[b+16>>1]!=0;if(!g){x[114414]=0;R(223,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break ub}break l}c=Uz(t,c-1|0);f=z[b+16>>1];Lc(c);h=z[b+16>>1];x[114414]=0;h=O(226,c|0,h|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break l}if(!h){break qb}x[114414]=0;x[e+168>>2]=0;x[e+192>>2]=0;T(834,e+240|0,c|0,f|0);f=x[114414];x[114414]=0;vb:{if((f|0)!=1){x[114414]=0;f=R(421,e+240|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break vb}x[114414]=0;f=R(835,f|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break vb}h=x[e+240>>2];x[114414]=0;h=R(836,h|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break vb}x[114414]=0;f=aa(837,f|0,h|0,e+168|0,e+192|0,0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break vb}x[114414]=0;O(304,c|0,x[e+168>>2])|0;c=x[114414];x[114414]=0;if((c|0)==1){break vb}Hc(e+240|0);break tb}d=N()|0;break k}d=N()|0;Hc(e+240|0);break k}Lc(b);f=0;x[e+168>>2]=0;x[e+192>>2]=0}x[114414]=0;P(838,e+240|0,b|0);c=x[114414];x[114414]=0;wb:{xb:{if((c|0)!=1){x[114414]=0;j=R(421,e+240|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break wb}c=x[e+240>>2];if(!g){x[114414]=0;f=R(835,j|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break sb}x[114414]=0;g=R(836,c|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break sb}x[114414]=0;f=aa(837,f|0,g|0,e+168|0,e+192|0,0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break sb}x[114414]=0;O(304,b|0,x[e+168>>2])|0;g=x[114414];x[114414]=0;if((g|0)==1){break sb}g=x[e+168>>2];c=c-g|0;j=g+j|0}if(f){break xb}d=1;break rb}d=N()|0;break k}x[114414]=0;g=D(i,104)+a|0;i=g+484380|0;R(416,i|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break sb}F=g+484400|0;J=g+484414|0;h=0;g=x[e+192>>2];while(1){yb:{if(A[i>>2]<=h>>>0|(!c|(g|0)!=1?g:0)){break yb}if(!Be(i)){break yb}x[114414]=0;x[e+144>>2]=0;x[e+208>>2]=0;g=R(835,j|0)|0;m=x[114414];x[114414]=0;if((m|0)==1){break sb}x[114414]=0;m=R(836,c|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break sb}x[114414]=0;g=ga(839,f|0,g|0,m|0,e+144|0,e+56|0,e+208|0)|0;m=x[114414];x[114414]=0;if((m|0)==1){break sb}x[114414]=0;x[e+168>>2]=g;O(304,b|0,g|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break sb}g=x[i>>2];x[114414]=0;m=x[e+168>>2];g=R(840,g-h|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break sb}Ch(e+208|0,g);zb:{if(x[e+208>>2]<=0){break zb}if(x[e+144>>2]!=(Je(i)|0)){break zb}g=0;if(x[e+144>>2]<=0){break zb}while(1){k=x[F>>2];K=z[J>>1];o=D(Je(i),h);C=x[x[e+56>>2]+(g<<2)>>2];u=x[e+208>>2];B=x[e+144>>2];Ab:{if(K&1){x[114414]=0;ba(841,k+(o<<1)|0,C|0,B|0,u|0,g|0);k=x[114414];x[114414]=0;if((k|0)!=1){break Ab}break sb}x[114414]=0;ba(842,k+o|0,C|0,B|0,u|0,g|0);k=x[114414];x[114414]=0;if((k|0)==1){break sb}}g=g+1|0;if((g|0)<x[e+144>>2]){continue}break}}x[114414]=0;k=x[e+208>>2];g=R(843,f|0)|0;o=x[114414];x[114414]=0;if((o|0)==1){break sb}c=c-m|0;j=j+m|0;x[e+192>>2]=g;h=h+k|0;continue}break}x[114414]=0;W(844,f|0);b=x[114414];x[114414]=0;if((b|0)!=1){break rb}break sb}break sb}d=N()|0;break k}d=N()|0;Hc(e+240|0);break k}Hc(e+240|0)}n=n+1|0;i=n&65535;if(i>>>0<=z[a+480190>>1]){continue}break}}Bb:{if(x[a+480180>>2]!=4){break Bb}while(1){if(z[a+480192>>1]<=q>>>0){break Bb}b=y[Pb(s,q)|0];c=y[Pb(s,q)+1|0];f=y[Pb(s,q)+2|0];g=y[Pb(s,q)+3|0];x[114414]=0;q=q+1|0;ia(845,a|0,q&65535,b|0,c|0,f|0,g|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}d=N()|0;break k}Cb:{Db:{Eb:{Fb:{if(!(y[r+2|0]&16)){break Fb}x[114414]=0;b=O(226,l|0,1)|0;c=x[114414];x[114414]=0;if((c|0)==1){break m}if(!b){break Fb}g=0;x[114414]=0;b=R(403,l|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break n}if(!(!(b&1)|!z[I>>1])){while(1){x[114414]=0;b=R(391,l|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break Eb}v[((g<<5)+a|0)+480288|0]=b;g=g+1|0;if(g>>>0<z[a+480188>>1]){continue}break}}while(1){x[114414]=0;b=O(226,l|0,1)|0;c=x[114414];x[114414]=0;Gb:{if((c|0)!=1){if(!b){break Fb}x[114414]=0;b=R(403,l|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break Db}if(!b){break Fb}x[114414]=0;c=R(391,l|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Cb}x[114414]=0;T(307,e+240|0,l|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break Cb}if(b>>>0>250){break Gb}x[114414]=0;P(644,e+240|0,(D(b,160)+a|0)+906140|0);b=x[114414];x[114414]=0;if((b|0)!=1){break Gb}d=N()|0;Ab(e+240|0);break k}d=N()|0;break k}Ab(e+240|0);continue}}q=a+901404|0;c=a+1074308|0;n=a+484344|0;b=hd(e+144|0);h=0;j=0;Hb:{Ib:{while(1){x[114414]=0;f=O(226,l|0,8)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Hb}if(!f){break Ib}x[114414]=0;f=R(391,l|0)|0;g=x[114414];x[114414]=0;Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{if((g|0)!=1){x[114414]=0;g=R(391,l|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break Zb}x[114414]=0;T(307,e+168|0,l|0,g|0);g=x[114414];x[114414]=0;if((g|0)==1){break Yb}if((f|0)<=1397900629){if((f|0)==1229211981){break Wb}if((f|0)!=1229476432){break Kb}x[114414]=0;f=R(403,e+168|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break q}x[a+480216>>2]=f;x[114414]=0;f=R(403,e+168|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break q}x[a+480220>>2]=f;break Kb}if((f|0)==1397900630){break Xb}if((f|0)!=1414548815){break Kb}x[114414]=0;f=O(595,e+168|0,9651)|0;g=x[114414];x[114414]=0;if((g|0)==1){break q}if(!f){break Ub}x[114414]=0;f=R(391,e+168|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){x[114414]=0;T(307,e+192|0,e+168|0,f|0);f=x[114414];x[114414]=0;if((f|0)!=1){break Vb}}d=N()|0;break p}d=N()|0;break o}d=N()|0;break o}d=N()|0;break o}_b:{$b:{ac:{f=x[a+480180>>2];switch(f-2|0){case 1:break Kb;case 0:break Lb;case 2:break $b;default:break ac}}if((f|0)==16){break _b}if((f|0)!=32){break Kb}x[114414]=0;h=R(321,e+168|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break q}x[114414]=0;j=R(321,e+168|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){break Kb}break q}x[114414]=0;x[e+240>>2]=32;f=R(223,e+168|0)|0;g=x[114414];x[114414]=0;bc:{if((g|0)==1){break bc}x[114414]=0;x[e+192>>2]=f;f=O(35,e+240|0,e+192|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break bc}f=x[f>>2];x[114414]=0;Z(846,e+168|0,b|0,4,f|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){break Kb}}d=N()|0;break p}x[114414]=0;g=R(403,e+168|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Jb}x[114414]=0;f=O(2,e+120|0,10917)|0;i=x[114414];x[114414]=0;cc:{dc:{ec:{if((i|0)!=1){x[114414]=0;P(187,e+192|0,f|0);i=x[114414];x[114414]=0;if((i|0)==1){break ec}x[114414]=0;x[e+56>>2]=g>>>4;x[e+24>>2]=g&15;X(501,e+240|0,e+192|0,e+56|0,e+24|0);g=x[114414];x[114414]=0;if((g|0)==1){break dc}g=e+240|0;Db(b,g);xb(g);Gb(e+192|0);xb(f);break Kb}d=N()|0;break p}d=N()|0;break cc}d=N()|0;Gb(e+192|0)}xb(f);break p}x[114414]=0;O(609,e+168|0,q|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break q}x[114414]=0;W(610,q|0);f=x[114414];x[114414]=0;if((f|0)==1){break q}break Kb}x[114414]=0;f=R(223,e+192|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Tb}w[e+240>>1]=f>>>5;f=Ae(n);x[114414]=0;w[e+56>>1]=f;f=O(433,e+240|0,e+56|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Tb}f=z[f>>1];if(f){i=0;while(1){x[114414]=0;U(847,e+192|0,e+240|0,32)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Tb}g=Zb(n,i);x[114414]=0;O(848,g|0,e+240|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Tb}i=i+1|0;if((f|0)!=(i|0)){continue}break}}Ab(e+192|0)}x[114414]=0;f=O(595,e+168|0,9656)|0;g=x[114414];x[114414]=0;if((g|0)==1){break q}if(!f){break Rb}x[114414]=0;f=R(391,e+168|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){x[114414]=0;T(307,e+240|0,e+168|0,f|0);f=x[114414];x[114414]=0;if((f|0)!=1){break Sb}}d=N()|0;break p}d=N()|0;Ab(e+192|0);break p}x[114414]=0;f=R(223,e+240|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Qb}w[e+192>>1]=(f>>>0)/20;f=z[a+480188>>1];x[114414]=0;w[e+56>>1]=f;f=O(433,e+192|0,e+56|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Qb}f=z[f>>1];if(f){g=0;while(1){x[114414]=0;U(612,e+240|0,((g<<5)+a|0)+480289|0,20)|0;i=x[114414];x[114414]=0;if((i|0)==1){break Qb}g=g+1|0;if((f|0)!=(g|0)){continue}break}}Ab(e+240|0)}x[114414]=0;O(629,a|0,e+168|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break q}x[114414]=0;X(630,a|0,e+168|0,1,0);f=x[114414];x[114414]=0;if((f|0)==1){break q}if((h-2186&65535)>>>0<=117){x[a+480180>>2]=16777216;x[114414]=0;T(641,a|0,e+168|0,h&65535);f=x[114414];x[114414]=0;if((f|0)==1){break q}}if(!x[c>>2]){break Kb}x[114414]=0;f=O(2,e+208|0,13391)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Pb}x[114414]=0;P(210,e+192|0,c|0);g=x[114414];x[114414]=0;if((g|0)==1){break Ob}x[114414]=0;T(3,e+240|0,f|0,e+192|0);g=x[114414];x[114414]=0;if((g|0)==1){break Nb}g=e+240|0;Db(b,g);xb(g);xb(e+192|0);xb(f);break Kb}d=N()|0;Ab(e+240|0);break p}d=N()|0;break p}d=N()|0;break Mb}d=N()|0;xb(e+192|0)}xb(f);break p}x[114414]=0;h=R(321,e+168|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break q}}Ab(e+168|0);continue}break}d=N()|0;break p}fc:{gc:{hc:{ic:{jc:{kc:{lc:{if(x[a+480180>>2]!=32){break lc}f=h&65535;if(f>>>0<256){break lc}if(f>>>0<532){break kc}}mc:{if(x[a+480180>>2]!=2){break mc}f=h&65535;if(f>>>0<12544){break mc}if(f>>>0<12820){break kc}}if(x[a+480180>>2]!=2){break jc}f=h&65535;if(f>>>0<4864|f>>>0>4895){break jc}}x[114414]=0;W(611,q|0);f=x[114414];x[114414]=0;if((f|0)==1){break ic}}if(!(v[r+2|0]&1)){break fc}if(!(x[c>>2]|!z[a+480192>>1])){g=1;while(1){f=x[(((g&65535)<<2)+a|0)+900380>>2];if(f){x[114414]=0;h=O(339,f|0,2)|0;i=x[114414];x[114414]=0;if((i|0)==1){break hc}i=x[a+480180>>2];x[114414]=0;T(849,h|0,4,i|0);h=x[114414];x[114414]=0;if((h|0)==1){break gc}v[f+19|0]=y[f+19|0]+3>>>2}g=g+1|0;if(z[a+480192>>1]>=(g&65535)>>>0){continue}break}}if(A[c>>2]<18350080){x[114414]=0;f=a+1074312|0;O(435,f|0,27)|0;g=x[114414];x[114414]=0;if((g|0)==1){break ic}x[114414]=0;O(435,f|0,57)|0;f=x[114414];x[114414]=0;if((f|0)==1){break ic}}if(A[c>>2]<19070976){x[114414]=0;O(435,a+1074312|0,73)|0;f=x[114414];x[114414]=0;if((f|0)==1){break ic}}if(A[c>>2]>=19267584){break fc}x[114414]=0;O(435,a+1074312|0,50)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break fc}}d=N()|0;break o}d=N()|0;break o}d=N()|0;break o}nc:{oc:{pc:{qc:{rc:{sc:{tc:{uc:{vc:{wc:{xc:{yc:{zc:{Ac:{Bc:{Cc:{Dc:{Ec:{if(Wc(b)){x[114414]=0;c=O(2,e+104|0,11353)|0;f=x[114414];x[114414]=0;Fc:{Gc:{Hc:{if((f|0)!=1){x[114414]=0;P(187,e+168|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break Hc}x[114414]=0;T(504,e+240|0,e+168|0,e+1639|0);f=x[114414];x[114414]=0;if((f|0)==1){break Gc}break Ec}d=N()|0;break o}d=N()|0;break Fc}d=N()|0;Gb(e+168|0)}xb(c);break o}x[114414]=0;c=O(2,e+88|0,13098)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Dc}x[114414]=0;P(187,e+168|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break Cc}x[114414]=0;X(401,e+240|0,e+168|0,e+1639|0,b|0);f=x[114414];x[114414]=0;if((f|0)==1){break Bc}}f=e+240|0;Db(b,f);xb(f);Gb(e+168|0);xb(c);x[114414]=0;c=O(2,e+72|0,11345)|0;f=x[114414];x[114414]=0;if((f|0)==1){break yc}x[114414]=0;P(187,e+168|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break xc}x[114414]=0;T(504,e+240|0,e+168|0,e+1639|0);f=x[114414];x[114414]=0;if((f|0)==1){break wc}f=e+240|0;Db(a+1304436|0,f);xb(f);Gb(e+168|0);xb(c);x[114414]=0;c=O(2,f|0,10522)|0;f=x[114414];x[114414]=0;if((f|0)==1){break uc}Db(a+1304448|0,c);xb(c);c=x[a+480180>>2];if((c|0)>15){break zc}switch(c-1|0){case 1:break qc;case 3:break rc;case 0:break sc;default:break v}}d=N()|0;break o}d=N()|0;break Ac}d=N()|0;Gb(e+168|0)}xb(c);break o}if((c|0)==16){break tc}if((c|0)==32){break pc}if((c|0)!=16777216){break v}x[114414]=0;c=O(2,e+168|0,6105)|0;f=x[114414];x[114414]=0;if((f|0)==1){break oc}Db(a+1304484|0,c);xb(c);x[114414]=0;c=O(2,e+192|0,9613)|0;f=x[114414];x[114414]=0;if((f|0)==1){break nc}Db(a+1304472|0,c);xb(c);break v}d=N()|0;break o}d=N()|0;break vc}d=N()|0;Gb(e+168|0)}xb(c);break o}d=N()|0;break o}x[114414]=0;c=O(2,e+168|0,6110)|0;f=x[114414];x[114414]=0;Ic:{if((f|0)!=1){Db(a+1304484|0,c);xb(c);x[114414]=0;c=O(2,e+192|0,4584)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ic}Db(a+1304472|0,c);xb(c);break v}d=N()|0;break o}d=N()|0;break o}x[114414]=0;c=O(2,e+168|0,8133)|0;f=x[114414];x[114414]=0;Jc:{if((f|0)!=1){Db(a+1304484|0,c);xb(c);x[114414]=0;c=O(2,e+192|0,9958)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Jc}Db(a+1304472|0,c);xb(c);break v}d=N()|0;break o}d=N()|0;break o}x[114414]=0;c=O(2,e+168|0,6083)|0;f=x[114414];x[114414]=0;Kc:{if((f|0)!=1){Db(a+1304484|0,c);xb(c);x[114414]=0;c=O(2,e+192|0,11118)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Kc}Db(a+1304472|0,c);xb(c);break v}d=N()|0;break o}d=N()|0;break o}x[114414]=0;c=O(2,e+168|0,6455)|0;f=x[114414];x[114414]=0;Lc:{if((f|0)!=1){Db(a+1304484|0,c);xb(c);x[114414]=0;c=O(2,e+192|0,10620)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Lc}Db(a+1304472|0,c);xb(c);break v}d=N()|0;break o}d=N()|0;break o}x[114414]=0;c=O(2,e+168|0,2520)|0;f=x[114414];x[114414]=0;Mc:{Nc:{Oc:{Pc:{Qc:{Rc:{Sc:{if((f|0)!=1){Db(a+1304484|0,c);xb(c);if(!(j&65535)){break Mc}x[114414]=0;c=O(2,e+40|0,11020)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Sc}x[114414]=0;P(187,e+56|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break Rc}x[114414]=0;x[e+36>>2]=(j&65280)>>>8;x[e+20>>2]=j&255;P(637,e+24|0,e+20|0);f=x[114414];x[114414]=0;if((f|0)==1){break Qc}x[114414]=0;X(622,e+192|0,e+56|0,e+36|0,e+24|0);f=x[114414];x[114414]=0;if((f|0)==1){break Pc}f=e+192|0;Db(a+1304472|0,f);xb(f);xb(e+24|0);Gb(e+56|0);xb(c);break v}d=N()|0;break o}d=N()|0;break o}d=N()|0;break Nc}d=N()|0;break Oc}d=N()|0;xb(e+24|0)}Gb(e+56|0)}xb(c);break o}x[114414]=0;c=O(2,e+192|0,4760)|0;f=x[114414];x[114414]=0;if((f|0)!=1){Db(a+1304472|0,c);xb(c);break v}d=N()|0;break o}d=N()|0;break o}d=N()|0;break o}d=N()|0;break o}d=N()|0;break k}d=N()|0;break k}d=N()|0;break k}d=N()|0;break i}d=N()|0;break g}d=N()|0;break g}d=N()|0;break g}d=N()|0;break d}d=N()|0;break d}d=N()|0;break d}d=N()|0;break c}d=N()|0;break c}d=N()|0;break d}Db(a+1304460|0,b);Tc:{if(x[a+1074308>>2]){x[a+1304496>>2]=7;break Tc}if(x[a+480180>>2]==1){x[a+1304496>>2]=2;break Tc}x[a+1304496>>2]=4}g=1;if(d&1){x[114414]=0;c=O(2,e+56|0,12508)|0;d=x[114414];x[114414]=0;if((d|0)==1){break s}x[114414]=0;T(623,a|0,2,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break r}xb(c)}xb(b);cR(t);bR(s);id(E);Ab(e+1104|0);Ab(e+1120|0)}Ab(l)}$d(G);break b}d=N()|0;break o}d=N()|0;xb(c);break o}d=N()|0}Ab(e+168|0)}xb(b);break k}d=N()|0;break k}d=N()|0;break k}d=N()|0}cR(t);break i}d=N()|0}bR(s);break g}d=N()|0}id(E)}Ab(e+1104|0)}Ab(e+1120|0)}Ab(l)}$d(G);Q(d|0);p()}hb=e+1648|0;return g|0}S(0)|0;zb();p()}function fka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,V=0,Y=0,_=0,$=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;e=hb-992|0;hb=e;Lc(b);a:{b:{if(!DR(b,e+936|0)){break b}if(!FR(e+936|0)){break b}if(!Qb(b,jd(ER(e+936|0),lb))){break b}if(!c){g=1;break b}Nd(a,8);Gi(a);f=y[e+936|3]-48|0;v[e+935|0]=f;d=y[e+944|0]|y[e+945|0]<<8|(y[e+946|0]<<16|y[e+947|0]<<24);Rc(b,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24));Bd(e+912|0,b,504);x[114414]=0;O(750,b|0,e+624|0)|0;d=x[114414];x[114414]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((d|0)!=1){if(y[e+624|0]&128|y[e+907|0]>63){break c}Sb(e+544|0,0,80);p:{if(!(y[e+968|0]|y[e+969|0]<<8|(y[e+970|0]<<16|y[e+971|0]<<24))){break p}d=y[e+968|0]|y[e+969|0]<<8|(y[e+970|0]<<16|y[e+971|0]<<24);x[114414]=0;d=O(224,b|0,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))|0;h=x[114414];x[114414]=0;if((h|0)!=1){if(!d){break p}x[114414]=0;O(751,b|0,e+544|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break p}}g=N()|0;break f}x[114414]=0;T(752,e+536|0,b|0,f&255);d=x[114414];x[114414]=0;if((d|0)!=1){d=e+536|0;V=rf(d);d=z[d>>1];if((d-128&65535)>>>0<65409){break c}w[a+480188>>1]=d;h=hb-16|0;hb=h;d=e+520|0;x[d>>2]=0;x[d+4>>2]=0;x[114414]=0;x[h+12>>2]=0;U(794,d+8|0,h+12|0,h+8|0)|0;F=x[114414];x[114414]=0;q:{if((F|0)!=1){hb=h+16|0;break q}break a}F=d;r:{if(y[e+960|0]|y[e+961|0]<<8|(y[e+962|0]<<16|y[e+963|0]<<24)){d=y[e+960|0]|y[e+961|0]<<8|(y[e+962|0]<<16|y[e+963|0]<<24);x[114414]=0;O(224,b|0,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))|0;d=x[114414];x[114414]=0;if((d|0)!=1){d=y[e+907|0];x[114414]=0;U(753,b|0,F|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break r}}g=N()|0;break g}if(y[e+907|0]){break d}}d=y[e+907|0];w[a+480192>>1]=d;w[a+480190>>1]=d;Y=1;if((f&255)>>>0>=2){Y=v[e+888|0]>=0;d=z[a+480192>>1]}if(d&65535){H=c&2;I=!Y;d=e+216|0;q=d|2;K=d|7;L=d|6;u=d|5;B=d|4;j=e+136|4;i=1;o=1;n=1;while(1){x[114414]=0;C=n&65535;d=U(405,a|0,o&65535,C|0)|0;h=x[114414];x[114414]=0;s:{t:{if((h|0)!=1){if(!d){break e}f=x[((i<<2)+a|0)+900380>>2];x[114414]=0;w[e+140>>1]=0;x[e+136>>2]=0;l=R(239,e+504|0)|0;d=x[114414];x[114414]=0;u:{v:{w:{if((d|0)!=1){h=i-1|0;d=Pb(F,h);x:{if(!(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))){break x}d=Pb(F,h);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[114414]=0;d=O(224,b|0,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))|0;h=x[114414];x[114414]=0;if((h|0)==1){break h}if(!d){break x}x[114414]=0;O(754,b|0,e+136|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break h}d=y[e+136|0]|y[e+137|0]<<8|(y[e+138|0]<<16|y[e+139|0]<<24);g=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);d=y[j|0]|y[j+1|0]<<8;g=(d<<8|d>>>8)<<16>>16>0?g<<((y[j|0]|y[j+1|0]<<8)>>>13&1):g;x[114414]=0;T(307,e+216|0,b|0,g|0);d=x[114414];x[114414]=0;if((d|0)==1){break h}d=e+216|0;Ud(l,d);Ab(d)}d=y[j+1|0]&15;r=(y[j|0]|y[j+1|0]<<8)&128;if(!r){break w}x[114414]=0;P(755,f|0,0);h=x[114414];x[114414]=0;ea=1;if((h|0)!=1){break v}break h}g=N()|0;break g}if(d>>>0>=7){break v}h=y[d+23750|0];if(!d){d=h;break t}w[a+480190>>1]=(z[a+480190>>1]+h|0)-1;d=f+108|0;G=f+236|0;m=h-2|0;k=4;while(1){i=k-4|0;g=m<<3;s=i+(g+23808|0)|0;i=y[i+(g+23760|0)|0]+n|0;t=D(k,12);g=0;while(1){E=g+t|0;na=fd(G,E),oa=i,w[na>>1]=oa;E=gc(d,E);v[E|0]=y[E|0]+y[s|0];g=g+1|0;if((g|0)!=12){continue}break}i=1;k=k+1|0;if((k|0)!=10){continue}break}d=h;break u}h=1;if((d|0)!=7){d=1;break t}i=0;x[114414]=0;P(756,f|0,-24);h=x[114414];x[114414]=0;d=1;if((h|0)==1){break h}h=1}G=1;break s}g=N()|0;break g}i=0;if(r|I){break s}i=f+108|0;k=7;while(1){m=D(k,12);s=D(k,-12)+72|0;g=0;while(1){t=gc(i,g+m|0);v[t|0]=s+y[t|0];g=g+1|0;if((g|0)!=12){continue}break}k=k+1|0;if((k|0)!=10){continue}break}i=0}x[114414]=0;O(757,e+912|0,e+216|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break h}if(!(!y[B|0]|y[B|0]>16)){v[f+31|0]=y[B|0];G=1}if(!(!y[u|0]|y[u|0]>128)){v[f+30|0]=y[u|0]}if(d){g=0;while(1){x[114414]=0;f=D(g+C|0,104)+a|0;P(448,f+484380|0,8);k=x[114414];x[114414]=0;if((k|0)==1){break h}k=y[L|0];x[114414]=0;v[e+96|0]=k;v[e+48|0]=64;k=O(409,e+96|0,e+48|0)|0;m=x[114414];x[114414]=0;if((m|0)==1){break h}w[f+484410>>1]=y[k|0]<<2;v[f+484416|0]=y[K|0];g=g+1|0;if((g|0)!=(d|0)){continue}break}}y:{if(r|!H){break y}r=ad(e+96|0,8,1,1,0);s=y[q|0]|y[q+1|0]<<8;m=s;f=y[e+216|0]|y[e+217|0]<<8;x[114414]=0;g=R(223,l|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break h}if(y[j+1|0]&16){DA(r);g=g>>>1|0}if(y[j+1|0]&32){mC(r);g=g>>>1|0}if(y[j+1|0]&64){pm(r,2)}g=i?(g>>>0)/((-1<<d^-1)>>>0)|0:g;if(!d){break y}k=(f<<8|f>>>8)&65535;f=k+((s<<8|s>>>8)&65535)|0;s=m<<8|m>>>8;i=0;while(1){m=D(i+C|0,104)+a|0;t=m+484380|0;x[t>>2]=g;x[114414]=0;U(361,r|0,t|0,l|0)|0;t=x[114414];x[114414]=0;if((t|0)==1){break h}k=k<<1;f=f<<1;if((s&65535)>>>0>=2){x[m+484388>>2]=f;x[m+484384>>2]=k;m=m+484414|0;w[m>>1]=z[m>>1]|2}g=g<<1;i=i+1|0;if((i|0)!=(d|0)){continue}break}}Ab(l);n=h+n|0;o=o+1|0;i=o&65535;if(i>>>0<=z[a+480192>>1]){continue}break}}d=e+544|4;z:{if(!(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))|!(y[e+552|0]|y[e+553|0]<<8)){break z}d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[114414]=0;d=O(224,b|0,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))|0;h=x[114414];x[114414]=0;if((h|0)==1){break i}if(!d){break z}d=y[e+552|0]|y[e+553|0]<<8;w[e+216>>1]=d<<8|d>>>8;d=y[e+907|0];x[114414]=0;w[e+136>>1]=d;d=O(433,e+216|0,e+136|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break j}l=z[d>>1];if(!l){break z}d=y[e+554|0]|y[e+555|0]<<8;g=(d<<8|d>>>8)&65535;d=e+216|0;i=d|5;o=d|3;k=d|1;f=e+144|0;n=e+136|4;d=0;while(1){x[114414]=0;U(758,b|0,e+216|0,g|0)|0;h=x[114414];x[114414]=0;A:{B:{C:{if((h|0)!=1){d=d+1|0;h=x[((d<<2)+a|0)+900380>>2];if(!y[e+216|0]){break A}q=eq(e+136|0,0,64);eq(n,y[e+216|0]-1&65535,64);r=y[e+216|0];eq(f,r+(y[k|0]?64/y[k|0]|0:0)|0,0);x[114414]=0;x[e+500>>2]=3;x[e+496>>2]=q;j=x[e+500>>2];x[e+8>>2]=x[e+496>>2];x[e+12>>2]=j;j=h+48|0;P(759,j|0,e+8|0);q=x[114414];x[114414]=0;if((q|0)==1){break C}if(y[e+216|0]!=1){break B}na=e,oa=bc(j),x[na+136>>2]=oa;q=x[td(e+488|0,e+136|0)>>2];x[114414]=0;O(760,j|0,q|0)|0;j=x[114414];x[114414]=0;if((j|0)!=1){break B}g=N()|0;break g}g=N()|0;break g}g=N()|0;break g}x[h>>2]=y[k|0]?y[k|0]<<9:32767;G=1;v[h+60|0]=y[h+60|0]|1}D:{if(g>>>0<19){break D}x[h+4>>2]=y[e+234|0]+1>>>1;if(g>>>0<21){break D}w[h+28>>1]=y[e+236|0]|y[e+237|0]<<8}h=D(z[fd(h+236|0,61)>>1],104)+a|0;v[h+484417|0]=y[o|0]<<4;E:{F:{if(g>>>0>=15){j=y[e+226|0]|y[e+227|0]<<8|(y[e+228|0]<<16|y[e+229|0]<<24);x[h+484384>>2]=j<<24|(j&65280)<<8|(j>>>8&65280|j>>>24);j=y[e+230|0]|y[e+231|0]<<8|(y[e+232|0]<<16|y[e+233|0]<<24);m=j<<24|(j&65280)<<8|(j>>>8&65280|j>>>24);j=y[e+226|0]|y[e+227|0]<<8|(y[e+228|0]<<16|y[e+229|0]<<24);x[h+484388>>2]=m+(j<<24|(j&65280)<<8|(j>>>8&65280|j>>>24));break F}if(g>>>0<6){break E}}j=h+484414|0;w[j>>1]=z[j>>1]&65533|y[i|0]<<1&2;w[j>>1]=z[j>>1]&65531|y[i|0]>>>1&4;if(!(y[i|0]&4)){break E}w[h+484412>>1]=0}if((d|0)!=(l|0)){continue}break}}if(!(y[e+564|0]|y[e+565|0]<<8|(y[e+566|0]<<16|y[e+567|0]<<24))|!(y[e+568|0]|y[e+569|0]<<8)){break k}d=y[e+564|0]|y[e+565|0]<<8|(y[e+566|0]<<16|y[e+567|0]<<24);x[114414]=0;d=O(224,b|0,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))|0;h=x[114414];x[114414]=0;if((h|0)==1){break i}if(!d){break k}d=y[e+568|0]|y[e+569|0]<<8;w[e+216>>1]=d<<8|d>>>8;d=y[e+907|0];x[114414]=0;w[e+136>>1]=d;d=O(433,e+216|0,e+136|0)|0;h=x[114414];x[114414]=0;if((h|0)!=1){k=z[d>>1];if(!k){break k}d=y[e+570|0]|y[e+571|0]<<8;i=(d<<8|d>>>8)&65535;f=0;G:while(1){H:{x[114414]=0;U(761,b|0,e+216|0,i|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break l}x[114414]=0;T(762,e+96|0,2,e+216|0);d=x[114414];x[114414]=0;if((d|0)==1){break m}x[114414]=0;P(355,e+136|0,e+96|0);d=x[114414];x[114414]=0;if((d|0)==1){break m}f=f+1|0;g=((f<<2)+a|0)+900380|0;d=x[g>>2];x[114414]=0;O(334,d+492|0,e+136|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break n}d=e+136|0;xb(d);h=x[g>>2];x[114414]=0;P(763,d|0,h|0);d=x[114414];x[114414]=0;if((d|0)==1){break o}d=e+136|0;na=e,oa=Gj(d),x[na+96>>2]=oa;na=e,oa=Ti(d),x[na+48>>2]=oa;while(1){x[114414]=0;d=O(764,e+96|0,e+48|0)|0;h=x[114414];x[114414]=0;I:{if((h|0)!=1){if(d){break I}cq(e+136|0);if((f|0)!=(k|0)){continue G}break k}break H}x[114414]=0;d=R(765,e+96|0)|0;h=x[114414];x[114414]=0;if((h|0)!=1){h=(z[d>>1]<<5)+a|0;j=h+946328|0;d=x[g>>2];l=x[d+520>>2];x[j>>2]=x[d+516>>2];x[j+4>>2]=l;l=x[d+512>>2];j=h+946320|0;x[j>>2]=x[d+508>>2];x[j+4>>2]=l;l=x[d+504>>2];j=h+946312|0;x[j>>2]=x[d+500>>2];x[j+4>>2]=l;j=x[d+496>>2];h=h+946304|0;x[h>>2]=x[d+492>>2];x[h+4>>2]=j;$t(e+96|0);continue}break}}break}g=N()|0;cq(e+136|0);break g}g=N()|0;break g}g=N()|0;break f}g=N()|0;break f}g=N()|0;break g}g=N()|0;xb(e+136|0);break g}g=N()|0;break g}g=N()|0;break g}x[114414]=0;W(611,a+901404|0);d=x[114414];x[114414]=0;if((d|0)==1){break i}d=a+901692|0;h=y[1447]|y[1448]<<8|(y[1449]<<16|y[1450]<<24);v[d|0]=h;v[d+1|0]=h>>>8;v[d+2|0]=h>>>16;v[d+3|0]=h>>>24;v[a+901696|0]=y[1451];Lc(b);J:{if(!y[V|0]){break J}fa=c&1;r=a+484344|0;B=a+1304424|0;K=a+1304400|0;L=a+484360|0;c=e+216|0;ga=c|1;j=c|4;d=e+200|0;c=d|4;t=d|2;d=e+120|0;E=d|2;ha=d|3;q=e+624|2;u=0;H=0;while(1){x[114414]=0;X(766,b|0,e+936|0,e+544|0,e+624|0);d=x[114414];x[114414]=0;K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{if((d|0)==1){break T}d=H&255;if(d){x[114414]=0;h=R(441,L|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break T}if((h|0)==255){break e}}l=Ni(L,d);f=hb-16|0;hb=f;g=f+8|0;h=hb-16|0;hb=h;x[114414]=0;d=e+472|0;R(796,d+4|0)|0;k=x[114414];x[114414]=0;U:{V:{if((k|0)==1){break V}x[114414]=0;x[h+12>>2]=0;U(797,d+8|0,h+12|0,g|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break V}na=d,oa=mc(d),x[na>>2]=oa;hb=h+16|0;break U}S(0)|0;zb();p()}h=d;hb=f+16|0;wq(l);o=y[e+935|0];if(o>>>0>1){break R}d=y[q|0]|y[q+1|0]<<8;if(((d<<8|d>>>8)&65535)>>>0>256|z[a+480188>>1]>16){break P}f=e+216|0;AR(f,e+624|0);d=y[q|0]|y[q+1|0]<<8;x[114414]=0;aa(767,l|0,f|0,(d<<8|d>>>8)&65535,65535,65535)|0;d=x[114414];x[114414]=0;if((d|0)==1){break Q}na=e,oa=bc(l),x[na+216>>2]=oa;na=e,oa=dc(l),x[na+136>>2]=oa;if(Hb(e+216|0,e+136|0)){break S}break N}g=N()|0;break g}while(1){d=e+216|0;f=x[d>>2];w[f>>1]=z[f>>1]+u;ge(d);if(Hb(d,e+136|0)){continue}break}break N}AR(e+216|0,e+624|0);if(!(y[e+228|0]|y[e+229|0]<<8)){break P}d=y[e+228|0]|y[e+229|0]<<8;if(((d<<8|d>>>8)&65535)>>>0>64|z[a+480188>>1]>64){break P}n=y[e+236|0]|y[e+237|0]<<8|(y[e+238|0]<<16|y[e+239|0]<<24);if(!(y[e+240|0]|y[e+241|0]<<8)){k=32;break O}d=y[e+240|0]|y[e+241|0]<<8;x[114414]=0;w[e+136>>1]=d<<8|d>>>8;w[e+96>>1]=800;d=O(433,e+136|0,e+96|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){d=z[d>>1];x[114414]=0;k=_f(722,((d<<5)+50>>>0)/100|0,0);d=x[114414];x[114414]=0;if((d|0)!=1){break O}}g=N()|0;break L}g=N()|0;break L}Wt(h);break e}d=y[e+224|0]|y[e+225|0]<<8|(y[e+226|0]<<16|y[e+227|0]<<24);x[114414]=0;d=O(224,b|0,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))|0;f=x[114414];x[114414]=0;W:{if((f|0)==1){break W}g=0;X:{if(!(d&z[a+480188>>1]!=0)){break X}Y:{while(1){Z:{x[114414]=0;d=R(403,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Z}x[114414]=0;v[e+136|0]=d;v[e+96|0]=64;d=O(409,e+136|0,e+96|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Y}w[((g<<5)+a|0)+480286>>1]=y[d|0];g=g+1|0;if(g>>>0<z[a+480188>>1]){continue}break X}break}g=N()|0;break L}g=N()|0;break L}_:{$:{if(!(y[e+232|0]|y[e+233|0]<<8|(y[e+234|0]<<16|y[e+235|0]<<24))){break $}d=y[e+232|0]|y[e+233|0]<<8|(y[e+234|0]<<16|y[e+235|0]<<24);x[114414]=0;d=O(224,b|0,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))|0;f=x[114414];x[114414]=0;if((f|0)==1){break W}if(!d){break $}g=0;if(!z[a+480188>>1]){break _}while(1){aa:{x[114414]=0;d=R(768,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break aa}na=((g<<5)+a|0)+480284|0,oa=(Xb(d,-16,16)<<3)+128|0,w[na>>1]=oa;g=g+1|0;if(g>>>0<z[a+480188>>1]){continue}break _}break}g=N()|0;break L}x[114414]=0;P(399,a|0,1);d=x[114414];x[114414]=0;if((d|0)==1){break W}}f=hb-16|0;hb=f;d=e+200|0;x[d>>2]=0;x[d+4>>2]=0;x[114414]=0;x[f+12>>2]=0;U(795,d+8|0,f+12|0,f+8|0)|0;g=x[114414];x[114414]=0;ba:{if((g|0)!=1){hb=f+16|0;break ba}break a}f=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);x[114414]=0;f=O(224,b|0,f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))|0;g=x[114414];x[114414]=0;ca:{da:{ea:{fa:{if((g|0)==1){break fa}if(!f){break ea}f=y[q|0]|y[q+1|0]<<8;x[114414]=0;f=O(226,b|0,((f<<8|f>>>8)&65535)<<1)|0;g=x[114414];x[114414]=0;if((g|0)==1){break fa}if(!f){break ea}f=y[q|0]|y[q+1|0]<<8;x[114414]=0;f=U(769,b|0,d|0,(f<<8|f>>>8)&65535)|0;g=x[114414];x[114414]=0;if((g|0)==1){break fa}if(!f){break ea}na=e,oa=bc(d),x[na+192>>2]=oa;na=e,oa=dc(d),x[na+184>>2]=oa;if(Hb(e+192|0,e+184|0)){while(1){ga:{f=y[e+230|0]|y[e+231|0]<<8;m=(f<<8|f>>>8)&65535;f=x[e+192>>2];f=y[f|0]|y[f+1|0]<<8;g=(f<<8|f>>>8)&65535;if(m>>>0<g>>>0){break ga}f=y[e+216|0]|y[e+217|0]<<8|(y[e+218|0]<<16|y[e+219|0]<<24);x[114414]=0;O(224,b|0,(f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))+(g<<2)|0)|0;f=x[114414];x[114414]=0;ha:{ia:{ja:{if((f|0)==1){break ja}x[114414]=0;f=R(450,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break ja}x[114414]=0;f=O(224,b|0,f|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break ja}if(!f){break ga}x[114414]=0;f=O(226,b|0,42)|0;g=x[114414];x[114414]=0;if((g|0)==1){break ja}if(!f){break ga}x[114414]=0;O(770,b|0,e+136|0)|0;f=x[114414];x[114414]=0;ka:{if((f|0)!=1){if(od(l)){break ka}x[114414]=0;P(771,l|0,65534);f=x[114414];x[114414]=0;if((f|0)!=1){break ka}}g=N()|0;break ca}f=y[e+176|0]|y[e+177|0]<<8;x[114414]=0;f=(f<<8|f>>>8)&65535;x[e+132>>2]=f;f=O(226,b|0,f|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break ia}if(!f){x[114414]=0;f=R(296,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break ia}xc(e+132|0,f)}xc(e+132|0,65534);g=qc(l);x[114414]=0;P(772,l|0,g+x[e+132>>2]|0);f=x[114414];x[114414]=0;if((f|0)==1){break da}i=0;if(!x[e+132>>2]){break ha}while(1){la:{x[114414]=0;f=R(440,b|0)|0;m=x[114414];x[114414]=0;if((m|0)==1){break la}f=f<<16>>16;if((f|0)>=0){x[114414]=0;P(771,l|0,f+u&65535);f=x[114414];x[114414]=0;if((f|0)==1){break la}}i=i+1|0;if(i>>>0<A[e+132>>2]){continue}break ha}break}g=N()|0;break ca}g=N()|0;break ca}g=N()|0;break ca}ma:{na:{oa:{if(y[e+136|0]){x[114414]=0;P(773,e+112|0,e+136|0);f=x[114414];x[114414]=0;pa:{if((f|0)!=1){x[114414]=0;P(774,e+120|0,e+112|0);f=x[114414];x[114414]=0;if((f|0)!=1){break pa}}g=N()|0;break ca}x[114414]=0;T(13,e+96|0,2,e+120|0);f=x[114414];x[114414]=0;if((f|0)==1){break na}x[114414]=0;P(442,l|0,e+96|0);f=x[114414];x[114414]=0;if((f|0)==1){break oa}xb(e+96|0);xb(e+120|0)}if(!(y[e+168|0]|y[e+169|0]<<8|(y[e+170|0]<<16|y[e+171|0]<<24))){break ga}f=y[e+168|0]|y[e+169|0]<<8|(y[e+170|0]<<16|y[e+171|0]<<24);x[114414]=0;f=O(224,b|0,f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))|0;i=x[114414];x[114414]=0;if((i|0)==1){break da}if(!f){break ga}while(1){qa:{x[114414]=0;f=O(775,b|0,e+120|0)|0;i=x[114414];x[114414]=0;ra:{sa:{if((i|0)!=1){if(!f){break ga}f=y[ha|0];x[114414]=0;T(307,e+96|0,b|0,f|0);f=x[114414];x[114414]=0;if((f|0)==1){break sa}f=y[e+120|0]|y[e+121|0]<<8;x[114414]=0;f=R(776,g+((f<<8|f>>>8)&65535)|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break qa}w[e+112>>1]=f;if((y[e+120|0]|y[e+121|0]<<8)!=65535){f=z[e+112>>1];if(qc(l)>>>0>f>>>0){break ra}}Ab(e+96|0);break ga}g=N()|0;break ca}g=N()|0;break ca}ta:{if(y[E|0]==1){f=65535}else{if(y[E|0]!=2){break ta}x[114414]=0;f=R(440,e+96|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break qa}x[114414]=0;i=O(777,h|0,e+112|0)|0;m=x[114414];x[114414]=0;if((m|0)==1){break qa}w[i>>1]=f;f=65534}na=uc(l,z[e+112>>1]),oa=f,w[na>>1]=oa}Ab(e+96|0);continue}break}g=N()|0;Ab(e+96|0);break ca}g=N()|0;xb(e+96|0);break ma}g=N()|0}xb(e+120|0);break ca}f=e+192|0;ge(f);if(Hb(f,e+184|0)){continue}break}}f=k>>>(n>>>25&1)|0;bA(d);break M}g=N()|0;break ca}bA(d);break K}g=N()|0}bA(d);break L}g=N()|0;break L}x[114414]=0;P(399,a|0,1);d=x[114414];x[114414]=0;ua:{if((d|0)!=1){g=0;f=32;if(!z[a+480188>>1]){break M}while(1){d=y[(e+g|0)+890|0];x[114414]=0;v[e+216|0]=d;v[e+136|0]=64;d=O(409,e+216|0,e+136|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break ua}w[((g<<5)+a|0)+480286>>1]=y[d|0];g=g+1|0;if(g>>>0<z[a+480188>>1]){continue}break}break M}g=N()|0;break L}g=N()|0;break L}i=y[e+887|0];g=y[e+887|0];k=y[e+888|0];n=y[e+888|0];d=y[e+884|0]|y[e+885|0]<<8;x[114414]=0;ca=g&64;_=k&32;I=(n&31)+1|0;d=Z(778,(d<<8|d>>>8)&65535,ca>>>6|0,_>>>5|0,I|0)|0;g=x[114414];x[114414]=0;va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{if((g|0)!=1){x[a+480204>>2]=d;na=a,oa=Md(y[e+889|0],1,32),x[na+480196>>2]=oa;if(_){x[a+480216>>2]=I;x[a+480220>>2]=I<<2}if(y[e+906|0]){d=y[e+906|0];x[114414]=0;v[e+216|0]=d;v[e+136|0]=64;d=O(409,e+216|0,e+136|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break wa}x[a+480200>>2]=y[d|0]<<2}x[a+480228>>2]=f;x[a+480232>>2]=f;x[a+480208>>2]=x[a+480208>>2]&-3|(y[e+887|0]^-1)>>>4&2;Ia:{if(!(y[e+588|0]|y[e+589|0]<<8|(y[e+590|0]<<16|y[e+591|0]<<24))){break Ia}d=y[e+588|0]|y[e+589|0]<<8|(y[e+590|0]<<16|y[e+591|0]<<24);x[114414]=0;d=O(224,b|0,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ha}if(!d){break Ia}d=y[e+592|0]|y[e+593|0]<<8|(y[e+594|0]<<16|y[e+595|0]<<24);x[114414]=0;U(437,b|0,K|0,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))|0;d=x[114414];x[114414]=0;if((d|0)==1){break Ha}if(y[V|0]<2){break Ia}x[114414]=0;T(13,e+216|0,2,K|0);d=x[114414];x[114414]=0;if((d|0)==1){break Ga}x[114414]=0;P(442,l|0,e+216|0);d=x[114414];x[114414]=0;if((d|0)==1){break Fa}xb(e+216|0)}d=y[e+560|0]|y[e+561|0]<<8|(y[e+562|0]<<16|y[e+563|0]<<24);Ja:{if((d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))>>>0<2){break Ja}d=y[e+556|0]|y[e+557|0]<<8|(y[e+558|0]<<16|y[e+559|0]<<24);x[114414]=0;d=O(224,b|0,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ha}if(!d){break Ja}d=y[e+560|0]|y[e+561|0]<<8|(y[e+562|0]<<16|y[e+563|0]<<24);x[114414]=0;Z(552,B|0,b|0,(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))-1|0,4)|0;d=x[114414];x[114414]=0;if((d|0)==1){break Ha}}if(!(y[e+600|0]|y[e+601|0]<<8|(y[e+602|0]<<16|y[e+603|0]<<24))){break va}d=y[e+600|0]|y[e+601|0]<<8|(y[e+602|0]<<16|y[e+603|0]<<24);x[114414]=0;d=O(224,b|0,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ha}if(!d){break va}x[114414]=0;d=O(226,b|0,12)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ha}if(!d){break va}x[114414]=0;O(304,b|0,6)|0;d=x[114414];x[114414]=0;if((d|0)==1){break Ha}x[114414]=0;d=R(440,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ha}if((d|0)!=1){break va}x[114414]=0;f=R(450,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break Da}if(!f){break va}x[114414]=0;d=O(226,b|0,f|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Da}if(d){break Ea}break va}g=N()|0;break L}g=N()|0;break L}g=N()|0;break L}g=N()|0;xb(e+216|0);break L}d=st(e+216|0,B);x[114414]=0;Z(552,B|0,b|0,f|0,4)|0;f=x[114414];x[114414]=0;if((f|0)==1){break ya}if(!Wc(d)){x[114414]=0;f=U(779,e- -64|0,2,13)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Ca}x[114414]=0;T(780,e+136|0,d|0,f|0);g=x[114414];x[114414]=0;if((g|0)==1){break Ba}x[114414]=0;T(781,e+80|0,e+136|0,B|0);g=x[114414];x[114414]=0;if((g|0)==1){break Aa}g=e+80|0;Db(B,g);xb(g);xb(e+136|0);xb(f)}xb(d);break va}g=N()|0;break L}g=N()|0;break xa}g=N()|0;break za}g=N()|0;xb(e+136|0)}xb(f);break xa}g=N()|0}xb(d);break L}g=N()|0;break L}Ka:{La:{Ma:{if(!(y[e+612|0]|y[e+613|0]<<8|(y[e+614|0]<<16|y[e+615|0]<<24))|o>>>0<2){break Ma}k=0;if(!z[a+480188>>1]){break Ma}while(1){d=y[e+612|0]|y[e+613|0]<<8|(y[e+614|0]<<16|y[e+615|0]<<24);x[114414]=0;d=O(224,b|0,(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))+(k<<2)|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ka}Na:{if(!d){break Na}x[114414]=0;d=R(450,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ka}x[114414]=0;g=O(224,b|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break Ka}f=0;d=0;if(!g){break Na}while(1){Oa:{x[114414]=0;g=O(226,b|0,8)|0;o=x[114414];x[114414]=0;Pa:{Qa:{Ra:{if((o|0)!=1){if(!g){break Oa}x[114414]=0;O(782,b|0,e+216|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Ra}if(!(y[e+216|0]|y[e+217|0]<<8|(y[e+218|0]<<16|y[e+219|0]<<24))){break Oa}g=y[e+216|0]|y[e+217|0]<<8|(y[e+218|0]<<16|y[e+219|0]<<24);switch(((g&31)<<24|(g&65280)<<8|(g>>>8&65280|g>>>24))-1|0){case 1:break Pa;case 0:break Qa;default:continue}}g=N()|0;break L}g=N()|0;break L}f=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);f=f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24);continue}d=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);d=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);continue}break}if(!f|!d){break Na}x[114414]=0;f=O(224,b|0,f|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break La}if(!f){break Na}x[114414]=0;U(612,b|0,((k<<5)+a|0)+480289|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break La}}k=k+1|0;if(k>>>0<z[a+480188>>1]){continue}break}}d=y[e+624|0]|y[e+625|0]<<8;x[114414]=0;o=d<<8|d>>>8;P(362,r|0,o+u&65535);f=x[114414];x[114414]=0;Sa:{Ta:{Ua:{Va:{if((f|0)==1){break Va}Wa:{if(d){ia=i&16;ja=u&65535;d=o&65535;ka=d>>>0<=1?1:d;d=0;while(1){Xa:{if(!fa){break Xa}f=y[e+952|0]|y[e+953|0]<<8|(y[e+954|0]<<16|y[e+955|0]<<24);x[114414]=0;f=O(224,b|0,(f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))+(d<<2)|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Wa}if(!f){break Xa}x[114414]=0;f=R(450,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Wa}x[114414]=0;f=O(224,b|0,f|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Wa}if(!f){break Xa}m=Wb(e+96|0);x[114414]=0;C=R(239,e+48|0)|0;f=x[114414];x[114414]=0;Ya:{Za:{if((f|0)!=1){g=y[e+935|0];if(g){break Za}x[114414]=0;O(783,b|0,e+216|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ta}w[e+120>>1]=y[e+216|0];s=y[ga|0]+1|0;f=48;break Ya}g=N()|0;break Sa}k=v[e+886|0];x[114414]=0;O(784,b|0,e+200|0)|0;f=x[114414];x[114414]=0;_a:{$a:{if((f|0)!=1){f=y[e+200|0]|y[e+201|0]<<8;w[e+120>>1]=f<<8|f>>>8;f=y[t|0]|y[t+1|0]<<8;s=((f<<8|f>>>8)&65535)+1|0;if(!(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))){break _a}i=x[b+8>>2];f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[114414]=0;O(224,b|0,f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ta}x[114414]=0;O(785,b|0,e+216|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ta}f=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);x[114414]=0;f=O(224,b|0,f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))|0;n=x[114414];x[114414]=0;if((n|0)==1){break Ta}if(!f){break $a}f=y[e+224|0]|y[e+225|0]<<8|(y[e+226|0]<<16|y[e+227|0]<<24);x[114414]=0;U(437,b|0,m|0,f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))|0;f=x[114414];x[114414]=0;if((f|0)!=1){break $a}break Ta}break Ta}ab:{if(!(y[e+232|0]|y[e+233|0]<<8|(y[e+234|0]<<16|y[e+235|0]<<24))){break ab}f=y[e+232|0]|y[e+233|0]<<8|(y[e+234|0]<<16|y[e+235|0]<<24);x[114414]=0;f=O(224,b|0,f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))|0;n=x[114414];x[114414]=0;if((n|0)==1){break Ta}if(!f){break ab}x[114414]=0;f=R(450,b|0)|0;n=x[114414];x[114414]=0;if((n|0)==1){break Ta}x[114414]=0;f=O(224,b|0,f|0)|0;n=x[114414];x[114414]=0;if((n|0)==1){break Ta}if(!f){break ab}x[114414]=0;T(307,e+136|0,b|0,D(z[e+120>>1],s)|0);f=x[114414];x[114414]=0;if((f|0)==1){break Ta}f=e+136|0;Ud(C,f);Ab(f)}x[114414]=0;O(224,b|0,i|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ta}}f=k+(g>>>0<3?48:24)|0}x[114414]=0;g=d+ja|0;k=U(363,r|0,g&65535,s|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break Ta}if(k){da=Zb(r,g);x[114414]=0;O(452,da|0,m|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Ta}sg(e+120|0,z[a+480188>>1]);n=0;while(1){x[114414]=0;g=U(427,da|0,n|0,0)|0;k=x[114414];x[114414]=0;bb:{cb:{if((k|0)!=1){k=0;if(z[e+120>>1]){break cb}break bb}break Ta}while(1){db:{if(!y[e+935|0]){x[114414]=0;P(786,e+216|0,b|0);i=x[114414];x[114414]=0;if((i|0)!=1){i=e+216|0;J=ed(i);$=rf(i);i=y[i|0];v[g+1|0]=i>>>3&16|y[J|0]>>>4|i>>>1&32;v[g+3|0]=y[J|0]&15;v[g+5|0]=y[$|0];i=i&63;i=i?i+f|0:0;break db}break Ta}x[114414]=0;P(562,e+216|0,b|0);i=x[114414];x[114414]=0;eb:{fb:{if((i|0)!=1){i=e+216|0;J=ed(i);$=rf(i);la=$h(i);x[114414]=0;M=R(403,C|0)|0;ma=x[114414];x[114414]=0;if((ma|0)==1){break Ta}v[g+4|0]=M;M=y[i|0];i=M&127;if(!i){break fb}i=f+i|0;break eb}break Ta}i=0;if((M|0)!=128){break eb}v[g|0]=254}v[g+1|0]=y[J|0]&63;v[g+3|0]=y[$|0];v[g+5|0]=y[la|0]}if(i-1>>>0<=119){v[g|0]=i}x[114414]=0;ba(787,g|0,(ca|0)!=0|0,(_|0)!=0|0,I|0,(ia|0)!=0|0);J=x[114414];x[114414]=0;if((J|0)!=1){G=(i|0)>84&Y|G;g=g+6|0;k=k+1|0;if(z[e+120>>1]<=(k&65535)>>>0){break bb}continue}break}break Ta}n=n+1|0;if((s|0)!=(n|0)){continue}break}}Ab(C);xb(m)}d=d+1|0;if((ka|0)!=(d|0)){continue}break}}na=e,oa=Gj(h),x[na+216>>2]=oa;na=e,oa=Ti(h),x[na+136>>2]=oa;gb:{while(1){x[114414]=0;d=O(788,e+216|0,e+136|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ua}hb:{ib:{jb:{kb:{lb:{mb:{if(!d){if(!(y[e+544|0]|y[e+545|0]<<8|(y[e+546|0]<<16|y[e+547|0]<<24))){break mb}d=y[e+544|0]|y[e+545|0]<<8|(y[e+546|0]<<16|y[e+547|0]<<24);x[114414]=0;d=O(224,b|0,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))|0;f=x[114414];x[114414]=0;if((f|0)==1){break Va}if(!d){break mb}u=o+u|0;break K}x[114414]=0;d=R(789,e+216|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break lb}f=rf(d);g=z[d>>1];if(!g){g=0;break kb}x[114414]=0;k=O(513,l|0,g-1&65535)|0;g=x[114414];x[114414]=0;if((g|0)==1){break hb}g=z[d>>1];if(!k){break kb}x[114414]=0;g=O(790,l|0,g-1&65535)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break jb}break hb}Wt(h);break J}g=N()|0;break L}if(z[f>>1]==((g&65535)+1|0)){break ib}x[114414]=0;g=U(791,r|0,1,0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break hb}if((g|0)==65535){break ib}na=uc(l,z[d>>1]),oa=g,w[na>>1]=oa}d=Zb(r,g);f=z[f>>1];x[114414]=0;f=R(792,f|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break gb}x[114414]=0;f=U(454,e+32|0,12,f|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break gb}f=Zn(Ie(f,x[Zb(r,g)+12>>2]-1|0));x[114414]=0;O(455,d|0,f|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break gb}o=(o&65535)>>>0>g>>>0?o:g+1|0}x[114414]=0;R(793,e+216|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){continue}break Ua}break}g=N()|0;break L}g=N()|0;break L}g=N()|0;break L}g=N()|0;break L}g=N()|0;break L}g=N()|0;Ab(C)}xb(m);break L}g=N()|0;break L}g=N()|0}Wt(h);break g}Wt(h);H=H+1|0;if(y[V|0]>(H&255)>>>0){continue}break}}x[114414]=0;P(444,a+484360|0,0);b=x[114414];x[114414]=0;if((b|0)!=1){if(!(G&1)){d=z[a+480192>>1];if(d){g=1;while(1){b=(((g&65535)<<2)+a|0)+900380|0;c=x[b>>2];if(c){_b(_t(c));d=z[a+480192>>1]}x[b>>2]=0;g=g+1|0;if((g&65535)>>>0<=(d&65535)>>>0){continue}break}}w[a+480192>>1]=0}nb:{ob:{pb:{qb:{rb:{sb:{tb:{if(ea){x[114414]=0;b=O(2,e+216|0,12249)|0;c=x[114414];x[114414]=0;if((c|0)==1){break tb}x[114414]=0;T(623,a|0,2,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break sb}xb(b)}d=17386;switch(y[e+935|0]){case 3:break ob;case 2:break pb;case 1:break qb;case 0:break rb;default:break nb}}g=N()|0;break g}g=N()|0;xb(b);break g}d=z[a+480188>>1]>4?13179:13165;break nb}d=13111;break nb}d=13080;break nb}d=13053}x[114414]=0;b=O(2,e+16|0,13129)|0;c=x[114414];x[114414]=0;ub:{vb:{wb:{xb:{yb:{if((c|0)!=1){x[114414]=0;P(187,e+96|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break yb}x[114414]=0;T(504,e+136|0,e+96|0,e+935|0);c=x[114414];x[114414]=0;if((c|0)==1){break xb}c=e+136|0;Db(a+1304436|0,c);xb(c);Gb(e+96|0);xb(b);x[114414]=0;b=O(2,c|0,8478)|0;c=x[114414];x[114414]=0;if((c|0)==1){break vb}Db(a+1304448|0,b);xb(b);x[114414]=0;O(206,a+1304460|0,d|0)|0;b=x[114414];x[114414]=0;g=1;if((b|0)==1){break ub}x[a+1304496>>2]=2;break d}g=N()|0;break g}g=N()|0;break wb}g=N()|0;Gb(e+96|0)}xb(b);break g}g=N()|0;break g}g=N()|0;break g}g=N()|0;break g}g=N()|0;break g}g=N()|0;break g}g=N()|0;Ab(l)}uR(F)}Ab(e+912|0);Q(g|0);p()}g=0}uR(F)}Ab(e+912|0)}hb=e+992|0;return g|0}S(0)|0;zb();p()}function ht(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,V=0,Y=0,_=0,$=0,ba=0,ca=0,da=0,ea=0,ga=0,ha=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;i=hb-176|0;hb=i;e=hb-16|0;hb=e;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[e+12>>2]=0;U(1378,a+8|0,e+12|0,e+8|0)|0;g=x[114414];x[114414]=0;a:{if((g|0)!=1){hb=e+16|0;break a}S(0)|0;zb();p()}ma=a;r=i+144|0;v[r+26|0]=0;w[r+24>>1]=0;x[r+16>>2]=0;x[r+20>>2]=-1;x[r+8>>2]=-1;x[r+12>>2]=-1;x[r>>2]=0;x[r+4>>2]=0;ra=x[d+16>>2];da=y[d+6|0];na=b+484360|0;if(da>>>0>=Vh(na)>>>0){da=y[na+16|0]}F=Ni(na,da);x[114414]=0;t=O(1336,i+104|0,b|0)|0;a=x[114414];x[114414]=0;b:{if((a|0)!=1){g=x[t+4>>2];x[114414]=0;Y=U(1337,i+72|0,b|0,da|0)|0;a=x[114414];x[114414]=0;c:{if((a|0)!=1){a=x[d>>2];d:{e:{f=z[d+4>>1];f:{if(f>>>0>=qc(F)>>>0){break f}while(1){x[114414]=0;e=O(513,F|0,f&65535)|0;h=x[114414];x[114414]=0;if((h|0)==1){break e}if(e){break f}a=0;f=f+1|0;if(qc(F)>>>0>(f&65535)>>>0){continue}break}}x[d>>2]=a;w[d+4>>1]=f;x[g+52>>2]=a;x[g+48>>2]=a;x[r+16>>2]=a;w[g+64>>1]=f;w[g+62>>1]=f;w[r+24>>1]=f;M=Do(i- -64|0);sa=Xc(i+56|0);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{ta=c&7;wa=(ta|0)!=7;r:{if(wa){break r}x[114414]=0;U(1338,M|0,1,1)|0;a=x[114414];x[114414]=0;if((a|0)==1){break q}x[114414]=0;U(1338,M|0,2,1)|0;a=x[114414];x[114414]=0;if((a|0)==1){break q}x[114414]=0;U(1338,M|0,3,1)|0;a=x[114414];x[114414]=0;if((a|0)==1){break q}x[114414]=0;U(1338,M|0,28,1)|0;a=x[114414];x[114414]=0;if((a|0)==1){break q}x[114414]=0;U(1338,M|0,35,1)|0;a=x[114414];x[114414]=0;if((a|0)==1){break q}x[114414]=0;U(1338,M|0,37,1)|0;a=x[114414];x[114414]=0;if((a|0)==1){break q}x[114414]=0;U(1338,M|0,36,1)|0;a=x[114414];x[114414]=0;if((a|0)==1){break q}x[114414]=0;U(1338,M|0,38,1)|0;a=x[114414];x[114414]=0;if((a|0)==1){break q}x[114414]=0;U(1339,sa|0,12,1)|0;a=x[114414];x[114414]=0;if((a|0)==1){break q}x[114414]=0;U(1339,sa|0,13,1)|0;a=x[114414];x[114414]=0;if((a|0)==1){break q}if((ra|0)!=2){break r}a=z[d+12>>1];if(qc(F)>>>0<=a>>>0){break r}a=z[uc(F,a)>>1];x[114414]=0;e=b+484344|0;h=O(392,e|0,a|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break g}if(!h){break r}j=Zb(e,a);h=x[d+8>>2];x[114414]=0;j=O(1340,j|0,h|0)|0;J=x[114414];x[114414]=0;if((J|0)==1){break g}if(!j){break r}a=Zb(e,a);x[114414]=0;f=U(427,a|0,h|0,0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break h}if(!z[b+480188>>1]){break r}a=t+20|0;e=0;while(1){s:{t:{u:{switch(y[f|0]-253|0){case 0:if(z[b+480192>>1]){break t}break;case 1:case 2:break t;default:break u}}x[114414]=0;h=R(520,f|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break i}if(!h){break s}if(it(f)){break s}}ya=Tc(a,e),za=-1,x[ya+16>>2]=za}f=f+6|0;e=e+1|0;if(e>>>0<z[b+480188>>1]){continue}break}}$=g- -64|0;I=g+48|0;_=g+68|0;oa=g+44|0;ua=t+8|0;ea=c&1;s=t+20|0;u=b+1074312|0;K=b+484344|0;J=0;while(1){x[g+48>>2]=x[g+52>>2];a=z[g+64>>1];w[g+62>>1]=a;x[114414]=0;a=O(513,F|0,a|0)|0;e=x[114414];x[114414]=0;v:{if((e|0)!=1){w:{if(!a){break w}if(A[g+48>>2]<A[Zb(K,z[uc(F,z[g+62>>1])>>1])+12>>2]){break w}x[I>>2]=0;Kb(i,u,63);if(Ib(i)){a=x[g+56>>2];x[g+56>>2]=0;x[g+48>>2]=a}a=z[g+64>>1]+1|0;w[g+62>>1]=a;w[g+64>>1]=a}e=x[d+16>>2];if(!(C[t+32>>3]>=C[d+8>>3])|(e|0)!=3){break v}break k}a=N()|0;break d}a=z[g+62>>1];x:{if(qc(F)>>>0>a>>>0){a=z[uc(F,z[g+62>>1])>>1];break x}a=65535}w[g+60>>1]=a;x[114414]=0;a=O(392,K|0,a&65535)|0;h=x[114414];x[114414]=0;if((h|0)==1){break m}if(!(z[g+60>>1]==65535|(e|0)!=2|a)&z[g+62>>1]==z[d+12>>1]){break k}y:{if(z[g+60>>1]<Ae(K)>>>0){break y}while(1){z:{A:{if(z[g+60>>1]!=65535){a=z[g+62>>1];if(qc(F)>>>0>a>>>0){break A}}if(z[F+28>>1]==z[g+62>>1]){break y}a=z[F+28>>1];break z}a=z[g+62>>1]+1|0}w[g+62>>1]=a;B:{if(qc(F)>>>0>(a&65535)>>>0){a=z[uc(F,z[g+62>>1])>>1];break B}a=65535}w[g+60>>1]=a;w[g+64>>1]=z[g+62>>1];x[114414]=0;a=O(392,K|0,a&65535)|0;h=x[114414];x[114414]=0;if((h|0)==1){break l}C:{if(a){break C}a=z[g+62>>1];x[114414]=0;a=Z(1341,Y|0,a|0,0,1)|0;h=x[114414];x[114414]=0;if((h|0)==1){break l}if(!a){break C}if(ra>>>0<=1){a=z[g+62>>1];x[r+8>>2]=0;w[r+20>>1]=a}if(!e){break y}x[114414]=0;a=Z(1342,Y|0,$|0,I|0,1)|0;h=x[114414];x[114414]=0;if((h|0)==1){break m}if(!a){break y}C[r>>3]=C[t+32>>3];x[114414]=0;P(1343,ma|0,r|0);a=x[114414];x[114414]=0;if((a|0)==1){break m}x[r+16>>2]=x[I>>2];w[r+24>>1]=z[$>>1];x[114414]=0;W(1344,t|0);a=x[114414];x[114414]=0;if((a|0)==1){break m}a=z[g+64>>1];w[g+62>>1]=a;ya=g,za=z[uc(F,a)>>1],w[ya+60>>1]=za;x[g+52>>2]=x[g+48>>2];break y}if(z[g+60>>1]>=Ae(K)>>>0){continue}break}}if(z[$>>1]==65535){break j}a=z[g+60>>1];x[114414]=0;a=O(392,K|0,a|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break m}if(!a){if(z[F+28>>1]==z[g+62>>1]){if(!e){break j}x[114414]=0;a=Z(1342,Y|0,$|0,I|0,1)|0;e=x[114414];x[114414]=0;if((e|0)==1){break m}if(!a){break j}C[r>>3]=C[t+32>>3];x[114414]=0;P(1343,ma|0,r|0);a=x[114414];x[114414]=0;if((a|0)==1){break m}x[r+16>>2]=x[I>>2];w[r+24>>1]=z[$>>1];x[114414]=0;W(1344,t|0);a=x[114414];x[114414]=0;if((a|0)==1){break m}x[g+52>>2]=x[g+48>>2];continue}w[g+64>>1]=z[g+62>>1]+1;continue}if(A[g+48>>2]>=A[Zb(K,z[g+60>>1])+12>>2]){x[I>>2]=0}h=z[g+62>>1];D:{if((e|0)!=2){a=x[I>>2];break D}a=x[I>>2];if((h|0)!=z[d+12>>1]){break D}if(x[d+8>>2]==(a|0)){break k}}x[114414]=0;a=Z(1341,Y|0,h|0,a|0,1)|0;h=x[114414];x[114414]=0;if((h|0)==1){break m}if(a){if(ra>>>0<=1){w[r+20>>1]=z[g+62>>1];x[r+8>>2]=x[g+48>>2]}if(!e){break j}x[114414]=0;a=Z(1342,Y|0,$|0,I|0,1)|0;e=x[114414];x[114414]=0;if((e|0)==1){break m}if(!a){break j}C[r>>3]=C[t+32>>3];x[114414]=0;P(1343,ma|0,r|0);a=x[114414];x[114414]=0;if((a|0)==1){break m}x[r+16>>2]=x[I>>2];w[r+24>>1]=z[$>>1];x[114414]=0;W(1344,t|0);a=x[114414];x[114414]=0;if((a|0)==1){break m}x[g+52>>2]=x[g+48>>2];continue}w[r+22>>1]=z[g+62>>1];a=x[g+48>>2];x[r+12>>2]=a;x[g+52>>2]=a+1;E:{F:{if(a>>>0>=A[Zb(K,z[g+60>>1])+12>>2]){x[I>>2]=0;break F}if(x[I>>2]){break E}}f=0;if(!z[b+480188>>1]){break E}while(1){H=C[t+32>>3];ya=Tc(s,f),Aa=H,C[ya>>3]=Aa;a=x[g>>2];ya=Tc(s,f),za=a,x[ya+8>>2]=za;f=f+1|0;if(f>>>0<z[b+480188>>1]){continue}break}}a=Zb(K,z[g+60>>1]);e=x[g+48>>2];x[114414]=0;f=U(427,a|0,e|0,0)|0;a=x[114414];x[114414]=0;G:{H:{I:{if((a|0)!=1){e=0;L=0;ga=0;if(!z[b+480188>>1]){break H}while(1){Kb(i,u,77);J:{if(ya=Ib(i),za=0,Ba=x[((e<<5)+b|0)+480280>>2]&1024,Ba?ya:za){break J}x[114414]=0;a=R(1345,f|0)|0;h=x[114414];x[114414]=0;K:{L:{M:{N:{O:{P:{if((h|0)==1){break P}if(a){Q:{if(!ea){break Q}a=y[f+1|0];if(a-251>>>0<5|!a){break Q}x[114414]=0;a=R(1346,f|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break P}x[114414]=0;h=R(1347,f|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break M}w[i+48>>1]=h;v[i|0]=y[f+1|0];w[i+2>>1]=z[i+48>>1];x[114414]=0;h=O(1348,ua|0,i|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break M}w[h>>1]=a}Nt((D(e,896)+g|0)+1418|0);break J}h=D(e,896)+g|0;a=h+1422|0;j=y[f+4|0]|y[f+5|0]<<8;v[a|0]=j;v[a+1|0]=j>>>8;a=h+1418|0;j=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[a|0]=j;v[a+1|0]=j>>>8;v[a+2|0]=j>>>16;v[a+3|0]=j>>>24;R:{S:{switch(y[f+3|0]-16|0){case 1:Kb(i,u,5);if(!Ib(i)){break J}q=y[f+5|0];if(q){break R}break J;case 3:break N;case 4:break O;case 0:break S;default:break J}}q=y[f+5|0]}x[114414]=0;T(1349,b|0,g|0,q&255);a=x[114414];x[114414]=0;if((a|0)!=1){break J}}a=N()|0;break d}k=h+1461|0;j=h+1423|0;a=y[j|0];if(!a){if(x[b+480180>>2]&16777250){break L}a=y[j|0]}v[k|0]=a;break K}a=y[f+5|0];if((a&240)!=224){break J}L=(a&15)+1|0;break J}a=N()|0;break d}v[j|0]=y[h+1461|0]}a=y[f+5|0];h=a&240;if((h|0)==96){ga=(a&15)+ga|0;break J}if((h|0)!=224|L){break J}a=y[f+5|0]&15;if(x[b+480180>>2]&2){L=0;if(!a){break J}}L=a+1|0}f=f+6|0;e=e+1|0;if(e>>>0<z[b+480188>>1]){continue}break}break I}a=N()|0;break d}e=ga;if(L){break G}}L=1;ga=e}G=D(x[g+40>>2]+ga|0,L);T:{if(!z[b+480188>>1]){h=0;ha=0;pa=0;ba=0;ja=0;break T}m=G-1|0;j=G-L|0;V=D(j,1e4);e=0;ja=0;ba=0;pa=0;ha=0;h=0;while(1){U:{l=0;k=D(e,896)+g|0;n=k+1418|0;a=n;if(!(y[a|0]|y[a+1|0]|y[a+2|0])){l=!y[a+3|0]}V:{if(l){break V}Kb(i,u,77);if(ya=Ib(i),za=0,Ba=x[((e<<5)+b|0)+480280>>2]&1024,Ba?ya:za){break V}f=y[k+1423|0];ca=k+1421|0;q=y[ca|0];l=y[n|0];a=k+1419|0;o=y[a|0];if(o){v[k+1429|0]=0;v[k+1433|0]=o;ya=Tc(s,e),za=255,v[ya+21|0]=za}x[114414]=0;B=R(520,n|0)|0;o=x[114414];x[114414]=0;if((o|0)==1){break U}o=k+608|0;if(B){v[k+1429|0]=l;x[114414]=0;W(1350,o|0);B=x[114414];x[114414]=0;if((B|0)==1){break U}}x[114414]=0;B=R(520,n|0)|0;ka=x[114414];x[114414]=0;if((ka|0)==1){break U}W:{X:{Y:{Z:{_:{$:{if(!(B|y[a|0])){break $}B=k+1433|0;a=y[B|0];if(z[b+480192>>1]){if(z[b+480192>>1]<a>>>0){break $}a=x[((y[B|0]<<2)+b|0)+900380>>2];if(!a){break $}aa:{if(!(v[a+15|0]&1)){break aa}B=x[a+8>>2];x[114414]=0;T(1351,o|0,B|0,b|0);B=x[114414];x[114414]=0;if((B|0)!=1){break aa}a=N()|0;break d}if(!Zd(l)){break $}a=z[fd(a+236|0,l-1|0)>>1]}if(!a|z[b+480190>>1]<a>>>0){break $}a=D(a,104)+b|0;if(!(y[a+484414|0]&32)){break $}a=z[a+484408>>1];x[114414]=0;T(1351,o|0,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break _}}ba:{ca:{da:{B=k+1420|0;a=y[B|0];switch(a-1|0){case 1:break Y;case 2:case 3:break ca;case 0:break da;default:break ba}}a=y[k+1422|0];ya=Tc(s,e),za=a,v[ya+21|0]=za;break Y}a=y[k+1422|0];if(!a){break Y}v[k+1462|0]=a;break Y}if((a|0)==11){break Z}break Y}a=N()|0;break d}if(!y[k+1422|0]){break Y}My(i,b,n,0);a=mc(i);x[k+1384>>2]=x[i>>2];if(!y[a|0]){break Y}q=0;break X}ea:{fa:{ga:{switch(q-12|0){case 0:a=x[g+48>>2];l=z[g+60>>1];x[114414]=0;a=aa(1352,b|0,l|0,a|0,e&65535,0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break U}x[g+56>>2]=0;w[g+64>>1]=a;if(!(!(x[b+480180>>2]&5)&pa)){x[g+52>>2]=0}ba=1;if(!ea){ja=1;break V}x[k+1412>>2]=0;v[k+1469|0]=0;ja=1;break W;case 2:x[114414]=0;a=Z(1353,b|0,g|0,e&65535,f|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break fa}if((a|0)==-1){q=14;break X}x[g+52>>2]=a;if(!ja){w[g+64>>1]=z[g+62>>1]+1}pa=1;if(!ea){break V}x[k+1412>>2]=0;v[k+1469|0]=0;break W;case 5:Kb(i,u,5);q=17;if(Ib(i)){break X}a=x[g+48>>2];l=z[g+60>>1];x[114414]=0;a=aa(1352,b|0,l|0,a|0,e&65535,0)|0;l=x[114414];x[114414]=0;ha:{ia:{if((l|0)!=1){x[i+48>>2]=D(a,1e4);if(!ea|!(x[b+480180>>2]&16777250)){break ha}a=x[i+48>>2];if(a>>>0<1e4){break ia}v[k+1463|0]=(a>>>0)/1e4;break ha}a=N()|0;break d}x[i+48>>2]=D(y[k+1463|0],1e4)}a=x[b+8>>2];n=x[i+48>>2];if(n>>>0>=32e4){a=x[a+24>>2];x[114414]=0;x[i>>2]=D(a,1e4);a=O(1354,i+48|0,i|0)|0;l=x[114414];x[114414]=0;if((l|0)!=1){x[oa>>2]=x[a>>2];break X}a=N()|0;break d}l=x[oa>>2];ka=(n>>>0)/1e4|0;qa=D(V,ka&15);n=l-qa|0;x[oa>>2]=(ka&240)==16?l+qa|0:l>>>0>=n>>>0?n:0;l=x[a+20>>2];a=x[a+24>>2];Kb(i,u,8);yo(oa,D(l,1e4),Ib(i)?255e4:D(a,1e4));break X;case 8:q=20;ja:{switch((f&240)-144>>>4|0){case 0:if(f>>>0>145){break X}x[k+696>>2]=x[k+696>>2]&-257|((f|0)==145)<<8;break X;case 1:v[k+1464|0]=f&15;break X;case 2:n=e;a=e;if(x[b+480180>>2]==2){n=z[b+480188>>1]-1|0;a=0}if(!(f&15)){ba=0;h=1;l=n&65535;if(l>>>0<(a&65535)>>>0){break X}while(1){H=C[t+32>>3];h=a&65535;ya=Tc(s,h),Aa=H,C[ya>>3]=Aa;n=x[g>>2];ya=Tc(s,h),za=n,x[ya+8>>2]=za;n=x[g+48>>2];ya=Tc(s,h),za=n,x[ya+12>>2]=za;x[(D(h,896)+g|0)+1412>>2]=x[g+48>>2];h=1;a=a+1|0;if(l>>>0>=(a&65535)>>>0){continue}break}break X}Kb(i,u,16);if(!Ib(i)){ba=0;ha=1;if(x[b+480180>>2]!=2|(a&65535)>>>0>(n&65535)>>>0){break X}break ea}if((a&65535)>>>0<=(n&65535)>>>0){break ea}ba=0;ha=1;break X;case 6:break ja;default:break X}}v[k+1472|0]=f&15;break X;case 7:q=19;a=f&240;if((a|0)!=240){if((a|0)!=96){break X}if(f&15){ya=g,za=x[Tc(s,e)+12>>2],x[ya+56>>2]=za;ha=1;break X}H=C[t+32>>3];ya=Tc(s,e),Aa=H,C[ya>>3]=Aa;a=x[g>>2];ya=Tc(s,e),za=a,x[ya+8>>2]=za;a=x[g+48>>2];ya=Tc(s,e),za=a,x[ya+12>>2]=za;x[k+1412>>2]=x[g+48>>2];h=1;break X}v[k+1472|0]=f&15;break X;case 1:case 3:case 4:case 6:break X;default:break ga}}if((q|0)!=28){break X}if((f&240)==160){Kb(i,u,58);q=28;if(Ib(i)){break X}v[k+1464|0]=f&15;break X}q=28;break X}a=N()|0;break d}l=x[I>>2]+1|0;while(1){x[(D(a&65535,896)+g|0)+1412>>2]=l;ha=1;ba=0;a=a+1|0;if((a&65535)>>>0<=(n&65535)>>>0){continue}break}}if(!ea){break V}ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{switch(q-2|0){case 0:if(!f){break ka}Kb(i,u,90);if(!Ib(i)){v[k+1440|0]=f}v[k+1439|0]=f;break W;case 1:if(!f){break ka}Kb(i,u,90);if(!Ib(i)){v[k+1439|0]=f}v[k+1440|0]=f;break W;case 2:if(!f){break ka}x[k+1384>>2]=f;break W;case 8:if(!f){break ka}x[k+1272>>2]=f<<8;break W;case 4:case 9:if(!f){break ka}v[k+1437|0]=f;break W;case 11:ya=Tc(s,e),za=f,v[ya+21|0]=za;break W;case 21:f=f<<(!(x[b+480180>>2]&59593760)&f<<24>>24>=0);a=f&255;if(a>>>0<=128){x[_>>2]=a<<1;break W}if(x[b+480180>>2]&16777250){break W}x[_>>2]=256;break W;case 22:Kb(i,u,9);sa:{if(Ib(i)){a=k+1445|0;if(f){v[a|0]=f;break sa}f=y[a|0];break sa}if(f){v[g+1445|0]=f;break sa}f=y[g+1445|0]}a=f&15;l=f&255;ta:{if(!((a|0)!=15|l>>>0<16)){f=(f&240)>>>4<<!(x[b+480180>>2]&59593760);a=x[_>>2]+(f<<1)|0;break ta}l=l&240;if(!(!a|(l|0)!=240)){f=a<<(x[b+480180>>2]&59593760?1:2);a=x[_>>2]-f|0;break ta}if(l){f=(f>>>3&30)<<!(x[b+480180>>2]&59593760);a=x[_>>2]+D(j,f)|0;break ta}f=a<<(x[b+480180>>2]&59593760?1:2);a=x[_>>2]-D(j,f)|0}x[_>>2]=a;_d(_,0,256);break W;case 19:if(f>>>0>64){break W}x[k+1368>>2]=f;break W;case 20:a=k+1444|0;ua:{if(f){v[a|0]=f;break ua}f=y[a|0]}q=k+1368|0;a=x[q>>2];l=f&15;n=f&255;va:{if(!((l|0)!=15|n>>>0<16)){x[i>>2]=a+(n>>>4|0);break va}if(!(!l|(n&240)!=240)){x[i>>2]=a-l;break va}if(l){x[i>>2]=a-D(j,l);break va}x[i>>2]=a+D(j,n>>>4|0)}_d(i,0,64);x[q>>2]=x[i>>2];break W;case 7:Sl(b,o,f,8);break W;case 25:break la;case 6:break ma;case 24:break na;case 3:break oa;case 5:break pa;case 18:break qa;case 17:break ra;default:break W}}if(!z[b+480188>>1]|f>>>0>15){break qa}l=(f&1)<<14;a=0;while(1){n=D(a,896)+g|0;x[n+696>>2]=(l|x[n+696>>2]&-16385)^16384;a=a+1|0;if(a>>>0<z[b+480188>>1]){continue}break}}if((f&240)!=128){break W}Sl(b,o,f&15,4);break W}if(f){v[k+1437|0]=f}f=0}Ek(o,f);break W}gN(b,o,f);break W}fN(o,f);break W}eN(o,f);break W}f=0}wa:{xa:{switch(y[B|0]-2|0){case 0:Sl(b,o,y[k+1422|0],6);break wa;case 5:Kb(i,u,53);l=Ib(i);a=y[k+1422|0];if(l){v[k+1451|0]=a&15;break wa}Ek(o,a<<4);break wa;case 6:break xa;default:break wa}}Ek(o,y[k+1422|0])}ya:{za:{Aa:{Ba:{Ca:{a=y[ca|0];switch(a-5|0){case 1:break ya;case 3:break Aa;case 0:case 2:break Ba;default:break Ca}}switch(a-26|0){case 1:break za;case 0:break Ba;default:break ya}}Da:{if(x[b+480180>>2]&16777248){a=G;if(!(y[b+480208|0]&4)){break Da}}a=j}l=y[k+1451|0];Kb(i,u,21);n=Ib(i);k=k+1447|0;a=D(a,l);v[k|0]=y[k|0]+(n?a<<2:a);break ya}Ea:{if(x[b+480180>>2]&16777248){a=G;if(!(y[b+480208|0]&4)){break Ea}}a=j}l=y[k+1454|0];Kb(i,u,21);n=Ib(i);k=k+1448|0;a=D(a,l);v[k|0]=y[k|0]+(n?a<<2:a);break ya}a=k+1449|0;v[a|0]=y[a|0]+D(m,y[k+1457|0]);x[114414]=0;P(1355,b|0,o|0);a=x[114414];x[114414]=0;if((a|0)==1){break U}}Kb(i,u,78);if(!Ib(i)){break V}a=f&255;if(!a){break V}dN(o,a)}e=e+1|0;if(e>>>0<z[b+480188>>1]){continue}break T}break}a=N()|0;break d}if(x[b+480180>>2]==4&x[g+40>>2]==65535){break j}x[g+32>>2]=x[b+480216>>2];if(cN(Zb(K,z[g+60>>1]))){ya=g,za=x[Zb(K,z[g+60>>1])+16>>2],x[ya+32>>2]=za}x[114414]=0;k=O(1356,b|0,g|0)|0;a=x[114414];x[114414]=0;Fa:{Ga:{if((a|0)!=1){a=D(k,G);C[t+32>>3]=+(a>>>0)/+A[b+24620>>2]+C[t+32>>3];x[g>>2]=a+x[g>>2];if(!(!z[b+480188>>1]|wa)){q=0;B=(J|0)!=0&(k|0)!=(J|0);ka=G>>>0<=1?1:G;qa=L-1|0;while(1){Ha:{if(x[Tc(s,q)+16>>2]==-1){break Ha}n=1;Ia:{Ja:{m=D(q,896)+g|0;V=m+1421|0;switch(y[V|0]-4|0){case 0:case 2:break Ia;default:break Ja}}n=y[m+1420|0]==11}if(y[m+1419|0]){x[m+1268>>2]=0}f=m+1423|0;e=y[f|0];x[114414]=0;ca=m+1418|0;a=R(520,ca|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break o}o=m+608|0;j=e&15;l=0;Ka:{if(!a){break Ka}La:{Ma:{Na:{if(!n){break Na}if(!y[Tc(s,q)+20|0]){break Na}a=x[m+1308>>2];x[114414]=0;a=Lo(1357,b,o,a,0);l=lb;la=x[114414];x[114414]=0;if((la|0)==1){break Ma}x[m+616>>2]=a;x[m+620>>2]=l}v[m+1432|0]=y[m+1429|0];la=m+1300|0;xa=x[la>>2];a=y[m+1433|0];if(!a){break La}x[114414]=0;ia(1358,b|0,o|0,a|0,n|0,1,1);a=x[114414];x[114414]=0;if((a|0)!=1){break La}break n}a=N()|0;break d}a=y[ca|0];x[114414]=0;fa(1359,b|0,o|0,a|0,n|0,1,0,65535);a=x[114414];x[114414]=0;if((a|0)==1){break n}a=e>>>4|0;ya=Tc(s,q),za=1,v[ya+20|0]=za;e=y[V|0];Oa:{if(!((y[f|0]&240)!=208|(e-19&255)>>>0>1)){l=j;if(j>>>0<G>>>0){break Oa}}l=(e|0)==33?a>>>0<G>>>0?a:0:0}l=!(x[b+480180>>2]&16777250)|(!l|L>>>0<2)?l:D(x[g+40>>2]+ga|0,qa)+l|0;if(!n){ya=Tc(s,q),za=0,x[ya+16>>2]=za}e=y[V|0];Pa:{Qa:{if((e|0)==9){break Qa}Ra:{if((e|0)!=19){if((e|0)!=20|(a|0)!=8){break Ra}break Qa}if((a|0)==8){break Qa}}if(y[m+1420|0]!=2){break Pa}}x[la>>2]=xa}Sa:{Ta:{switch(e-39|0){default:if((e|0)!=10){break Sa}v[i|0]=0;a=x[g+48>>2];e=z[g+60>>1];x[114414]=0;a=aa(1352,b|0,e|0,a|0,q&65535,i|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){if(!y[i|0]){a=a<<8;if(!a){a=x[m+1272>>2]}a=(y[m+1464|0]<<16)+a|0}x[114414]=0;T(1360,b|0,o|0,a|0);a=x[114414];x[114414]=0;if((a|0)!=1){break Ka}}a=N()|0;break d;case 2:a=x[m+684>>2];e=y[f|0];x[114414]=0;e=yna(a,0,e,0);a=lb;la=a>>>8|0;a=_f(722,(a&255)<<24|e>>>8,la);e=x[114414];x[114414]=0;if((e|0)==1){break n}x[114414]=0;T(1360,b|0,o|0,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break n}break Ka;case 1:break Sa;case 0:break Ta}}if(!x[m+712>>2]){break Sa}x[114414]=0;X(1361,t|0,q&65535,J|0,-1);a=x[114414];x[114414]=0;if((a|0)==1){break n}a=y[f|0];x[114414]=0;T(1362,g|0,o|0,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break n}l=x[g+40>>2]-1|0;break Ka}if(y[m+1420|0]!=15){break Ka}e=x[m+712>>2];if(!e){break Ka}a=y[m+1422|0];if(a>>>0>9){break Ka}Ua:{if(!a){a=x[m+1272>>2];break Ua}a=x[(e+(a<<2)|0)- -64>>2];x[m+1272>>2]=a}x[114414]=0;T(1360,b|0,o|0,a|0);a=x[114414];x[114414]=0;if((a|0)!=1){break Ka}a=N()|0;break d}Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{switch(y[ca|0]-253|0){case 0:if(z[b+480192>>1]){break bb}break;case 1:case 2:break bb;default:break cb}}e=y[V|0];if((e-19&255)>>>0<=1){if((y[f|0]&240)!=192){a=h;break $a}a=h;if(j>>>0<G>>>0){break bb}break $a}if((e|0)==33&(j|0)!=0&j+l>>>0<G>>>0){break bb}a=h;if((e|0)!=25){break ab}}e=y[V|0];a=1}if((e|0)==13){break _a}}if(y[m+1420|0]==1){x[m+1296>>2]=y[m+1422|0]<<2}if((!x[m+712>>2]|a)&1){break Za}j=0;if(e>>>0>42){break Xa}break Ya}x[m+1296>>2]=y[f|0]<<2;e=13;if(!((!x[m+712>>2]|a)&1)){break Ya}}if(!(a&1)){break Wa}break Va}Kb(i,M,e);j=1;if(Ib(i)){break Xa}j=a;if(y[V|0]!=19){break Xa}e=y[f|0]&240;if((e|0)!=32){j=a;if((e|0)!=16){break Xa}}j=1}a=m+1420|0;if(y[a|0]<16){ol(i,sa,y[a|0]);if((Ib(i)|j)&1){break Va}break Wa}if(j&1){break Va}}if(B){x[114414]=0;X(1361,t|0,q&65535,J|0,-1);a=x[114414];x[114414]=0;if((a|0)==1){break o}}db:{eb:{fb:{a=y[V|0];if(a-6>>>0>=2){gb:{switch(a-19|0){case 1:break eb;case 0:break fb;default:break gb}}if((a|0)!=11){break db}}if(!G|!y[f|0]&x[b+480180>>2]==1){break db}a=m+1480|0;e=0;while(1){v[a|0]=!e|y[a|0]&254;wn(b,o,y[f|0]);e=e+1|0;if((ka|0)!=(e|0)){continue}break}break db}e=y[f|0];if(!(e&15)){if(!(x[b+480180>>2]&1048580)){break db}e=y[f|0]}a=m+1480|0;v[a|0]=y[a|0]|1;a=e&240;if((a|0)!=176){if((a|0)!=160){break db}Dp(b,o,e&15,0);break db}Cp(b,o,e&15,0);break db}hb:{ib:{jb:{a=y[f|0];switch(a-158|0){case 1:break ib;case 0:break jb;default:break hb}}x[114414]=0;X(1361,t|0,q&65535,J|0,-1);a=x[114414];x[114414]=0;if((a|0)==1){break o}x[m+696>>2]=x[m+696>>2]&-129;break db}x[114414]=0;X(1361,t|0,q&65535,J|0,-1);a=x[114414];x[114414]=0;if((a|0)==1){break o}x[m+696>>2]=x[m+696>>2]|128;if(!x[m+684>>2]|x[o+4>>2]){break db}x[114414]=0;a=R(520,ca|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break o}if(!(y[m+696|0]&2?a:1)){break db}a=x[m+684>>2]-1|0;x[o>>2]=-1;x[o+4>>2]=a;break db}if((a&240)!=112|a>>>0<115){break db}x[114414]=0;T(1363,o|0,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break o}}a=m+1480|0;v[a|0]=y[a|0]|1;kb:{lb:{mb:{nb:{e=m+1420|0;switch(y[e|0]-3|0){case 0:case 1:break lb;case 3:break mb;case 2:break nb;default:break kb}}a=y[m+1422|0];Kb(i,u,41);Dp(b,o,a,Ib(i));break kb}a=y[m+1422|0];Kb(i,u,41);Cp(b,o,a,Ib(i));break kb}f=y[m+1422|0];ob:{if(f){break ob}Kb(i,u,41);f=0;if(!Ib(i)){break ob}f=y[m+1462|0];if(!f){break kb}}if(!G){break kb}e=y[e|0]==3?f<<4:f;f=0;while(1){v[a|0]=!f|y[a|0]&254;wn(b,o,e&255);f=f+1|0;if((G|0)!=(f|0)){continue}break}}if(n){a=x[Tc(s,q)+16>>2];e=Tc(s,q);x[e+16>>2]=x[e+16>>2]+G;x[114414]=0;X(1361,t|0,q&65535,k|0,(a+l|0)+1|0);a=x[114414];x[114414]=0;if((a|0)!=1){break Ha}a=N()|0;break d}a=Tc(s,q);x[a+16>>2]=x[a+16>>2]+(G-l|0);break Ha}x[114414]=0;W(1364,o|0);a=x[114414];x[114414]=0;if((a|0)==1){break o}ya=Tc(s,q),za=0,x[ya+16>>2]=za}q=q+1|0;if(q>>>0<z[b+480188>>1]){continue}break}}if(!ha){break Fa}Kb(i,u,68);if(ya=Ib(i),za=0,Ba=ja|pa,Ba?ya:za){break Fa}a=i+48|0;Kb(a,u,49);if(Ib(a)&ja){break Fa}a=i+40|0;Kb(a,u,103);J=k;if(Ib(a)&ba){continue}f=0;h=hb-16|0;hb=h;e=h+8|0;a=hb-16|0;hb=a;x[114414]=0;R(1382,i+4|0)|0;j=x[114414];x[114414]=0;pb:{qb:{if((j|0)==1){break qb}x[114414]=0;x[a+12>>2]=0;U(1383,i+8|0,a+12|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break qb}ya=i,za=mc(i),x[ya>>2]=za;hb=a+16|0;a=i;break pb}S(0)|0;zb();p()}e=a;hb=h+16|0;if(!z[b+480188>>1]){break Ga}while(1){rb:{h=D(f,896)+g|0;a=y[h+1423|0];h=y[h+1421|0];if(!(!(!((h|0)!=20|a>>>0<177)&a>>>0<192)&(a>>>0<97|a>>>0>111|(h|0)!=19))){H=C[Tc(s,f)>>3];x[114414]=0;C[i+48>>3]=H;h=O(1365,e|0,i+48|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break rb}if(!x[h>>2]){x[114414]=0;h=O(1365,e|0,i+48|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break rb}x[h>>2]=1}x[114414]=0;h=O(1365,e|0,i+48|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break rb}h=x[h>>2];x[114414]=0;a=O(1366,h|0,(a&15)+1|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break rb}x[114414]=0;h=O(1365,e|0,i+48|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break rb}x[h>>2]=a}f=f+1|0;if(f>>>0<z[b+480188>>1]){continue}break Ga}break}break p}a=N()|0;break d}ya=i,za=Gj(e),x[ya+40>>2]=za;ya=i,za=Ti(e),x[ya+32>>2]=za;while(1){x[114414]=0;a=O(1367,i+40|0,i+32|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break p}if(!a){sb:{if(x[b+480180>>2]!=32){break sb}f=0;if(!z[b+480188>>1]){break sb}while(1){a=D(f,896)+g|0;if(!(y[a+1421|0]!=20|(y[a+1423|0]+79&255)>>>0>14)){H=C[t+32>>3];ya=Tc(s,f),Aa=H,C[ya>>3]=Aa;a=x[g>>2];ya=Tc(s,f),za=a,x[ya+8>>2]=za}f=f+1|0;if(f>>>0<z[b+480188>>1]){continue}break}}XM(e);break Fa}x[114414]=0;a=R(1368,i+40|0)|0;h=x[114414];x[114414]=0;tb:{ub:{if((h|0)!=1){h=yb(a);H=C[t+32>>3];C[t+32>>3]=(H-C[a>>3])*+(x[h>>2]-1|0)+H;f=0;if(z[b+480188>>1]){break ub}break tb}break p}while(1){if(C[Tc(s,f)>>3]!=C[a>>3]){f=f+1|0;if(f>>>0<z[b+480188>>1]){continue}break tb}break}a=x[g>>2];j=Tc(s,f);x[g>>2]=x[g>>2]+D(x[h>>2]-1|0,a-x[j+8>>2]|0);a=i+48|0;Kb(a,u,16);if(!Ib(a)&x[b+480180>>2]!=2){break tb}H=C[t+32>>3];ya=Tc(s,f),Aa=H,C[ya>>3]=Aa;a=x[g>>2];ya=Tc(s,f),za=a,x[ya+8>>2]=za;a=x[g+48>>2];ya=Tc(s,f),za=a+1|0,x[ya+12>>2]=za}x[114414]=0;R(1369,i+40|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){continue}break}break p}J=k;continue}}a=N()|0;break d}a=N()|0;XM(e);break d}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}v[r+26|0]=1}vb:{wb:{if(!(!z[b+480188>>1]|(ta|0)!=7)){a=0;while(1){if(x[Tc(s,a)+16>>2]!=-1){x[114414]=0;X(1361,t|0,a&65535,J|0,-1);e=x[114414];x[114414]=0;if((e|0)==1){break wb}}a=a+1|0;if(a>>>0<z[b+480188>>1]){continue}break}}if(y[r+26|0]){w[r+20>>1]=z[g+62>>1];x[r+8>>2]=x[g+48>>2]}C[r>>3]=C[t+32>>3];x[114414]=0;P(1343,ma|0,r|0);a=x[114414];x[114414]=0;if((a|0)==1){break vb}xb:{yb:{if(!ea){break yb}zb:{if(x[d+16>>2]?y[r+26|0]:1){d=b+1074376|0;e=sc(d,g,602);a=0;while(1){h=D(a,896);Bp((h+e|0)+608|0,(g+h|0)+608|0);a=a+1|0;if((a|0)!=256){continue}break}Ly(d);a=0;x[b+1074400>>2]=0;v[b+1074464|0]=1;d=b+1074392|0;x[d>>2]=-2;x[d+4>>2]=0;x[b+1074428>>2]=x[b+1074424>>2];d=b+1304392|0;if(zd(d)){e=x[d>>2];x[114414]=0;W(1370,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break vb}}Ab:{if(z[b+480188>>1]){g=(ta|0)==7;while(1){e=D(a,896)+b|0;h=y[e+1075805|0];if(h){v[e+1075808|0]=h}if(!(y[Tc(s,a)+21|0]==255|g)){h=Tc(s,a);x[114414]=0;v[i|0]=64;h=O(409,h+21|0,i|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break Ab}x[e+1075672>>2]=y[h|0]<<2}Bb:{h=e+1075088|0;j=x[h>>2];if(!j|!(y[j+35|0]&2)){break Bb}if(!zd(d)){break Bb}j=x[d>>2];h=x[h>>2];x[114414]=0;k=j;j=a&65535;T(1371,k|0,j|0,h+68|0);h=x[114414];x[114414]=0;if((h|0)!=1){h=x[d>>2];x[114414]=0;T(1372,h|0,j|0,1);h=x[114414];x[114414]=0;if((h|0)!=1){break Bb}}a=N()|0;break d}x[e+1075e3>>2]=0;a=a+1|0;if(a>>>0<z[b+480188>>1]){continue}break}}d=Fz(i);ya=i,za=Gj(ua),x[ya+40>>2]=za;ya=i,za=Ti(ua),x[ya+32>>2]=za;Cb:{while(1){Db:{x[114414]=0;a=O(1373,i+40|0,i+32|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Db}if(!a){e=250;a=d;Eb:{while(1){j=1;if(x[a>>2]){break Eb}a=a+4|0;e=e-32|0;if(e>>>0>31){continue}break}j=(x[d+28>>2]&67108863)!=0}if(!j){break zb}a=0;while(1){e=i+48|0;Kb(e,d,a);Fb:{if(!Ib(e)){break Fb}e=x[(D(a,160)+b|0)+906300>>2];g=x[x[e>>2]+172>>2];x[114414]=0;W(g|0,e|0);e=x[114414];x[114414]=0;if((e|0)!=1){break Fb}a=N()|0;break d}a=a+1|0;if((a|0)!=250){continue}break}break zb}x[114414]=0;e=R(1374,i+40|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break Cb}g=y[e|0]-1&255;a=x[(D(g,160)+b|0)+906300>>2];if(a){h=i+48|0;Kb(h,d,g);if(!Ib(h)){x[114414]=0;U(1375,d|0,g|0,1)|0;g=x[114414];x[114414]=0;if((g|0)==1){break xb}g=x[x[a>>2]+168>>2];x[114414]=0;P(g|0,a|0,-1);g=x[114414];x[114414]=0;if((g|0)==1){break xb}}g=z[e+2>>1];h=x[x[a>>2]+44>>2];e=z[e+4>>1];x[114414]=0;va(h|0,a|0,g|0,E(E(E(e>>>0)*E(.0010010009864345193))));a=x[114414];x[114414]=0;if((a|0)==1){break xb}}x[114414]=0;R(1376,i+40|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){continue}}break}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}if((c|0)==3){break zb}x[b+1074416>>2]=x[b+480196>>2];x[b+1074420>>2]=x[b+480204>>2];x[b+1074444>>2]=x[b+480200>>2]}if(y[na+16|0]==(da|0)){break yb}x[114414]=0;P(444,na|0,da|0);a=x[114414];x[114414]=0;if((a|0)==1){break vb}}if(c&9){x[114414]=0;P(1377,b+1304360|0,Y|0);a=x[114414];x[114414]=0;if((a|0)==1){break vb}}et(Y);aN(t);hb=i+176|0;return}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}a=N()|0}et(Y);break c}a=N()|0}aN(t);break b}a=N()|0}_l(ma);Q(a|0);p()}function cja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;e=hb-1760|0;hb=e;Lc(b);f=hb-16|0;hb=f;i=f+8|0;g=e+1632|0;rQ(i,g);h=Eb(i);i=nc(b,ac(f,i));if((h|0)==(i|0)){cc(b,Eb(f+8|0))}hb=f+16|0;f=(h|0)==(i|0);if(!f){sQ(g)}a:{if(!f){break a}if(!zQ(e+1632|0)){break a}if(!Qb(b,jd(256,0))){break a}b:{if(!c){break b}Nd(a,1048576);Gi(a);d=Ub(e+1616|0,10936);x[114414]=0;P(187,e+1360|0,d|0);f=x[114414];x[114414]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((f|0)!=1){q=e+1640|0;x[e+160>>2]=y[q+1|0];f=y[q|0];x[114414]=0;x[e+24>>2]=f;P(637,e+88|0,e+24|0);f=x[114414];x[114414]=0;if((f|0)==1){break q}x[114414]=0;X(622,e+272|0,e+1360|0,e+160|0,e+88|0);f=x[114414];x[114414]=0;if((f|0)==1){break p}f=e+272|0;Db(a+1304436|0,f);xb(f);i=e+88|0;xb(i);g=e+1360|0;Gb(g);xb(d);d=Ub(f,10708);Db(a+1304448|0,d);xb(d);Kg(i,2,e+1642|0);Ic(g,i);x[114414]=0;T(13,f|0,7,g|0);d=x[114414];x[114414]=0;if((d|0)==1){break k}d=e+272|0;Db(a+1304460|0,d);xb(d);f=e+1360|0;xb(f);x[a+1304496>>2]=7;Bu(f,2,e+1674|0);Ic(d,f);Db(a+1304400|0,d);xb(d);d=e+1744|0;w[a+480188>>1]=y[d|0]|y[d+1|0]<<8;d=Md(y[e+1748|0],1,31);x[a+480204>>2]=125e4;x[a+480208>>2]=32792;x[a+480196>>2]=d;u=e+1754|0;w[a+480192>>1]=y[u|0]|y[u+1|0]<<8;B=e+1756|0;w[a+480190>>1]=y[B|0]|y[B+1|0]<<8;d=Md(y[e+1749|0],1,32);x[a+480216>>2]=d;x[a+480228>>2]=96;x[a+480232>>2]=48;x[a+480220>>2]=d<<2;Su(b,f);C=a+484360|0;r=e+1738|0;Dq(Vb(C),f,y[r|0]|y[r+1|0]<<8,65535,65535);d=e+1740|0;Se(Vb(C),y[d|0]|y[d+1|0]<<8);o=pg(b);Bd(e+1344|0,b,o?274:0);x[114414]=0;d=R(391,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break m}x[114414]=0;T(307,e+1328|0,b|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break m}s=z[a+480188>>1];if(o){w[a+480188>>1]=s+8}t=c&1;if(!t){break l}d=e+1742|0;d=y[d|0]|y[d+1|0]<<8;x[114414]=0;P(362,a+484344|0,d|0);d=x[114414];x[114414]=0;if((d|0)!=1){break l}break f}f=N()|0;break n}f=N()|0;break o}f=N()|0;xb(e+88|0)}Gb(e+1360|0)}xb(d);break c}f=N()|0;break d}m=e+1742|0;if(!(y[m|0]|y[m+1|0]<<8)){break g}E=a+484344|0;F=e+1750|0;g=0;while(1){x[114414]=0;d=R(321,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break h}x[114414]=0;x[e+160>>2]=d;d=R(391,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break i}x[114414]=0;T(307,e+272|0,b|0,d+1&-2);d=x[114414];x[114414]=0;if((d|0)==1){break i}xc(e+160|0,1024);r:{if(!t){break r}d=x[e+160>>2];if(!d){break r}x[114414]=0;d=U(363,E|0,g&65535,d|0)|0;f=x[114414];x[114414]=0;s:{if((f|0)!=1){if(!d){break r}j=0;if(v[F|0]&1){h=0;while(1){x[114414]=0;d=O(226,e+272|0,1)|0;f=x[114414];x[114414]=0;t:{if((f|0)!=1){if(!d){break r}x[114414]=0;d=R(403,e+272|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break j}f=0;if((d|0)!=255){break t}x[114414]=0;f=R(403,e+272|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){x[114414]=0;d=R(403,e+272|0)|0;i=x[114414];x[114414]=0;if((i|0)!=1){break t}}break j}break j}u:{if(!(d&127)){break u}i=Zb(E,g);x[114414]=0;i=U(427,i|0,h|0,j&65535)|0;k=x[114414];x[114414]=0;if((k|0)==1){break j}v[e+88|0]=0;v[e+89|0]=0;v[e+90|0]=0;v[e+91|0]=0;v[e+91|0]=0;v[e+92|0]=0;v[e+93|0]=0;v[e+94|0]=0;if(d&1){x[114414]=0;k=R(403,e+272|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break j}v[e+88|0]=k}if(d&2){x[114414]=0;k=R(403,e+272|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break j}v[e+89|0]=k}if(d&4){x[114414]=0;k=R(403,e+272|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break j}v[e+90|0]=k}if(d&8){x[114414]=0;k=R(403,e+272|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break j}v[e+91|0]=k}if(d&16){x[114414]=0;k=R(403,e+272|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break j}v[e+92|0]=k}if(d&32){x[114414]=0;k=R(403,e+272|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break j}v[e+93|0]=k}if(d&64){x[114414]=0;d=R(403,e+272|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break j}v[e+94|0]=d}x[114414]=0;d=O(869,i|0,e+88|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break j}x[114414]=0;x[e+24>>2]=f;x[e+256>>2]=x[e+160>>2]+(h^-1);l=O(297,e+24|0,e+256|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break j}n=d|n;k=0;d=i;G=x[l>>2];if(!G){break u}while(1){d=D(z[a+480188>>1],6)+d|0;l=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);v[d|0]=l;v[d+1|0]=l>>>8;v[d+2|0]=l>>>16;v[d+3|0]=l>>>24;l=y[i+4|0]|y[i+5|0]<<8;v[d+4|0]=l;v[d+5|0]=l>>>8;k=k+1|0;if((G|0)!=(k|0)){continue}break}}h=(f+h|0)+1|0;d=x[e+160>>2];if(h>>>0>=d>>>0){while(1){j=j+1|0;h=h-d|0;if(d>>>0<=h>>>0){continue}break}}if(s>>>0>(j&65535)>>>0){continue}break}break r}f=0;if(x[e+160>>2]){break s}break r}break j}while(1){d=Zb(E,g);x[114414]=0;i=O(453,d|0,f|0)|0;d=x[114414];x[114414]=0;v:{w:{if((d|0)!=1){d=0;if(s){break w}break v}break j}while(1){x:{x[114414]=0;O(870,e+272|0,e+88|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break x}x[114414]=0;h=O(869,i+D(d,6)|0,e+88|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break x}n=h|n;d=d+1|0;if((s|0)!=(d|0)){continue}break v}break}break j}f=f+1|0;if(f>>>0<A[e+160>>2]){continue}break}}Ab(e+272|0);g=g+1|0;if(g>>>0<(y[m|0]|y[m+1|0]<<8)>>>0){continue}break}break g}f=N()|0;xb(e+1360|0);break c}f=N()|0;Ab(e+272|0);break e}f=N()|0;break e}f=N()|0;break e}d=e+1746|0;f=y[d+1|0]<<8;if(!((y[d|0]|f)>>>0<=1|(f|y[d|0])>>>0>4999)){y:{if(n&1){f=y[d|0]|y[d+1|0]<<8;d=0;x[114414]=0;h=_f(410,((f>>>1|0)+11025e5>>>0)/(f>>>0)|0,0);f=x[114414];x[114414]=0;if((f|0)==1){break f}break y}f=x[a+480216>>2];i=x[a+480196>>2];d=y[d|0]|y[d+1|0]<<8;x[114414]=0;h=na(549,+(2646e7/+(D(d,D(f,i))>>>0)))|0;f=x[114414];x[114414]=0;d=2;if((f|0)!=1){break y}f=N()|0;break e}x[a+480224>>2]=d;x[a+480204>>2]=h}d=z[a+480188>>1];x[114414]=0;v[e+272|0]=0;E=U(871,e+1312|0,d|0,e+272|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){f=a+1304412|0;i=a+484344|0;h=a+1304424|0;l=e+272|3;k=0;z:{A:{B:{C:{D:{while(1){x[114414]=0;d=O(226,e+1328|0,8)|0;g=x[114414];x[114414]=0;E:{if((g|0)!=1){if(d){break E}if(z[a+480188>>1]){d=0;while(1){f=v[Bc(E,d)|0];F:{if((f|0)<=(d|0)|(f|0)>=z[a+480188>>1]){break F}g=((f<<5)+a|0)+480288|0;f=y[g|0];if(!f){break F}h=((d<<5)+a|0)+480288|0;j=y[h|0];if(!j){v[h|0]=f;break F}h=(D(j-1&255,160)+a|0)+906300|0;if((Sj(h)|0)!=255){while(1){h=(D(Sj(h),160)+a|0)+906300|0;if((Sj(h)|0)!=255){continue}break}}f=h+28|0;g=y[g|0]-1&255;g=g>>>0<250?g+128|0:0;v[f|0]=g;v[f+1|0]=g>>>8;v[f+2|0]=g>>>16;v[f+3|0]=g>>>24}d=d+1|0;if(d>>>0<z[a+480188>>1]){continue}break}}x[e+264>>2]=0;x[e+268>>2]=0;x[e+256>>2]=0;x[e+260>>2]=0;x[e+248>>2]=0;x[e+252>>2]=0;x[e+240>>2]=0;x[e+244>>2]=0;G:{H:{I:{J:{K:{L:{if(o){h=0;x[114414]=0;O(872,e+1344|0,e+272|0)|0;d=x[114414];x[114414]=0;M:{if((d|0)!=1){while(1){d=z[a+480192>>1];x[114414]=0;d=O(873,a|0,d+1&65535)|0;f=x[114414];x[114414]=0;N:{O:{P:{Q:{R:{S:{T:{if((f|0)!=1){f=h<<1;g=f+(e+256|0)|0;w[g>>1]=d;l=f+(e+240|0)|0;f=e+f|0;j=f+274|0;w[l>>1]=y[j|0]|y[j+1|0]<<8;if((d|0)==65535){break O}f=y[f+274|0]|y[f+275|0]<<8;x[114414]=0;d=U(405,a|0,d|0,f+1&65535)|0;f=x[114414];x[114414]=0;if((f|0)==1){break T}if(!d){break N}x[114414]=0;P(465,e+160|0,11504);f=x[114414];x[114414]=0;if((f|0)==1){break S}x[114414]=0;x[e+24>>2]=h+1;T(874,e+88|0,e+160|0,e+24|0);f=x[114414];x[114414]=0;if((f|0)==1){break R}x[114414]=0;O(334,d+492|0,e+88|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break Q}xb(e+88|0);Gb(e+160|0);break N}f=N()|0;break z}f=N()|0;break z}f=N()|0;break z}f=N()|0;break P}f=N()|0;xb(e+88|0)}Gb(e+160|0);break z}w[g>>1]=0}h=h+1|0;if((h|0)!=8){continue}break M}}f=N()|0;break z}f=y[e+272|0]|y[e+273|0]<<8;d=0;x[114414]=0;l=O(360,e+224|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break G}if(y[e+272|0]|y[e+273|0]<<8){while(1){x[114414]=0;f=R(321,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break I}x[114414]=0;T(307,e+88|0,b|0,f<<5);f=x[114414];x[114414]=0;if((f|0)==1){break J}f=e+88|0;Ud(vc(l,d),f);Ab(f);d=d+1|0;if(d>>>0<(y[e+272|0]|y[e+273|0]<<8)>>>0){continue}break}}d=y[m|0]|y[m+1|0]<<8;x[114414]=0;n=U(875,e+208|0,d|0,23944)|0;d=x[114414];x[114414]=0;if((d|0)==1){break K}if(y[r|0]|y[r+1|0]<<8){g=0;while(1){h=e+g|0;U:{if(y[h+290|0]>=(y[e+272|0]|y[e+273|0]<<8)>>>0){break U}if(z[uc(Vb(C),g)>>1]>=(y[m|0]|y[m+1|0]<<8)>>>0){break U}f=z[uc(Vb(C),g)>>1];V:{if(z[uc(n,f)>>1]==65535){d=y[h+290|0];I=uc(n,f),J=d,w[I>>1]=J;break V}if(z[uc(n,f)>>1]==y[h+290|0]){break V}x[114414]=0;d=U(876,i|0,f|0,0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break L}if((d|0)==65535){break V}I=uc(Vb(C),g),J=d,w[I>>1]=J;f=d}x[114414]=0;d=O(392,i|0,f|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break L}if(!d){break U}t=vc(l,y[h+290|0]);Lc(t);x[114414]=0;d=R(223,t|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break L}if(!x[Zb(i,f)+12>>2]){break U}F=d>>>5|0;j=0;while(1){d=Zb(i,f);h=z[a+480188>>1];x[114414]=0;d=U(427,d|0,j|0,h-8&65535)|0;h=x[114414];x[114414]=0;if((h|0)==1){break L}h=0;while(1){Zh(e+88|0);o=z[e+92>>1];v[d+4|0]=o;v[d+5|0]=o>>>8;o=x[e+88>>2];v[d|0]=o;v[d+1|0]=o>>>8;v[d+2|0]=o>>>16;v[d+3|0]=o>>>24;W:{if(j>>>0>=F>>>0){break W}x[114414]=0;O(877,t|0,e+88|0)|0;o=x[114414];x[114414]=0;if((o|0)==1){break L}if(v[e+88|0]>=0){break W}v[d|0]=61;v[d+1|0]=y[(e+256|0)+(h<<1)|0];o=y[e+88|0]&31;v[e+160|0]=o;if(o){_e(e+160|0,15);v[d+3|0]=20;v[d+5|0]=y[e+160|0]|208}v[d+2|0]=1;v[d+4|0]=y[e+89|0]+3>>>2}d=d+6|0;h=h+1|0;if((h|0)!=8){continue}break}j=j+1|0;if(j>>>0<A[Zb(i,f)+12>>2]){continue}break}}g=g+1|0;if(g>>>0<(y[r|0]|y[r+1|0]<<8)>>>0){continue}break}}qf(n);id(l)}d=e+1750|0;if(!(!(y[d|0]&2)|!(y[m|0]|y[m+1|0]<<8))){d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=(((d&8?z[a+480188>>1]:s)&65535)+((y[q|0]|y[q+1|0]<<8)>>>0>591?k:0)|0)+(d>>>4&1)|0;j=0;while(1){h=0;X:{if(!d){break X}while(1){Y:{x[114414]=0;f=O(226,b|0,4)|0;i=x[114414];x[114414]=0;if((i|0)==1){break Y}if(!f){break X}f=y[q|0]|y[q+1|0]<<8;x[114414]=0;P(878,f|0,b|0);f=x[114414];x[114414]=0;if((f|0)==1){break Y}h=h+1|0;if((d|0)!=(h|0)){continue}break X}break}f=N()|0;break z}j=j+1|0;if(j>>>0<(y[m|0]|y[m+1|0]<<8)>>>0){continue}break}}x[114414]=0;r=O(360,e+192|0,255)|0;d=x[114414];x[114414]=0;Z:{_:{$:{aa:{ba:{ca:{if((d|0)!=1){d=e+88|0;o=d|7;C=d|1;l=d|4;s=d|2;t=d|3;g=0;while(1){d=g;x[114414]=0;O(879,b|0,e+160|0)|0;f=x[114414];x[114414]=0;da:{ea:{fa:{ga:{if((f|0)!=1){x[114414]=0;f=R(391,b|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break ga}i=y[q|0]|y[q+1|0]<<8;x[114414]=0;f=(f|0)==32?428:f;f=f?i>>>0>513?f+4|0:f:f;T(307,e+272|0,b|0,f|0);i=x[114414];x[114414]=0;if((i|0)==1){break fa}g=d+1|0;i=e+272|0;m=df(e+24|0,Ud(vc(r,d),i));Ab(i);if(d>>>0>=(y[u|0]|y[u+1|0]<<8)>>>0){break da}x[114414]=0;d=g&65535;h=U(405,a|0,d|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break ea}f=N()|0;break _}f=N()|0;break Z}f=N()|0;break Z}f=N()|0;break Z}if(!h){break da}x[114414]=0;T(354,e+88|0,2,e+160|0);d=x[114414];x[114414]=0;ha:{ia:{ja:{if((d|0)==1){break ja}x[114414]=0;P(355,e+272|0,e+88|0);d=x[114414];x[114414]=0;if((d|0)==1){break ja}x[114414]=0;O(334,h+492|0,e+272|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break ia}xb(e+272|0);if(!f){break da}x[114414]=0;O(880,m|0,e+272|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break aa}n=0;if((y[q|0]|y[q+1|0]<<8)>>>0<513){break ha}x[114414]=0;n=R(321,m|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break ha}f=N()|0;break _}f=N()|0;break _}f=N()|0;xb(e+272|0);break _}f=3;ka:{if((y[q|0]|y[q+1|0]<<8)>>>0<514){break ka}x[114414]=0;f=R(391,m|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break ka}f=N()|0;break _}x[h>>2]=y[e+374|0]|y[e+375|0]<<8;v[h+16|0]=y[((y[e+376|0]|y[e+377|0]<<8)&3)+23946|0];v[h+17|0]=y[(y[e+377|0]&3)+23946|0];v[h+18|0]=y[((y[e+376|0]|y[e+377|0]<<8)>>>12&3)+23950|0];j=0;la:{ma:{na:{oa:{while(1){pa:{if(!(f&1)){break pa}x[114414]=0;O(881,m|0,e+88|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break oa}x[114414]=0;i=O(339,h|0,y[j+23954|0])|0;d=x[114414];x[114414]=0;if((d|0)==1){break na}if((j|0)!=3){d=y[i+12|0]&-17}else{d=y[e+88|0]<<4&16|y[i+12|0]&-17}v[i+12|0]=d;v[i+12|0]=y[i+12|0]&254|v[e+88|0]&1;v[i+12|0]=y[i+12|0]&251|y[e+88|0]<<1&4;v[i+12|0]=y[i+12|0]&253|y[e+88|0]>>>1&2;d=y[C|0];x[114414]=0;v[e+72|0]=d;v[e+56|0]=16;d=O(409,e+72|0,e+56|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break ma}d=y[d|0];x[114414]=0;P(472,i|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break ma}d=y[s|0];v[i+15|0]=d;v[i+16|0]=d;v[i+13|0]=y[t|0];v[i+14|0]=y[l|0];d=0;if(!Lb(i)){break pa}while(1){k=(e+88|0)+(d<<2)|0;F=y[k+8|0]|y[k+9|0]<<8;I=Pb(i,d),J=F,w[I>>1]=J;k=Md(y[k+10|0]|y[k+11|0]<<8,0,64);I=Pb(i,d),J=k,v[I+2|0]=J;d=d+1|0;if(Lb(i)>>>0>d>>>0){continue}break}}f=f>>>1|0;j=j+1|0;if((j|0)!=4){continue}break}if(!(v[h+60|0]&1|y[h+16|0]==3)){x[h>>2]=32767}x[114414]=0;T(882,h|0,127,1);d=x[114414];x[114414]=0;if((d|0)==1){break ca}x[114414]=0;T(883,h|0,0,1);d=x[114414];x[114414]=0;if((d|0)==1){break ca}if(!n){break da}x[114414]=0;O(884,m|0,e+88|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break $}if(!(n&2)){break la}d=y[s|0]|y[s+1|0]<<8;x[114414]=0;d=gb(885,a|0,+(d>>>0))|0;f=x[114414];x[114414]=0;if((f|0)==1){break $}x[114414]=0;T(882,h|0,d|0,1);d=x[114414];x[114414]=0;if((d|0)==1){break $}d=y[l|0];x[114414]=0;T(883,h|0,d|0,1);d=x[114414];x[114414]=0;if((d|0)!=1){break la}break $}f=N()|0;break _}f=N()|0;break _}f=N()|0;break _}v[h+25|0]=y[C|0]==1;if(!(n&4)){break da}v[h+31|0]=y[o|0]+1;v[h+34|0]=y[e+96|0]+1;if(v[e+96|0]<0){v[h+30|0]=y[e+103|0]+1}if(y[e+100|0]){d=0;i=h+108|0;while(1){f=d+1|0;x[e+72>>2]=f+v[e+100|0];vQ(e+72|0);j=x[e+72>>2];I=gc(i,d),J=j,v[I|0]=J;d=f;if(d>>>0<128){continue}break}}x[114414]=0;P(755,h|0,0);d=x[114414];x[114414]=0;if((d|0)==1){break $}}Ab(m);if((g|0)!=255){continue}break}m=Fz(e+88|0);i=e+24|4;q=Fz(e+160|0);h=0;qa:{ra:{while(1){x[114414]=0;O(879,b|0,e+272|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break qa}x[114414]=0;d=R(391,b|0)|0;f=x[114414];x[114414]=0;sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{if((f|0)!=1){x[114414]=0;T(307,e+72|0,b|0,d|0);f=x[114414];x[114414]=0;if((f|0)==1){break za}if((y[B|0]|y[B+1|0]<<8)>>>0>h>>>0){x[114414]=0;T(354,e+56|0,2,e+272|0);f=x[114414];x[114414]=0;if((f|0)==1){break sa}x[114414]=0;P(355,e+24|0,e+56|0);f=x[114414];x[114414]=0;if((f|0)==1){break sa}x[114414]=0;O(334,((h<<5)+a|0)+946336|0,e+24|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break ya}xb(e+24|0)}if(!d|(y[B|0]|y[B+1|0]<<8)>>>0<=h>>>0){break ta}x[114414]=0;d=D(h+1|0,104)+a|0;f=d+484380|0;P(448,f|0,32);g=x[114414];x[114414]=0;if((g|0)==1){break xa}x[114414]=0;O(886,e+72|0,e+24|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break wa}x[f>>2]=y[e+24|0]|y[e+25|0]<<8|(y[e+26|0]<<16|y[e+27|0]<<24);x[d+484404>>2]=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);if(y[e+32|0]>=2){g=d+484414|0;w[g>>1]=z[g>>1]|1;x[f>>2]=x[f>>2]>>>1}if(y[e+33|0]>=2){g=d+484414|0;w[g>>1]=z[g>>1]|64;x[f>>2]=x[f>>2]>>>1}n=2;Aa:{if(y[e+35|0]!=1){n=6;if(y[e+35|0]!=2){break Aa}}f=d+484414|0;w[f>>1]=z[f>>1]|n}x[d+484384>>2]=y[e+36|0]|y[e+37|0]<<8|(y[e+38|0]<<16|y[e+39|0]<<24);x[d+484388>>2]=y[e+40|0]|y[e+41|0]<<8|(y[e+42|0]<<16|y[e+43|0]<<24);w[d+484410>>1]=(y[e+44|0]|y[e+45|0]<<8)>>>7;if(y[e+46|0]!=128){break va}f=d+484414|0;j=z[f>>1]|256;w[f>>1]=j;break ua}f=N()|0;break Z}f=N()|0;break Z}f=N()|0;xb(e+24|0);break ra}f=N()|0;break ra}f=N()|0;break ra}w[d+484408>>1]=v[e+46|0]+128;j=z[d+484414>>1]}f=d+484414|0;w[f>>1]=j|32;v[d+484416|0]=y[e+47|0];if(y[e+34|0]&2){d=e+56|0;Kb(d,q,h);he(d,1)}if(y[e+34|0]&5){w[f>>1]=z[f>>1]|16384}if(!(y[e+34|0]&8)){break ta}d=e+56|0;Kb(d,m,h);he(d,1);d=0;while(1){f=d<<1;Ba:{if(z[f+(e+240|0)>>1]!=(h|0)){break Ba}f=x[((z[f+(e+256|0)>>1]<<2)+a|0)+900380>>2];if(!f){break Ba}v[f+14|0]=0}d=d+1|0;if((d|0)!=8){continue}break}}Ab(e+72|0);h=h+1|0;if((h|0)==256){break ba}continue}break}f=N()|0}Ab(e+72|0);break Z}f=N()|0;break Z}f=N()|0;break z}f=N()|0;break _}Ca:{if(!(y[u|0]|y[u+1|0]<<8)){break Ca}f=0;Da:{Ea:{while(1){Fa:{d=vc(r,f);x[114414]=0;d=R(223,d|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break Fa}Ga:{if(!d){f=f+1|0;break Ga}d=vc(r,f);Lc(d);x[114414]=0;O(880,d|0,e+272|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break Ea}i=hb-16|0;hb=i;d=e+24|0;x[d>>2]=0;x[d+4>>2]=0;x[114414]=0;x[i+12>>2]=0;U(893,d+8|0,i+12|0,i+8|0)|0;g=x[114414];x[114414]=0;Ha:{if((g|0)!=1){hb=i+16|0;break Ha}S(0)|0;zb();p()}g=y[e+272|0]|y[e+273|0]<<8;x[114414]=0;i=d;U(887,b|0,d|0,g|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break Da}f=f+1|0;g=x[((f<<2)+a|0)+900380>>2];if(!(!g|y[g+34|0])){x[g+4>>2]=32;x[114414]=0;P(755,g|0,0);d=x[114414];x[114414]=0;if((d|0)==1){break Da}B=g+108|0;s=g+236|0;d=0;while(1){h=d+e|0;Ia:{if(y[h+274|0]>=(y[e+272|0]|y[e+273|0]<<8)>>>0){break Ia}n=ll(i,y[h+274|0]);h=y[n|0];j=h+1|0;k=d+12|0;I=fd(s,k),J=j,w[I>>1]=J;if(h>>>0>=z[a+480190>>1]){break Ia}h=D(j,104)+a|0;v[h+484418|0]=y[e+370|0]&3;v[h+484419|0]=y[e+371|0];v[h+484420|0]=y[e+372|0];v[h+484421|0]=y[e+373|0];w[h+484412>>1]=y[n+1|0]<<1;v[h+484417|0]=y[n+2|0];h=e+72|0;j=j-1|0;Kb(h,m,j);if(Ib(h)){v[g+14|0]=0}h=e+72|0;Kb(h,q,j);if(!Ib(h)){break Ia}I=gc(B,k),J=61,v[I|0]=J}d=d+1|0;if((d|0)!=96){continue}break}}uQ(i)}if((y[u|0]|y[u+1|0]<<8)>>>0>f>>>0){continue}break Ca}break}f=N()|0;break Z}f=N()|0;break Z}f=N()|0;uQ(i);break Z}Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if(!(!(c&2)|!z[a+480190>>1])){h=0;while(1){h=h+1|0;d=D(h,104)+a|0;c=d+484416|0;f=v[c|0];i=d+484417|0;g=v[i|0];x[114414]=0;j=d+484380|0;ma(888,j|0,+((+(g|0)*.0078125-+(f-49|0))*.08333333333333333));f=x[114414];x[114414]=0;if((f|0)==1){break Ja}v[i|0]=0;v[c|0]=0;c=z[d+484414>>1];Va:{if(!(c&16384)){c=ad(e+272|0,c&1?16:8,c&64?3:1,0,12);x[114414]=0;U(361,c|0,j|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break Va}f=N()|0;break Z}x[114414]=0;f=R(391,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break Ua}x[114414]=0;O(304,b|0,12)|0;c=x[114414];x[114414]=0;if((c|0)==1){break Ua}c=Wb(e+272|0);x[114414]=0;U(437,b|0,c|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ta}x[114414]=0;O(335,d+484423|0,c|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break Ta}x[114414]=0;d=O(2,e+8|0,12296)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Sa}x[114414]=0;P(187,e+72|0,d|0);f=x[114414];x[114414]=0;if((f|0)==1){break Ra}x[e+4>>2]=h;f=pA(a);x[114414]=0;T(13,e+56|0,f|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break Qa}x[114414]=0;X(622,e+24|0,e+72|0,e+4|0,e+56|0);f=x[114414];x[114414]=0;if((f|0)==1){break Pa}x[114414]=0;T(623,a|0,2,e+24|0);f=x[114414];x[114414]=0;if((f|0)==1){break Oa}xb(e+24|0);xb(e+56|0);Gb(e+72|0);xb(d);xb(c)}if(z[a+480190>>1]>h>>>0){continue}break}}id(r);Oq(E);Ab(e+1328|0);Ab(e+1344|0);break b}f=N()|0;break Z}f=N()|0;break Ka}f=N()|0;break Ka}f=N()|0;break La}f=N()|0;break Ma}f=N()|0;break Na}f=N()|0;xb(e+24|0)}xb(e+56|0)}Gb(e+72|0)}xb(d)}xb(c);break Z}f=N()|0;break Z}f=N()|0;break _}f=N()|0}Ab(m)}id(r);break z}f=N()|0;qf(n);break H}f=N()|0;break H}f=N()|0;break H}f=N()|0}id(l);break z}f=N()|0;break z}f=N()|0;break z}x[114414]=0;d=R(391,e+1328|0)|0;g=x[114414];x[114414]=0;Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{if((g|0)!=1){x[114414]=0;g=R(391,e+1328|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break hb}x[114414]=0;T(307,e+88|0,e+1328|0,g|0);g=x[114414];x[114414]=0;if((g|0)==1){break hb}if((d|0)<=844387157){if((d|0)==4674381){break _a}if((d|0)==5068115){break Za}if(n&1|(d|0)!=726487106){break Xa}x[a+480224>>2]=2;x[114414]=0;H=+ha(889,e+88|0);d=x[114414];x[114414]=0;if((d|0)==1){break Wa}if(H<=1e-8){break Xa}d=x[a+480216>>2];g=x[a+480196>>2];x[114414]=0;d=na(549,+(2646e7/(H*+(D(d,g)>>>0))))|0;g=x[114414];x[114414]=0;if((g|0)==1){break gb}x[a+480204>>2]=d;break Xa}if((d|0)<=1314144591){if((d|0)==844387158){break Ya}if((d|0)!=1280004692){break Xa}j=0;if(!z[a+480188>>1]){break Xa}while(1){x[114414]=0;d=O(226,e+88|0,1)|0;g=x[114414];x[114414]=0;if((g|0)==1){break C}if(!d){break Xa}d=Wb(e+272|0);x[114414]=0;U(564,e+88|0,d|0,-1)|0;g=x[114414];x[114414]=0;if((g|0)==1){break eb}g=Rb(d);t=Bb(d);x[114414]=0;X(423,e+24|0,3,g|0,t|0);g=x[114414];x[114414]=0;if((g|0)==1){break db}x[114414]=0;P(355,e+160|0,e+24|0);g=x[114414];x[114414]=0;if((g|0)==1){break db}x[114414]=0;O(343,((j<<5)+a|0)+480289|0,e+160|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break cb}xb(e+160|0);xb(d);j=j+1|0;if(j>>>0<z[a+480188>>1]){continue}break}break Xa}if((d|0)==1397445204){break fb}if((d|0)!=1314144592){break Xa}d=0;if(!(y[m|0]|y[m+1|0]<<8)){break Xa}while(1){x[114414]=0;g=O(226,e+88|0,1)|0;j=x[114414];x[114414]=0;if((j|0)==1){break ab}if(!g){break Xa}x[114414]=0;g=O(890,i|0,d&65535)|0;j=x[114414];x[114414]=0;if((j|0)==1){break ab}if(!g){break Xa}g=Wb(e+272|0);x[114414]=0;U(564,e+88|0,g|0,-1)|0;j=x[114414];x[114414]=0;if((j|0)==1){break $a}j=Zb(i,d);x[114414]=0;O(452,j|0,g|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break $a}xb(g);d=d+1|0;if(d>>>0<(y[m|0]|y[m+1|0]<<8)>>>0){continue}break}break Xa}f=N()|0;break z}f=N()|0;break z}f=N()|0;break A}x[114414]=0;d=R(321,e+88|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break B}d=d>>>0<256?48:d>>>8|0;x[a+480228>>2]=d;x[a+480232>>2]=d>>>1;d=0;if(!z[a+480188>>1]){break Xa}while(1){x[114414]=0;g=O(891,e+88|0,e+272|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break D}if(g){w[((d<<5)+a|0)+480286>>1]=(y[e+272|0]|y[e+273|0]<<8)>>>10;g=y[l|0];I=Bc(E,d),J=g,v[I|0]=J}d=d+1|0;if(d>>>0<z[a+480188>>1]){continue}break}break Xa}f=N()|0;break bb}f=N()|0;break bb}f=N()|0;xb(e+160|0)}xb(d);break A}f=N()|0;break A}f=N()|0;xb(g);break A}x[114414]=0;O(304,e+88|0,1)|0;d=x[114414];x[114414]=0;if((d|0)==1){break B}x[114414]=0;d=R(296,e+88|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break B}x[114414]=0;Z(552,h|0,e+88|0,d|0,2)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break Xa}break B}x[114414]=0;O(892,e+88|0,e+24|0)|0;d=x[114414];x[114414]=0;ib:{if((d|0)!=1){d=Wb(e+272|0);x[114414]=0;U(564,e+88|0,d|0,-1)|0;g=x[114414];x[114414]=0;if((g|0)==1){break ib}if(ku(d,8414)){x[114414]=0;T(13,e+160|0,7,d|0);g=x[114414];x[114414]=0;if((g|0)==1){break ib}g=e+160|0;Db(f,g);xb(g)}xb(d);break Xa}f=N()|0;break A}f=N()|0;xb(d);break A}x[114414]=0;k=R(391,e+88|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break B}}Ab(e+88|0);continue}break}f=N()|0;break A}f=N()|0;break A}f=N()|0;break A}f=N()|0}Ab(e+88|0)}Oq(E);break e}f=N()|0;break e}f=N()|0}Ab(e+1328|0)}Ab(e+1344|0)}Q(f|0);p()}d=1}hb=e+1760|0;return d|0}function r1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=0,q=E(0),r=0,s=0,t=0,u=0,C=E(0),F=0,G=0,H=E(0),I=E(0),J=0,K=0,L=E(0),M=E(0),N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=E(0),Y=E(0),Z=0,_=0,$=0,aa=E(0),ba=E(0),ca=E(0),da=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;V=hb-16|0;hb=V;a:{if(x[a+1420>>2]>=0){x[f>>2]=0;e=b;d=0;b=0;b:{c:{d:{f=x[a+1420>>2];if((f|0)<=0){break d}while(1){x[(D(d,20)+a|0)+1436>>2]=0;d=d+1|0;if((f|0)!=(d|0)){continue}break}if((f|0)<=3){break d}b=c;break c}if((c|0)<4){break b}b=c-3|0;d=0;e:{while(1){f:{g:{h:{h=d+e|0;if(!(y[h|0]!=79|(y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24))!=(y[83488]|y[83489]<<8|(y[83490]<<16|y[83491]<<24)))){k=d+26|0;if((k|0)>=(b|0)){break f}j=d+27|0;m=e+k|0;g=y[m|0];if((j+g|0)>=(b|0)){break f}i=g+27|0;c=0;if(g){break h}break g}d=d+1|0;if((d|0)<(b|0)){continue}break e}while(1){i=y[e+(c+j|0)|0]+i|0;c=c+1|0;if((g|0)!=(c|0)){continue}break}}c=0;j=0;while(1){g=22;c=Yw(c,y[e+(d+j|0)|0]);j=j+1|0;if((j|0)!=22){continue}break}while(1){c=Yw(c,0);g=g+1|0;if((g|0)!=26){continue}break}x[a+1420>>2]=f+1;f=D(f,20)+a|0;x[f+1432>>2]=c;x[f+1428>>2]=i-26;x[f+1424>>2]=y[h+22|0]|y[h+23|0]<<8|(y[h+24|0]<<16|y[h+25|0]<<24);c=y[e+(k+y[m|0]|0)|0]==255?-1:y[h+6|0]|y[h+7|0]<<8|(y[h+8|0]<<16|y[h+9|0]<<24);x[f+1436>>2]=k;x[f+1440>>2]=c;f=x[a+1420>>2];if((f|0)==4){break e}d=d+1|0;if((d|0)<(b|0)){continue}break e}break}b=d}if((f|0)<=0){break b}}h=0;while(1){g=D(h,20)+a|0;l=g+1432|0;c=x[l>>2];d=0;o=g+1428|0;i=x[o>>2];k=x[g+1436>>2];m=b-k|0;j=(i|0)<(m|0)?i:m;if((j|0)>0){while(1){c=Yw(c,y[e+(d+k|0)|0]);d=d+1|0;if((j|0)!=(d|0)){continue}break}}x[o>>2]=i-j;x[l>>2]=c;i:{if((i|0)<=(m|0)){d=c;c=g+1424|0;if((d|0)==x[c>>2]){x[a+1380>>2]=-1;x[a+992>>2]=0;x[a+1420>>2]=-1;b=x[(D(h,20)+a|0)+1440>>2];x[a+1060>>2]=b;x[a+1064>>2]=(b|0)!=-1;b=j+k|0;break b}d=f-1|0;x[a+1420>>2]=d;d=D(d,20)+a|0;x[c+16>>2]=x[d+1440>>2];f=d+1432|0;g=x[f+4>>2];x[c+8>>2]=x[f>>2];x[c+12>>2]=g;d=d+1424|0;f=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=f;f=x[a+1420>>2];break i}h=h+1|0}if((f|0)>(h|0)){continue}break}}break a}x[a+100>>2]=0;x[a+32>>2]=b;x[a+40>>2]=b+c;if(!sH(a)){x[f>>2]=0;b=0;break a}oa=V+12|0;fa=hb-16|0;hb=fa;x[a+1504>>2]=0;x[a+1508>>2]=0;j:{if(x[a+96>>2]){break j}k:{l:{m:{if(x[a+1380>>2]!=-1){break m}c=ye(a);if(x[a+96>>2]){break k}if((c|0)!=79){break l}if((ye(a)|0)!=103){break l}if((ye(a)|0)!=103){break l}if((ye(a)|0)!=83){break l}if(!mH(a)){break k}if(!(v[a+1375|0]&1)){break m}v[a+1376|0]=0;x[a+1384>>2]=0;fc(a,32);break k}g=Vw(a);break k}fc(a,30)}if(!g){break j}if(lc(a,1)){fc(a,35);break j}n:{o:{if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){c=lc(a,El(x[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=x[a+408>>2]){break j}x[fa+12>>2]=c;h=D(c,6)+a|0;if(!y[h+412|0]){j=x[a+112>>2];k=j>>1;break o}j=x[a+116>>2];k=j>>1;c=lc(a,1);i=lc(a,1);if(c|!y[h+412|0]){break o}x[V+4>>2]=j-x[a+112>>2]>>2;c=x[a+112>>2]+j>>2;break n}ea(2707,9049,3152,6707);p()}x[V+4>>2]=0;c=k}x[fa+8>>2]=c;p:{if(!(!y[h+412|0]|i)){c=D(j,3);x[V+8>>2]=c-x[a+112>>2]>>2;j=c+x[a+112>>2]>>2;break p}x[V+8>>2]=k}x[fa+4>>2]=j;j=1}if(j){q:{Z=x[V+4>>2];la=x[V+8>>2];ka=x[fa+4>>2];Q=hb-2368|0;hb=Q;ia=x[a+404>>2];na=D(x[fa+12>>2],6)+a|0;ga=y[na+413|0];W=ia+D(ga,40)|0;R=x[((y[na+412|0]<<2)+a|0)+104>>2];r:{l=x[a+4>>2];s:{if((l|0)>0){while(1){c=y[(x[W+4>>2]+D(o,3)|0)+2|0];h=o<<2;r=h+(Q+1344|0)|0;x[r>>2]=0;c=y[(c+W|0)+9|0];if(!z[((c<<1)+a|0)+132>>1]){fc(a,21);c=0;break s}g=x[a+260>>2];t:{u:{if(lc(a,1)){k=x[(a+h|0)+996>>2];i=g+D(c,1596)|0;s=x[(y[i+1588|0]<<2)+47372>>2];c=El(s)-1|0;ta=k,ua=lc(a,c),w[ta>>1]=ua;ta=k,ua=lc(a,c),w[ta+2>>1]=ua;if(y[i|0]){T=i+82|0;J=i+65|0;U=i+49|0;N=i+33|0;G=i+1|0;h=2;j=0;while(1){t=y[j+G|0];m=y[t+N|0];c=0;u=y[t+U|0];v:{if(!u){break v}g=x[a+124>>2]+D(y[t+J|0],2096)|0;if(x[a+1396>>2]<=9){pk(a)}c=x[a+1392>>2];l=w[(g+((c&1023)<<1)|0)+36>>1];w:{if((l|0)>=0){F=c;l=l&65535;c=y[l+x[g+8>>2]|0];x[a+1392>>2]=F>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:l;break w}c=Dl(a,g)}if(!y[g+23|0]){break v}c=x[x[g+2088>>2]+(c<<2)>>2]}if(m){O=-1<<u^-1;g=h+m|0;while(1){l=0;m=w[(T+(t<<4)|0)+((c&O)<<1)>>1];x:{if((m|0)<0){break x}m=x[a+124>>2]+D(m&65535,2096)|0;if(x[a+1396>>2]<=9){pk(a)}l=x[a+1392>>2];S=w[(m+((l&1023)<<1)|0)+36>>1];y:{if((S|0)>=0){F=l;S=S&65535;l=y[S+x[m+8>>2]|0];x[a+1392>>2]=F>>>l;l=x[a+1396>>2]-l|0;x[a+1396>>2]=(l|0)>0?l:0;l=(l|0)<0?-1:S;break y}l=Dl(a,m)}if(!y[m+23|0]){break x}l=x[x[m+2088>>2]+(l<<2)>>2]}c=c>>u;w[k+(h<<1)>>1]=l;h=h+1|0;if((g|0)!=(h|0)){continue}break}h=g}j=j+1|0;if(j>>>0<y[i|0]){continue}break}}if(x[a+1396>>2]!=-1){break u}}x[r>>2]=1;break t}w[Q+320>>1]=257;h=x[i+1592>>2];if((h|0)>=3){g=i+338|0;t=i+1088|0;c=2;while(1){h=c<<1;m=h+t|0;u=y[m|0];l=u<<1;j=z[l+g>>1];r=y[m+1|0];T=r<<1;J=w[k+l>>1];m=w[T+k>>1]-J|0;l=m>>31;j=(D((l^m)-l|0,z[h+g>>1]-j|0)|0)/(z[g+T>>1]-j|0)|0;l=J+((m|0)<0?0-j|0:j)|0;T=h+k|0;j=z[T>>1];z:{A:{if(j){h=Q+320|0;v[h+r|0]=1;v[h+u|0]=1;v[c+h|0]=1;h=j<<16>>16;m=s-l|0;if((h|0)>=((l|0)>(m|0)?m:l)<<1){if((l|0)<(m|0)){break z}l=s+(j^-1)|0;break A}if(h&1){l=l-(h+1>>>1|0)|0;break A}l=(h>>1)+l|0;break A}v[(Q+320|0)+c|0]=0}w[T>>1]=l}c=c+1|0;h=x[i+1592>>2];if((c|0)<(h|0)){continue}break}}l=0;if((h|0)<=0){break t}while(1){if(!y[(Q+320|0)+l|0]){w[k+(l<<1)>>1]=65535;h=x[i+1592>>2]}l=l+1|0;if((l|0)<(h|0)){continue}break}}l=x[a+4>>2];o=o+1|0;if((l|0)>(o|0)){continue}break}}B:{C:{c=x[a+80>>2];if(!(x[a+84>>2]!=x[a+92>>2]?c:0)){sc(Q+320|0,Q+1344|0,l<<2);g=z[W>>1];if(g){i=x[(ia+D(ga,40)|0)+4>>2];l=0;while(1){j=i+D(l,3)|0;h=y[j+1|0];k=Q+1344|0;j=k+(y[j|0]<<2)|0;if(!(x[(h<<2)+k>>2]?x[j>>2]:0)){x[(Q+1344|0)+(h<<2)>>2]=0;x[j>>2]=0}l=l+1|0;if((g|0)!=(l|0)){continue}break}}T=R>>1;ha=ia+D(ga,40)|0;if(y[ha+8|0]){h=0;while(1){c=0;j=x[a+4>>2];if((j|0)>0){k=x[ha+4>>2];l=0;while(1){if(y[(k+D(l,3)|0)+2|0]==(h|0)){m=c+Q|0;g=l<<2;D:{if(x[g+(Q+1344|0)>>2]){i=0;g=1;break D}i=x[(a+g|0)+800>>2];g=0}v[m|0]=g;x[(Q+256|0)+(c<<2)>>2]=i;c=c+1|0}l=l+1|0;if((j|0)!=(l|0)){continue}break}}S=Q+256|0;t=hb-16|0;hb=t;o=x[a+4>>2];s=x[a+396>>2];g=y[(h+ha|0)+24|0];m=s+D(g,24)|0;j=x[m+4>>2];ja=z[((g<<1)+a|0)+268>>1];i=T<<((ja|0)==2);k=i>>>0>j>>>0?j:i;j=x[m>>2];u=(k-(i>>>0>j>>>0?j:i)>>>0)/A[m+8>>2]|0;r=u<<2;i=D(o,r+4|0);U=x[x[a+124>>2]+D(y[m+13|0],2096)>>2];qa=x[a+92>>2];E:{if(x[a+80>>2]){l=en(a,i);o=x[a+4>>2];break E}l=sd(i)}j=0;if((o|0)>0){k=l+(o<<2)|0;while(1){x[l+(j<<2)>>2]=k;k=k+r|0;j=j+1|0;if((j|0)!=(o|0)){continue}break}}k=l;F:{G:{H:{if((c|0)>0){j=T<<2;i=0;while(1){if(!y[i+Q|0]){Sb(x[S+(i<<2)>>2],0,j)}i=i+1|0;if((i|0)!=(c|0)){continue}break}if((c|0)==1|(ja|0)!=2){break H}i=0;if((c|0)<=0){break G}while(1){if(!y[i+Q|0]){break G}i=i+1|0;if((i|0)!=(c|0)){continue}break}break F}i=0;if((ja|0)==2){break G}}F=s+D(g,24)|0;ra=(u|0)<=0;o=0;while(1){if(!ra){K=0;pa=(c|0)<=0;sa=pa|(o|0)!=0;l=0;while(1){i=0;if(!sa){while(1){if(!y[i+Q|0]){j=x[a+124>>2]+D(y[m+13|0],2096)|0;if(x[a+1396>>2]<=9){pk(a)}g=x[a+1392>>2];s=w[(j+((g&1023)<<1)|0)+36>>1];I:{if((s|0)>=0){P=g;s=s&65535;g=y[s+x[j+8>>2]|0];x[a+1392>>2]=P>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:s;break I}g=Dl(a,j)}g=y[j+23|0]?x[x[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break F}x[x[(i<<2)+k>>2]+(K<<2)>>2]=x[x[F+16>>2]+(g<<2)>>2]}i=i+1|0;if((i|0)!=(c|0)){continue}break}}J:{if((U|0)<=0){break J}g=0;if((l|0)>=(u|0)){break J}while(1){i=0;if(!pa){while(1){K:{if(y[i+Q|0]){break K}j=i<<2;s=w[(x[F+20>>2]+(y[x[x[j+k>>2]+(K<<2)>>2]+g|0]<<4)|0)+(o<<1)>>1];if((s|0)<0){break K}s=x[a+124>>2]+D(s&65535,2096)|0;P=x[j+S>>2];G=x[m+8>>2];O=x[m>>2]+D(G,l)|0;L:{M:{if(ja){J=0;j=1;if((G|0)<=0){break L}while(1){ma=P+(O<<2)|0;r=G-J|0;N=0;n=E(0);$=jH(a,s);N:{if(($|0)<0){break N}N=x[s>>2];_=(r|0)>(N|0)?N:r;$=D(N,$);if(y[s+22|0]){N=1;if((_|0)<=0){break N}r=0;while(1){da=ma+(r<<2)|0;n=E(B[x[s+28>>2]+(r+$<<2)>>2]+n);B[da>>2]=B[da>>2]+n;n=E(B[s+12>>2]+n);r=r+1|0;if((_|0)!=(r|0)){continue}break}break N}N=1;if((_|0)<=0){break N}r=0;while(1){da=ma+(r<<2)|0;B[da>>2]=B[da>>2]+B[x[s+28>>2]+(r+$<<2)>>2];r=r+1|0;if((_|0)!=(r|0)){continue}break}}if(!N){break M}r=x[s>>2];O=r+O|0;J=r+J|0;if((G|0)>(J|0)){continue}break}break L}J=0;j=1;r=(G|0)/x[s>>2]|0;if((r|0)<=0){break L}P=P+(O<<2)|0;while(1){ma=P+(J<<2)|0;j=G-(J+O|0)|0;N=0;n=E(0);$=jH(a,s);O:{if(($|0)<0){break O}N=1;_=x[s>>2];da=(j|0)>(_|0)?_:j;if((da|0)<=0){break O}_=D(_,$);j=0;while(1){$=ma+(D(j,r)<<2)|0;C=E(B[x[s+28>>2]+(j+_<<2)>>2]+n);B[$>>2]=B[$>>2]+C;n=y[s+22|0]?C:n;j=j+1|0;if((da|0)!=(j|0)){continue}break}}if(!N){break M}j=1;J=J+1|0;if((r|0)!=(J|0)){continue}break}break L}j=0}if(!j){break F}}i=i+1|0;if((i|0)!=(c|0)){continue}break}}l=l+1|0;g=g+1|0;if((U|0)<=(g|0)){break J}if((l|0)<(u|0)){continue}break}}K=K+1|0;if((l|0)<(u|0)){continue}break}}o=o+1|0;if((o|0)!=8){continue}break}break F}if((c|0)==(i|0)){break F}r=(u|0)<=0;J=r|(c|0)<3;s=s+D(g,24)|0;N=(c|0)!=2;l=0;while(1){P:{if(!N){if(r){break P}i=0;o=0;while(1){g=x[m>>2]+D(x[m+8>>2],i)|0;x[t+12>>2]=g&1;x[t+8>>2]=g>>1;if(!l){j=x[a+124>>2]+D(y[m+13|0],2096)|0;if(x[a+1396>>2]<=9){pk(a)}g=x[a+1392>>2];G=w[(j+((g&1023)<<1)|0)+36>>1];Q:{if((G|0)>=0){F=g;G=G&65535;g=y[G+x[j+8>>2]|0];x[a+1392>>2]=F>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:G;break Q}g=Dl(a,j)}g=y[j+23|0]?x[x[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break F}x[x[k>>2]+(o<<2)>>2]=x[x[s+16>>2]+(g<<2)>>2]}R:{if((U|0)<=0){break R}g=0;if((i|0)>=(u|0)){break R}while(1){j=x[m+8>>2];G=w[(x[s+20>>2]+(y[x[x[k>>2]+(o<<2)>>2]+g|0]<<4)|0)+(l<<1)>>1];S:{if((G|0)>=0){if(!lH(a,x[a+124>>2]+D(G&65535,2096)|0,S,2,t+12|0,t+8|0,T,j)){break F}i=i+1|0;break S}i=i+1|0;j=x[m>>2]+D(j,i)|0;x[t+8>>2]=j>>1;x[t+12>>2]=j&1}g=g+1|0;if((U|0)<=(g|0)){break R}if((i|0)<(u|0)){continue}break}}o=o+1|0;if((i|0)<(u|0)){continue}break}break P}if(J){break P}i=0;o=0;while(1){j=x[m>>2]+D(x[m+8>>2],i)|0;g=(j|0)/(c|0)|0;x[t+12>>2]=j-D(c,g);x[t+8>>2]=g;if(!l){j=x[a+124>>2]+D(y[m+13|0],2096)|0;if(x[a+1396>>2]<=9){pk(a)}g=x[a+1392>>2];G=w[(j+((g&1023)<<1)|0)+36>>1];T:{if((G|0)>=0){F=g;G=G&65535;g=y[G+x[j+8>>2]|0];x[a+1392>>2]=F>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:G;break T}g=Dl(a,j)}g=y[j+23|0]?x[x[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break F}x[x[k>>2]+(o<<2)>>2]=x[x[s+16>>2]+(g<<2)>>2]}U:{if((U|0)<=0){break U}g=0;if((i|0)>=(u|0)){break U}while(1){j=x[m+8>>2];G=w[(x[s+20>>2]+(y[x[x[k>>2]+(o<<2)>>2]+g|0]<<4)|0)+(l<<1)>>1];V:{if((G|0)>=0){if(!lH(a,x[a+124>>2]+D(G&65535,2096)|0,S,c,t+12|0,t+8|0,T,j)){break F}i=i+1|0;break V}i=i+1|0;j=x[m>>2]+D(j,i)|0;G=(j|0)/(c|0)|0;x[t+8>>2]=G;x[t+12>>2]=j-D(c,G)}g=g+1|0;if((U|0)<=(g|0)){break U}if((i|0)<(u|0)){continue}break}}o=o+1|0;if((i|0)<(u|0)){continue}break}}l=l+1|0;if((l|0)!=8){continue}break}}if(!x[a+80>>2]){_b(k)}x[a+92>>2]=qa;hb=t+16|0;h=h+1|0;if(h>>>0<y[ha+8|0]){continue}break}c=x[a+80>>2]}if(!(x[a+84>>2]!=x[a+92>>2]?c:0)){c=z[W>>1];if(c){i=(T|0)<=1?1:T;j=ia+D(ga,40)|0;g=a+800|0;while(1){h=c;c=c-1|0;if((R|0)>=2){k=x[j+4>>2]+D(c,3)|0;m=x[g+(y[k+1|0]<<2)>>2];k=x[g+(y[k|0]<<2)>>2];l=0;while(1){o=l<<2;t=o+m|0;q=B[t>>2];o=k+o|0;n=B[o>>2];W:{if(!(n<=E(0))){if(!(q<=E(0))){C=E(n-q);break W}C=n;n=E(q+n);break W}if(!(q<=E(0))){C=E(q+n);break W}C=n;n=E(n-q)}B[o>>2]=n;B[t>>2]=C;l=l+1|0;if((i|0)!=(l|0)){continue}break}}if((h|0)>1){continue}break}}if(x[a+4>>2]<=0){break B}U=T<<2;l=0;while(1){c=l<<2;h=c+a|0;o=x[h+800>>2];X:{if(x[c+(Q+320|0)>>2]){Sb(o,0,U);break X}r=x[h+996>>2];c=y[(W+y[(x[W+4>>2]+D(l,3)|0)+2|0]|0)+9|0];Y:{if(!z[((c<<1)+a|0)+132>>1]){fc(a,21);break Y}t=R>>1;k=x[a+260>>2]+D(c,1596)|0;h=D(y[k+1588|0],w[r>>1]);c=0;m=x[k+1592>>2];if((m|0)>=2){N=k+338|0;G=k+838|0;j=1;while(1){g=y[j+G|0]<<1;i=w[g+r>>1];if((i|0)>=0){i=D(y[k+1588|0],i&65535);g=z[g+N>>1];if((g|0)!=(c|0)){m=i-h|0;s=g-c|0;u=(m|0)/(s|0)|0;J=(g|0)<(t|0)?g:t;Z:{if((J|0)<=(c|0)){break Z}O=o+(c<<2)|0;B[O>>2]=B[O>>2]*B[((h&255)<<2)+47392>>2];c=c+1|0;if((J|0)<=(c|0)){break Z}F=m;m=m>>31;O=u>>31;O=((F^m)-m|0)-D(s,(O^u)-O|0)|0;S=m|1;m=0;while(1){K=o+(c<<2)|0;F=K;n=B[K>>2];m=m+O|0;K=(m|0)<(s|0);h=(h+u|0)+(K?0:S)|0;B[F>>2]=n*B[((h&255)<<2)+47392>>2];m=m-(K?0:s)|0;c=c+1|0;if((J|0)!=(c|0)){continue}break}}m=x[k+1592>>2];c=g}h=i}j=j+1|0;if((j|0)<(m|0)){continue}break}}if((c|0)<(t|0)){n=B[(h<<2)+47392>>2];while(1){h=o+(c<<2)|0;B[h>>2]=B[h>>2]*n;c=c+1|0;if((t|0)!=(c|0)){continue}break}}}}l=l+1|0;c=x[a+4>>2];if((l|0)<(c|0)){continue}break}break C}ea(2707,9049,3335,2120);p()}ea(2707,9049,3302,2120);p()}l=0;if((c|0)<=0){break B}while(1){U=y[na+412|0];J=R>>1;h=J<<2;_=x[a+92>>2];o=x[((l<<2)+a|0)+800>>2];c=J<<2;W=o+c|0;_:{if(x[a+80>>2]){m=en(a,h);break _}m=sd(h)}c=(m+c|0)-8|0;g=x[((U<<2)+a|0)+1068>>2];$:{if(R>>>0<2){h=g;break $}i=o;h=g;while(1){B[c+4>>2]=E(B[h>>2]*B[i>>2])-E(B[h+4>>2]*B[i+8>>2]);B[c>>2]=E(B[h>>2]*B[i+8>>2])+E(B[h+4>>2]*B[i>>2]);h=h+8|0;c=c-8|0;i=i+16|0;if((W|0)!=(i|0)){continue}break}}if(c>>>0>=m>>>0){i=((J<<2)+o|0)-12|0;while(1){B[c+4>>2]=E(B[h+4>>2]*B[i>>2])-E(B[h>>2]*B[i+8>>2]);B[c>>2]=E(B[h>>2]*E(-B[i>>2]))-E(B[h+4>>2]*B[i+8>>2]);i=i-16|0;h=h+8|0;c=c-8|0;if(m>>>0<=c>>>0){continue}break}}G=R>>2;if((R|0)>=16){h=G<<2;c=h+m|0;k=h+o|0;h=(g+(J<<2)|0)-32|0;j=o;i=m;while(1){n=B[i>>2];C=B[c>>2];q=B[i+4>>2];H=B[c+4>>2];B[k+4>>2]=q+H;B[k>>2]=B[i>>2]+B[c>>2];q=E(H-q);n=E(C-n);B[j+4>>2]=E(B[h+16>>2]*q)-E(B[h+20>>2]*n);B[j>>2]=E(B[h+20>>2]*q)+E(B[h+16>>2]*n);n=B[i+8>>2];C=B[c+8>>2];q=B[i+12>>2];H=B[c+12>>2];B[k+12>>2]=q+H;B[k+8>>2]=B[i+8>>2]+B[c+8>>2];q=E(H-q);n=E(C-n);B[j+12>>2]=E(B[h>>2]*q)-E(B[h+4>>2]*n);B[j+8>>2]=E(B[h+4>>2]*q)+E(B[h>>2]*n);i=i+16|0;c=c+16|0;j=j+16|0;k=k+16|0;h=h-32|0;if(g>>>0<=h>>>0){continue}break}}k=El(R);h=R>>4;t=J-1|0;c=R>>3;i=0-c|0;kH(h,o,t,i,g);kH(h,o,t-G|0,i,g);N=R>>5;h=0-h|0;bp(N,o,t,h,g,16);bp(N,o,t-c|0,h,g,16);bp(N,o,t-(c<<1)|0,h,g,16);bp(N,o,t+D(c,-3)|0,h,g,16);j=2;if((k|0)>=10){j=k-4>>>1|0;c=2;while(1){i=c;c=c+1|0;s=2<<i;if((s|0)>0){u=8<<i;h=0;r=R>>i+2;O=0-(r>>1)|0;i=R>>i+4;while(1){bp(i,o,t-D(h,r)|0,O,g,u);h=h+1|0;if((s|0)!=(h|0)){continue}break}}if((c|0)!=(j|0)){continue}break}}ga=k-7|0;if((ga|0)>(j|0)){while(1){c=j;j=c+1|0;h=R>>c+6;if((h|0)>0){s=2<<c;O=8<<c;ia=32<<c;ha=R>>c+2;ja=0-(ha>>1)|0;c=g;i=t;while(1){k=s;if((k|0)>0){u=D(O,12)+c|0;n=B[u>>2];r=(O<<3)+c|0;C=B[r>>2];S=(O<<2)+c|0;q=B[S>>2];H=B[u+4>>2];L=B[r+4>>2];X=B[S+4>>2];Y=B[c+4>>2];ca=B[c>>2];u=(i<<2)+o|0;r=u+(ja<<2)|0;S=0-ha<<2;while(1){K=r-4|0;M=B[K>>2];aa=B[r>>2];ba=B[u>>2];B[u>>2]=aa+ba;F=u-4|0;I=B[F>>2];B[F>>2]=B[K>>2]+I;I=E(I-M);M=E(ba-aa);B[K>>2]=E(I*ca)+E(M*Y);B[r>>2]=E(M*ca)-E(I*Y);K=r-12|0;aa=B[K>>2];F=u-8|0;I=B[F>>2];P=F;F=r-8|0;ba=B[F>>2];B[P>>2]=ba+I;P=u-12|0;M=B[P>>2];B[P>>2]=B[K>>2]+M;M=E(M-aa);I=E(I-ba);B[K>>2]=E(M*q)+E(I*X);B[F>>2]=E(I*q)-E(M*X);K=r-20|0;aa=B[K>>2];F=u-16|0;I=B[F>>2];P=F;F=r-16|0;ba=B[F>>2];B[P>>2]=ba+I;P=u-20|0;M=B[P>>2];B[P>>2]=B[K>>2]+M;M=E(M-aa);I=E(I-ba);B[K>>2]=E(M*C)+E(I*L);B[F>>2]=E(I*C)-E(M*L);K=r-28|0;aa=B[K>>2];F=u-24|0;I=B[F>>2];P=F;F=r-24|0;ba=B[F>>2];B[P>>2]=ba+I;P=u-28|0;M=B[P>>2];B[P>>2]=B[K>>2]+M;M=E(M-aa);I=E(I-ba);B[K>>2]=E(M*n)+E(I*H);B[F>>2]=E(I*n)-E(M*H);r=r+S|0;u=u+S|0;K=k>>>0>1;k=k-1|0;if(K){continue}break}}i=i-8|0;c=(ia<<2)+c|0;k=h>>>0>1;h=h-1|0;if(k){continue}break}}if((j|0)!=(ga|0)){continue}break}}h=N<<6;if((0-h|0)<0){c=(t<<2)+o|0;i=c-h|0;n=B[g+(R>>3<<2)>>2];ca=E(-n);while(1){h=c-32|0;L=B[h>>2];X=B[c>>2];B[c>>2]=L+X;g=c-4|0;C=B[g>>2];k=g;g=c-36|0;Y=B[g>>2];B[k>>2]=Y+C;j=c-8|0;q=B[j>>2];k=j;j=c-40|0;I=B[j>>2];B[k>>2]=I+q;k=c-12|0;H=B[k>>2];F=k;k=c-44|0;M=B[k>>2];B[F>>2]=M+H;B[h>>2]=X-L;B[g>>2]=C-Y;g=c-16|0;C=B[g>>2];F=g;g=c-48|0;aa=B[g>>2];B[F>>2]=aa+C;H=E(H-M);q=E(q-I);B[j>>2]=E(H+q)*n;B[k>>2]=E(H-q)*n;j=c-28|0;q=B[j>>2];k=c-60|0;H=B[k>>2];t=c-24|0;L=B[t>>2];s=c-56|0;X=B[s>>2];u=c-20|0;Y=B[u>>2];F=u;u=c-52|0;I=B[u>>2];B[F>>2]=I+Y;B[t>>2]=X+L;B[j>>2]=H+q;B[g>>2]=Y-I;B[u>>2]=aa-C;C=E(q-H);q=E(L-X);B[s>>2]=E(C-q)*n;B[k>>2]=E(C+q)*ca;iH(c);iH(h);c=c+-64|0;if(i>>>0<c>>>0){continue}break}}j=J-4|0;if((R|0)>=16){h=m+(j<<2)|0;c=(m+(G<<2)|0)-16|0;i=x[((U<<2)+a|0)+1100>>2];while(1){g=(z[i>>1]<<2)+o|0;B[h+12>>2]=B[g>>2];B[h+8>>2]=B[g+4>>2];B[c+12>>2]=B[g+8>>2];B[c+8>>2]=B[g+12>>2];g=(z[i+2>>1]<<2)+o|0;B[h+4>>2]=B[g>>2];B[h>>2]=B[g+4>>2];B[c+4>>2]=B[g+8>>2];B[c>>2]=B[g+12>>2];i=i+4|0;h=h-16|0;c=c-16|0;if(m>>>0<=c>>>0){continue}break}}c=m+(J<<2)|0;g=c-16|0;if(m>>>0<g>>>0){i=x[((U<<2)+a|0)+1084>>2];k=c;h=m;while(1){n=B[i+4>>2];t=k-4|0;C=B[t>>2];q=B[h+4>>2];H=E(C+q);L=B[i>>2];X=B[h>>2];s=k-8|0;Y=B[s>>2];ca=E(X-Y);I=E(E(n*H)-E(L*ca));C=E(q-C);B[h+4>>2]=I+C;n=E(E(L*H)+E(n*ca));q=E(Y+X);B[h>>2]=n+q;B[t>>2]=I-C;B[s>>2]=q-n;n=B[i+12>>2];k=k-12|0;C=B[k>>2];q=B[h+12>>2];H=E(C+q);L=B[i+8>>2];X=B[h+8>>2];Y=B[g>>2];ca=E(X-Y);I=E(E(n*H)-E(L*ca));C=E(q-C);B[h+12>>2]=I+C;n=E(E(L*H)+E(n*ca));q=E(Y+X);B[h+8>>2]=n+q;B[g>>2]=q-n;B[k>>2]=I-C;i=i+16|0;k=g;h=h+16|0;g=g-16|0;if(h>>>0<g>>>0){continue}break}}g=c-32|0;if(m>>>0<=g>>>0){h=x[((U<<2)+a|0)+1076>>2]+(J<<2)|0;i=(j<<2)+o|0;k=((R<<2)+o|0)-16|0;while(1){n=B[h-4>>2];C=B[c-8>>2];q=B[h-8>>2];H=B[c-4>>2];L=E(E(n*C)-E(q*H));B[o>>2]=L;B[i+12>>2]=-L;n=E(E(q*E(-C))-E(H*n));B[W>>2]=n;B[k+12>>2]=n;n=B[h-12>>2];C=B[c-16>>2];q=B[h-16>>2];H=B[c-12>>2];L=E(E(n*C)-E(q*H));B[o+4>>2]=L;B[i+8>>2]=-L;n=E(E(q*E(-C))-E(H*n));B[W+4>>2]=n;B[k+8>>2]=n;n=B[h-20>>2];C=B[c-24>>2];q=B[h-24>>2];H=B[c-20>>2];L=E(E(n*C)-E(q*H));B[o+8>>2]=L;B[i+4>>2]=-L;n=E(E(q*E(-C))-E(H*n));B[W+8>>2]=n;B[k+4>>2]=n;n=B[h-28>>2];C=B[g>>2];h=h-32|0;q=B[h>>2];H=B[c-28>>2];L=E(E(n*C)-E(q*H));B[o+12>>2]=L;B[i>>2]=-L;n=E(E(q*E(-C))-E(H*n));B[W+12>>2]=n;B[k>>2]=n;k=k-16|0;i=i-16|0;W=W+16|0;o=o+16|0;c=g;g=c-32|0;if(m>>>0<=g>>>0){continue}break}}if(!x[a+80>>2]){_b(m)}x[a+92>>2]=_;l=l+1|0;if((l|0)<x[a+4>>2]){continue}break}}oH(a);aa:{if(y[a+1377|0]){x[a+1060>>2]=0-T;v[a+1377|0]=0;x[a+1064>>2]=1;x[a+1412>>2]=R-ka;break aa}c=x[a+1412>>2];if(!c){break aa}h=la-Z|0;if((h|0)<=(c|0)){x[a+1412>>2]=c-h;x[V+4>>2]=la;Z=la;break aa}Z=c+Z|0;x[V+4>>2]=Z;x[a+1412>>2]=0}c=x[a+1064>>2];ba:{ca:{da:{if(x[a+1388>>2]==x[a+1404>>2]){ea:{if(!c|!(y[a+1375|0]&4)){break ea}c=x[a+1408>>2];h=x[a+1060>>2];if(c>>>0>=h+(ka-Z|0)>>>0){break ea}h=c-h|0;c=(c>>>0>=h>>>0?h:0)+Z|0;c=(c|0)<(ka|0)?c:ka;x[oa>>2]=c;x[a+1060>>2]=c+x[a+1060>>2];break ba}x[a+1064>>2]=1;x[a+1060>>2]=x[a+1408>>2]+(Z-T|0);break da}if(!c){break ca}}x[a+1060>>2]=x[a+1060>>2]+(la-Z|0)}if(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0){break r}x[oa>>2]=ka}c=1}hb=Q+2368|0;break q}ea(2707,9049,3451,2120);p()}}else{c=0}hb=fa+16|0;if(!c){fa:{ga:{ha:{c=x[a+100>>2];switch(c-32|0){case 0:break ga;case 3:break ha;default:break fa}}x[a+100>>2]=0;while(1){if((Rg(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;b=x[a+32>>2]-b|0;break a}if(x[a+992>>2]){break fa}x[a+100>>2]=0;while(1){if((Rg(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;b=x[a+32>>2]-b|0;break a}x[a+1420>>2]=0;x[a+992>>2]=0;x[a+1504>>2]=0;x[a+1508>>2]=0;x[a+1412>>2]=0;x[a+1416>>2]=0;v[a+1377|0]=0;x[a+1064>>2]=0;x[a+100>>2]=c;x[f>>2]=0;b=1;break a}i=x[V+12>>2];m=x[V+4>>2];c=x[V+8>>2];j=0;ia:{ja:{g=x[a+992>>2];ka:{if(!g){k=x[a+4>>2];g=0;break ka}k=g<<1;la:{if((k|0)==x[a+112>>2]){h=a+1092|0}else{h=0;if((k|0)!=x[a+116>>2]){break la}h=a+1096|0}h=x[h>>2]}if(!h){break ja}k=x[a+4>>2];if((k|0)>0){o=(g|0)<=0;while(1){if(!o){l=(j<<2)+a|0;k=0;while(1){Z=x[l+800>>2]+(k+m<<2)|0;t=k<<2;B[Z>>2]=E(B[h+(g+(k^-1)<<2)>>2]*B[t+x[l+928>>2]>>2])+E(B[h+t>>2]*B[Z>>2]);k=k+1|0;if((g|0)!=(k|0)){continue}break}k=x[a+4>>2]}j=j+1|0;if((j|0)<(k|0)){continue}break}}g=x[a+992>>2]}o=i-c|0;x[a+992>>2]=o;if((k|0)>0){j=0;while(1){if((c|0)<(i|0)){l=(j<<2)+a|0;k=0;h=c;while(1){B[x[l+928>>2]+(k<<2)>>2]=B[x[l+800>>2]+(h<<2)>>2];k=k+1|0;h=c+k|0;if((k|0)!=(o|0)){continue}break}k=x[a+4>>2]}j=j+1|0;if((j|0)<(k|0)){continue}break}}if(!g){break ja}c=((c|0)>(i|0)?i:c)-m|0;x[a+1416>>2]=c+x[a+1416>>2];break ia}c=0}h=c;g=x[a+4>>2];if((g|0)>0){c=0;while(1){i=(c<<2)+a|0;x[i+864>>2]=x[i+800>>2]+(m<<2);c=c+1|0;if((g|0)!=(c|0)){continue}break}}if(d){x[d>>2]=g}x[f>>2]=h;x[e>>2]=a+864;b=x[a+32>>2]-b|0}hb=V+16|0;return b|0}function Eg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0),l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=hb-2912|0;hb=d;a:{b:{c:{d:{e:{f:{if(nv(c)){xc(b,268435456);o=x[c+8>>2];i=d+2888|0;e=i;x[e>>2]=0;x[e+4>>2]=0;Jj(e+8|0);x[d+2884>>2]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((y[a+3|0]-4&255)>>>0<=4){x[114414]=0;e=R(296,c|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break n}x[d+2884>>2]=e;break t}e=y[a+3|0];if(e>>>0>18){break t}e=1<<e;u:{if(!(e&126991)){if(e&396800){break u}break t}if(!y[a|0]){break t}}e=x[b>>2];x[114414]=0;e=O(620,a|0,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break s}x[114414]=0;T(834,d+704|0,c|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break s}g=d+704|0;e=x[g+4>>2];x[i>>2]=x[g>>2];x[i+4>>2]=e;f=i+8|0;Oy(f);e=g+8|0;Wl(f,e);x[f>>2]=x[e>>2];x[f+4>>2]=x[e+4>>2];h=x[yb(e)>>2];t=yb(f),u=h,x[t>>2]=u;t=yb(e),u=0,x[t>>2]=u;x[e>>2]=0;x[e+4>>2]=0;Hc(g);e=0;x[114414]=0;f=R(421,i|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break n}x[d+2884>>2]=x[i>>2];if(!f){break g}}e=y[a+3|0];if(e>>>0>18){break p}g=1<<e;v:{if(!(g&126991)){e=0;if(g&396800){break v}break p}e=!y[a|0]}if(e|A[b>>2]<262145){break p}e=x[d+2884>>2];g=y[a+3|0];x[114414]=0;x[d+688>>2]=((g|0)==11)<<4;g=O(35,d+688|0,d+2884|0)|0;h=x[114414];x[114414]=0;if((h|0)!=1){x[d+704>>2]=e-x[g>>2];e=y[a+3|0];if(e>>>0>16){break r}w:{if(!(1<<e&126991)){if((e|0)==11){break w}break r}if(!(y[a|0]&7)){break r}}e=x[d+704>>2];if(e>>>0<=2147483647){e=e<<1;break q}e=-1;break q}a=N()|0;break b}a=N()|0;break b}e=0;x[114414]=0;g=R(1264,a|0)|0;h=x[114414];x[114414]=0;x:{y:{if((h|0)!=1){z:{A:{switch(y[a+3|0]){case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:e=y[a|0];break z;case 9:e=16;break z;case 11:e=4;break z;case 10:case 17:case 18:break A;default:break z}}e=8}g=D(e,g)>>>3|0;e=g-1|0;h=x[d+704>>2];if(e>>>0>-1-h>>>0){break y}e=e+h|0;break x}a=N()|0;break b}e=-1}e=(e>>>0)/(g>>>0)|0}x[d+704>>2]=e;xc(b,e);break o}B:{C:{D:{E:{if(!(y[a+3|0]==4|y[a+3|0]==5|(y[a+3|0]==8|y[a+3|0]==7))){if(y[a+3|0]!=6){break o}e=0;if(A[d+2884>>2]<10){break g}x[114414]=0;O(304,c|0,4)|0;e=x[114414];x[114414]=0;if((e|0)==1){break n}x[114414]=0;e=R(391,c|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break E}x[d+688>>2]=e;e=x[d+2884>>2];x[114414]=0;x[d+2880>>2]=e;e=O(297,d+688|0,d+2880|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break D}x[d+704>>2]=x[e>>2];ng(c,8);e=x[d+704>>2];if(e>>>0>50529027){break C}e=D(e,85);break B}x[114414]=0;x[d+704>>2]=x[d+2884>>2];e=R(1264,a|0)|0;g=x[114414];x[114414]=0;F:{G:{if((g|0)!=1){g=x[d+704>>2];e=8/(e>>>0)|0;if(g>>>0>4294967295/(e>>>0)>>>0){break G}e=D(e,g);break F}a=N()|0;break b}e=-1}x[d+704>>2]=e;xc(b,e);break o}a=N()|0;break b}a=N()|0;break b}e=-1}x[d+704>>2]=e;xc(b,(e>>>0)/(y[a|0]>>>3>>>0)|0)}if(!x[b>>2]){e=0;break g}w[b+34>>1]=z[b+34>>1]&65534|y[a|0]>15;w[b+34>>1]=z[b+34>>1]&65471|(y[a+1|0]!=1)<<6;x[114414]=0;e=R(416,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break f}if(!e){e=0;x[b>>2]=0;break g}e=ad(d+704|0,8,1,0,11);x[114414]=0;e=O(1265,a|0,e|0)|0;g=x[114414];x[114414]=0;H:{I:{J:{K:{L:{if((g|0)!=1){if(!e){break H}e=0;x[114414]=0;a=O(1266,c|0,d+704|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break I}if(!a){break h}a=x[b>>2];x[114414]=0;x[d+688>>2]=a+1>>>1;a=R(296,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break L}xc(d+688|0,a);x[114414]=0;a=R(835,f|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break K}e=x[d+688>>2];if(e){break J}e=16;break h}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=a+16|0;b=x[b+20>>2];f=0;while(1){m=f;f=d+704|0;g=m+y[f|y[a|0]&15]|0;v[b|0]=g;f=y[f|y[a|0]>>>4]+(g&255)|0;v[b+1|0]=f;a=a+1|0;b=b+2|0;e=e-1|0;if(e){continue}break}e=x[d+688>>2]+16|0;break h}a=N()|0;break b}if(!(y[a+3|0]!=4&y[a+3|0]!=5)){a=y[a+3|0];x[114414]=0;a=Z(1267,d+1792|0,c|0,b|0,(a|0)==5|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break f}Ab(a);e=x[c+8>>2]-o|0;break h}M:{if(!(y[a+3|0]!=6|y[a+1|0]!=1)){x[114414]=0;O(304,c|0,4)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}x[114414]=0;a=R(391,c|0)|0;e=x[114414];x[114414]=0;N:{O:{P:{if((e|0)!=1){x[114414]=0;x[d+688>>2]=a;e=R(403,c|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break P}x[114414]=0;T(1268,d+704|0,c|0,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break N}a=d+704|0;xc(d+688|0,x[a>>2]);x[114414]=0;f=x[d+688>>2];P(678,d+1784|0,a|0);a=x[114414];x[114414]=0;Q:{if((a|0)==1){break Q}a=x[b+20>>2];x[114414]=0;a=R(417,a|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break M}b=Kj(b);x[114414]=0;T(1269,d+1776|0,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break Q}x[114414]=0;T(1270,d+1784|0,d+1776|0,e<<24>>24);a=x[114414];x[114414]=0;if((a|0)!=1){break O}}a=N()|0;Hc(d+704|0);break b}a=N()|0;break b}a=N()|0;break b}e=f+9|0;Hc(d+704|0);break h}a=N()|0;break b}if(!(y[a+3|0]!=9|y[a+1|0]!=1|y[a|0]!=16)){a=x[d+2884>>2];e=z[Tl(d+1768|0)>>1];x[114414]=0;e=Z(1271,b|0,f|0,a|0,e|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(y[a+3|0]!=8|y[a+1|0]!=1|y[a|0]>16){break m}e=0;x[114414]=0;f=O(226,c|0,8)|0;g=x[114414];x[114414]=0;if((g|0)==1){break f}if(!f){break h}x[114414]=0;f=R(391,c|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break f}x[d+2884>>2]=f;if(f>>>0<4){break h}x[114414]=0;T(307,d+688|0,c|0,f|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}e=d+688|0;f=Cm(d+704|0,e);Ab(e);x[114414]=0;h=R(1272,f|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break e}if(!x[b>>2]){break j}q=y[a|0];r=(q|0)!=16;a=0;g=0;while(1){R:{if(r){break R}x[114414]=0;s=O(228,f|0,8)|0;e=x[114414];x[114414]=0;if((e|0)!=1){break R}a=S(75884)|0;break k}x[114414]=0;m=O(228,f|0,1)|0;e=x[114414];x[114414]=0;if((e|0)==1){break l}x[114414]=0;e=O(228,f|0,1)|0;j=x[114414];x[114414]=0;if((j|0)==1){break l}S:{T:{U:{if(!e){e=8;while(1){x[114414]=0;j=O(228,f|0,1)|0;n=x[114414];x[114414]=0;if((n|0)==1){break S}if(j){break U}e=e+16|0;continue}}x[114414]=0;e=O(228,f|0,3)|0;j=x[114414];x[114414]=0;if((j|0)!=1){break T}break l}x[114414]=0;j=O(228,f|0,4)|0;n=x[114414];x[114414]=0;if((n|0)==1){break l}e=e+j|0}g=(g&255)+(((m?-1:0)^e)&255)|0;V:{if((q|0)!=16){v[x[b+20>>2]+a|0]=g;break V}w[x[b+20>>2]+(a<<1)>>1]=s&255|g<<8}a=a+1|0;if(a>>>0<A[b>>2]){continue}break j}break}a=S(75884)|0;break k}break a}a=N()|0;break b}if(!(y[a+3|0]!=7|y[a+1|0]!=1|y[a|0]>16)){e=0;if(A[d+2884>>2]<5){break h}a=x[b+20>>2];x[114414]=0;a=R(417,a|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break a}x[114414]=0;a=R(420,a|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break f}b=Kj(b);x[114414]=0;e=U(1273,c|0,a|0,b|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=8|y[a+1|0]!=1)){W:{X:{Y:{Z:{_:{a=y[a+3|0];switch(a|0){case 2:break X;case 1:break Y;case 0:break Z;default:break _}}e=0;switch(a-10|0){case 0:break W;case 2:break X;default:break h}}x[114414]=0;e=U(1274,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[114414]=0;e=U(1275,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}a=x[d+2884>>2];e=y[Ry(d+680|0)|0];x[114414]=0;e=Z(1276,b|0,f|0,a|0,e|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[114414]=0;e=U(1277,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=8|y[a+1|0]!=3)){$:{aa:{ba:{ca:{g=y[a+3|0];switch(g|0){case 2:break $;case 1:break ba;case 0:break ca;default:break aa}}x[114414]=0;e=U(1278,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[114414]=0;e=U(1279,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}e=0;if((g|0)!=12){break h}}e=x[d+2884>>2];g=y[Ry(d+672|0)|0];x[114414]=0;e=Z(1280,b|0,f|0,e|0,g|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break f}if(y[a+3|0]!=12){break h}f=x[b>>2]<<1;if((f|0)<=0){break h}a=x[b+20>>2];b=f+a|0;while(1){v[a+1|0]=y[a+1|0]+y[a|0];a=a+2|0;if(b>>>0>a>>>0){continue}break}break h}if(!(y[a|0]!=8|y[a+1|0]!=2)){e=0;da:{switch(y[a+3|0]){case 0:x[114414]=0;e=U(1281,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h;case 1:x[114414]=0;e=U(1282,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h;case 2:break da;default:break h}}a=x[d+2884>>2];e=y[Ry(d+664|0)|0];x[114414]=0;e=Z(1283,b|0,f|0,a|0,e|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a+2|0]|(y[a|0]!=16|y[a+1|0]!=1))){ea:{fa:{ga:{ha:{a=y[a+3|0];switch(a|0){case 2:break ea;case 1:break ga;case 0:break ha;default:break fa}}x[114414]=0;e=U(1284,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[114414]=0;e=U(1285,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}e=0;if((a|0)!=12){break h}}a=x[d+2884>>2];e=z[Tl(d+656|0)>>1];x[114414]=0;e=Z(1286,b|0,f|0,a|0,e|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=16|y[a+1|0]!=1|y[a+2|0]!=1)){e=0;ia:{switch(y[a+3|0]){case 0:x[114414]=0;e=U(1287,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h;case 1:x[114414]=0;e=U(1288,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h;case 2:break ia;default:break h}}a=x[d+2884>>2];e=z[Tl(d+648|0)>>1];x[114414]=0;e=Z(1289,b|0,f|0,a|0,e|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a+2|0]|(y[a|0]!=16|y[a+1|0]!=3))){ja:{ka:{la:{ma:{g=y[a+3|0];switch(g|0){case 2:break ja;case 1:break la;case 0:break ma;default:break ka}}x[114414]=0;e=U(1290,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[114414]=0;e=U(1291,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}e=0;if((g|0)!=12){break h}}e=x[d+2884>>2];g=z[Tl(d+640|0)>>1];x[114414]=0;e=Z(1292,b|0,f|0,e|0,g|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break f}if(y[a+3|0]!=12){break h}f=x[b>>2]<<2;if((f|0)<=0){break h}a=x[b+20>>2];b=f+a|0;while(1){w[a+2>>1]=z[a+2>>1]+z[a>>1];a=a+4|0;if(b>>>0>a>>>0){continue}break}break h}if(!(y[a|0]!=16|y[a+1|0]!=3|y[a+2|0]!=1)){e=0;na:{switch(y[a+3|0]){case 0:x[114414]=0;e=U(1293,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h;case 1:x[114414]=0;e=U(1294,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h;case 2:break na;default:break h}}a=x[d+2884>>2];e=z[Tl(d+632|0)>>1];x[114414]=0;e=Z(1295,b|0,f|0,a|0,e|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a+2|0]|(y[a|0]!=16|y[a+1|0]!=2))){e=0;oa:{switch(y[a+3|0]){case 0:x[114414]=0;e=U(1296,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h;case 1:x[114414]=0;e=U(1297,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h;case 2:break oa;default:break h}}a=x[d+2884>>2];e=z[Tl(d+624|0)>>1];x[114414]=0;e=Z(1298,b|0,f|0,a|0,e|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=16|y[a+1|0]!=2|y[a+2|0]!=1)){e=0;pa:{switch(y[a+3|0]){case 0:x[114414]=0;e=U(1299,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h;case 1:x[114414]=0;e=U(1300,b|0,f|0,x[d+2884>>2])|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h;case 2:break pa;default:break h}}a=x[d+2884>>2];e=z[Tl(d+616|0)>>1];x[114414]=0;e=Z(1301,b|0,f|0,a|0,e|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a+3|0]|(y[a|0]!=24|y[a+1|0]!=1))){e=x[d+2884>>2];if(!y[a+2|0]){x[114414]=0;w[d>>1]=z[d+608>>1];e=Z(1302,b|0,f|0,e|0,d|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[114414]=0;w[d+2>>1]=z[d+600>>1];e=Z(1303,b|0,f|0,e|0,d+2|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a+3|0]|(y[a|0]!=24|y[a+1|0]!=2))){e=x[d+2884>>2];if(!y[a+2|0]){x[114414]=0;w[d+4>>1]=z[d+592>>1];e=Z(1304,b|0,f|0,e|0,d+4|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[114414]=0;w[d+6>>1]=z[d+584>>1];e=Z(1305,b|0,f|0,e|0,d+6|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a+3|0]|(y[a|0]!=32|y[a+1|0]!=1))){e=x[d+2884>>2];if(!y[a+2|0]){x[114414]=0;w[d+8>>1]=z[d+576>>1];e=Z(1306,b|0,f|0,e|0,d+8|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[114414]=0;w[d+10>>1]=z[d+568>>1];e=Z(1307,b|0,f|0,e|0,d+10|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a+3|0]|(y[a|0]!=32|y[a+1|0]!=2))){e=x[d+2884>>2];if(!y[a+2|0]){x[114414]=0;w[d+12>>1]=z[d+560>>1];e=Z(1308,b|0,f|0,e|0,d+12|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[114414]=0;w[d+14>>1]=z[d+552>>1];e=Z(1309,b|0,f|0,e|0,d+14|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a+3|0]|(y[a|0]!=64|y[a+1|0]!=1))){e=x[d+2884>>2];if(!y[a+2|0]){x[114414]=0;w[d+16>>1]=z[d+544>>1];e=Z(1310,b|0,f|0,e|0,d+16|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[114414]=0;w[d+18>>1]=z[d+536>>1];e=Z(1311,b|0,f|0,e|0,d+18|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a+3|0]|(y[a|0]!=64|y[a+1|0]!=2))){e=x[d+2884>>2];if(!y[a+2|0]){x[114414]=0;w[d+20>>1]=z[d+528>>1];e=Z(1312,b|0,f|0,e|0,d+20|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[114414]=0;w[d+22>>1]=z[d+520>>1];e=Z(1313,b|0,f|0,e|0,d+22|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=32|y[a+1|0]!=1|y[a+3|0]!=3)){e=x[d+2884>>2];if(!y[a+2|0]){x[114414]=0;w[d+24>>1]=z[d+512>>1];e=Z(1314,b|0,f|0,e|0,d+24|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[114414]=0;w[d+26>>1]=z[d+504>>1];e=Z(1315,b|0,f|0,e|0,d+26|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=32|y[a+1|0]!=2|y[a+3|0]!=3)){e=x[d+2884>>2];if(!y[a+2|0]){x[114414]=0;w[d+28>>1]=z[d+496>>1];e=Z(1316,b|0,f|0,e|0,d+28|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[114414]=0;w[d+30>>1]=z[d+488>>1];e=Z(1317,b|0,f|0,e|0,d+30|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=64|y[a+1|0]!=1|y[a+3|0]!=3)){e=x[d+2884>>2];if(!y[a+2|0]){x[114414]=0;w[d+32>>1]=z[d+480>>1];e=Z(1318,b|0,f|0,e|0,d+32|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[114414]=0;w[d+34>>1]=z[d+472>>1];e=Z(1319,b|0,f|0,e|0,d+34|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}if(!(y[a|0]!=64|y[a+1|0]!=2|y[a+3|0]!=3)){e=x[d+2884>>2];if(!y[a+2|0]){x[114414]=0;w[d+36>>1]=z[d+464>>1];e=Z(1320,b|0,f|0,e|0,d+36|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[114414]=0;w[d+38>>1]=z[d+456>>1];e=Z(1321,b|0,f|0,e|0,d+38|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}qa:{if(!(y[a+1|0]!=1&y[a+1|0]!=2|y[a|0]!=24|y[a+3|0]!=16)){x[d+704>>2]=-2147483648;e=x[d+2884>>2];ra:{if(!y[a+2|0]){x[114414]=0;x[d+48>>2]=x[d+448>>2];x[d+444>>2]=0;a=x[d+444>>2];x[d+40>>2]=x[d+440>>2];x[d+44>>2]=a;e=aa(1322,b|0,f|0,e|0,d+704|0,d+40|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){break ra}break qa}x[114414]=0;x[d- -64>>2]=x[d+432>>2];x[d+428>>2]=0;a=x[d+428>>2];x[d+56>>2]=x[d+424>>2];x[d+60>>2]=a;e=aa(1323,b|0,f|0,e|0,d+704|0,d+56|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break qa}}if(!e){break h}a=x[d+704>>2];if((a|0)==-2147483648){break h}f=z[b+32>>1];x[114414]=0;f=yna(f,0,a,0);a=lb;f=f+1073741824|0;a=f>>>0<1073741824?a+1|0:a;a=_f(722,(a&2147483647)<<1|f>>>31,a>>>31|0);f=x[114414];x[114414]=0;if((f|0)==1){break qa}t=b,u=Md(a,1,64),w[t+32>>1]=u;w[b+34>>1]=z[b+34>>1]|8192;break h}sa:{if(!(y[a+1|0]!=1&y[a+1|0]!=2|y[a|0]!=32|y[a+3|0]!=16)){x[d+704>>2]=-2147483648;e=x[d+2884>>2];ta:{if(!y[a+2|0]){x[114414]=0;x[d+80>>2]=x[d+416>>2];x[d+412>>2]=0;a=x[d+412>>2];x[d+72>>2]=x[d+408>>2];x[d+76>>2]=a;e=aa(1324,b|0,f|0,e|0,d+704|0,d+72|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){break ta}break sa}x[114414]=0;x[d+96>>2]=x[d+400>>2];x[d+396>>2]=0;a=x[d+396>>2];x[d+88>>2]=x[d+392>>2];x[d+92>>2]=a;e=aa(1325,b|0,f|0,e|0,d+704|0,d+88|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break sa}}if(!e){break h}a=x[d+704>>2];if((a|0)==-2147483648){break h}f=z[b+32>>1];x[114414]=0;a=yna(f,0,a,0);f=lb;g=a+1073741824|0;f=g>>>0<1073741824?f+1|0:f;a=_f(722,(f&2147483647)<<1|g>>>31,f>>>31|0);f=x[114414];x[114414]=0;if((f|0)==1){break sa}t=b,u=Md(a,1,64),w[t+32>>1]=u;w[b+34>>1]=z[b+34>>1]|8192;break h}ua:{if(!(y[a+1|0]!=1&y[a+1|0]!=2|y[a|0]!=32|y[a+3|0]!=15)){x[d+704>>2]=1065353216;e=x[d+2884>>2];va:{if(!y[a+2|0]){x[114414]=0;x[d+380>>2]=0;x[d+384>>2]=1065353216;a=x[d+388>>2];x[d+112>>2]=x[d+384>>2];x[d+116>>2]=a;a=x[d+380>>2];x[d+104>>2]=x[d+376>>2];x[d+108>>2]=a;e=aa(1326,b|0,f|0,e|0,d+704|0,d+104|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){break va}break ua}x[114414]=0;x[d+364>>2]=0;x[d+368>>2]=1065353216;a=x[d+372>>2];x[d+128>>2]=x[d+368>>2];x[d+132>>2]=a;a=x[d+364>>2];x[d+120>>2]=x[d+360>>2];x[d+124>>2]=a;e=aa(1327,b|0,f|0,e|0,d+704|0,d+120|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break ua}}if(!e){break h}k=B[d+704>>2];if(k==E(1)){break h}k=Qy(E(k*E(z[b+32>>1])),E(1),E(64));x[114414]=0;a=eb(1328,E(k))|0;f=x[114414];x[114414]=0;if((f|0)==1){break ua}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break h}wa:{if(!(y[a+1|0]!=1&y[a+1|0]!=2|y[a|0]!=64|y[a+3|0]!=15)){x[d+704>>2]=0;x[d+708>>2]=1072693248;e=x[d+2884>>2];xa:{if(!y[a+2|0]){x[114414]=0;x[d+344>>2]=0;x[d+348>>2]=1072693248;x[d+336>>2]=0;x[d+340>>2]=0;x[d+144>>2]=0;x[d+148>>2]=0;x[d+152>>2]=0;x[d+156>>2]=1072693248;a=x[d+356>>2];x[d+160>>2]=x[d+352>>2];x[d+164>>2]=a;a=x[d+332>>2];x[d+136>>2]=x[d+328>>2];x[d+140>>2]=a;e=aa(1329,b|0,f|0,e|0,d+704|0,d+136|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){break xa}break wa}x[114414]=0;x[d+312>>2]=0;x[d+316>>2]=1072693248;x[d+304>>2]=0;x[d+308>>2]=0;x[d+176>>2]=0;x[d+180>>2]=0;x[d+184>>2]=0;x[d+188>>2]=1072693248;a=x[d+324>>2];x[d+192>>2]=x[d+320>>2];x[d+196>>2]=a;a=x[d+300>>2];x[d+168>>2]=x[d+296>>2];x[d+172>>2]=a;e=aa(1330,b|0,f|0,e|0,d+704|0,d+168|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break wa}}if(!e){break h}l=C[d+704>>3];if(l==1){break h}l=Py(l*+z[b+32>>1],1,64);x[114414]=0;a=na(1331,+l)|0;f=x[114414];x[114414]=0;if((f|0)==1){break wa}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break h}ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{if(!(y[a|0]!=32|y[a+1|0]!=1|y[a+3|0]!=13)){e=y[a+2|0];a=x[d+2884>>2];if(!e){x[d+288>>2]=939524096;e=d+288|0;break Ea}x[d+280>>2]=939524096;e=d+280|0;break Ca}if(!(y[a|0]!=32|y[a+1|0]!=2|y[a+3|0]!=13)){e=y[a+2|0];a=x[d+2884>>2];if(!e){x[d+272>>2]=939524096;e=d+272|0;break Aa}x[d+264>>2]=939524096;e=d+264|0;break ya}if(y[a|0]!=32|y[a+1|0]!=1|y[a+3|0]!=14){break Ba}e=y[a+2|0];a=x[d+2884>>2];if(e){break Da}x[d+256>>2]=872415232;e=d+256|0}x[114414]=0;g=x[e+4>>2];x[d+200>>2]=x[e>>2];x[d+204>>2]=g;e=Z(1332,b|0,f|0,a|0,d+200|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}x[d+248>>2]=872415232;e=d+248|0}x[114414]=0;g=x[e+4>>2];x[d+208>>2]=x[e>>2];x[d+212>>2]=g;e=Z(1333,b|0,f|0,a|0,d+208|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}e=0;if(y[a|0]!=32|y[a+1|0]!=2|y[a+3|0]!=14){break h}e=y[a+2|0];a=x[d+2884>>2];if(e){break za}x[d+240>>2]=872415232;e=d+240|0}x[114414]=0;g=x[e+4>>2];x[d+216>>2]=x[e>>2];x[d+220>>2]=g;e=Z(1334,b|0,f|0,a|0,d+216|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){break h}break f}x[d+232>>2]=872415232;e=d+232|0}x[114414]=0;g=x[e+4>>2];x[d+224>>2]=x[e>>2];x[d+228>>2]=g;e=Z(1335,b|0,f|0,a|0,d+224|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}break h}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=S(75884)|0}if((ib|0)!=(ca(75884)|0)){break d}Y(a|0)|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)==1){break i}}e=h+4|0;Ab(f);break h}a=N()|0;break d}x[114414]=0;O(224,c|0,e+o|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}}Hc(i)}hb=d+2912|0;return e|0}a=N()|0;break b}a=N()|0}Ab(f);break b}a=N()|0}Hc(i);Q(a|0);p()}S(0)|0;zb();p()}function una(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;d=hb-384|0;hb=d;Lc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{if(!If(b,d+376|0)){break Q}if(!$T(d+376|0)){break Q}if(!c){q=1;break Q}r=fm(d+360|0,b);x[114414]=0;T(429,d+344|0,r|0,1);b=x[114414];x[114414]=0;R:{S:{T:{U:{V:{W:{X:{Y:{if((b|0)!=1){x[114414]=0;T(430,d+176|0,d+344|0,1229866575);b=x[114414];x[114414]=0;if((b|0)==1){break W}x[114414]=0;q=O(431,d+176|0,d+328|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break Y}Ab(d+176|0);if(!q){break R}x[114414]=0;P(397,a|0,524288);b=x[114414];x[114414]=0;if((b|0)==1){break c}x[114414]=0;W(432,a|0);b=x[114414];x[114414]=0;if((b|0)!=1){break X}break c}b=N()|0;break a}b=N()|0;Ab(d+176|0);break b}x[a+480208>>2]=12;b=y[d+336|0]|y[d+337|0]<<8;G=a,H=Md((b<<8|b>>>8)&65535,1,127),w[G+480188>>1]=H;b=y[d+328|0]|y[d+329|0]<<8;x[114414]=0;w[d+176>>1]=b<<8|b>>>8;w[d+264>>1]=255;b=O(433,d+176|0,d+264|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break d}w[a+480192>>1]=z[b>>1];b=d+328|2;b=y[b|0]|y[b+1|0]<<8;x[114414]=0;w[d+176>>1]=b<<8|b>>>8;w[d+264>>1]=3999;b=O(433,d+176|0,d+264|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break e}w[a+480190>>1]=z[b>>1];x[114414]=0;b=a+1074312|0;U(434,b|0,6,1)|0;e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;O(435,b|0,21)|0;e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;O(435,b|0,13)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}x[114414]=0;b=O(2,d+312|0,5253)|0;e=x[114414];x[114414]=0;if((e|0)==1){break f}Db(a+1304436|0,b);xb(b);x[114414]=0;b=O(2,d+296|0,6298)|0;e=x[114414];x[114414]=0;if((e|0)==1){break g}Db(a+1304448|0,b);xb(b);x[114414]=0;e=O(2,d+280|0,11042)|0;b=x[114414];x[114414]=0;if((b|0)==1){break h}x[114414]=0;P(187,d+264|0,e|0);b=x[114414];x[114414]=0;if((b|0)==1){break j}x[114414]=0;P(436,d+248|0,d+376|4);b=x[114414];x[114414]=0;if((b|0)==1){break l}x[114414]=0;P(436,d+232|0,d+376|5);b=x[114414];x[114414]=0;if((b|0)==1){break n}x[114414]=0;X(190,d+176|0,d+264|0,d+248|0,d+232|0);b=x[114414];x[114414]=0;if((b|0)==1){break o}b=d+176|0;Db(a+1304460|0,b);xb(b);xb(d+232|0);xb(d+248|0);b=d+264|0;Gb(b);xb(e);x[a+1304496>>2]=2;x[114414]=0;T(430,b|0,d+344|0,1312902469);b=x[114414];x[114414]=0;if((b|0)==1){break p}x[114414]=0;b=R(223,d+264|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break r}x[114414]=0;f=a+1304400|0;U(437,d+264|0,f|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break r}x[114414]=0;T(430,d+248|0,d+344|0,1397706311);b=x[114414];x[114414]=0;if((b|0)==1){break s}b=a+484360|0;wq(Vb(b));Z:{e=d+328|4;g=y[e|0]|y[e+1|0]<<8;_:{if(!g){break _}e=0;g=(g<<8|g>>>8)&65535;while(1){x[114414]=0;h=O(226,d+248|0,46)|0;i=x[114414];x[114414]=0;$:{if((i|0)!=1){if(!h){break _}x[114414]=0;U(438,d+248|0,d+176|0,44)|0;h=x[114414];x[114414]=0;if((h|0)!=1){if(!Wc(f)){break $}x[114414]=0;O(439,f|0,d+176|0)|0;h=x[114414];x[114414]=0;if((h|0)!=1){break $}}b=N()|0;break t}b=N()|0;break t}x[114414]=0;h=R(440,d+248|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break Z}if(!od(Vb(b))){x[114414]=0;i=R(441,b|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break Z}if((i|0)==255){break _}}i=Vb(b);x[114414]=0;T(6,d+232|0,2,d+176|0);k=x[114414];x[114414]=0;if((k|0)==1){break u}x[114414]=0;P(442,i|0,d+232|0);i=x[114414];x[114414]=0;if((i|0)==1){break v}xb(d+232|0);i=Vb(b);x[114414]=0;aa(443,i|0,d+248|0,h|0,65535,65535)|0;h=x[114414];x[114414]=0;if((h|0)==1){break Z}e=e+1|0;if(g>>>0>(e&65535)>>>0){continue}break}}x[114414]=0;P(444,b|0,0);b=x[114414];x[114414]=0;if((b|0)==1){break w}x[114414]=0;T(430,d+232|0,d+344|0,1229869908);b=x[114414];x[114414]=0;if((b|0)==1){break x}x[114414]=0;b=R(445,d+232|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break E}aa:{if(!b){break aa}if(z[a+480192>>1]){g=1;while(1){x[114414]=0;O(446,d+232|0,d+176|0)|0;b=x[114414];x[114414]=0;ba:{ca:{da:{if((b|0)!=1){b=y[d+206|0]|y[d+207|0]<<8;x[114414]=0;b=U(405,a|0,g&65535,(b<<8|b>>>8)&65535)|0;e=x[114414];x[114414]=0;if((e|0)==1){break da}if(!b){break ba}e=y[d+206|0]|y[d+207|0]<<8;if(((e<<8|e>>>8)&65535)>>>0>3999){break ba}x[114414]=0;T(447,d+80|0,2,d+176|0);e=x[114414];x[114414]=0;if((e|0)!=1){x[114414]=0;P(355,d+112|0,d+80|0);e=x[114414];x[114414]=0;if((e|0)!=1){break ca}}b=N()|0;break y}b=N()|0;break y}b=N()|0;break y}x[114414]=0;O(334,b+492|0,d+112|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break z}xb(d+112|0);x[114414]=0;T(447,d+80|0,2,d+176|0);e=x[114414];x[114414]=0;if((e|0)==1){break A}x[114414]=0;P(355,d+112|0,d+80|0);e=x[114414];x[114414]=0;if((e|0)==1){break A}e=y[d+206|0]|y[d+207|0]<<8;x[114414]=0;O(334,((((e<<8|e>>>8)&65535)<<5)+a|0)+946304|0,d+112|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break B}xb(d+112|0);x[b>>2]=0;e=y[d+222|0]|y[d+223|0]<<8;x[b+8>>2]=(e<<8|e>>>8)+128&65535;xc(b+8|0,256);v[b+15|0]=y[b+15|0]|1;b=y[d+206|0]|y[d+207|0]<<8;x[114414]=0;b=D((b<<8|b>>>8)&65535,104)+a|0;P(448,b+484380|0,0);e=x[114414];x[114414]=0;if((e|0)==1){break C}e=y[d+208|0]|y[d+209|0]<<8;x[114414]=0;w[d+112>>1]=e<<8|e>>>8;w[d+80>>1]=64;e=O(433,d+112|0,d+80|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break D}w[b+484410>>1]=z[e>>1]<<2;e=y[d+210|0]|y[d+211|0]<<8|(y[d+212|0]<<16|y[d+213|0]<<24);x[114414]=0;e=e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24);f=yna(e,e>>31,8303,0);e=lb;f=f+4181|0;e=f>>>0<4181?e+1|0:e;e=_f(410,zna(f,e,8363,0),lb);f=x[114414];x[114414]=0;if((f|0)==1){break C}x[b+484404>>2]=e;if(!(y[d+218|0]|y[d+219|0]<<8|(y[d+220|0]<<16|y[d+221|0]<<24))|!(y[d+225|0]&3)){break ba}e=y[d+214|0]|y[d+215|0]<<8|(y[d+216|0]<<16|y[d+217|0]<<24);h=e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24);x[b+484384>>2]=h;e=y[d+218|0]|y[d+219|0]<<8|(y[d+220|0]<<16|y[d+221|0]<<24);f=b+484414|0;w[f>>1]=z[f>>1]|2;x[b+484388>>2]=h+(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24));if(!(y[d+225|0]&2)){break ba}w[f>>1]=z[f>>1]|4}g=g+1|0;if(z[a+480192>>1]>=(g&65535)>>>0){continue}break}}x[114414]=0;T(430,d+160|0,d+344|0,1447382614);b=x[114414];x[114414]=0;if((b|0)==1){break E}x[114414]=0;b=x[d+172>>2];x[d+32>>2]=x[d+168>>2];x[d+36>>2]=b;b=x[d+164>>2];x[d+24>>2]=x[d+160>>2];x[d+28>>2]=b;X(449,d+24|0,0,a|0,0);b=x[114414];x[114414]=0;if((b|0)==1){break E}x[114414]=0;T(430,d+144|0,d+344|0,1346719318);b=x[114414];x[114414]=0;if((b|0)==1){break E}x[114414]=0;b=x[d+156>>2];x[d+16>>2]=x[d+152>>2];x[d+20>>2]=b;b=x[d+148>>2];x[d+8>>2]=x[d+144>>2];x[d+12>>2]=b;X(449,d+8|0,1,a|0,y[d+380|0]>2|0);b=x[114414];x[114414]=0;if((b|0)==1){break E}if(!z[a+480192>>1]){break aa}b=1;while(1){e=x[(((b&65535)<<2)+a|0)+900380>>2];if(!(!e|v[e+60|0]&1)){x[e>>2]=32767}b=b+1|0;if(z[a+480192>>1]>=(b&65535)>>>0){continue}break}}Ab(d+232|0);x[114414]=0;T(430,d+176|0,d+344|0,1346458708);b=x[114414];x[114414]=0;if((b|0)==1){break F}x[114414]=0;b=R(303,d+176|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break H}if(!(c&1)|b^1){break V}x[114414]=0;T(430,d+232|0,d+344|0,1347305805);b=x[114414];x[114414]=0;if((b|0)==1){break I}x[114414]=0;O(304,d+232|0,1)|0;b=x[114414];x[114414]=0;if((b|0)==1){break K}k=d+328|6;e=y[k|0]|y[k+1|0]<<8;b=0;x[114414]=0;m=a+484344|0;P(362,m|0,(e<<8|e>>>8)&65535);e=x[114414];x[114414]=0;if((e|0)==1){break K}f=hb-16|0;hb=f;e=d+128|0;x[e>>2]=0;x[e+4>>2]=0;x[114414]=0;x[f+12>>2]=0;U(473,e+8|0,f+12|0,f+8|0)|0;g=x[114414];x[114414]=0;ea:{if((g|0)!=1){hb=f+16|0;break ea}S(0)|0;zb();p()}if(y[k|0]|y[k+1|0]<<8){b=d+48|0;u=b|5;A=b|3;B=b|4;C=b|2;E=b|1;f=0;b=0;while(1){x[114414]=0;s=R(440,d+176|0)|0;g=x[114414];x[114414]=0;fa:{ga:{ha:{ia:{ja:{if((g|0)!=1){x[114414]=0;g=R(450,d+176|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break ja}x[114414]=0;T(307,d+112|0,d+176|0,g|0);g=x[114414];x[114414]=0;if((g|0)==1){break ia}x[114414]=0;g=U(363,m|0,f&65535,s|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break ha}if(!g){break fa}o=Wb(d+96|0);x[114414]=0;U(451,d+232|0,o|0,-1)|0;g=x[114414];x[114414]=0;if((g|0)!=1){g=Zb(m,f);x[114414]=0;O(452,g|0,o|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){break ga}}break N}b=N()|0;break L}b=N()|0;break L}b=N()|0;break L}b=N()|0;break M}g=Zb(m,f);x[114414]=0;t=O(453,g|0,0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break N}XT(e);n=0;ka:{while(1){x[114414]=0;g=O(226,d+112|0,1)|0;h=x[114414];x[114414]=0;la:{ma:{na:{if((h|0)!=1){if(!g){break ka}x[114414]=0;i=R(403,d+112|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break N}if(i){break ma}G=d,H=bc(e),x[G+48>>2]=H;G=d,H=dc(e),x[G+40>>2]=H;if(Hb(d+48|0,d+40|0)){break na}break la}break N}while(1){oa:{g=x[d+48>>2];h=Zb(m,f);i=y[g+1|0];g=y[g|0];x[114414]=0;g=U(454,d+80|0,g|0,i|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break oa}g=Ie(g,n);x[114414]=0;O(455,h|0,g|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break oa}g=d+48|0;ge(g);if(Hb(g,d+40|0)){continue}break la}break}break N}Zh(d+48|0);h=z[a+480188>>1];x[114414]=0;g=R(403,d+112|0)|0;j=x[114414];x[114414]=0;pa:{qa:{if((j|0)!=1){h=h>>>0<i>>>0;i=D(i-1|0,6)+t|0;ra:{if(!(g&1)){break ra}x[114414]=0;j=R(403,d+112|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break N}l=h?d+48|0:i;if((j|0)!=31){if((j-1&255)>>>0>252){break ra}j=(D(j>>>4|0,12)+(j&15)|0)+13|0}else{j=255}v[l|0]=j}if(!(g&2)){break pa}x[114414]=0;j=R(403,d+112|0)|0;l=x[114414];x[114414]=0;if((l|0)!=1){break qa}}break N}v[(h?E:i+1|0)|0]=j}if(!(g&60)){continue}v[d+79|0]=0;v[d+78|0]=0;v[d+77|0]=0;v[d+76|0]=0;if(g&4){x[114414]=0;j=R(403,d+112|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break N}v[d+78|0]=j}if(g&8){x[114414]=0;j=R(403,d+112|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break N}v[d+76|0]=j}if(g&16){x[114414]=0;j=R(403,d+112|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break N}v[d+79|0]=j}if(g&32){x[114414]=0;g=R(403,d+112|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break N}v[d+77|0]=g}WT(d+79|0,d+77|0);WT(d+78|0,d+76|0);g=y[d+78|0];if(!(y[d+79|0]==13|g?(g|0)!=13:0)){wh(d+79|0,d+78|0);wh(d+77|0,d+76|0)}x[114414]=0;ba(456,d- -64|0,d+79|0,d+77|0,d+78|0,d+76|0);g=x[114414];x[114414]=0;sa:{if((g|0)==1){break sa}x[114414]=0;g=O(457,y[d+64|0],y[d+65|0])|0;j=x[114414];x[114414]=0;if((j|0)==1){break sa}ta:{if(!g){break ta}G=d,H=bc(e),x[G+40>>2]=H;g=x[td(d+72|0,d+40|0)>>2];x[114414]=0;U(458,e|0,g|0,d- -64|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){break ta}break N}v[(h?C:i+2|0)|0]=y[d+79|0];v[(h?B:i+4|0)|0]=y[d+77|0];g=y[d+78|0];v[(h?A:i+3|0)|0]=g;v[(h?u:i+5|0)|0]=y[d+76|0];if((g|0)==40){F=1;continue}if((g|0)!=31){continue}b=1;continue}break N}XT(e);n=n+1|0;if(s>>>0<=n>>>0){break ka}g=Zb(m,f);x[114414]=0;t=O(453,g|0,n|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){continue}break}break N}xb(o)}Ab(d+112|0);f=f+1|0;g=y[k|0]|y[k+1|0]<<8;if(f>>>0<((g<<8|g>>>8)&65535)>>>0){continue}break}}VT(e);g=b;Ab(d+232|0);if(!(c&4)){break T}e=0;if(!F){break U}f=z[a+480188>>1];if(!f){e=1;break U}b=0;while(1){e=1;h=(b<<5)+a|0;v[h+480288|0]=1;h=h+480280|0;x[h>>2]=x[h>>2]|67108864;b=b+1|0;if((f|0)!=(b|0)){continue}break}break U}b=N()|0;break t}b=N()|0;break b}g=0;e=0;if(!(c&4)){break S}}x[114414]=0;x[d+96>>2]=-1778364416;x[d+100>>2]=-16756736;T(430,d+232|0,d+344|0,1146310725);b=x[114414];x[114414]=0;ua:{va:{wa:{xa:{ya:{za:{if((b|0)!=1){x[114414]=0;b=R(445,d+232|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break wa}if(!b){break ya}x[114414]=0;h=R(440,d+232|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break wa}if(h){break za}f=e;break xa}b=N()|0;break G}b=0;f=e;while(1){x[114414]=0;i=R(403,d+232|0)|0;k=x[114414];x[114414]=0;Aa:{Ba:{if((k|0)!=1){if(z[a+480188>>1]<=b>>>0){break Aa}if(!e){break Ba}k=((b<<5)+a|0)+480280|0;x[k>>2]=x[k>>2]&-67108865|((i|0)!=0)<<26;break Aa}break wa}if(i){break Aa}f=1;v[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((h|0)!=(b|0)){continue}break}break xa}Ab(d+232|0);if(!e){break T}break ua}x[114414]=0;O(459,d+232|0,d+96|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break va}}b=N()|0;Ab(d+232|0);break G}Ab(d+232|0);if(!(f&1)){break T}}x[114414]=0;W(460,a+906300|0);b=x[114414];x[114414]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{if((b|0)==1){break Ha}b=a+906316|0;x[b>>2]=810369604;x[b+4>>2]=1869112133;v[a+906324|0]=16;v[a+906325|0]=0;v[a+906326|0]=10;v[a+906327|0]=0;b=a+906328|0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;x[114414]=0;x[d+232>>2]=0;b=a+906332|0;T(461,b|0,b+16|0,d+232|0);b=x[114414];x[114414]=0;if((b|0)==1){break Ga}x[114414]=0;e=O(118,d+112|0,5483)|0;b=x[114414];x[114414]=0;if((b|0)==1){break Fa}x[114414]=0;O(462,a+906348|0,e|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break Ea}xb(e);x[114414]=0;e=O(118,d+128|0,5467)|0;b=x[114414];x[114414]=0;if((b|0)==1){break Da}x[114414]=0;O(463,a+906380|0,e|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break Ca}xb(e);x[114414]=0;b=a+906304|0;P(464,b|0,8);e=x[114414];x[114414]=0;if((e|0)==1){break Ha}TT(d+232|0,y[d+97|0],y[d+99|0],y[d+101|0],y[d+103|0]);e=x[d+236>>2];b=x[b>>2];f=x[d+232>>2];v[b|0]=f;v[b+1|0]=f>>>8;v[b+2|0]=f>>>16;v[b+3|0]=f>>>24;v[b+4|0]=e;v[b+5|0]=e>>>8;v[b+6|0]=e>>>16;v[b+7|0]=e>>>24;break T}b=N()|0;break G}b=N()|0;break G}b=N()|0;break G}b=N()|0;xb(e);break G}b=N()|0;break G}b=N()|0;xb(e);break G}if(!g){break S}b=0;Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{while(1){db:{x[114414]=0;x[d+64>>2]=D(b,127)>>>5;P(465,d+96|0,11446);e=x[114414];x[114414]=0;if((e|0)==1){break db}x[114414]=0;P(466,d+48|0,d- -64|0);e=x[114414];x[114414]=0;if((e|0)==1){break cb}x[114414]=0;T(467,d+232|0,d+96|0,d+48|0);e=x[114414];x[114414]=0;if((e|0)==1){break bb}x[114414]=0;e=(b<<5)+a|0;P(468,d+40|0,e+902204|0);f=x[114414];x[114414]=0;if((f|0)==1){break ab}x[114414]=0;O(426,d+40|0,d+232|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break ab}xb(d+232|0);xb(d+48|0);f=d+96|0;Gb(f);x[114414]=0;P(465,f|0,11428);f=x[114414];x[114414]=0;if((f|0)==1){break Za}x[114414]=0;P(466,d+48|0,d- -64|0);f=x[114414];x[114414]=0;if((f|0)==1){break Ya}x[114414]=0;T(467,d+232|0,d+96|0,d+48|0);f=x[114414];x[114414]=0;if((f|0)==1){break Xa}x[114414]=0;P(468,d+40|0,e+903228|0);f=x[114414];x[114414]=0;if((f|0)==1){break Wa}x[114414]=0;O(426,d+40|0,d+232|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Wa}xb(d+232|0);xb(d+48|0);f=d+96|0;Gb(f);x[114414]=0;P(465,f|0,11410);f=x[114414];x[114414]=0;if((f|0)==1){break Ta}x[114414]=0;P(466,d+48|0,d- -64|0);f=x[114414];x[114414]=0;if((f|0)==1){break Sa}x[114414]=0;T(467,d+232|0,d+96|0,d+48|0);f=x[114414];x[114414]=0;if((f|0)==1){break Ra}x[114414]=0;P(468,d+40|0,e+904252|0);f=x[114414];x[114414]=0;if((f|0)==1){break Qa}x[114414]=0;O(426,d+40|0,d+232|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Qa}xb(d+232|0);xb(d+48|0);f=d+96|0;Gb(f);x[114414]=0;P(465,f|0,11401);f=x[114414];x[114414]=0;if((f|0)==1){break Na}x[114414]=0;P(466,d+48|0,d- -64|0);f=x[114414];x[114414]=0;if((f|0)==1){break Ma}x[114414]=0;T(467,d+232|0,d+96|0,d+48|0);f=x[114414];x[114414]=0;if((f|0)==1){break La}x[114414]=0;P(468,d+40|0,e+905276|0);e=x[114414];x[114414]=0;if((e|0)==1){break Ka}x[114414]=0;O(426,d+40|0,d+232|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Ka}xb(d+232|0);xb(d+48|0);Gb(d+96|0);b=b+1|0;if((b|0)!=32){continue}break S}break}b=N()|0;break G}b=N()|0;break _a}b=N()|0;break $a}b=N()|0;xb(d+232|0)}xb(d+48|0)}Gb(d+96|0);break G}b=N()|0;break G}b=N()|0;break Ua}b=N()|0;break Va}b=N()|0;xb(d+232|0)}xb(d+48|0)}Gb(d+96|0);break G}b=N()|0;break G}b=N()|0;break Oa}b=N()|0;break Pa}b=N()|0;xb(d+232|0)}xb(d+48|0)}Gb(d+96|0);break G}b=N()|0;break G}b=N()|0;break Ia}b=N()|0;break Ja}b=N()|0;xb(d+232|0)}xb(d+48|0)}Gb(d+96|0);break G}x[114414]=0;T(430,d+232|0,d+344|0,1397575756);b=x[114414];x[114414]=0;if((b|0)==1){break O}x[114414]=0;b=R(303,d+232|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break P}e=1;if(!(!z[a+480190>>1]|(!(c&2)|b^1))){c=1;while(1){x[114414]=0;b=R(450,d+232|0)|0;f=x[114414];x[114414]=0;eb:{if((f|0)!=1){x[114414]=0;f=R(450,d+232|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break P}if(!(b&7)){break eb}e=(D(e,104)+a|0)+484380|0;x[e>>2]=f;b=ad(d+96|0,b&4?32:b&2?16:8,1,1,0);x[114414]=0;U(361,b|0,e|0,d+232|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break eb}break P}break P}c=c+1|0;e=c&65535;if(e>>>0<=z[a+480190>>1]){continue}break}}Ab(d+232|0);Ab(d+176|0);Ab(d+248|0);Ab(d+264|0)}TA(d+344|0);Ab(r)}hb=d+384|0;return q|0}b=N()|0;Ab(d+232|0);break G}b=N()|0;break G}b=N()|0;xb(o)}Ab(d+112|0)}VT(e);break J}b=N()|0}Ab(d+232|0);break G}b=N()|0;break G}b=N()|0}Ab(d+176|0);break t}b=N()|0;break t}b=N()|0;break y}b=N()|0;break y}b=N()|0;break y}b=N()|0;xb(d+112|0);break y}b=N()|0;break y}b=N()|0;xb(d+112|0)}Ab(d+232|0);break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;xb(d+232|0);break t}b=N()|0}Ab(d+248|0);break q}b=N()|0;break q}b=N()|0}Ab(d+264|0);break b}b=N()|0;break b}b=N()|0;xb(d+232|0);break m}b=N()|0}xb(d+248|0);break k}b=N()|0}Gb(d+264|0);break i}b=N()|0}xb(e);break b}b=N()|0;break b}b=N()|0;break b}b=N()|0;break b}b=N()|0;break b}b=N()|0;break b}b=N()|0}TA(d+344|0)}Ab(r);Q(b|0);p()}function zia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;e=hb-384|0;hb=e;Lc(b);a:{if(!pu(b,e+368|0)){break a}if(!XP(e+368|0)){break a}r=fm(e+352|0,b);l=yz(e+336|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if(!c){x[114414]=0;X(922,e+80|0,r|0,1,1413891155);b=x[114414];x[114414]=0;if((b|0)==1){break t}break v}x[114414]=0;T(923,e+80|0,r|0,1);b=x[114414];x[114414]=0;if((b|0)==1){break u}}if(x[l>>2]){xd(l);RP(l);Yp(l);Hf(yb(l),x[l>>2],af(l));u=yb(l),A=0,x[u>>2]=A;x[l>>2]=0;x[l+4>>2]=0}b=e+80|0;Wl(l,b);x[l>>2]=x[b>>2];x[l+4>>2]=x[b+4>>2];k=x[yb(b)>>2];u=yb(l),A=k,x[u>>2]=A;u=yb(b),A=0,x[u>>2]=A;x[b>>2]=0;x[b+4>>2]=0;Yl(b);x[114414]=0;T(924,b|0,l|0,1413891155);b=x[114414];x[114414]=0;w:{x:{if((b|0)!=1){x[114414]=0;d=O(925,e+80|0,9890)|0;b=x[114414];x[114414]=0;if((b|0)==1){break x}Ab(e+80|0);if((c|0)!=0&d){break w}break b}d=N()|0;break d}d=N()|0;Ab(e+80|0);break d}x[114414]=0;P(397,a|0,4194304);b=x[114414];x[114414]=0;if((b|0)==1){break e}x[a+480208>>2]=12;x[114414]=0;T(924,e+320|0,l|0,1280592212);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=R(223,e+320|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break h}x[114414]=0;U(655,e+320|0,a+1304400|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break h}o=a+484360|0;wq(Vb(o));k=hb-16|0;hb=k;b=e+304|0;x[b>>2]=0;x[b+4>>2]=0;x[114414]=0;x[k+12>>2]=0;U(944,b+8|0,k+12|0,k+8|0)|0;d=x[114414];x[114414]=0;y:{if((d|0)!=1){hb=k+16|0;break y}S(0)|0;zb();p()}k=b;x[114414]=0;v[e+303|0]=0;T(926,e+288|0,l|0,1196314451);b=x[114414];x[114414]=0;if((b|0)==1){break j}b=e+288|0;u=e,A=bc(b),x[u+280>>2]=A;u=e,A=dc(b),x[u+272>>2]=A;z:{if(!Hb(e+280|0,e+272|0)){break z}q=e+228|0;m=e+240|0;n=e+260|0;A:{while(1){h=fm(e+80|0,x[e+280>>2]);x[114414]=0;b=O(927,h|0,e|0)|0;d=x[114414];x[114414]=0;B:{if((d|0)!=1){if(b&y[e+9|0]==1){break B}Ab(h);d=0;break c}d=N()|0;break l}u=a,A=Md(y[e+10|0],z[a+480188>>1],127),w[u+480188>>1]=A;x[114414]=0;f=R(928,e+216|0)|0;b=x[114414];x[114414]=0;C:{D:{E:{F:{G:{H:{if((b|0)!=1){x[114414]=0;T(929,e+16|0,1,e|0);b=x[114414];x[114414]=0;if((b|0)==1){break H}x[114414]=0;P(355,e+184|0,e+16|0);b=x[114414];x[114414]=0;if((b|0)==1){break H}x[114414]=0;P(930,e- -64|0,n|0);b=x[114414];x[114414]=0;if((b|0)==1){break G}x[114414]=0;O(426,e- -64|0,e+184|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break G}xb(e+184|0);if(od(Vb(o))){break E}x[114414]=0;b=R(441,o|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break F}if((b|0)!=255){break E}b=2;break D}d=N()|0;break l}d=N()|0;break m}d=N()|0;xb(e+184|0);break m}d=N()|0;break m}b=Vb(o);x[114414]=0;T(6,e+184|0,4,n|0);d=x[114414];x[114414]=0;I:{J:{K:{L:{M:{if((d|0)!=1){x[114414]=0;P(442,b|0,e+184|0);b=x[114414];x[114414]=0;if((b|0)==1){break M}xb(e+184|0);x[114414]=0;T(923,e+16|0,h|0,1);b=x[114414];x[114414]=0;if((b|0)==1){break L}b=e+16|0;u=e,A=bc(b),x[u+208>>2]=A;u=e,A=dc(b),x[u+200>>2]=A;if(Hb(e+208|0,e+200|0)){break K}break J}d=N()|0;break m}d=N()|0;xb(e+184|0);break m}d=N()|0;break m}while(1){N:{d=x[e+208>>2];b=df(e+184|0,yb(d));g=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[e+64>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[e+68>>2]=g;O:{d=e- -64|0;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);if((d|0)!=1212960847){if((d|0)!=1312903248){break O}d=0;if(!z[a+480188>>1]){break O}while(1){P:{x[114414]=0;g=O(226,b|0,2)|0;j=x[114414];x[114414]=0;if((j|0)==1){break P}if(!g){break O}x[114414]=0;P(428,e+32|0,b|0);g=x[114414];x[114414]=0;Q:{R:{S:{T:{if((g|0)!=1){g=ed(e+32|0);switch(y[e+32|0]){case 4:break R;case 2:break S;case 0:break T;default:break Q}}break N}g=y[g|0];u=Bc(f,d),A=g^128,v[u|0]=A;g=e+48|0;oe(g,m,d);he(g,0);break Q}u=Bc(f,d),A=128,v[u|0]=A;g=e+48|0;oe(g,m,d);he(g,1);break Q}u=Bc(f,d),A=128,v[u|0]=A;g=e+48|0;oe(g,m,d);he(g,0)}d=d+1|0;if(d>>>0<z[a+480188>>1]){continue}break O}break}break N}if(zz(e- -64|0)>>>0<9){break O}j=0;x[114414]=0;O(304,b|0,2)|0;d=x[114414];x[114414]=0;g=65535;if((d|0)==1){break N}while(1){x[114414]=0;d=O(226,b|0,1)|0;i=x[114414];x[114414]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{if((i|0)!=1){if(!d){break O}x[114414]=0;d=R(403,b|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break N}switch(d|0){case 0:break O;case 14:break V;case 13:break W;case 12:break Y;case 8:break Z;case 7:break _;case 4:break $;case 1:break aa;default:break X}}break N}if(z[e+252>>1]==65535){d=Vb(o);x[114414]=0;d=R(511,d|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break N}w[e+252>>1]=d}d=Vb(o);x[114414]=0;d=R(511,d|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break N}x[114414]=0;w[e+254>>1]=d;d=O(931,b|0,e+303|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break N}ba:{ca:{switch(d-254|0){case 1:x[114414]=0;d=$(932)|0;i=x[114414];x[114414]=0;if((i|0)!=1){break ba}break N;case 0:break ca;default:break ba}}x[114414]=0;d=$(933)|0;i=x[114414];x[114414]=0;if((i|0)==1){break N}}i=Vb(o);x[114414]=0;P(771,i|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break N}g=(g&65535)==65535?j:g;break U}x[114414]=0;d=R(321,b|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break N}if(d>>>0>=(g&65535)>>>0){w[e+256>>1]=d-g}Se(Vb(o),z[e+256>>1]);break U}x[114414]=0;d=R(403,b|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break N}v[e+259|0]=d;break U}x[114414]=0;d=R(403,b|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break N}v[e+258|0]=d;break U}x[114414]=0;d=O(892,b|0,e+48|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break N}if(y[e+48|0]|!d|(y[e+50|0]|y[e+49|0]!=255)){break X}if(y[e+51|0]|y[e+52|0]!=1){break X}if(!y[e+53|0]){break U}}Ab(b);b=1;break I}x[114414]=0;P(786,e+176|0,b|0);d=x[114414];x[114414]=0;da:{ea:{fa:{ga:{if((d|0)!=1){d=e+176|0;i=ed(d);s=rf(d);if(y[d|0]>=wc(f)>>>0){break U}switch(y[s|0]){case 4:break ea;case 2:break fa;case 0:break ga;default:break da}}break N}i=y[i|0];u=Bc(f,y[d|0]),A=i^128,v[u|0]=A;i=e+48|0;oe(i,m,y[d|0]);he(i,0);break da}u=Bc(f,y[d|0]),A=128,v[u|0]=A;i=e+48|0;oe(i,m,y[d|0]);he(i,1);break da}u=Bc(f,y[d|0]),A=128,v[u|0]=A;i=e+48|0;oe(i,m,y[d|0]);he(i,0)}ha:{if(t){break ha}t=0;if(!Lk(k)){break U}if(y[Bc(VP(k),y[d|0])|0]!=y[Bc(f,y[d|0])|0]){break ha}i=e+48|0;oe(i,VP(k)+24|0,y[d|0]);i=Ib(i);s=e+32|0;oe(s,m,y[d|0]);if((Ib(s)|0)==(i|0)){break U}}t=1;break U}x[114414]=0;P(428,e+48|0,b|0);d=x[114414];x[114414]=0;if((d|0)==1){break N}d=ed(e+48|0);i=y[e+48|0];if(wc(q)>>>0<=i>>>0){break U}d=y[d|0];u=Bc(q,y[e+48|0]),A=(d>>>2|0)+1|0,v[u|0]=A}j=j+1|0;continue}}Ab(b);b=e+208|0;Xi(b);if(Hb(b,e+200|0)){continue}break J}break}d=N()|0;Ab(b);break C}b=0;if(z[e+252>>1]==65535|z[e+254>>1]==65535){break I}b=Vb(o);x[114414]=0;W(934,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){b=0;x[114414]=0;P(935,k|0,f|0);d=x[114414];x[114414]=0;if((d|0)!=1){break I}}d=N()|0;break C}Yl(e+16|0)}Kt(f);Ab(h);if(b){break A}b=e+280|0;of(b);if(Hb(b,e+272|0)){continue}break z}break}Yl(e+16|0);break m}d=0;if((b|0)!=2){break c}}d=0;x[114414]=0;P(444,o|0,0);b=x[114414];x[114414]=0;if((b|0)==1){break s}if(od(k)){break c}ia:{if(c&2){x[114414]=0;T(926,e+184|0,l|0,1347244868);b=x[114414];x[114414]=0;if((b|0)==1){break ia}b=e+184|0;u=e,A=bc(b),x[u+64>>2]=A;u=e,A=dc(b),x[u+48>>2]=A;if(Hb(e- -64|0,e+48|0)){d=a+480190|0;f=e+93|0;g=e+97|0;m=y[e+303|0];while(1){b=x[e- -64>>2];ja:{ka:{la:{ma:{na:{if(!m){x[114414]=0;h=O(936,b|0,e+80|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break na}if(!h){break ja}h=y[e+132|0]|y[e+133|0]<<8;w[e+32>>1]=h+1;if(h>>>0>3998){break la}x[114414]=0;h=O(402,d|0,e+32|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break na}w[a+480190>>1]=z[h>>1];x[114414]=0;P(937,e+80|0,(D(z[e+32>>1],104)+a|0)+484380|0);h=x[114414];x[114414]=0;if((h|0)==1){break na}x[114414]=0;T(938,e|0,1,f|0);h=x[114414];x[114414]=0;oa:{pa:{if((h|0)==1){break pa}x[114414]=0;P(355,e+16|0,e|0);h=x[114414];x[114414]=0;if((h|0)==1){break pa}x[114414]=0;O(334,((z[e+32>>1]<<5)+a|0)+946304|0,e+16|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break oa}xb(e+16|0);break la}d=N()|0;break ka}d=N()|0;xb(e+16|0);break ka}x[114414]=0;h=O(939,b|0,e+80|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break ma}if(!h){break ja}h=y[e+136|0]|y[e+137|0]<<8;w[e+32>>1]=h+1;if(h>>>0>3998){break la}x[114414]=0;h=O(402,d|0,e+32|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break ma}w[a+480190>>1]=z[h>>1];x[114414]=0;P(940,e+80|0,(D(z[e+32>>1],104)+a|0)+484380|0);h=x[114414];x[114414]=0;if((h|0)==1){break ma}x[114414]=0;T(938,e|0,1,g|0);h=x[114414];x[114414]=0;qa:{ra:{if((h|0)==1){break ra}x[114414]=0;P(355,e+16|0,e|0);h=x[114414];x[114414]=0;if((h|0)==1){break ra}x[114414]=0;O(334,((z[e+32>>1]<<5)+a|0)+946304|0,e+16|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break qa}xb(e+16|0);break la}d=N()|0;break ka}d=N()|0;xb(e+16|0);break ka}d=N()|0;break ka}d=N()|0;break ka}if((z[e+32>>1]-1&65535)>>>0>3998){break ja}h=ad(e+80|0,8,1,0,2);x[114414]=0;U(361,h|0,(D(z[e+32>>1],104)+a|0)+484380|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break ja}d=N()|0}id(e+184|0);break k}b=e- -64|0;of(b);if(Hb(b,e+48|0)){continue}break}}id(e+184|0)}b=0;u=a,A=y[Xl(k,0)+43|0],x[u+480196>>2]=A;u=a,A=D(y[Xl(k,0)+42|0],1e4),x[u+480204>>2]=A;Se(Vb(o),z[Xl(k,0)+40>>1]);sa:{if(z[a+480188>>1]){while(1){x[114414]=0;d=(b<<5)+a|0;f=d+480280|0;W(381,f|0);g=x[114414];x[114414]=0;if((g|0)==1){break sa}u=d+480286|0,A=y[Bc(Xl(k,0)+12|0,b)|0],w[u>>1]=A;u=d+480284|0,A=y[Bc(Xl(k,0),b)|0],w[u>>1]=A;d=e+80|0;oe(d,Xl(k,0)+24|0,b);d=Ib(d);x[f>>2]=x[f>>2]&-257|(d?256:0);b=b+1|0;if(b>>>0<z[a+480188>>1]){continue}break}}x[114414]=0;b=O(2,e- -64|0,(y[e+303|0]?13009:12882)|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break n}Db(a+1304436|0,b);xb(b);x[114414]=0;b=O(2,e+48|0,6118)|0;d=x[114414];x[114414]=0;if((d|0)==1){break o}Db(a+1304448|0,b);xb(b);x[a+1304496>>2]=4;d=1;if(!(c&1)|!z[a+480188>>1]){break c}x[114414]=0;T(926,e+32|0,l|0,1146045008);b=x[114414];x[114414]=0;if((b|0)==1){break p}b=rd(e+32|0);x[114414]=0;h=a+484344|0;P(362,h|0,b&65535);b=x[114414];x[114414]=0;if((b|0)==1){break r}b=e+32|0;u=e,A=bc(b),x[u+184>>2]=A;u=e,A=dc(b),x[u+16>>2]=A;if(Hb(e+184|0,e+16|0)){while(1){m=x[e+184>>2];x[114414]=0;b=R(223,m|0)|0;c=x[114414];x[114414]=0;ta:{ua:{va:{if((c|0)==1){break va}x[114414]=0;c=R(391,m|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break va}if((b|0)!=(c|0)){break ta}x[114414]=0;b=O(941,m|0,8)|0;c=x[114414];x[114414]=0;if((c|0)==1){break va}if(b){break ua}break ta}d=N()|0;break q}x[114414]=0;q=O(931,m|0,e+303|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;j=R(321,m|0)|0;b=x[114414];x[114414]=0;wa:{if((b|0)==1){break wa}x[114414]=0;b=U(363,h|0,q|0,j|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break wa}if(!j|b^1){break ta}g=0;while(1){xa:{b=Zb(h,q);x[114414]=0;c=O(453,b|0,g|0)|0;b=x[114414];x[114414]=0;ya:{za:{Aa:{if((b|0)!=1){x[114414]=0;b=R(321,m|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break Aa}if(b>>>0<3){break ya}x[114414]=0;T(307,e+80|0,m|0,b-2|0);b=x[114414];x[114414]=0;if((b|0)!=1){break za}d=N()|0;break q}d=N()|0;break q}d=N()|0;break q}while(1){x[114414]=0;b=O(226,e+80|0,3)|0;d=x[114414];x[114414]=0;if((d|0)==1){break xa}if(b){x[114414]=0;P(428,e|0,e+80|0);b=x[114414];x[114414]=0;Ba:{Ca:{Da:{Ea:{if((b|0)!=1){b=ed(e);w[e+280>>1]=z[a+480188>>1]-1;b=y[b|0];x[114414]=0;w[e+272>>1]=b;b=O(433,e+280|0,e+272|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break xa}d=z[b>>1];f=c+D(d,6)|0;b=v[e|0];if((b|0)>=0){break Ba}x[114414]=0;b=R(403,e+80|0)|0;n=x[114414];x[114414]=0;if((n|0)==1){break xa}if(y[e+303|0]){break Da}if((b|0)!=255){break Ea}b=254;break Ca}break xa}if(b>>>0>128){break Ca}b=(D(b>>>4|0,12)+(b&15)|0)+13|0;break Ca}b=b>>>0<85?b+36|0:b}v[f|0]=b;b=y[e|0]}if(b&64){x[114414]=0;b=R(403,e+80|0)|0;n=x[114414];x[114414]=0;if((n|0)==1){break xa}v[f+1|0]=b+1;b=y[e|0]}if(b&32){x[114414]=0;b=R(403,e+80|0)|0;n=x[114414];x[114414]=0;if((n|0)==1){break xa}v[e+280|0]=b;v[f+2|0]=1;x[114414]=0;v[e+272|0]=127;b=O(409,e+280|0,e+272|0)|0;n=x[114414];x[114414]=0;if((n|0)==1){break xa}v[f+4|0]=y[b|0]+1>>>1;b=y[e|0]}if(!(b&16)){continue}x[114414]=0;P(428,e+280|0,e+80|0);b=x[114414];x[114414]=0;if((b|0)==1){break xa}n=e+280|0;b=y[ed(n)|0];v[f+5|0]=b;Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{switch(y[n|0]-1|0){case 0:v[(c+D(d,6)|0)+3|0]=11;if(!y[e+303|0]){v[f+5|0]=b<<3|15;continue}v[f+5|0]=b<<4|15;continue;case 1:v[(c+D(d,6)|0)+3|0]=11;if(y[e+303|0]){v[f+5|0]=b<<4;continue}v[f+5|0]=b<<3&240;continue;case 2:v[(c+D(d,6)|0)+3|0]=11;if(y[e+303|0]){v[f+5|0]=b|240;continue}v[f+5|0]=b>>>1|240;continue;case 3:v[(c+D(d,6)|0)+3|0]=11;if(y[e+303|0]){v[f+5|0]=b&15;continue}if(b>>>0<=1){v[f+5|0]=b|240;continue}v[f+5|0]=b>>>1&15;continue;case 10:v[(c+D(d,6)|0)+3|0]=2;u=f,A=Jt(b,y[e+303|0])|240,v[u+5|0]=A;continue;case 11:v[(c+D(d,6)|0)+3|0]=2;u=f,A=Jt(b,y[e+303|0]),v[u+5|0]=A;continue;case 12:v[(c+D(d,6)|0)+3|0]=3;u=f,A=Jt(b,y[e+303|0])|240,v[u+5|0]=A;continue;case 13:v[(c+D(d,6)|0)+3|0]=3;u=f,A=Jt(b,y[e+303|0]),v[u+5|0]=A;continue;case 14:v[(c+D(d,6)|0)+3|0]=4;if(y[e+303|0]){continue}v[f+5|0]=(b&252)>>>2;continue;case 16:v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&1|16;continue;case 15:v[(c+D(d,6)|0)+3|0]=6;v[f+5|0]=b&240;continue;case 17:v[(c+D(d,6)|0)+3|0]=6;v[f+5|0]=(b&240)>>>4;continue;case 18:v[(c+D(d,6)|0)+3|0]=20;continue;case 20:v[(c+D(d,6)|0)+3|0]=5;continue;case 21:v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|48;continue;case 22:v[(c+D(d,6)|0)+3|0]=7;v[f+5|0]=b|240;continue;case 23:v[(c+D(d,6)|0)+3|0]=7;continue;case 30:v[(c+D(d,6)|0)+3|0]=8;continue;case 31:v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|64;continue;case 40:v[(c+D(d,6)|0)+3|0]=10;x[114414]=0;b=R(403,e+80|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break Oa}break xa;case 41:v[(c+D(d,6)|0)+3|0]=15;continue;case 42:v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|192;continue;case 43:v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|208;continue;case 72:break Ga;case 71:break Ha;case 70:break Ia;case 61:break Ja;case 60:break Ka;case 53:break La;case 52:break Ma;case 51:break Na;case 50:break Pa;default:break Fa}}v[(c+D(d,6)|0)+3|0]=12;b=(b&254)>>>1|0}v[f+5|0]=b;x[114414]=0;O(304,e+80|0,1)|0;b=x[114414];x[114414]=0;if((b|0)!=1){continue}break xa}v[(c+D(d,6)|0)+3|0]=14;v[f+5|0]=0;continue}v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|176;continue}v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|224;continue}v[(c+D(d,6)|0)+3|0]=16;continue}v[(c+D(d,6)|0)+3|0]=17;continue}v[(c+D(d,6)|0)+3|0]=1;continue}v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|32;continue}v[(c+D(d,6)|0)+3|0]=20;v[f+5|0]=b&15|128;continue}v[(c+D(d,6)|0)+3|0]=0;continue}break}Ab(e+80|0)}g=g+1|0;if((j|0)!=(g|0)){continue}break ta}break}d=N()|0;Ab(e+80|0);break q}d=N()|0;break q}d=N()|0;break q}b=e+184|0;of(b);if(Hb(b,e+16|0)){continue}break}}Qa:{Ra:{if(Lk(k)>>>0<2){break Ra}if(!Lk(k)){break Ra}d=0;while(1){b=Ni(o,d&255);c=Xl(k,d);f=z[uc(b,z[c+36>>1])>>1];x[114414]=0;f=O(392,h|0,f|0)|0;g=x[114414];x[114414]=0;Sa:{Ta:{if((g|0)!=1){if(!f){break Sa}f=z[c+36>>1];x[114414]=0;f=O(790,b|0,f|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break Ta}}d=N()|0;break q}if(z[a+480188>>1]!=0&t){m=c+24|0;b=0;while(1){j=UP(m,b);g=Zb(h,f);Ua:{if(j){x[114414]=0;j=U(454,e+80|0,20,145)|0;q=x[114414];x[114414]=0;if((q|0)!=1){j=ai(Yn(Ie(j,0),b&65535));x[114414]=0;O(455,g|0,j|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){break Ua}}d=N()|0;break q}j=y[Bc(c,b)|0];x[114414]=0;j=U(454,e+184|0,9,j|0)|0;q=x[114414];x[114414]=0;if((q|0)!=1){j=ai(Yn(Ie(j,0),b&65535));x[114414]=0;O(455,g|0,j|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){break Ua}}d=N()|0;break q}b=b+1|0;if(b>>>0<z[a+480188>>1]){continue}break}}b=Zb(h,f);g=y[c+43|0];x[114414]=0;g=U(454,e+16|0,16,g|0)|0;m=x[114414];x[114414]=0;if((m|0)==1){break Qa}g=ai(Ie(g,0));x[114414]=0;O(455,b|0,g|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break Qa}b=Zb(h,f);c=y[c+42|0];x[114414]=0;c=U(454,e|0,17,c|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){c=ai(Ie(c,0));x[114414]=0;O(455,b|0,c|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break Sa}}d=N()|0;break q}d=d+1|0;if(Lk(k)>>>0>d>>>0){continue}break}}id(e+32|0);d=1;break c}d=N()|0;break q}d=N()|0;break k}d=N()|0;break k}d=N()|0;break d}d=N()|0;break d}d=N()|0;break k}d=N()|0}id(e+32|0);break k}d=N()|0;break k}d=N()|0;break k}d=N()|0;break k}Kt(f)}Ab(h)}id(e+288|0);break i}d=N()|0}TP(k);break g}d=N()|0}Ab(e+320|0);break d}d=N()|0;break d}d=N()|0}Yl(l);Ab(r);Q(d|0);p()}id(e+288|0);TP(k);Ab(e+320|0)}Yl(l);Ab(r)}hb=e+384|0;return d|0}function q1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=E(0),u=0,C=0,G=0,H=0,I=0,K=0,L=E(0),M=0,N=0,O=0,P=E(0);s=hb-1520|0;hb=s;f=s+8|0;g=Sb(f,0,1512);if(e){i=x[e+4>>2];e=x[e>>2];x[g+80>>2]=e;x[g+84>>2]=i;e=i&-8;x[g+92>>2]=e;x[g+84>>2]=e}x[g+1420>>2]=-1;x[g+124>>2]=0;x[g+32>>2]=0;x[g+96>>2]=0;x[g+100>>2]=0;v[s+56|0]=1;x[s+48>>2]=a+b;x[s+40>>2]=a;b=0;n=hb-1024|0;hb=n;v[f+1377|0]=1;a:{if(!is(f)){break a}e=y[f+1375|0];if(!(e&2)){fc(f,34);break a}if(e&4){fc(f,34);break a}if(e&1){fc(f,34);break a}if(x[f+1116>>2]!=1){fc(f,34);break a}e=y[f+1120|0];if((e|0)!=30){b:{if((e|0)!=64){break b}if(!Xw(f,n+1018|0,6)|y[n+1018|0]!=102|(y[n+1019|0]!=105|y[n+1020|0]!=115)){break b}if(y[n+1021|0]!=104|y[n+1022|0]!=101|y[n+1023|0]!=97){break b}if((ye(f)|0)!=100){break b}if(ye(f)){break b}fc(f,38);break a}fc(f,34);break a}if((ye(f)|0)!=1){fc(f,34);break a}if(!Xw(f,n+1018|0,6)){fc(f,10);break a}if(!Ww(n+1018|0)){fc(f,34);break a}if(ri(f)){fc(f,34);break a}e=ye(f);x[f+4>>2]=e;if(!e){fc(f,34);break a}if(e>>>0>=17){fc(f,5);break a}e=ri(f);x[f>>2]=e;if(!e){fc(f,34);break a}ri(f);ri(f);ri(f);e=ye(f);i=e>>>4|0;x[f+116>>2]=1<<i;g=e&15;x[f+112>>2]=1<<g;if(g-14>>>0<=4294967287){fc(f,20);break a}if(e+32<<24>>24>=0){fc(f,20);break a}c:{if(g>>>0>i>>>0){fc(f,20);break c}if(!(ye(f)&1)){fc(f,34);break c}if(!is(f)){break a}if(!Vw(f)){break a}if(!Uw(f)){break a}d:{if((Rg(f)|0)==3){while(1){N=(n+1018|0)+b|0,O=Rg(f),v[N|0]=O;b=b+1|0;if((b|0)!=6){continue}break}if(!Ww(n+1018|0)){fc(f,20);break c}g=Tw(f);e=Rd(f,g+1|0);x[f+20>>2]=e;if(e){b=0;if((g|0)>0){while(1){e=Rg(f);v[x[f+20>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=x[f+20>>2]}v[e+g|0]=0;b=Tw(f);x[f+28>>2]=0;x[f+24>>2]=b;e:{f:{if((b|0)<=0){break f}b=Rd(f,b<<2);x[f+28>>2]=b;if(!b){fc(f,3);break c}if(x[f+24>>2]<=0){break f}while(1){g=Tw(f);b=Rd(f,g+1|0);i=h<<2;x[i+x[f+28>>2]>>2]=b;e=x[i+x[f+28>>2]>>2];if(!e){break e}b=0;if((g|0)>0){while(1){e=Rg(f);v[x[i+x[f+28>>2]>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=x[i+x[f+28>>2]>>2]}v[e+g|0]=0;h=h+1|0;if((h|0)<x[f+24>>2]){continue}break}}if(!(Rg(f)&1)){fc(f,20);break c}qH(f,y[f+1376|0]);v[f+1376|0]=0;while(1){b=Uw(f);qH(f,b);v[f+1376|0]=0;if(b){continue}break}b=0;if(!Vw(f)){break a}if(!sH(f)){if(x[f+100>>2]!=21){break a}x[f+100>>2]=20;break a}e=0;while(1){g=e<<24;i=0;while(1){g=g>>31&79764919^g<<1;i=i+1|0;if((i|0)!=8){continue}break}x[(e<<2)+455936>>2]=g;e=e+1|0;if((e|0)!=256){continue}break}if((Rg(f)|0)==5){while(1){N=(n+1018|0)+b|0,O=Rg(f),v[N|0]=O;b=b+1|0;if((b|0)!=6){continue}break}if(!Ww(n+1018|0)){fc(f,20);break c}b=lc(f,8)+1|0;x[f+120>>2]=b;b=Rd(f,D(b,2096));x[f+124>>2]=b;if(!b){fc(f,3);break c}Sb(b,0,D(x[f+120>>2],2096));g:{h:{if(x[f+120>>2]>0){while(1){b=x[f+124>>2];if((lc(f,8)&255)!=66){fc(f,20);break c}if((lc(f,8)&255)!=67){fc(f,20);break c}if((lc(f,8)&255)!=86){fc(f,20);break c}g=b+D(o,2096)|0;N=g,O=lc(f,8)&255|lc(f,8)<<8,x[N>>2]=O;N=g,O=lc(f,8)&255|(lc(f,8)<<8&65280|lc(f,8)<<16),x[N+4>>2]=O;b=0;m=g+4|0;h=lc(f,1);if(!h){b=lc(f,1)}v[g+23|0]=b;if(!(x[g>>2]|!x[m>>2])){fc(f,20);break c}e=x[m>>2];i:{if(b&255){e=en(f,e);break i}e=Rd(f,e);x[g+8>>2]=e}if(!e){fc(f,3);break c}j:{if(!h){b=0;i=0;h=x[m>>2];if((h|0)<=0){break j}while(1){k:{l:{if(y[g+23|0]){if(!lc(f,1)){break l}}h=lc(f,5)+1|0;v[b+e|0]=h;if((h&255)!=32){i=i+1|0;break k}fc(f,20);break c}v[b+e|0]=255}b=b+1|0;h=x[m>>2];if((b|0)<(h|0)){continue}break}break j}l=lc(f,5);i=0;b=0;h=x[m>>2];if((h|0)<=0){break j}while(1){k=lc(f,El(h-b|0));l=l+1|0;if((l|0)>=32){fc(f,20);break c}h=b+k|0;if((h|0)>x[m>>2]){fc(f,20);break c}Sb(b+e|0,l,k);b=h;h=x[m>>2];if((b|0)<(h|0)){continue}break}}m:{n:{if(y[g+23|0]){if(h>>2>(i|0)){break n}if(x[f+16>>2]<(h|0)){x[f+16>>2]=h;h=x[m>>2]}b=Rd(f,h);x[g+8>>2]=b;if(!b){fc(f,3);break c}sc(b,e,x[m>>2]);qi(f,e,x[m>>2]);e=x[g+8>>2];v[g+23|0]=0}i=0;b=0;h=0;k=x[m>>2];if((k|0)>0){while(1){h=((y[b+e|0]-11&255)>>>0<244)+h|0;b=b+1|0;if((k|0)!=(b|0)){continue}break}}x[g+2092>>2]=h;b=Rd(f,k<<2);x[g+32>>2]=b;if(b){h=g+2092|0;break m}fc(f,3);break c}x[g+2092>>2]=i;h=g+2092|0;o:{if(!i){i=0;break o}b=Rd(f,i);x[g+8>>2]=b;if(!b){fc(f,3);break c}b=en(f,x[h>>2]<<2);x[g+32>>2]=b;if(!b){fc(f,3);break c}i=en(f,x[h>>2]<<2);if(i){break o}fc(f,3);break c}b=x[m>>2]+(x[h>>2]<<3)|0;if(b>>>0<=A[f+16>>2]){break m}x[f+16>>2]=b}l=x[m>>2];k=0;b=hb-128|0;hb=b;q=Sb(b,0,128);p:{q:{r:{s:{t:{u:{v:{w:{if((l|0)<=0){break w}while(1){if(y[e+k|0]!=255){break w}k=k+1|0;if((l|0)!=(k|0)){continue}break}break v}if((k|0)!=(l|0)){break u}}k=1;if(!x[g+2092>>2]){break t}ea(11728,9049,1103,3800);p()}b=e+k|0;j=y[b|0];if(j>>>0>=32){break s}hH(g,0,k,0,j,i);j=y[b|0];if(j){b=1;while(1){x[q+(b<<2)>>2]=1<<32-b;r=(b|0)==(j|0);b=b+1|0;if(!r){continue}break}}H=1;r=k+1|0;if((l|0)<=(r|0)){k=1;break t}while(1){I=e+r|0;j=y[I|0];x:{if((j|0)==255){break x}if(j>>>0>31){break r}k=0;b=j;if(!b){break t}while(1){K=q+(b<<2)|0;u=x[K>>2];if(!u){u=(b|0)>1;b=b-1|0;if(u){continue}break t}break}x[K>>2]=0;hH(g,Cl(u),r,H,j,i);H=H+1|0;k=y[I|0];if(k>>>0<=b>>>0){break x}while(1){j=q+(k<<2)|0;if(x[j>>2]){break q}x[j>>2]=u+(1<<32-k);k=k-1|0;if((k|0)>(b|0)){continue}break}}k=1;r=r+1|0;if((l|0)!=(r|0)){continue}break}}hb=q+128|0;break p}ea(10747,9049,1104,3800);p()}ea(10740,9049,1118,3800);p()}ea(11772,9049,1133,3800);p()}if(!k){if(y[g+23|0]){qi(f,i,0)}fc(f,20);break c}b=x[h>>2];if(b){b=Rd(f,(b<<2)+4|0);x[g+2084>>2]=b;if(!b){fc(f,3);break c}b=Rd(f,(x[h>>2]<<2)+4|0);x[g+2088>>2]=b;if(!b){fc(f,3);break c}x[g+2088>>2]=b+4;x[b>>2]=-1;k=0;l=0;y:{if(y[g+23|0]){l=x[g+2092>>2];if((l|0)<=0){break y}while(1){b=k<<2;N=b+x[g+2084>>2]|0,O=Cl(x[b+x[g+32>>2]>>2]),x[N>>2]=O;k=k+1|0;l=x[g+2092>>2];if((k|0)<(l|0)){continue}break}break y}if(x[g+4>>2]>0){while(1){if(gH(g,y[e+k|0])){N=x[g+2084>>2]+(l<<2)|0,O=Cl(x[x[g+32>>2]+(k<<2)>>2]),x[N>>2]=O;l=l+1|0}k=k+1|0;if((k|0)<x[g+4>>2]){continue}break}}if(x[g+2092>>2]==(l|0)){break y}ea(3741,9049,1200,5968);p()}OG(x[g+2084>>2],l,2336);x[x[g+2084>>2]+(x[g+2092>>2]<<2)>>2]=-1;z:{A:{u=x[g+(y[g+23|0]?2092:4)>>2];if((u|0)>0){b=0;while(1){I=y[(y[g+23|0]?x[(b<<2)+i>>2]:b)+e|0];B:{if(!gH(g,I)){break B}K=b<<2;j=Cl(x[K+x[g+32>>2]>>2]);q=x[g+2084>>2];k=0;l=x[g+2092>>2];if((l|0)>=2){while(1){r=l>>>1|0;M=r+k|0;H=j>>>0<A[q+(M<<2)>>2];k=H?k:M;l=H?r:l-r|0;if((l|0)>1){continue}break}}l=k<<2;if((j|0)!=x[l+q>>2]){break A}if(y[g+23|0]){x[l+x[g+2088>>2]>>2]=x[i+K>>2];v[x[g+8>>2]+k|0]=I;break B}x[l+x[g+2088>>2]>>2]=b}b=b+1|0;if((u|0)!=(b|0)){continue}break}}break z}ea(8065,9049,1230,5968);p()}}if(y[g+23|0]){qi(f,i,x[h>>2]<<2);qi(f,x[g+32>>2],x[h>>2]<<2);qi(f,e,x[m>>2]);x[g+32>>2]=0}Sb(g+36|0,255,2048);b=x[g+(y[g+23|0]?2092:4)>>2];if((b|0)>0){k=(b|0)>=32767?32767:b;i=x[g+8>>2];b=0;while(1){C:{if(y[b+i|0]>10){break C}D:{if(y[g+23|0]){e=Cl(x[x[g+2084>>2]+(b<<2)>>2]);break D}e=x[x[g+32>>2]+(b<<2)>>2]}if(e>>>0>1023){break C}while(1){w[(g+(e<<1)|0)+36>>1]=b;i=x[g+8>>2];e=(1<<y[i+b|0])+e|0;if(e>>>0<1024){continue}break}}b=b+1|0;if((k|0)!=(b|0)){continue}break}}b=lc(f,4);v[g+21|0]=b;b=b&255;if(b>>>0>=3){fc(f,20);break c}if(b){N=g,P=pH(lc(f,32)),B[N+12>>2]=P;N=g,P=pH(lc(f,32)),B[N+16>>2]=P;N=g,O=lc(f,4)+1|0,v[N+20|0]=O;N=g,O=lc(f,1),v[N+22|0]=O;e=x[g>>2];i=x[m>>2];E:{if(y[g+21|0]==1){C=J(gs(+E(E(Zo(+E(i|0)))/E(e|0))));F:{if(F(C)<2147483648){b=~~C;break F}b=-2147483648}C=J(Kw(+E(E(b|0)+E(1)),e));G:{if(F(C)<2147483648){k=~~C;break G}k=-2147483648}b=((i|0)>=(k|0))+b|0;t=E(b|0);if(Kw(+E(t+E(1)),e)<=+(i|0)){b=-1}else{C=J(Kw(+t,e));H:{if(F(C)<2147483648){e=~~C;break H}e=-2147483648}b=(e|0)>(i|0)?-1:b}if((b|0)>=0){break E}fc(f,20);break c}b=D(e,i)}x[g+24>>2]=b;if(!b){fc(f,20);break c}e=en(f,b<<1);if(!e){break h}b=0;l=x[g+24>>2];if((l|0)>0){while(1){i=lc(f,y[g+20|0]);if((i|0)==-1){qi(f,e,x[g+24>>2]<<1);fc(f,20);break c}w[e+(b<<1)>>1]=i;b=b+1|0;l=x[g+24>>2];if((b|0)<(l|0)){continue}break}}I:{if(y[g+21|0]==1){q=y[g+23|0];J:{if(q){b=x[h>>2];if(b){break J}break I}b=x[m>>2]}b=Rd(f,D(x[g>>2],b)<<2);x[g+28>>2]=b;if(!b){qi(f,e,x[g+24>>2]<<1);fc(f,3);break c}m=x[(q?h:m)>>2];if((m|0)>0){r=g+2088|0;t=E(0);h=0;while(1){k=q?x[x[r>>2]+(h<<2)>>2]:h;b=1;j=0;K:{l=x[g>>2];if((l|0)<=0){break K}while(1){L=E(E(B[g+12>>2]+t)+E(B[g+16>>2]*E(z[e+(((k>>>0)/(b>>>0)>>>0)%A[g+24>>2]<<1)>>1])));B[x[g+28>>2]+(D(h,l)+j<<2)>>2]=L;t=y[g+22|0]?L:t;j=j+1|0;l=x[g>>2];if((j|0)>=(l|0)){break K}i=x[g+24>>2];yna(i,0,b,0);if(lb){qi(f,e,i<<1);fc(f,20);break c}else{b=D(b,i);continue}}}h=h+1|0;if((m|0)!=(h|0)){continue}break}}v[g+21|0]=2;l=x[g+24>>2];break I}b=Rd(f,l<<2);x[g+28>>2]=b;l=x[g+24>>2];if(!b){break g}b=0;if((l|0)<=0){break I}t=E(0);while(1){L=E(E(B[g+12>>2]+t)+E(B[g+16>>2]*E(z[e+(b<<1)>>1])));B[x[g+28>>2]+(b<<2)>>2]=L;t=y[g+22|0]?L:t;b=b+1|0;l=x[g+24>>2];if((b|0)<(l|0)){continue}break}}qi(f,e,l<<1)}o=o+1|0;if((o|0)<x[f+120>>2]){continue}break}}L:{b=lc(f,6)+1&255;if(!b){break L}while(1){if(!lc(f,16)){G=G+1|0;if((b|0)!=(G|0)){continue}break L}break}fc(f,20);break c}b=lc(f,6)+1|0;x[f+128>>2]=b;b=Rd(f,D(b,1596));x[f+260>>2]=b;M:{if(b){k=0;if(x[f+128>>2]>0){break M}G=0;break d}fc(f,3);break c}G=0;N:while(1){b=lc(f,16);w[((k<<1)+f|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){fc(f,20);break c}if(!b){e=x[f+260>>2]+D(k,1596)|0;N=e,O=lc(f,8),v[N|0]=O;N=e,O=lc(f,16),w[N+2>>1]=O;N=e,O=lc(f,16),w[N+4>>1]=O;N=e,O=lc(f,6),v[N+6|0]=O;N=e,O=lc(f,8),v[N+7|0]=O;b=(lc(f,4)&255)+1|0;v[e+8|0]=b;if((b|0)==(b&255)){g=e+9|0;b=0;while(1){N=b+g|0,O=lc(f,8),v[N|0]=O;b=b+1|0;if(b>>>0<y[e+8|0]){continue}break}}fc(f,4);break c}b=x[f+260>>2]+D(k,1596)|0;e=lc(f,5);v[b|0]=e;O:{if(e&255){g=b+1|0;e=-1;j=0;while(1){h=lc(f,4);v[g+j|0]=h;h=h&255;e=(e|0)<(h|0)?h:e;j=j+1|0;if(j>>>0<y[b|0]){continue}break}i=b+82|0;l=b+65|0;m=b+49|0;o=b+33|0;h=0;while(1){N=h+o|0,O=lc(f,3)+1|0,v[N|0]=O;g=h+m|0;j=lc(f,2);v[g|0]=j;P:{if(j&255){j=lc(f,8);v[h+l|0]=j;if(x[f+120>>2]<=(j&255)){break O}if(y[g|0]==31){break P}}j=0;while(1){q=lc(f,8)-1|0;w[(i+(h<<4)|0)+(j<<1)>>1]=q;if(x[f+120>>2]<=q<<16>>16){break O}j=j+1|0;if((j|0)<1<<y[g|0]){continue}break}}g=(e|0)!=(h|0);h=h+1|0;if(g){continue}break}}N=b,O=lc(f,2)+1|0,v[N+1588|0]=O;e=lc(f,4);x[b+1592>>2]=2;w[b+338>>1]=0;v[b+1589|0]=e;w[b+340>>1]=1<<e;g=b+338|0;i=y[b|0];Q:{if(i){h=b+33|0;m=b+1|0;l=0;j=2;while(1){e=0;o=h+y[l+m|0]|0;if(y[o|0]){while(1){i=lc(f,y[b+1589|0]);w[g+(x[b+1592>>2]<<1)>>1]=i;j=x[b+1592>>2]+1|0;x[b+1592>>2]=j;e=e+1|0;if(e>>>0<y[o|0]){continue}break}i=y[b|0]}l=l+1|0;if(l>>>0<(i&255)>>>0){continue}break}if((j|0)<=0){break Q}}e=0;while(1){h=z[g+(e<<1)>>1];i=(n+16|0)+(e<<2)|0;w[i+2>>1]=e;w[i>>1]=h;e=e+1|0;j=x[b+1592>>2];if((e|0)<(j|0)){continue}break}}OG(n+16|0,j,2335);j=x[b+1592>>2];h=((j|0)<=1?1:j)-1|0;e=0;while(1){if((e|0)==(h|0)){R:{if((j|0)<=0){break R}h=b+838|0;e=0;while(1){v[e+h|0]=y[((n+16|0)+(e<<2)|0)+2|0];e=e+1|0;j=x[b+1592>>2];if((e|0)<(j|0)){continue}break}if((j|0)<3){break R}q=b+1088|0;e=2;while(1){x[n+12>>2]=0;x[n+8>>2]=0;i=0;if((e|0)>0){j=g+(e<<1)|0;l=-1;o=65536;while(1){m=g+(i<<1)|0;h=z[m>>1];if(!((l|0)>=(h|0)|z[j>>1]<=h>>>0)){x[n+12>>2]=i;h=z[m>>1];l=h}if(!((h|0)>=(o|0)|z[j>>1]>=h>>>0)){x[n+8>>2]=i;o=z[m>>1]}i=i+1|0;if((i|0)!=(e|0)){continue}break}}h=q+(e<<1)|0;v[h|0]=x[n+12>>2];v[h+1|0]=x[n+8>>2];e=e+1|0;j=x[b+1592>>2];if((e|0)<(j|0)){continue}break}}G=(j|0)>(G|0)?j:G;k=k+1|0;if((k|0)<x[f+128>>2]){continue N}break d}i=n+16|0;l=z[i+(e<<2)>>1];e=e+1|0;if((l|0)!=z[i+(e<<2)>>1]){continue}break}}break}fc(f,20);break c}fc(f,3);break c}qi(f,e,l<<1);fc(f,3);break c}fc(f,20);break c}fc(f,3);break c}fc(f,3);break c}fc(f,20);break c}b=lc(f,6)+1|0;x[f+264>>2]=b;b=Rd(f,D(b,24));x[f+396>>2]=b;if(!b){fc(f,3);break c}o=0;Sb(b,0,D(x[f+264>>2],24));S:{T:{if(x[f+264>>2]>0){k=20;while(1){b=x[f+396>>2];e=lc(f,16);w[((o<<1)+f|0)+268>>1]=e;if((e&65535)>>>0>2){break S}h=b+D(o,24)|0;N=h,O=lc(f,24),x[N>>2]=O;b=lc(f,24);x[h+4>>2]=b;if(b>>>0<A[h>>2]){break S}N=h,O=lc(f,24)+1|0,x[N+8>>2]=O;N=h,O=lc(f,6)+1|0,v[N+12|0]=O;b=lc(f,8);v[h+13|0]=b;if(x[f+120>>2]<=(b&255)){break S}b=0;U:{if(!y[h+12|0]){e=0;break U}while(1){g=(n+16|0)+b|0;i=lc(f,3);if(lc(f,1)){e=lc(f,5)}else{e=0}v[g|0]=i+(e<<3);b=b+1|0;e=y[h+12|0];if(b>>>0<e>>>0){continue}break}}b=Rd(f,e<<4);x[h+20>>2]=b;if(!b){break T}if(y[h+12|0]){i=0;while(1){e=y[(n+16|0)+i|0];b=0;while(1){V:{if(e>>>b&1){g=lc(f,8);l=b<<1;j=i<<4;w[l+(j+x[h+20>>2]|0)>>1]=g;if(x[f+120>>2]<=w[l+(j+x[h+20>>2]|0)>>1]){break S}break V}w[(x[h+20>>2]+(i<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;if((b|0)!=8){continue}break}i=i+1|0;if(i>>>0<y[h+12|0]){continue}break}}b=Rd(f,x[(x[f+124>>2]+D(y[h+13|0],2096)|0)+4>>2]<<2);x[h+16>>2]=b;if(!b){break T}i=0;Sb(b,0,x[(x[f+124>>2]+D(y[h+13|0],2096)|0)+4>>2]<<2);b=x[f+124>>2];e=y[h+13|0];if(x[(b+D(e,2096)|0)+4>>2]>0){while(1){b=x[D(e,2096)+b>>2];e=Rd(f,b);l=i<<2;x[l+x[h+16>>2]>>2]=e;if(!x[l+x[h+16>>2]>>2]){break T}if((b|0)>0){j=y[h+12|0];e=i;while(1){g=b-1|0;v[g+x[l+x[h+16>>2]>>2]|0]=(e|0)%(j&255);j=y[h+12|0];e=(e|0)/(j|0)|0;m=b>>>0>1;b=g;if(m){continue}break}}i=i+1|0;b=x[f+124>>2];e=y[h+13|0];if((i|0)<x[(b+D(e,2096)|0)+4>>2]){continue}break}}o=o+1|0;if((o|0)<x[f+264>>2]){continue}break}}b=lc(f,6)+1|0;x[f+400>>2]=b;b=Rd(f,D(b,40));x[f+404>>2]=b;if(!b){fc(f,3);break c}i=0;Sb(b,0,D(x[f+400>>2],40));if(x[f+400>>2]>0){while(1){b=x[f+404>>2];if(lc(f,16)){fc(f,20);break c}g=b+D(i,40)|0;b=Rd(f,D(x[f+4>>2],3));x[g+4>>2]=b;if(!b){fc(f,3);break c}if(lc(f,1)){b=lc(f,4)+1|0}else{b=1}v[g+8|0]=b;W:{if(lc(f,1)){b=lc(f,8)+1|0;w[g>>1]=b;X:{e=x[f+4>>2];b=b&65535;if((e|0)>=(b|0)){k=0;if(b){break X}break W}fc(f,20);break c}while(1){e=lc(f,El(e-1|0));b=D(k,3);v[b+x[g+4>>2]|0]=e;e=lc(f,El(x[f+4>>2]-1|0));v[(b+x[g+4>>2]|0)+1|0]=e;e=x[f+4>>2];b=b+x[g+4>>2]|0;h=y[b|0];if((e|0)<=(h|0)){fc(f,20);break c}b=y[b+1|0];if((b|0)>=(e|0)){fc(f,20);break c}if((b|0)!=(h|0)){k=k+1|0;if(k>>>0>=z[g>>1]){break W}continue}break}fc(f,20);break c}w[g>>1]=0}if(lc(f,2)){fc(f,20);break c}h=x[f+4>>2];Y:{Z:{b=y[g+8|0];if(b>>>0<=1){e=0;if((h|0)>0){while(1){v[(x[g+4>>2]+D(e,3)|0)+2|0]=0;e=e+1|0;if((e|0)<x[f+4>>2]){continue}break}b=y[g+8|0]}if(!(b&255)){break Y}break Z}e=0;if((h|0)<=0){break Z}while(1){_:{b=lc(f,4);h=D(e,3);v[(h+x[g+4>>2]|0)+2|0]=b;if(y[(h+x[g+4>>2]|0)+2|0]>=y[g+8|0]){break _}e=e+1|0;if((e|0)<x[f+4>>2]){continue}break Z}break}fc(f,20);break c}b=0;while(1){lc(f,8);e=b+g|0;N=e,O=lc(f,8),v[N+9|0]=O;h=lc(f,8);v[e+24|0]=h;if(x[f+128>>2]<=y[e+9|0]){fc(f,20);break c}if(x[f+264>>2]>(h&255)){b=b+1|0;if(b>>>0>=y[g+8|0]){break Y}continue}break}fc(f,20);break c}i=i+1|0;if((i|0)<x[f+400>>2]){continue}break}}b=lc(f,6);x[f+408>>2]=b+1;$:{if(b>>>0>2147483646){break $}g=f+412|0;e=0;while(1){b=g+D(e,6)|0;N=b,O=lc(f,1),v[N|0]=O;N=b,O=lc(f,16),w[N+2>>1]=O;N=b,O=lc(f,16),w[N+4>>1]=O;h=lc(f,8);v[b+1|0]=h;if(z[b+2>>1]){fc(f,20);break c}if(z[b+4>>1]){fc(f,20);break c}if(x[f+400>>2]>(h&255)){e=e+1|0;if((e|0)>=x[f+408>>2]){break $}continue}break}fc(f,20);break c}oH(f);b=0;x[f+992>>2]=0;if(x[f+4>>2]>0){g=G<<1;j=0;while(1){e=(j<<2)+f|0;N=e,O=Rd(f,x[f+116>>2]<<2),x[N+800>>2]=O;N=e,O=Rd(f,x[f+116>>2]<<1&2147483646),x[N+928>>2]=O;h=Rd(f,g);x[e+996>>2]=h;i=x[e+800>>2];if(h?!i|!x[e+928>>2]:1){fc(f,3);break c}Sb(i,0,x[f+116>>2]<<2);j=j+1|0;if((j|0)<x[f+4>>2]){continue}break}}if(!nH(f,0,x[f+112>>2])){break a}if(!nH(f,1,x[f+116>>2])){break a}x[f+104>>2]=x[f+112>>2];e=x[f+116>>2];x[f+108>>2]=e;h=e<<1&2147483646;i=x[f+264>>2];if((i|0)<=0){e=4}else{e=(e|0)/2|0;l=x[f+396>>2];j=0;k=0;while(1){g=l+D(k,24)|0;m=x[g+4>>2];o=e>>>0>m>>>0?m:e;m=x[g>>2];g=(o-(e>>>0>m>>>0?m:e)>>>0)/A[g+8>>2]|0;j=(g|0)>(j|0)?g:j;k=k+1|0;if((i|0)!=(k|0)){continue}break}e=(j<<2)+4|0}e=D(e,x[f+4>>2]);e=e>>>0<h>>>0?h:e;x[f+12>>2]=e;aa:{ba:{if(!x[f+80>>2]){break ba}g=x[f+92>>2];if((g|0)!=x[f+84>>2]){break aa}if(g>>>0>=(e+x[f+88>>2]|0)+1512>>>0){break ba}fc(f,3);break a}ca:{if(x[f+1380>>2]==-1){x[f+52>>2]=y[f+48|0]?0:x[f+32>>2]-x[f+36>>2]|0;break ca}x[f+52>>2]=0}b=1;break a}ea(3568,9049,4196,4950);p()}k=3}fc(f,k)}b=0}hb=n+1024|0;da:{ea:{if(!b){x[d>>2]=x[s+104>>2]?1:x[s+108>>2];break ea}e=Rd(s+8|0,1512);if(e){N=c,O=x[sc(e,s+8|0,1512)+32>>2]-a|0,x[N>>2]=O;x[d>>2]=0;break da}}tH(s+8|0);e=0}hb=s+1520|0;return e|0}function kma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0;d=hb-288|0;hb=d;Lc(b);f=hb-16|0;hb=f;g=f+8|0;m=d+264|0;nu(g,m);i=Eb(g);g=nc(b,ac(f,g));if((i|0)==(g|0)){cc(b,Eb(f+8|0))}hb=f+16|0;f=(g|0)==(i|0);if(!f){eT(m)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!f){break u}if(!iT(d+264|0)){break u}if(!c){e=1;break u}Nd(a,1024);Gi(a);x[a+480208>>2]=x[a+480208>>2]|12;Ig(a+1074312|0,21);if(y[d+280|0]|y[d+281|0]<<8){e=y[d+280|0]|y[d+281|0]<<8;x[a+480204>>2]=D((e<<8|e>>>8)&65535,1e4)}if(y[d+278|0]|y[d+279|0]<<8){e=y[d+278|0]|y[d+279|0]<<8;x[a+480196>>2]=(e<<8|e>>>8)&65535}if(!y[d+274|0]){uj(a,1)}e=d+264|4;e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);WA(b,a+1304400|0,(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))-14|0);b=fm(d+160|0,b);x[114414]=0;T(546,d+248|0,b|0,1);e=x[114414];x[114414]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((e|0)!=1){Ab(b);x[114414]=0;T(547,d+160|0,d+248|0,1395544366);b=x[114414];x[114414]=0;if((b|0)==1){break E}x[114414]=0;b=R(445,d+160|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break L}if(!b){break F}x[114414]=0;b=R(440,d+160|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break L}x[114414]=0;e=R(440,d+160|0)|0;f=x[114414];x[114414]=0;N:{if((f|0)==1){break N}x[114414]=0;O(304,d+160|0,4)|0;f=x[114414];x[114414]=0;if((f|0)==1){break N}f=a+484360|0;g=Vb(f);x[114414]=0;aa(548,g|0,d+160|0,b|0,65535,65535)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break M}}break L}e=N()|0;Ab(b);break a}Se(Vb(f),e);b=d+160|0;Ab(b);x[114414]=0;T(547,b|0,d+248|0,1346458708);b=x[114414];x[114414]=0;if((b|0)==1){break K}x[114414]=0;b=R(445,d+160|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break J}if(!b){break H}x[114414]=0;b=R(440,d+160|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break J}w[a+480188>>1]=b;if((b-33&65535)>>>0<65504){break H}x[114414]=0;b=R(440,d+160|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break J}x[114414]=0;q=a+484344|0;P(362,q|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break J}x[114414]=0;m=R(450,d+160|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break J}switch(m-841887796|0){case 0:case 2:break G;case 1:break H;default:break I}}e=N()|0;Ab(d+160|0);break b}e=N()|0;break b}e=N()|0;Ab(d+160|0);break b}if(!m){break G}}Ab(d+160|0);break A}Ab(d+160|0);x[114414]=0;T(547,d+232|0,d+248|0,1398157625);b=x[114414];x[114414]=0;if((b|0)==1){break D}x[114414]=0;b=R(445,d+232|0)|0;e=x[114414];x[114414]=0;O:{if((e|0)==1){break O}if(!b){break B}x[114414]=0;O(304,d+232|0,2)|0;b=x[114414];x[114414]=0;if((b|0)==1){break O}x[114414]=0;e=R(450,d+232|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}f=x[a+480204>>2];b=0;x[114414]=0;e=na(549,+((+(e>>>0)*2.3283064365386963e-10+ +((f>>>0)/1e4>>>0))*1e4))|0;f=x[114414];x[114414]=0;if((f|0)==1){break c}x[a+480204>>2]=e;x[114414]=0;O(550,d+232|0,d+160|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break c}while(1){if(z[a+480188>>1]<=b>>>0){break C}e=(d+160|0)+(b<<1)|0;e=y[e|0]|y[e+1|0]<<8;x[114414]=0;x[d+96>>2]=(e<<8|e>>>8)&65535;x[d+80>>2]=180;e=O(414,d+96|0,d+80|0)|0;f=x[114414];x[114414]=0;P:{if((f|0)==1){break P}e=x[e>>2];x[114414]=0;e=e-90|0;f=e>>31<<7|e>>>25;e=_f(410,zna(e<<7|45,f,90,0),lb);f=x[114414];x[114414]=0;if((f|0)==1){break P}w[((b<<5)+a|0)+480284>>1]=e+128;b=b+1|0;if((b|0)!=32){continue}break C}break}break c}break c}Ab(d+160|0);break A}e=N()|0;break b}e=N()|0;break b}x[114414]=0;O(304,d+232|0,16)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}x[114414]=0;b=O(226,d+232|0,2)|0;e=x[114414];x[114414]=0;if((e|0)==1){break c}if(b){x[114414]=0;b=R(440,d+232|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;w[d+96>>1]=b;w[d+80>>1]=256;b=O(433,d+96|0,d+80|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break c}x[a+480200>>2]=z[b>>1]}x[114414]=0;O(304,d+232|0,128)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}x[114414]=0;b=O(550,d+232|0,d+96|0)|0;e=x[114414];x[114414]=0;Q:{if((e|0)!=1){if(!b){break B}b=0;while(1){if(z[a+480188>>1]<=b>>>0){break Q}e=(d+96|0)+(b<<1)|0;e=y[e|0]|y[e+1|0]<<8;x[114414]=0;x[d+80>>2]=(e<<8|e>>>8)&65535;x[d+56>>2]=128;e=O(414,d+80|0,d+56|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){w[((b<<5)+a|0)+480286>>1]=x[e>>2]/2&255;b=b+1|0;if((b|0)!=32){continue}break Q}break}break c}break c}x[a+480228>>2]=x[a+480228>>2]<<1}Ab(d+232|0);x[114414]=0;T(547,d+160|0,d+248|0,1413830740);b=x[114414];x[114414]=0;R:{S:{if((b|0)!=1){x[114414]=0;b=R(445,d+160|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break d}if(!b){break R}x[114414]=0;O(551,d+160|0,d+96|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break d}if((y[d+106|0]|y[d+107|0]<<8)!=65535){break S}x[114414]=0;O(304,d+160|0,1)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break S}break d}e=N()|0;break b}x[114414]=0;b=R(296,d+160|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;Z(552,a+1304424|0,d+160|0,b|0,2)|0;b=x[114414];x[114414]=0;if((b|0)==1){break d}}Ab(d+160|0);x[114414]=0;T(547,d+96|0,d+248|0,1229869908);b=x[114414];x[114414]=0;if((b|0)==1){break e}x[114414]=0;b=R(445,d+96|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){if(!b){break w}x[114414]=0;b=R(440,d+96|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break g}T:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break T}x[114414]=0;e=O(226,d+96|0,D(f,(b>>>14&2)+50|0)|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break y}if(!e){break T}w[a+480190>>1]=f;g=a+480190|0;if(!f){break z}i=d+178|0;k=(b|0)>=0;b=1;U:{V:{while(1){W:{e=b;X:{Y:{Z:{if(!k){x[114414]=0;e=R(440,d+96|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break Z}e=e+1|0}x[114414]=0;w[d+56>>1]=e;O(553,d+96|0,d+160|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){if((z[d+56>>1]-4e3&65535)>>>0<61537){break X}x[114414]=0;e=O(402,g|0,d+56|0)|0;l=x[114414];x[114414]=0;if((l|0)!=1){break Y}}e=N()|0;break f}e=N()|0;break f}w[a+480190>>1]=z[e>>1];l=z[d+56>>1];e=y[d+282|0]|y[d+283|0]<<8|(y[d+284|0]<<16|y[d+285|0]<<24);x[114414]=0;X(554,d+160|0,(D(l,104)+a|0)+484380|0,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24),m|0);e=x[114414];x[114414]=0;if((e|0)==1){break W}x[114414]=0;T(555,d+80|0,2,i|0);e=x[114414];x[114414]=0;if((e|0)==1){break V}x[114414]=0;P(355,d+232|0,d+80|0);e=x[114414];x[114414]=0;if((e|0)==1){break V}x[114414]=0;O(334,((z[d+56>>1]<<5)+a|0)+946304|0,d+232|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break U}xb(d+232|0)}e=b&65535;b=b+1|0;if(e>>>0<f>>>0){continue}break z}break}e=N()|0;break f}e=N()|0;break f}e=N()|0;xb(d+232|0);break f}Ab(d+96|0);break A}e=N()|0;break f}e=0;break v}x[114414]=0;b=R(440,d+96|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){break x}}e=N()|0;break f}if((b|0)!=4){break w}b=z[g>>1];x[114414]=0;w[d+160>>1]=b;w[d+232>>1]=255;b=O(433,d+160|0,d+232|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break h}w[a+480192>>1]=z[b>>1];x[114414]=0;T(547,d+232|0,d+248|0,1229278806);b=x[114414];x[114414]=0;if((b|0)==1){break i}b=d+80|0;g=b|4;i=b|3;k=b|5;l=b|7;while(1){x[114414]=0;b=O(226,d+96|0,15)|0;e=x[114414];x[114414]=0;_:{$:{if((e|0)!=1){aa:{if(!b){break $}x[114414]=0;O(556,d+96|0,d+80|0)|0;b=x[114414];x[114414]=0;ba:{if((b|0)!=1){b=y[d+80|0]|y[d+81|0]<<8;if(z[a+480192>>1]<=((b<<8|b>>>8)&65535)>>>0){continue}b=y[d+80|0]|y[d+81|0]<<8;b=D((b<<8|b>>>8)&65535,104)+a|0;v[b+484524|0]=y[d+88|0];e=y[l|0];v[b+484523|0]=255;v[b+484525|0]=e;b=y[d+80|0]|y[d+81|0]<<8;e=y[d+80|0]|y[d+81|0]<<8;x[114414]=0;e=U(405,a|0,(b<<8|b>>>8)+1&65535,(e<<8|e>>>8)+1&65535)|0;b=x[114414];x[114414]=0;if((b|0)==1){break aa}if(!e){continue}b=y[k|0]|y[k+1|0]<<8;x[114414]=0;w[d+160>>1]=b<<8|b>>>8;w[d+56>>1]=4095;b=O(433,d+160|0,d+56|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break aa}x[e>>2]=z[b>>1];if(y[i|0]==255){continue}b=y[i|0];x[114414]=0;b=O(224,d+232|0,D(b,34)+2|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break aa}if(!b){continue}x[114414]=0;O(557,d+232|0,d+160|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break aa}v[e+60|0]=y[e+60|0]|1;b=y[d+160|0]|y[d+161|0]<<8;x[d+56>>2]=(b<<8|b>>>8)&65535;x[114414]=0;x[d+76>>2]=3;x[d+64>>2]=240;x[d+60>>2]=16;x[d+72>>2]=d+56;b=x[d+76>>2];x[d>>2]=x[d+72>>2];x[d+4>>2]=b;b=R(558,d|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break aa}x[114414]=0;f=e+48|0;P(472,f|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break aa}b=0;if(Lb(f)){break ba}break _}break aa}while(1){ca:{v[d+56|0]=64;o=(d+160|0)+(b<<1)|0;j=y[o+2|0];x[114414]=0;v[d+48|0]=j;j=O(409,d+56|0,d+48|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break ca}j=y[j|0];E=Pb(f,b),F=j,v[E+2|0]=F;o=y[o+3|0];E=Pb(f,b),F=o,w[E>>1]=F;b=b+1|0;if(Lb(f)>>>0>b>>>0){continue}break _}break}}}e=N()|0;Ab(d+232|0);break f}Ab(d+232|0);break w}if(y[g|0]!=255){v[e+60|0]=y[e+60|0]|4;b=y[g|0];v[e+63|0]=b;v[e- -64|0]=b}if(od(f)){continue}v[e+60|0]=y[e+60|0]|2;b=Lb(f)-1|0;v[e+61|0]=b;v[e+62|0]=b;continue}}b=d+96|0;Ab(b);x[114414]=0;T(559,b|0,d+248|0,1145131092);b=x[114414];x[114414]=0;if((b|0)==1){break j}b=d+96|0;E=d,F=bc(b),x[E+48>>2]=F;E=d,F=dc(b),x[E+40>>2]=F;if(Hb(d+48|0,d+40|0)){t=c&1;l=d+232|4;o=(m|0)!=841887798;u=(m|0)!=841887796;while(1){g=x[d+48>>2];x[114414]=0;O(304,g|0,4)|0;b=x[114414];x[114414]=0;da:{ea:{fa:{if((b|0)!=1){x[114414]=0;f=R(440,g|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break l}x[114414]=0;i=R(440,g|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break m}i=o?i:(i>>>0)/A[a+480196>>2]|0;if(!t|f>>>0>255){break da}x[114414]=0;b=U(363,q|0,f|0,i|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break m}if(!b){break da}if(o){break ea}x[114414]=0;O(304,g|0,4)|0;b=x[114414];x[114414]=0;if((b|0)==1){break m}k=0;if(!z[a+480188>>1]){break da}while(1){x[114414]=0;b=R(440,g|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break fa}x[114414]=0;T(307,d+160|0,g|0,b+(b&1)&65535);b=x[114414];x[114414]=0;if((b|0)==1){break n}x[d+232>>2]=0;x[d+236>>2]=0;j=0;ga:{while(1){x[114414]=0;b=O(226,d+160|0,6)|0;e=x[114414];x[114414]=0;if((e|0)==1){break o}if(!(b&A[d+232>>2]<i>>>0)){break ga}b=Zb(q,f);x[114414]=0;b=U(427,b|0,x[d+232>>2],k&65535)|0;e=x[114414];x[114414]=0;ha:{ia:{if((e|0)!=1){x[114414]=0;P(560,d+56|0,d+160|0);e=x[114414];x[114414]=0;if((e|0)==1){break o}e=d+56|0;h=ed(e);B=rf(e);C=$h(e);r=mc(e);n=v[e|0];if((n-1&255)>>>0>95){break ia}v[b|0]=n+13;if(!x[d+236>>2]){break ha}v[b+3|0]=19;x[114414]=0;x[d+80>>2]=15;n=O(414,l|0,d+80|0)|0;s=x[114414];x[114414]=0;if((s|0)==1){break o}v[b+5|0]=y[n|0]|208;break ha}break o}if((n|0)>=0){break ha}if(x[d+236>>2]){v[b+3|0]=19;x[114414]=0;x[d+80>>2]=15;n=O(414,l|0,d+80|0)|0;s=x[114414];x[114414]=0;if((s|0)!=1){v[b+5|0]=y[n|0]|192;break ha}break o}v[b|0]=254}if(y[h|0]){v[b+2|0]=1;x[114414]=0;v[d+80|0]=64;h=O(409,h|0,d+80|0)|0;n=x[114414];x[114414]=0;if((n|0)==1){break o}v[b+4|0]=y[h|0]}h=y[B|0];if(h){v[b+1|0]=h}h=y[C|0];if(h|y[r|0]){v[b+3|0]=h;v[b+5|0]=y[r|0];x[114414]=0;W(541,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break o}}b=v[e+5|0];e=b&255;if((b|0)<0){x[114414]=0;b=R(403,d+160|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break o}e=b|e<<8&32512}b=x[a+480196>>2];x[114414]=0;j=e+j|0;T(561,d+80|0,j|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){b=x[d+84>>2];x[d+232>>2]=x[d+80>>2];x[d+236>>2]=b;continue}break}break o}Ab(d+160|0);k=k+1|0;if(z[a+480188>>1]>(k&65535)>>>0){continue}break}break da}e=N()|0;break k}e=N()|0;break k}b=Zb(q,f);x[114414]=0;b=U(427,b|0,0,0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break s}k=0;if(!i){break da}while(1){e=0;ja:{if(!z[a+480188>>1]){break ja}while(1){ka:{x[114414]=0;P(562,d+160|0,g|0);f=x[114414];x[114414]=0;if((f|0)==1){break ka}la:{if(!u){x[d+232>>2]=x[d+160>>2];f=d+232|0;j=ed(f);h=rf(f);r=$h(f);f=v[f|0];if((f|0)>0){v[b|0]=(D((f&240)>>>4|0,12)+(f&15)|0)+12}f=y[j|0];if(f>>>0>=4){v[b+2|0]=1;v[b+4|0]=(f>>>2|0)-1;f=y[j|0]}v[b+1|0]=f<<4&48|y[h|0]>>>4;v[b+3|0]=y[h|0]&15;v[b+5|0]=y[r|0];break la}x[114414]=0;f=x[d+160>>2];x[d+32>>2]=f;x[d+12>>2]=f;P(563,d+12|0,b|0);f=x[114414];x[114414]=0;if((f|0)==1){break ka}f=gc(d+160|0,0);v[b+1|0]=y[b+1|0]|y[f|0]&48}x[114414]=0;W(541,b|0);f=x[114414];x[114414]=0;if((f|0)==1){break ka}f=y[b+3|0];ma:{if(f>>>0>11){break ma}f=1<<f;na:{if(!(f&2240)){if(!(f&12)){break ma}if(!y[b+5|0]){break na}break ma}f=y[b+5|0];j=f&240;if(j){v[b+5|0]=j;break ma}if(f){break ma}}v[b+3|0]=0}b=b+6|0;e=e+1|0;if(z[a+480188>>1]>(e&65535)>>>0){continue}break ja}break}e=N()|0;break k}k=k+1|0;if((k|0)!=(i|0)){continue}break}}b=d+48|0;of(b);if(Hb(b,d+40|0)){continue}break}}id(d+96|0);x[114414]=0;T(547,d+160|0,d+248|0,1346458702);b=x[114414];x[114414]=0;if((b|0)==1){e=N()|0;break b}x[114414]=0;b=R(445,d+160|0)|0;e=x[114414];x[114414]=0;oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{if((e|0)!=1){if(b){f=Wb(d+96|0);b=0;Ca:{while(1){Da:{x[114414]=0;e=O(226,d+160|0,1)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Da}if(!e){break Ca}if(Ae(q)>>>0<=b>>>0){break Ca}x[114414]=0;U(564,d+160|0,f|0,32)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Da}e=Zb(q,b);x[114414]=0;O(452,e|0,f|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Da}b=b+1|0;continue}break}e=N()|0;xb(f);break Ba}xb(f)}b=d+160|0;Ab(b);x[114414]=0;T(547,b|0,d+248|0,1414679374);b=x[114414];x[114414]=0;if((b|0)==1){break Aa}x[114414]=0;b=R(445,d+160|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break wa}if(!b){break xa}f=Wb(d+96|0);b=0;while(1){x[114414]=0;e=O(226,d+160|0,1)|0;g=x[114414];x[114414]=0;if((g|0)==1){break za}if(!e|z[a+480188>>1]<=b>>>0){break ya}x[114414]=0;U(564,d+160|0,f|0,32)|0;e=x[114414];x[114414]=0;if((e|0)==1){break za}x[114414]=0;O(343,((b<<5)+a|0)+480289|0,f|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break za}b=b+1|0;continue}}e=N()|0}Ab(d+160|0);break b}e=N()|0;break b}e=N()|0;xb(f);break va}xb(f)}b=d+160|0;Ab(b);x[114414]=0;T(559,b|0,d+248|0,1145129300);b=x[114414];x[114414]=0;if((b|0)==1){break ua}b=d+160|0;E=d,F=bc(b),x[E+96>>2]=F;E=d,F=dc(b),x[E+232>>2]=F;if(Hb(d+96|0,d+232|0)){e=c&2;while(1){b=x[d+96>>2];x[114414]=0;c=R(440,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break p}if(!(!e|c>>>0>=z[a+480190>>1])){c=D(c,104)+a|0;f=z[c+484518>>1];f=ad(d+80|0,f&1?16:8,f&64?2:1,1,0);x[114414]=0;U(361,f|0,c+484484|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break p}}b=d+96|0;of(b);if(Hb(b,d+232|0)){continue}break}}id(d+160|0);b=hd(d+96|0);if((m|0)!=841887798){break sa}x[114414]=0;c=O(2,d+160|0,5447)|0;e=x[114414];x[114414]=0;if((e|0)==1){break ta}Db(b,c);xb(c);break ra}e=N()|0}Ab(d+160|0);break b}e=N()|0;break b}e=N()|0;break q}x[114414]=0;T(547,d+160|0,d+248|0,1447383635);c=x[114414];x[114414]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((c|0)!=1){x[114414]=0;c=R(445,d+160|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break qa}if(!c){break Fa}x[114414]=0;e=R(450,d+160|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break Ka}x[114414]=0;c=O(2,d+16|0,10998)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Ja}x[114414]=0;P(187,d+80|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break Ia}x[114414]=0;x[d+56>>2]=e>>>4;x[d+48>>2]=e&15;X(565,d+232|0,d+80|0,d+56|0,d+48|0);e=x[114414];x[114414]=0;if((e|0)==1){break Ha}e=d+232|0;Db(b,e);xb(e);Gb(d+80|0);break Ea}e=N()|0;break q}e=N()|0;break r}e=N()|0;break r}e=N()|0;break Ga}e=N()|0;Gb(d+80|0)}xb(c);break r}x[114414]=0;c=O(2,d+232|0,4728)|0;e=x[114414];x[114414]=0;if((e|0)==1){break t}Db(b,c)}xb(c);Ab(d+160|0)}x[114414]=0;c=O(2,d+80|0,4728)|0;e=x[114414];x[114414]=0;if((e|0)==1){break pa}Db(a+1304436|0,c);xb(c);x[114414]=0;c=O(2,d+56|0,6114)|0;e=x[114414];x[114414]=0;if((e|0)==1){break oa}Db(a+1304448|0,c);xb(c);Db(a+1304460|0,b);x[a+1304496>>2]=2;xb(b);e=1;break v}e=N()|0;break r}e=N()|0;break q}e=N()|0;break q}BA(d+248|0)}hb=d+288|0;return e|0}e=N()|0;break r}e=N()|0;break k}Ab(d+160|0)}xb(b);break b}e=N()|0;id(d+160|0);break b}e=N()|0;Ab(d+160|0);break k}e=N()|0;break k}e=N()|0;break k}e=N()|0}id(d+96|0);break b}e=N()|0;break b}e=N()|0;break f}e=N()|0;break f}e=N()|0}Ab(d+96|0);break b}e=N()|0;break b}e=N()|0;Ab(d+160|0);break b}e=N()|0;Ab(d+232|0)}BA(d+248|0)}Q(e|0);p()}function NF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,w=0,z=0,B=0,C=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;r=hb-48|0;hb=r;a:{if(c>>>0<=2){c=c<<2;I=x[c+61148>>2];J=x[c+61136>>2];while(1){c=x[b+4>>2];b:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break b}c=Zc(b)}if(kk(c)){continue}break}n=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}n=(c|0)==45?-1:1;c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break c}c=Zc(b)}e:{f:{while(1){if(v[g+1459|0]==(c|32)){g:{if(g>>>0>6){break g}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break g}c=Zc(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}l=hb-16|0;hb=l;h=(q(E(E(n|0)*E(Infinity))),j(2));b=h&2147483647;h:{if(b-8388608>>>0<=2130706431){c=b;b=b>>>7|0;c=c<<25;d=b+1065353216|0;break h}c=h<<25;d=h>>>7|2147418112;if(b>>>0>=2139095040){break h}c=0;d=0;if(!b){break h}c=b;b=G(b);gf(l,c,0,0,0,b+81|0);k=x[l>>2];i=x[l+4>>2];c=x[l+8>>2];d=x[l+12>>2]^65536|16265-b<<16}x[r>>2]=k;x[r+4>>2]=i;x[r+8>>2]=c;x[r+12>>2]=h&-2147483648|d;hb=l+16|0;k=x[r+8>>2];i=x[r+12>>2];h=x[r>>2];m=x[r+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(v[g+5964|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break l}c=Zc(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=x[b+4>>2];o:{if((g|0)!=x[b+104>>2]){x[b+4>>2]=g+1;g=y[g|0];break o}g=Zc(b)}if((g&-33)==88){f=hb-432|0;hb=f;c=x[b+4>>2];p:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0];break p}g=Zc(b)}q:{r:{while(1){if((g|0)!=48){s:{if((g|0)!=46){break q}c=x[b+4>>2];if((c|0)==x[b+104>>2]){break s}x[b+4>>2]=c+1;g=y[c|0];break r}}else{c=x[b+4>>2];if((c|0)!=x[b+104>>2]){H=1;x[b+4>>2]=c+1;g=y[c|0]}else{H=1;g=Zc(b)}continue}break}g=Zc(b)}s=1;if((g|0)!=48){break q}while(1){c=t;t=c-1|0;u=u-!c|0;c=x[b+4>>2];t:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0];break t}g=Zc(b)}if((g|0)==48){continue}break}H=1}m=1073676288;while(1){u:{c=g|32;v:{w:{K=g-48|0;if(K>>>0<10){break w}if((g|0)!=46&c-97>>>0>=6){break u}if((g|0)!=46){break w}if(s){break u}s=1;t=k;u=i;break v}c=(g|0)>57?c-87|0:K;x:{if((i|0)<=0&k>>>0<=7|(i|0)<0){e=c+(e<<4)|0;break x}if(!i&k>>>0<=28){yg(f+48|0,c);yd(f+32|0,C,F,h,m,0,0,0,1073414144);C=x[f+32>>2];F=x[f+36>>2];h=x[f+40>>2];m=x[f+44>>2];yd(f+16|0,x[f+48>>2],x[f+52>>2],x[f+56>>2],x[f+60>>2],C,F,h,m);$f(f,x[f+16>>2],x[f+20>>2],x[f+24>>2],x[f+28>>2],l,p,z,B);z=x[f+8>>2];B=x[f+12>>2];l=x[f>>2];p=x[f+4>>2];break x}if(!c|o){break x}yd(f+80|0,C,F,h,m,0,0,0,1073610752);$f(f- -64|0,x[f+80>>2],x[f+84>>2],x[f+88>>2],x[f+92>>2],l,p,z,B);z=x[f+72>>2];B=x[f+76>>2];o=1;l=x[f+64>>2];p=x[f+68>>2]}k=k+1|0;i=k?i:i+1|0;H=1}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;g=y[c|0]}else{g=Zc(b)}continue}break}y:{if(!H){c=x[b+116>>2];z:{A:{if((c|0)>0|(c|0)>=0){c=x[b+4>>2];x[b+4>>2]=c-1;if(!d){break A}x[b+4>>2]=c-2;if(!s){break z}x[b+4>>2]=c-3;break z}if(d){break z}}Jh(b,0,0)}ni(f+96|0,+(n|0)*0);l=x[f+96>>2];p=x[f+100>>2];c=x[f+108>>2];b=x[f+104>>2];break y}if((i|0)<=0&k>>>0<=7|(i|0)<0){h=k;m=i;while(1){e=e<<4;h=h+1|0;m=h?m:m+1|0;if((h|0)!=8|m){continue}break}}B:{C:{D:{if((g&-33)==80){h=MF(b,d);c=lb;m=c;if(h|(c|0)!=-2147483648){break B}if(d){c=x[b+116>>2];if((c|0)>0|(c|0)>=0){break D}break C}l=0;p=0;Jh(b,0,0);c=0;b=0;break y}h=0;m=0;if(x[b+116>>2]<0){break B}}x[b+4>>2]=x[b+4>>2]-1}h=0;m=0}if(!e){ni(f+112|0,+(n|0)*0);l=x[f+112>>2];p=x[f+116>>2];c=x[f+124>>2];b=x[f+120>>2];break y}b=s?t:k;i=(s?u:i)<<2|b>>>30;c=h+(b<<2)|0;b=i+m|0;k=c-32|0;i=(c>>>0<h>>>0?b+1|0:b)-(c>>>0<32)|0;b=i;if(k>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){x[114240]=68;yg(f+160|0,n);yd(f+144|0,x[f+160>>2],x[f+164>>2],x[f+168>>2],x[f+172>>2],-1,-1,-1,2147418111);yd(f+128|0,x[f+144>>2],x[f+148>>2],x[f+152>>2],x[f+156>>2],-1,-1,-1,2147418111);l=x[f+128>>2];p=x[f+132>>2];c=x[f+140>>2];b=x[f+136>>2];break y}b=I-226|0;c=b>>31;if((i|0)>=(c|0)&b>>>0<=k>>>0|(c|0)<(i|0)){if((e|0)>=0){while(1){$f(f+416|0,l,p,z,B,0,0,0,-1073807360);b=SF(l,p,z,B,1073610752);c=(b|0)>=0;b=c;$f(f+400|0,l,p,z,B,b?x[f+416>>2]:l,b?x[f+420>>2]:p,b?x[f+424>>2]:z,b?x[f+428>>2]:B);b=k;k=b-1|0;i=i-!b|0;z=x[f+408>>2];B=x[f+412>>2];l=x[f+400>>2];p=x[f+404>>2];e=c|e<<1;if((e|0)>=0){continue}break}}b=i-((I>>31)+(k>>>0<I>>>0)|0)|0;c=(k-I|0)+32|0;b=c>>>0<32?b+1|0:b;c=c>>>0<J>>>0&(b|0)<=0|(b|0)<0?(c|0)>0?c:0:J;E:{if((c|0)>=113){yg(f+384|0,n);t=x[f+392>>2];u=x[f+396>>2];C=x[f+384>>2];F=x[f+388>>2];h=0;b=0;break E}ni(f+352|0,ok(1,144-c|0));yg(f+336|0,n);C=x[f+336>>2];F=x[f+340>>2];t=x[f+344>>2];u=x[f+348>>2];RF(f+368|0,x[f+352>>2],x[f+356>>2],x[f+360>>2],x[f+364>>2],C,F,t,u);w=x[f+376>>2];L=x[f+380>>2];h=x[f+372>>2];b=x[f+368>>2]}d=!(e&1)&((ul(l,p,z,B,0,0,0,0)|0)!=0&(c|0)<32);Wm(f+320|0,d+e|0);yd(f+304|0,C,F,t,u,x[f+320>>2],x[f+324>>2],x[f+328>>2],x[f+332>>2]);c=b;$f(f+272|0,x[f+304>>2],x[f+308>>2],x[f+312>>2],x[f+316>>2],b,h,w,L);b=d;yd(f+288|0,C,F,t,u,b?0:l,b?0:p,b?0:z,b?0:B);$f(f+256|0,x[f+288>>2],x[f+292>>2],x[f+296>>2],x[f+300>>2],x[f+272>>2],x[f+276>>2],x[f+280>>2],x[f+284>>2]);pw(f+240|0,x[f+256>>2],x[f+260>>2],x[f+264>>2],x[f+268>>2],c,h,w,L);b=x[f+240>>2];d=x[f+244>>2];c=x[f+248>>2];h=x[f+252>>2];if(!ul(b,d,c,h,0,0,0,0)){x[114240]=68}QF(f+224|0,b,d,c,h,k);l=x[f+224>>2];p=x[f+228>>2];c=x[f+236>>2];b=x[f+232>>2];break y}x[114240]=68;yg(f+208|0,n);yd(f+192|0,x[f+208>>2],x[f+212>>2],x[f+216>>2],x[f+220>>2],0,0,0,65536);yd(f+176|0,x[f+192>>2],x[f+196>>2],x[f+200>>2],x[f+204>>2],0,0,0,65536);l=x[f+176>>2];p=x[f+180>>2];c=x[f+188>>2];b=x[f+184>>2]}x[r+16>>2]=l;x[r+20>>2]=p;x[r+24>>2]=b;x[r+28>>2]=c;hb=f+432|0;k=x[r+24>>2];i=x[r+28>>2];h=x[r+16>>2];m=x[r+20>>2];break a}if(x[b+116>>2]<0){break n}x[b+4>>2]=x[b+4>>2]-1}g=b;w=n;f=d;b=0;n=0;e=hb-8976|0;hb=e;K=0-I|0;L=K-J|0;F:{G:{while(1){if((c|0)!=48){H:{if((c|0)!=46){break F}c=x[g+4>>2];if((c|0)==x[g+104>>2]){break H}x[g+4>>2]=c+1;c=y[c|0];break G}}else{b=x[g+4>>2];if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0]}else{c=Zc(g)}b=1;continue}break}c=Zc(g)}o=1;if((c|0)!=48){break F}while(1){b=k;k=b-1|0;i=i-!b|0;b=x[g+4>>2];I:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0];break I}c=Zc(g)}if((c|0)==48){continue}break}b=1}x[e+784>>2]=0;J:{K:{d=(c|0)==46;l=c-48|0;L:{M:{N:{if(d|l>>>0<=9){while(1){O:{if(d&1){if(!o){k=h;i=m;o=1;break O}d=!b;break N}h=h+1|0;m=h?m:m+1|0;if((n|0)<=2044){H=(c|0)==48?H:h;b=(e+784|0)+(n<<2)|0;if(s){l=(D(x[b>>2],10)+c|0)-48|0}x[b>>2]=l;b=1;d=s+1|0;c=(d|0)==9;s=c?0:d;n=c+n|0;break O}if((c|0)==48){break O}x[e+8960>>2]=x[e+8960>>2]|1;H=18396}c=x[g+4>>2];P:{if((c|0)!=x[g+104>>2]){x[g+4>>2]=c+1;c=y[c|0];break P}c=Zc(g)}d=(c|0)==46;l=c-48|0;if(d|l>>>0<10){continue}break}}k=o?k:h;i=o?i:m;if(!(!b|(c&-33)!=69)){l=MF(g,f);b=lb;p=b;Q:{if(l|(b|0)!=-2147483648){break Q}if(!f){break L}l=0;p=0;if(x[g+116>>2]<0){break Q}x[g+4>>2]=x[g+4>>2]-1}i=i+p|0;k=k+l|0;i=k>>>0<l>>>0?i+1|0:i;break K}d=!b;if((c|0)<0){break M}}if(x[g+116>>2]<0){break M}x[g+4>>2]=x[g+4>>2]-1}if(!d){break K}x[114240]=28}h=0;m=0;Jh(g,0,0);c=0;b=0;break J}b=x[e+784>>2];if(!b){ni(e,+(w|0)*0);h=x[e>>2];m=x[e+4>>2];c=x[e+12>>2];b=x[e+8>>2];break J}if(!((h|0)!=(k|0)|(i|0)!=(m|0)|(h>>>0>9&(m|0)>=0|(m|0)>0)|(b>>>J|0?(J|0)<=30:0))){yg(e+48|0,w);Wm(e+32|0,b);yd(e+16|0,x[e+48>>2],x[e+52>>2],x[e+56>>2],x[e+60>>2],x[e+32>>2],x[e+36>>2],x[e+40>>2],x[e+44>>2]);h=x[e+16>>2];m=x[e+20>>2];c=x[e+28>>2];b=x[e+24>>2];break J}if(k>>>0>K>>>1>>>0&(i|0)>=0|(i|0)>0){x[114240]=68;yg(e+96|0,w);yd(e+80|0,x[e+96>>2],x[e+100>>2],x[e+104>>2],x[e+108>>2],-1,-1,-1,2147418111);yd(e- -64|0,x[e+80>>2],x[e+84>>2],x[e+88>>2],x[e+92>>2],-1,-1,-1,2147418111);h=x[e+64>>2];m=x[e+68>>2];c=x[e+76>>2];b=x[e+72>>2];break J}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if(c&(i|0)<=(b|0)|(b|0)>(i|0)){x[114240]=68;yg(e+144|0,w);yd(e+128|0,x[e+144>>2],x[e+148>>2],x[e+152>>2],x[e+156>>2],0,0,0,65536);yd(e+112|0,x[e+128>>2],x[e+132>>2],x[e+136>>2],x[e+140>>2],0,0,0,65536);h=x[e+112>>2];m=x[e+116>>2];c=x[e+124>>2];b=x[e+120>>2];break J}if(s){if((s|0)<=8){b=(e+784|0)+(n<<2)|0;g=x[b>>2];while(1){g=D(g,10);s=s+1|0;if((s|0)!=9){continue}break}x[b>>2]=g}n=n+1|0}o=k;R:{if((k|0)<(H|0)|(H|0)>=9|(k|0)>17){break R}if((o|0)==9){yg(e+192|0,w);Wm(e+176|0,x[e+784>>2]);yd(e+160|0,x[e+192>>2],x[e+196>>2],x[e+200>>2],x[e+204>>2],x[e+176>>2],x[e+180>>2],x[e+184>>2],x[e+188>>2]);h=x[e+160>>2];m=x[e+164>>2];c=x[e+172>>2];b=x[e+168>>2];break J}if((o|0)<=8){yg(e+272|0,w);Wm(e+256|0,x[e+784>>2]);yd(e+240|0,x[e+272>>2],x[e+276>>2],x[e+280>>2],x[e+284>>2],x[e+256>>2],x[e+260>>2],x[e+264>>2],x[e+268>>2]);yg(e+224|0,x[(0-o<<2)+61136>>2]);PF(e+208|0,x[e+240>>2],x[e+244>>2],x[e+248>>2],x[e+252>>2],x[e+224>>2],x[e+228>>2],x[e+232>>2],x[e+236>>2]);h=x[e+208>>2];m=x[e+212>>2];c=x[e+220>>2];b=x[e+216>>2];break J}b=(D(o,-3)+J|0)+27|0;c=x[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break R}yg(e+352|0,w);Wm(e+336|0,c);yd(e+320|0,x[e+352>>2],x[e+356>>2],x[e+360>>2],x[e+364>>2],x[e+336>>2],x[e+340>>2],x[e+344>>2],x[e+348>>2]);yg(e+304|0,x[(o<<2)+61064>>2]);yd(e+288|0,x[e+320>>2],x[e+324>>2],x[e+328>>2],x[e+332>>2],x[e+304>>2],x[e+308>>2],x[e+312>>2],x[e+316>>2]);h=x[e+288>>2];m=x[e+292>>2];c=x[e+300>>2];b=x[e+296>>2];break J}while(1){c=n;n=c-1|0;if(!x[(e+784|0)+(n<<2)>>2]){continue}break}s=0;b=(o|0)%9|0;S:{if(!b){d=0;break S}d=0;b=(o|0)<0?b+9|0:b;T:{if(!c){c=0;break T}k=x[(0-b<<2)+61136>>2];i=1e9/(k|0)|0;l=0;g=0;while(1){h=l;l=(e+784|0)+(g<<2)|0;m=x[l>>2];n=(m>>>0)/(k>>>0)|0;h=h+n|0;x[l>>2]=h;h=!h&(d|0)==(g|0);d=h?d+1&2047:d;o=h?o-9|0:o;l=D(i,m-D(k,n)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!l){break T}x[(e+784|0)+(c<<2)>>2]=l;c=c+1|0}o=(o-b|0)+9|0}while(1){g=(e+784|0)+(d<<2)|0;U:{while(1){if(((o|0)!=36|A[g>>2]>=10384593)&(o|0)>=36){break U}n=c+2047|0;l=0;b=c;while(1){c=b;h=n&2047;n=(e+784|0)+(h<<2)|0;b=x[n>>2];m=b>>>3|0;k=l;l=b<<29;k=k+l|0;b=m;i=k>>>0<l>>>0?b+1|0:b;if(!i&k>>>0<1000000001){l=0}else{b=k;l=Bna(b,i,1e9,0);k=b-yna(l,lb,1e9,0)|0}x[n>>2]=k;b=(h|0)!=(c-1&2047)?c:(d|0)==(h|0)?c:k?c:h;n=h-1|0;if((d|0)!=(h|0)){continue}break}s=s-29|0;if(!l){continue}break}d=d-1&2047;if((d|0)==(b|0)){k=e+784|0;c=k+((b+2046&2047)<<2)|0;g=c;i=x[c>>2];c=b-1&2047;x[g>>2]=i|x[k+(c<<2)>>2]}o=o+9|0;x[(e+784|0)+(d<<2)>>2]=l;continue}break}V:{W:while(1){k=c+1&2047;l=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(o|0)>45?9:1;X:{while(1){b=d;g=0;Y:{while(1){Z:{d=b+g&2047;if((d|0)==(c|0)){break Z}d=x[(e+784|0)+(d<<2)>>2];i=x[(g<<2)+61088>>2];if(d>>>0<i>>>0){break Z}if(d>>>0>i>>>0){break Y}g=g+1|0;if((g|0)!=4){continue}}break}if((o|0)!=36){break Y}k=0;i=0;g=0;h=0;m=0;while(1){d=b+g&2047;if((d|0)==(c|0)){c=c+1&2047;x[(e+(c<<2)|0)+780>>2]=0}Wm(e+768|0,x[(e+784|0)+(d<<2)>>2]);yd(e+752|0,k,i,h,m,0,0,1342177280,1075633366);$f(e+736|0,x[e+752>>2],x[e+756>>2],x[e+760>>2],x[e+764>>2],x[e+768>>2],x[e+772>>2],x[e+776>>2],x[e+780>>2]);h=x[e+744>>2];m=x[e+748>>2];k=x[e+736>>2];i=x[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}yg(e+720|0,w);yd(e+704|0,k,i,h,m,x[e+720>>2],x[e+724>>2],x[e+728>>2],x[e+732>>2]);h=x[e+712>>2];m=x[e+716>>2];k=0;i=0;l=x[e+704>>2];p=x[e+708>>2];f=s+113|0;g=f-I|0;n=(g|0)<(J|0);d=n?(g|0)>0?g:0:J;if((d|0)<=112){break X}break V}s=h+s|0;d=c;if((b|0)==(c|0)){continue}break}m=1e9>>>h|0;n=-1<<h^-1;g=0;d=b;while(1){i=g;g=(e+784|0)+(b<<2)|0;f=x[g>>2];i=i+(f>>>h|0)|0;x[g>>2]=i;i=!i&(b|0)==(d|0);d=i?d+1&2047:d;o=i?o-9|0:o;g=D(m,f&n);b=b+1&2047;if((c|0)!=(b|0)){continue}break}if(!g){continue}if((d|0)!=(k|0)){x[(e+784|0)+(c<<2)>>2]=g;c=k;continue W}x[l>>2]=x[l>>2]|1;continue}break}break}ni(e+656|0,ok(1,225-d|0));RF(e+688|0,x[e+656>>2],x[e+660>>2],x[e+664>>2],x[e+668>>2],l,p,h,m);C=x[e+696>>2];F=x[e+700>>2];z=x[e+688>>2];B=x[e+692>>2];ni(e+640|0,ok(1,113-d|0));OF(e+672|0,l,p,h,m,x[e+640>>2],x[e+644>>2],x[e+648>>2],x[e+652>>2]);k=x[e+672>>2];i=x[e+676>>2];t=x[e+680>>2];u=x[e+684>>2];pw(e+624|0,l,p,h,m,k,i,t,u);$f(e+608|0,z,B,C,F,x[e+624>>2],x[e+628>>2],x[e+632>>2],x[e+636>>2]);h=x[e+616>>2];m=x[e+620>>2];l=x[e+608>>2];p=x[e+612>>2]}o=b+4&2047;_:{if((o|0)==(c|0)){break _}o=x[(e+784|0)+(o<<2)>>2];$:{if(o>>>0<=499999999){if(!o&(b+5&2047)==(c|0)){break $}ni(e+496|0,+(w|0)*.25);$f(e+480|0,k,i,t,u,x[e+496>>2],x[e+500>>2],x[e+504>>2],x[e+508>>2]);t=x[e+488>>2];u=x[e+492>>2];k=x[e+480>>2];i=x[e+484>>2];break $}if((o|0)!=5e8){ni(e+592|0,+(w|0)*.75);$f(e+576|0,k,i,t,u,x[e+592>>2],x[e+596>>2],x[e+600>>2],x[e+604>>2]);t=x[e+584>>2];u=x[e+588>>2];k=x[e+576>>2];i=x[e+580>>2];break $}M=+(w|0);if((b+5&2047)==(c|0)){ni(e+528|0,M*.5);$f(e+512|0,k,i,t,u,x[e+528>>2],x[e+532>>2],x[e+536>>2],x[e+540>>2]);t=x[e+520>>2];u=x[e+524>>2];k=x[e+512>>2];i=x[e+516>>2];break $}ni(e+560|0,M*.75);$f(e+544|0,k,i,t,u,x[e+560>>2],x[e+564>>2],x[e+568>>2],x[e+572>>2]);t=x[e+552>>2];u=x[e+556>>2];k=x[e+544>>2];i=x[e+548>>2]}if((d|0)>111){break _}OF(e+464|0,k,i,t,u,0,0,0,1073676288);if(ul(x[e+464>>2],x[e+468>>2],x[e+472>>2],x[e+476>>2],0,0,0,0)){break _}$f(e+448|0,k,i,t,u,0,0,0,1073676288);t=x[e+456>>2];u=x[e+460>>2];k=x[e+448>>2];i=x[e+452>>2]}$f(e+432|0,l,p,h,m,k,i,t,u);pw(e+416|0,x[e+432>>2],x[e+436>>2],x[e+440>>2],x[e+444>>2],z,B,C,F);h=x[e+424>>2];m=x[e+428>>2];l=x[e+416>>2];p=x[e+420>>2];aa:{if((L-2|0)>=(f&2147483647)){break aa}x[e+408>>2]=h;x[e+412>>2]=m&2147483647;x[e+400>>2]=l;x[e+404>>2]=p;yd(e+384|0,l,p,h,m,0,0,0,1073610752);b=SF(x[e+400>>2],x[e+404>>2],x[e+408>>2],x[e+412>>2],1081081856);b=(b|0)>=0;h=b?x[e+392>>2]:h;m=b?x[e+396>>2]:m;l=b?x[e+384>>2]:l;p=b?x[e+388>>2]:p;s=b+s|0;if(!((ul(k,i,t,u,0,0,0,0)|0)!=0&(b?n&(d|0)!=(g|0):n))&(s+110|0)<=(L|0)){break aa}x[114240]=68}QF(e+368|0,l,p,h,m,s);h=x[e+368>>2];m=x[e+372>>2];c=x[e+380>>2];b=x[e+376>>2]}x[r+40>>2]=b;x[r+44>>2]=c;x[r+32>>2]=h;x[r+36>>2]=m;hb=e+8976|0;k=x[r+40>>2];i=x[r+44>>2];h=x[r+32>>2];m=x[r+36>>2];break a;case 3:break j;default:break m}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}break i}ba:{c=x[b+4>>2];ca:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break ca}c=Zc(b)}if((c|0)==40){g=1;break ba}i=2147450880;if(x[b+116>>2]<0){break a}x[b+4>>2]=x[b+4>>2]-1;break a}while(1){c=x[b+4>>2];da:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break da}c=Zc(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}i=2147450880;if((c|0)==41){break a}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}ea:{if(d){if(g){break ea}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(g){continue}break}break a}x[114240]=28;Jh(b,0,0)}i=0}x[a>>2]=h;x[a+4>>2]=m;x[a+8>>2]=k;x[a+12>>2]=i;hb=r+48|0}function Gka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;d=hb-400|0;hb=d;Lc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if(!Ku(b,d+392|0)){break q}if(!UR(d+392|0)){break q}if(!c){o=1;break q}I=fm(d+376|0,b);x[114414]=0;T(714,d+360|0,I|0,0);b=x[114414];x[114414]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((b|0)!=1){x[114414]=0;T(715,d+344|0,d+360|0,20041);b=x[114414];x[114414]=0;if((b|0)==1){break E}x[114414]=0;e=R(303,d+344|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break w}if(!e){break r}x[114414]=0;e=O(716,d+344|0,d+248|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break w}if(!e){break r}x[114414]=0;P(397,a|0,16384);b=x[114414];x[114414]=0;if((b|0)==1){break w}x[a+480208>>2]=8;x[114414]=0;e=a+1074312|0;U(434,e|0,9,1)|0;b=x[114414];x[114414]=0;if((b|0)==1){break w}x[114414]=0;O(435,e|0,21)|0;b=x[114414];x[114414]=0;if((b|0)==1){break w}x[114414]=0;O(435,e|0,30)|0;b=x[114414];x[114414]=0;if((b|0)==1){break w}x[114414]=0;e=O(2,d+232|0,4485)|0;b=x[114414];x[114414]=0;if((b|0)==1){break B}Db(a+1304436|0,e);xb(e);x[114414]=0;e=O(2,d+216|0,6703)|0;b=x[114414];x[114414]=0;if((b|0)==1){break A}Db(a+1304448|0,e);xb(e);x[114414]=0;f=O(2,d+200|0,13278)|0;b=x[114414];x[114414]=0;if((b|0)==1){break z}g=10634;b=y[d+396|0];switch(b-16|0){case 1:break x;case 0:break D;default:break C}}b=N()|0;break a}b=N()|0;break b}g=10553;break x}if(!b){break y}g=17386;break x}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}g=9122}x[114414]=0;e=O(2,d+184|0,g|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break e}x[114414]=0;T(3,d- -64|0,f|0,e|0);b=x[114414];x[114414]=0;if((b|0)==1){break f}b=d- -64|0;Db(a+1304460|0,b);xb(b);xb(e);xb(f);x[a+1304496>>2]=4;x[114414]=0;T(354,d+168|0,3,d+248|0);b=x[114414];x[114414]=0;if((b|0)==1){break g}x[114414]=0;P(355,d- -64|0,d+168|0);b=x[114414];x[114414]=0;if((b|0)==1){break g}b=d- -64|0;Db(a+1304400|0,b);xb(b);x[114414]=0;T(717,d+152|0,3,d+280|0);b=x[114414];x[114414]=0;if((b|0)==1){break h}x[114414]=0;P(355,d+168|0,d+152|0);b=x[114414];x[114414]=0;if((b|0)==1){break h}x[114414]=0;T(13,d- -64|0,4,d+168|0);b=x[114414];x[114414]=0;if((b|0)==1){break i}b=d- -64|0;Db(a+1304412|0,b);xb(b);xb(d+168|0);x[a+480200>>2]=y[d+304|0]+1;J=a,K=Md(y[d+305|0],1,255),x[J+480196>>2]=K;J=a,K=D(Md(y[d+306|0],4,255),1e4),x[J+480204>>2]=K;f=a+484360|0;e=Vb(f);b=y[d+300|0]|y[d+301|0]<<8;x[114414]=0;aa(548,e|0,d+344|0,b|0,65535,65535)|0;b=x[114414];x[114414]=0;if((b|0)==1){break w}Se(Vb(f),y[d+302|0]|y[d+303|0]<<8);w[a+480188>>1]=0;b=0;while(1){x[114414]=0;i=(b<<5)+a|0;q=i+480280|0;W(381,q|0);e=x[114414];x[114414]=0;if((e|0)==1){break j}f=b+d|0;e=y[f+307|0]<<1&254;w[i+480284>>1]=(e|0)==254?256:e;F:{if(v[f+307|0]<0){x[q>>2]=x[q>>2]|1024;break F}w[a+480188>>1]=b+1}x[114414]=0;U(718,d+344|0,i+480289|0,8)|0;e=x[114414];x[114414]=0;if((e|0)==1){break j}b=b+1|0;if((b|0)!=32){continue}break}x[114414]=0;T(715,d- -64|0,d+360|0,17741);b=x[114414];x[114414]=0;if((b|0)==1){break k}e=d+344|0;b=d- -64|0;Ud(e,b);Ab(b);x[114414]=0;e=R(223,e|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break w}x[114414]=0;Z(552,a+1304424|0,d+344|0,e|0,0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break w}x[114414]=0;T(715,d- -64|0,d+360|0,21321);b=x[114414];x[114414]=0;if((b|0)==1){break l}e=d+344|0;b=d- -64|0;Ud(e,b);Ab(b);x[114414]=0;e=R(303,e|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break w}G:{if(e){x[114414]=0;T(715,d- -64|0,d+360|0,16723);b=x[114414];x[114414]=0;if((b|0)==1){break m}x[114414]=0;q=R(403,d+344|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break n}H:{if(!q){break H}f=c&2;while(1){x[114414]=0;i=R(403,d+344|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break n}if(!i){break H}x[114414]=0;e=O(226,d+344|0,56)|0;b=x[114414];x[114414]=0;if((b|0)==1){break n}if(!e){break H}if(i>>>0>z[a+480190>>1]){w[a+480190>>1]=i}x[114414]=0;k=D(i,104)+a|0;o=k+484380|0;P(448,o|0,0);b=x[114414];x[114414]=0;if((b|0)==1){break n}x[114414]=0;U(515,d+344|0,((i<<5)+a|0)+946304|0,32)|0;b=x[114414];x[114414]=0;if((b|0)==1){break n}x[114414]=0;U(518,d+344|0,k+484423|0,8)|0;b=x[114414];x[114414]=0;if((b|0)==1){break n}I:{if(y[d+396|0]<=15){x[114414]=0;h=R(321,d+344|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break I}break n}x[114414]=0;h=R(391,d+344|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break n}}x[k+484404>>2]=h<<1;x[114414]=0;e=R(391,d+344|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break n}x[o>>2]=e;x[114414]=0;e=R(391,d+344|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break n}r=k+484384|0;x[r>>2]=e;x[114414]=0;e=R(391,d+344|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break n}t=k+484388|0;x[t>>2]=e;if(e){b=k+484414|0;w[b>>1]=z[b>>1]|2;x[t>>2]=e+x[r>>2]}x[114414]=0;e=R(403,d+344|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break G}if(y[d+396|0]<=15){w[k+484410>>1]=e}x[114414]=0;i=R(403,d+344|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break n}e=k+484414|0;b=z[e>>1];u=8;if(i&1){b=b|1;w[e>>1]=b;x[o>>2]=x[o>>2]>>>1;x[r>>2]=x[r>>2]>>>1;x[t>>2]=x[t>>2]>>>1;u=16}w[e>>1]=b&65531|i<<1&4;b=ad(d+168|0,u,1,0,((i&12)!=0)<<3);J:{if(!f){break J}x[114414]=0;U(361,b|0,o|0,d- -64|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break J}break n}j=j+1|0;if(q>>>0>(j&255)>>>0){continue}break}}Ab(d- -64|0)}x[114414]=0;T(715,d- -64|0,d+360|0,18761);b=x[114414];x[114414]=0;if((b|0)==1){break p}e=d+344|0;b=d- -64|0;Ud(e,b);Ab(b);x[114414]=0;e=R(303,e|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break w}if(e){h=fA(d+168|0);j=fA(d+152|0);l=fA(d+136|0);x[114414]=0;T(715,d+120|0,d+360|0,17750);b=x[114414];x[114414]=0;if((b|0)==1){break o}x[114414]=0;b=x[d+132>>2];x[d+40>>2]=x[d+128>>2];x[d+44>>2]=b;b=x[d+124>>2];x[d+32>>2]=x[d+120>>2];x[d+36>>2]=b;P(719,d+32|0,h|0);b=x[114414];x[114414]=0;if((b|0)==1){break o}x[114414]=0;T(715,d+104|0,d+360|0,17744);b=x[114414];x[114414]=0;if((b|0)==1){break o}x[114414]=0;b=x[d+116>>2];x[d+24>>2]=x[d+112>>2];x[d+28>>2]=b;b=x[d+108>>2];x[d+16>>2]=x[d+104>>2];x[d+20>>2]=b;P(719,d+16|0,j|0);b=x[114414];x[114414]=0;if((b|0)==1){break o}x[114414]=0;T(715,d+88|0,d+360|0,17734);b=x[114414];x[114414]=0;if((b|0)==1){break o}x[114414]=0;b=x[d+100>>2];x[d+8>>2]=x[d+96>>2];x[d+12>>2]=b;b=x[d+92>>2];x[d>>2]=x[d+88>>2];x[d+4>>2]=b;P(719,d|0,l|0);b=x[114414];x[114414]=0;if((b|0)==1){break o}x[114414]=0;B=R(403,d+344|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break o}if(B){b=d- -64|0;k=b|4;o=b|2;A=b|6;C=b|5;E=b|3;G=b|1;u=0;while(1){x[114414]=0;P(428,d+48|0,d+344|0);b=x[114414];x[114414]=0;if((b|0)==1){break o}n=ed(d+48|0);K:{L:{M:{if(!y[d+48|0]){break M}b=y[n|0];x[114414]=0;e=O(226,d+344|0,D(b,14)+32|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break o}if(!e){break M}b=y[d+48|0];x[114414]=0;F=U(405,a|0,b|0,0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break o}if(F){break L}}b=y[n|0];x[114414]=0;O(304,d+344|0,D(b,14)+32|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break K}break o}x[114414]=0;U(515,d+344|0,F+492|0,32)|0;b=x[114414];x[114414]=0;if((b|0)==1){break o}if(!y[n|0]){break K}r=F+88|0;t=F+68|0;i=F+48|0;q=F+236|0;s=0;b=0;while(1){x[114414]=0;O(720,d+344|0,d- -64|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break o}f=y[d- -64|0];N:{if(!f|f>>>0>z[a+480190>>1]){break N}if(y[G|0]>128){v[G|0]=128}if(y[G|0]>=(b&255)>>>0){while(1){e=y[d- -64|0];J=fd(q,b&255),K=e,w[J>>1]=K;b=b+1|0;if(y[G|0]>=(b&255)>>>0){continue}break}}f=y[G|0];b=y[E|0];x[114414]=0;T(721,i|0,b|0,h|0);b=x[114414];x[114414]=0;if((b|0)==1){break o}b=y[C|0];x[114414]=0;T(721,t|0,b|0,j|0);b=x[114414];x[114414]=0;if((b|0)==1){break o}b=y[d+77|0];x[114414]=0;T(721,r|0,b|0,l|0);b=x[114414];x[114414]=0;if((b|0)==1){break o}x[F>>2]=(y[A|0]|y[A+1|0]<<8)+1>>>1;m=y[d- -64|0];O:{if(y[E|0]&64){w[(D(m,104)+a|0)+484410>>1]=y[o|0];break O}b=(D(m,104)+a|0)+484414|0;w[b>>1]=z[b>>1]|32768}b=y[k|0];x[114414]=0;w[d+86>>1]=b<<1;w[d+84>>1]=254;e=O(433,d+86|0,d+84|0)|0;b=x[114414];x[114414]=0;P:{if((b|0)!=1){g=D(m,104)+a|0;w[g+484408>>1]=z[e>>1];v[g+484418|0]=y[(y[d+75|0]&3)+23717|0];m=g+484419|0;v[m|0]=y[d+74|0];b=g+484420|0;v[b|0]=y[d+73|0]+3>>>2;v[g+484421|0]=y[d+72|0];e=y[m|0];if(!e){H=255;break P}b=y[b|0];x[114414]=0;e=_f(722,(((b<<8|e>>>1)&65407)>>>0)/(e>>>0)|0,0);b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;H=R(723,e|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break P}}break o}break o}b=f+1|0;v[m|0]=H;if(!(y[C|0]&64)){break N}e=g+484414|0;w[e>>1]=z[e>>1]|32}s=s+1|0;if(y[n|0]>(s&255)>>>0){continue}break}}u=u+1|0;if(B>>>0>(u&255)>>>0){continue}break}}Nn(l);Nn(j);Nn(h)}o=1;n=nq(d+168|0);if(!(c&1)){break s}x[114414]=0;T(715,d- -64|0,d+360|0,21076);b=x[114414];x[114414]=0;Q:{R:{S:{if((b|0)!=1){b=Ud(d+344|0,d- -64|0);x[114414]=0;c=R(303,b|0)|0;b=x[114414];x[114414]=0;T:{U:{V:{W:{X:{Y:{if((b|0)!=1){Ab(d- -64|0);Z:{if(!c){break Z}x[114414]=0;f=R(321,d+344|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break Y}x[114414]=0;P(724,n|0,f+1|0);b=x[114414];x[114414]=0;if((b|0)==1){break Y}if(!f){break Z}b=1;while(1){x[114414]=0;e=R(321,d+344|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break X}x[114414]=0;T(307,d- -64|0,d+344|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break X}e=d- -64|0;Ud(vc(n,b),e);c=(b|0)==(f|0);Ab(e);b=b+1|0;if(!c){continue}break}}x[114414]=0;T(715,d- -64|0,d+360|0,16720);b=x[114414];x[114414]=0;if((b|0)==1){break W}b=Ud(d+344|0,d- -64|0);x[114414]=0;c=R(303,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break V}Ab(d- -64|0);if(!c){break T}c=0;x[114414]=0;B=R(403,d+344|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break u}if(B){while(1){s=32;_:{if(y[d+396|0]>=16){x[114414]=0;O(725,d+344|0,d- -64|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break S}b=y[d- -64|0];if(!(b>>>0<=z[a+480188>>1]|b>>>0>32)){w[a+480188>>1]=y[d- -64|0]}s=y[d- -64|0];if(!s){break _}}b=0;while(1){x[114414]=0;f=R(321,d+344|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break R}if(!(!f|b>>>0>31|z[a+480188>>1]>b>>>0)){w[a+480188>>1]=b+1}b=b+1|0;if((s|0)!=(b|0)){continue}break}}c=c+1|0;if(B>>>0>(c&65535)>>>0){continue}break}}x[114414]=0;O(224,d+344|0,1)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break U}break u}b=N()|0;Ab(d- -64|0);break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;Ab(d- -64|0);break t}x[114414]=0;A=a+484344|0;P(362,A|0,B|0);b=x[114414];x[114414]=0;if((b|0)==1){break u}if(!B){break T}b=d- -64|0;i=b|2;q=b|1;j=0;while(1){C=Wb(d+152|0);$:{if(y[d+396|0]<16){E=32;c=64;break $}x[114414]=0;O(725,d+344|0,d- -64|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break v}E=y[d- -64|0];c=y[q|0];x[114414]=0;T(726,d+48|0,3,i|0);b=x[114414];x[114414]=0;if((b|0)==1){break v}x[114414]=0;P(355,d+136|0,d+48|0);b=x[114414];x[114414]=0;if((b|0)==1){break v}b=d+136|0;Db(C,b);xb(b);c=c+1|0}x[114414]=0;e=U(363,A|0,j&65535,c|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break v}aa:{if(!e){x[114414]=0;O(304,d+344|0,E<<1)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break aa}break v}b=Zb(A,j);x[114414]=0;O(452,b|0,C|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break v}m=0;if(!E){break aa}while(1){x[114414]=0;e=R(321,d+344|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break v}ba:{if(!e){break ba}if(rd(n)>>>0<=e>>>0){break ba}k=m&65535;if(k>>>0>=z[a+480188>>1]){break ba}l=vc(n,e);Lc(l);g=0;while(1){x[114414]=0;e=O(226,l|0,1)|0;b=x[114414];x[114414]=0;ca:{da:{ea:{fa:{ga:{ha:{if((b|0)!=1){if(!e){break ba}b=Zb(A,j);x[114414]=0;b=U(427,b|0,g|0,k|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break v}x[114414]=0;f=R(403,l|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break v}r=f<<24>>24;h=(r&252)>>>2|0;switch((r&3)-1|0){case 2:break ea;case 1:break fa;case 0:break ga;default:break ha}}break v}g=(g+h|0)+1|0;break ca}if(!g){g=0;break ca}e=Zb(A,j);x[114414]=0;f=U(427,e|0,g-1|0,k|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){while(1){e=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;e=y[f+4|0]|y[f+5|0]<<8;v[b+4|0]=e;v[b+5|0]=e>>>8;g=g+1|0;if(c>>>0<=g>>>0){break ca}b=D(z[a+480188>>1],6)+b|0;e=h&255;h=h-1|0;if(e){continue}break ca}}break v}if(g>>>0<=h>>>0){break da}e=Zb(A,j);x[114414]=0;f=U(427,e|0,h|0,k|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Q}e=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;e=y[f+4|0]|y[f+5|0]<<8;v[b+4|0]=e;v[b+5|0]=e>>>8;break da}if(h&1){x[114414]=0;f=R(403,l|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Q}v[b|0]=f>>>0>120?-1:f}if(h&2){x[114414]=0;f=R(403,l|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Q}v[b+1|0]=f}f=0;s=0;if(h&4){x[114414]=0;s=R(403,l|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break v}}t=0;if(h&8){x[114414]=0;f=R(403,l|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break v}t=f>>>4|0;f=f&15}u=0;H=0;if(h&16){x[114414]=0;H=R(403,l|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break v}}if((r|0)<0){x[114414]=0;u=R(403,l|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break v}}x[114414]=0;ia(727,b|0,s|0,f|0,t|0,H|0,u|0);b=x[114414];x[114414]=0;if((b|0)==1){break v}}g=g+1|0}if(c>>>0>g>>>0){continue}break}}m=m+1|0;if((m&65535)>>>0<E>>>0){continue}break}}xb(C);j=j+1|0;if((B|0)!=(j|0)){continue}break}}x[114414]=0;T(715,d- -64|0,d+360|0,20048);b=x[114414];x[114414]=0;ia:{ja:{ka:{if((b|0)!=1){b=Ud(d+344|0,d- -64|0);x[114414]=0;c=R(303,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break ka}Ab(d- -64|0);if(!c){break s}c=a+484344|0;if(!Ae(c)){break s}while(1){x[114414]=0;b=O(226,d+344|0,16)|0;a=x[114414];x[114414]=0;if((a|0)==1){break ja}if(!b){break s}x[114414]=0;U(728,d+344|0,d- -64|0,16)|0;a=x[114414];x[114414]=0;if((a|0)==1){break ia}a=Zb(c,0);x[114414]=0;O(729,a|0,d- -64|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break ia}if(Ae(c)){continue}break}break s}b=N()|0;break t}b=N()|0;Ab(d- -64|0);break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;break t}break v}break n}b=N()|0;break c}b=N()|0;xb(C);break t}b=N()|0}id(n);break c}id(n)}Ab(d+344|0);eA(d+360|0);Ab(I)}hb=d+400|0;return o|0}b=N()|0;break c}b=N()|0;Nn(l);Nn(j);Nn(h);break c}b=N()|0;Ab(d- -64|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;xb(d+168|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;xb(e);break d}b=N()|0}xb(f)}Ab(d+344|0)}eA(d+360|0)}Ab(I);Q(b|0);p()}function Zga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;d=hb-608|0;hb=d;Lc(b);a:{if(!Vn(b,d+528|0)){break a}if(!VO(d+528|0)){break a}if(!Qb(b,jd(UO(d+528|0),lb))){break a}b:{if(!c){break b}Nd(a,4);Gi(a);x[a+1074372>>2]=4;l=hd(d+512|0);c:{d:{e:{f:{j=d+566|0;g:{if(!(cd(j,13652,20)|(y[d+588|0]|y[d+589|0]<<8|(y[d+590|0]<<16|y[d+591|0]<<24))!=276)){if((y[d+586|0]|y[d+587|0]<<8)>>>0<260){break g}x[114414]=0;f=U(602,d+545|0,0,20)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}e=f?1154:34;break e}if(!cd(j,13631,20)){e=1;break e}x[114414]=0;T(717,d+496|0,3,j|0);f=x[114414];x[114414]=0;h:{i:{j:{if((f|0)==1){break j}x[114414]=0;P(355,d+120|0,d+496|0);f=x[114414];x[114414]=0;if((f|0)==1){break j}x[114414]=0;T(13,d+224|0,4,d+120|0);f=x[114414];x[114414]=0;if((f|0)==1){break i}f=d+224|0;Db(l,f);xb(f);xb(d+120|0);if((y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24))!=1852141647|(y[j+4|0]|y[j+5|0]<<8|(y[j+6|0]<<16|y[j+7|0]<<24))!=542396493){break h}e=1048;break e}e=N()|0;break c}e=N()|0;xb(d+120|0);break c}if(!cd(j,13291,12)){e=16;if((z[d+578>>1]|z[d+580>>1]<<16)==538976288&(z[d+582>>1]|z[d+584>>1]<<16)==538976288){break e}x[a+1074372>>2]=5;break e}if(cd(j,7501,20)){break f}}e=48;break e}if(!cd(j,24032,15)){x[114414]=0;f=a+1074312|0;O(435,f|0,54)|0;i=x[114414];x[114414]=0;B=1;if((i|0)==1){break d}x[114414]=0;O(435,f|0,51)|0;f=x[114414];x[114414]=0;e=16;if((f|0)==1){break d}break e}k:{if(cd(j,24048,14)){if(cd(j,24063,14)){break k}}x[114414]=0;f=a+1074312|0;O(435,f|0,57)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}x[114414]=0;O(435,f|0,51)|0;f=x[114414];x[114414]=0;e=16;if((f|0)!=1){break e}break d}e=cd(j,13379,11)?16:256}x[114414]=0;t=d+545|0;T(717,d+120|0,3,t|0);f=x[114414];x[114414]=0;l:{m:{n:{o:{p:{if((f|0)==1){break p}x[114414]=0;P(355,d+224|0,d+120|0);f=x[114414];x[114414]=0;if((f|0)==1){break p}f=d+224|0;Db(a+1304400|0,f);xb(f);x[a+480260>>2]=1;x[a+480264>>2]=31999;q=a+484360|0;Se(Vb(q),y[d+594|0]|y[d+595|0]<<8);w[a+480188>>1]=y[d+596|0]|y[d+597|0]<<8;i=y[d+600|0]|y[d+601|0]<<8;x[114414]=0;w[d+224>>1]=i;w[d+120>>1]=255;f=O(433,f|0,d+120|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break o}w[a+480192>>1]=z[f>>1];if(y[d+604|0]|y[d+605|0]<<8){x[a+480196>>2]=y[d+604|0]|y[d+605|0]<<8}if(y[d+606|0]|y[d+607|0]<<8){f=x[19566];G=a,H=Md(D(y[d+606|0]|y[d+607|0]<<8,1e4),D(x[f+20>>2],1e4),D(x[f+24>>2],1e4)),x[G+480204>>2]=H}x[a+480208>>2]=0;x[a+480208>>2]=x[a+480208>>2]&-17|(y[d+602|0]|y[d+603|0]<<8)<<4&16;f=(y[d+602|0]|y[d+603|0]<<8)<<3&32768;x[a+480208>>2]=f|x[a+480208>>2]&-32769;i=Vb(q);g=y[d+592|0]|y[d+593|0]<<8;x[114414]=0;aa(548,i|0,b|0,g|0,65535,65535)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}g=f>>>15|0?(e|0)==34?146:e:e;if(!(y[d+592|0]|y[d+593|0]<<8|g>>>0>1023)){f=Vb(q);x[114414]=0;T(1019,f|0,1,0);f=x[114414];x[114414]=0;if((f|0)==1){break d}}f=y[d+588|0]|y[d+589|0]<<8|(y[d+590|0]<<16|y[d+591|0]<<24);x[114414]=0;O(224,b|0,f+60|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}if((y[d+586|0]|y[d+587|0]<<8)>>>0>=260){x[114414]=0;T(1020,b|0,d+528|0,a|0);f=x[114414];x[114414]=0;if((f|0)==1){break d}}v[d+495|0]=0;i=hb-16|0;hb=i;f=d+496|0;x[f>>2]=0;x[f+4>>2]=0;x[114414]=0;x[i+12>>2]=0;U(1037,f+8|0,i+12|0,i+8|0)|0;e=x[114414];x[114414]=0;q:{if((e|0)!=1){hb=i+16|0;break q}S(0)|0;zb();p()}if(z[a+480192>>1]){break n}i=-1;break m}e=N()|0;break c}e=N()|0;break c}C=c&2;E=d+138|0;F=d+257|0;e=1;m=1;i=-1;while(1){r:{x[114414]=0;k=R(391,b|0)|0;h=x[114414];x[114414]=0;s:{t:{u:{v:{w:{x:{if((h|0)!=1){ng(b,4);x[114414]=0;U(1021,b|0,d+224|0,(k?k:263)|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break r}y:{if((g|0)==1){if((y[d+224|0]|y[d+225|0]<<8|(y[d+226|0]<<16|y[d+227|0]<<24))==245){x[a+1074308>>2]=16777381;x[114414]=0;g=O(2,d+208|0,9209)|0;k=x[114414];x[114414]=0;if((k|0)!=1){Db(l,g);xb(g);g=17;break y}e=N()|0;break l}g=16;if((y[d+224|0]|y[d+225|0]<<8|(y[d+226|0]<<16|y[d+227|0]<<24))!=263){break y}x[a+1074308>>2]=16777395;x[114414]=0;g=O(2,d+192|0,9133)|0;k=x[114414];x[114414]=0;if((k|0)!=1){Db(l,g);xb(g);g=17;break y}e=N()|0;break l}if(y[d+251|0]|y[d+252|0]<<8){break y}if(!(!(g&2)|(y[d+253|0]|y[d+254|0]<<8|(y[d+255|0]<<16|y[d+256|0]<<24))|(y[d+224|0]|y[d+225|0]<<8|(y[d+226|0]<<16|y[d+227|0]<<24))!=263)){g=g|16;break y}if(!(!(g&256)|(y[d+224|0]|y[d+225|0]<<8|(y[d+226|0]<<16|y[d+227|0]<<24))==29)){g=g&-257;break y}if(!(g&160)){break y}g=(y[d+224|0]|y[d+225|0]<<8|(y[d+226|0]<<16|y[d+227|0]<<24))==33?g:0}x[114414]=0;k=U(405,a|0,m&65535,0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break r}if(!k){break s}k=((e<<2)+a|0)+900380|0;e=x[k>>2];x[114414]=0;P(1022,d+224|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break r}e=y[d+250|0];z:{if((i|0)==-1){i=e;break z}if(!(g&32)|(e|0)==(i|0)){break z}g=g&-161|128}if(!(y[d+251|0]|y[d+252|0]<<8)){break s}e=y[d+465|0];h=y[d+466|0];o=y[d+467|0]|y[d+468|0]<<8;n=y[d+471|0];r=y[d+251|0]|y[d+252|0]<<8;x[114414]=0;T(1023,d+176|0,a|0,r|0);r=x[114414];x[114414]=0;if((r|0)==1){break x}g=n|(o|(e|h))?g&-4:g;e=12;while(1){h=z[fd(x[k>>2]+236|0,e)>>1];if(qc(d+176|0)>>>0>h>>>0){h=z[uc(d+176|0,z[fd(x[k>>2]+236|0,e)>>1])>>1];G=fd(x[k>>2]+236|0,e),H=h,w[G>>1]=H}e=e+1|0;if((e|0)!=108){continue}break}if((y[d+586|0]|y[d+587|0]<<8)>>>0>259){Lb(f);SO(f);og(f)}e=y[d+251|0]|y[d+252|0]<<8;x[114414]=0;k=O(1024,d+160|0,e|0)|0;e=x[114414];x[114414]=0;A:{if((e|0)!=1){e=0;if(y[d+251|0]|y[d+252|0]<<8){break A}break w}e=N()|0;break u}B:{C:{D:{E:{while(1){x[114414]=0;O(1025,b|0,d+120|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break B}x[114414]=0;P(1026,d+104|0,d+120|0);h=x[114414];x[114414]=0;F:{if((h|0)==1){break F}x[114414]=0;P(1027,f|0,d+104|0);h=x[114414];x[114414]=0;if((h|0)==1){break F}h=y[d+120|0]|y[d+121|0]<<8|(y[d+122|0]<<16|y[d+123|0]<<24);G=Pb(k,e),H=h,x[G>>2]=H;o=y[d+137|0];if(qc(d+176|0)>>>0>e>>>0){h=z[uc(d+176|0,e)>>1];x[114414]=0;n=(D(h,104)+a|0)+484380|0;P(1028,d+120|0,n|0);r=x[114414];x[114414]=0;if((r|0)==1){break E}x[114414]=0;P(1029,F|0,n|0);n=x[114414];x[114414]=0;if((n|0)==1){break E}x[114414]=0;T(555,d+88|0,3,E|0);n=x[114414];x[114414]=0;if((n|0)==1){break D}x[114414]=0;P(355,d+104|0,d+88|0);n=x[114414];x[114414]=0;if((n|0)==1){break D}x[114414]=0;O(334,((h<<5)+a|0)+946304|0,d+104|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break C}xb(d+104|0);g=(y[d+134|0]&3)==3?(g&2)>>>1|0?g|4:g:g}s=o|s;e=e+1|0;if(e>>>0>=(y[d+251|0]|y[d+252|0]<<8)>>>0){break w}continue}break}e=N()|0;break v}e=N()|0;break v}e=N()|0;break v}e=N()|0;xb(d+104|0);break v}e=N()|0;break v}e=N()|0;break l}e=N()|0;break l}if((y[d+586|0]|y[d+587|0]<<8)>>>0<260){break t}e=0;if(!(y[d+251|0]|y[d+252|0]<<8)){break t}G:{while(1){H:{o=y[Pb(f,e)+3|0];h=x[Pb(k,e)>>2];x[114414]=0;T(307,d+120|0,b|0,((o|0)==11?(h+1>>>1|0)+16|0:h)|0);h=x[114414];x[114414]=0;if((h|0)==1){break H}if(!(!C|qc(d+176|0)>>>0<=e>>>0)){o=z[uc(d+176|0,e)>>1];h=Pb(f,e);h=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);x[114414]=0;x[d+80>>2]=h;x[d+8>>2]=h;h=Z(1030,(D(o,104)+a|0)+484380|0,d+8|0,d+120|0,d+495|0)|0;o=x[114414];x[114414]=0;if((o|0)==1){break G}u=h^1|u}Ab(d+120|0);e=e+1|0;if(e>>>0<(y[d+251|0]|y[d+252|0]<<8)>>>0){continue}break t}break}e=N()|0;break v}e=N()|0;Ab(d+120|0)}Ge(k)}qf(d+176|0);break l}Ge(k);qf(d+176|0)}m=m+1|0;e=m&65535;if(e>>>0<=z[a+480192>>1]){continue}break m}break}e=N()|0;break l}I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if(!(!(g&2)|s&255)){x[114414]=0;e=U(602,t|0,0,20)|0;k=x[114414];x[114414]=0;if((k|0)==1){break Z}g=e?g|16:g}_:{if((y[d+586|0]|y[d+587|0]<<8)>>>0>259){break _}if(c&3){x[114414]=0;T(1020,b|0,d+528|0,a|0);e=x[114414];x[114414]=0;if((e|0)==1){break Z}}if(!(c&2)|!z[a+480190>>1]){break _}c=1;while(1){e=c&65535;k=Pb(f,e-1|0);x[114414]=0;U(361,k|0,(D(e,104)+a|0)+484380|0,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Y}c=c+1|0;if(z[a+480190>>1]>=(c&65535)>>>0){continue}break}}if(u&1){x[114414]=0;c=O(2,d+120|0,12508)|0;e=x[114414];x[114414]=0;if((e|0)==1){break X}x[114414]=0;T(623,a|0,2,c|0);e=x[114414];x[114414]=0;if((e|0)==1){break W}xb(c)}x[114414]=0;c=O(595,b|0,2044)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Z}if(c){x[114414]=0;c=R(391,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Z}x[114414]=0;Z(552,a+1304424|0,b|0,c|0,0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break Z}g=g|16}x[114414]=0;k=O(595,b|0,9870)|0;c=x[114414];x[114414]=0;if((c|0)==1){break I}if(k){x[114414]=0;c=R(391,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break I}x[114414]=0;e=a+901404|0;U(1031,b|0,e|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break I}x[114414]=0;W(610,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break I}g=g|16}x[114414]=0;c=O(595,b|0,9651)|0;e=x[114414];x[114414]=0;if((e|0)==1){break I}if(c){x[114414]=0;c=R(391,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break V}w[d+224>>1]=c>>>5;e=a+484344|0;c=Ae(e);x[114414]=0;w[d+176>>1]=c;c=O(433,d+224|0,d+176|0)|0;m=x[114414];x[114414]=0;if((m|0)==1){break U}m=z[c>>1];if(m){c=0;while(1){x[114414]=0;U(847,b|0,d+224|0,32)|0;h=x[114414];x[114414]=0;if((h|0)==1){break T}h=Zb(e,c);x[114414]=0;O(848,h|0,d+224|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break T}c=c+1|0;if((m|0)!=(c|0)){continue}break}}g=g|16}x[114414]=0;c=O(595,b|0,9656)|0;e=x[114414];x[114414]=0;if((e|0)==1){break I}if(c){x[114414]=0;c=R(391,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break S}w[d+224>>1]=(c>>>0)/20;c=z[a+480188>>1];x[114414]=0;w[d+176>>1]=c;c=O(433,d+224|0,d+176|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break R}c=z[c>>1];if(c){e=0;while(1){x[114414]=0;U(612,b|0,((e<<5)+a|0)+480289|0,20)|0;m=x[114414];x[114414]=0;if((m|0)==1){break N}e=e+1|0;if((c|0)!=(e|0)){continue}break}}g=g|16}x[114414]=0;c=O(226,b|0,8)|0;e=x[114414];x[114414]=0;if((e|0)==1){break I}if(c){c=x[b+8>>2];x[114414]=0;O(613,a|0,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break M}g=(c|0)==x[b+8>>2]?g:g|16}if(!(g&16)){break O}if(!(g&4)){break P}x[a+1074308>>2]=17367040;x[114414]=0;c=O(2,d+224|0,10231)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Q}Db(l,c);xb(c);break O}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;xb(c);break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}if(!(g&2)){break O}x[a+1074308>>2]=18219008;x[114414]=0;c=O(2,d+224|0,10370)|0;e=x[114414];x[114414]=0;if((e|0)==1){break L}Db(l,c);xb(c)}$:{if((y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24))==1852141647&(y[j+4|0]|y[j+5|0]<<8|(y[j+6|0]<<16|y[j+7|0]<<24))==542396493){x[114414]=0;g=U(1032,d+176|0,d+574|0,12)|0;c=x[114414];x[114414]=0;aa:{ba:{ca:{if((c|0)!=1){x[114414]=0;T(13,d+104|0,1,g|0);c=x[114414];x[114414]=0;if((c|0)==1){break ca}x[114414]=0;e=R(1033,d+104|0)|0;j=x[114414];x[114414]=0;c=1;if((j|0)==1){break ba}x[a+1074308>>2]=e;xb(d+104|0);x[a+1074372>>2]=A[a+1074308>>2]<19007257?4:5;xb(g);e=a+1074308|0;g=24;break $}e=N()|0;break l}e=N()|0;break aa}e=N()|0;xb(d+104|0)}xb(g);break l}if(!(!x[a+1074308>>2]|g&8)){x[a+1074372>>2]=0;ju(a+1074312|0)}e=a+1074308|0;c=1;if(!(g&32)){break $}x[a+1074372>>2]=5;if(!k){x[114414]=0;W(611,a+901404|0);c=x[114414];x[114414]=0;if((c|0)==1){break I}}c=0;if((y[d+586|0]|y[d+587|0]<<8)>>>0<260){break $}x[114414]=0;U(434,a+1074312|0,4,1)|0;j=x[114414];x[114414]=0;if((j|0)==1){break I}}da:{if(!Wc(l)){break da}if(!(!(g&256)|s&255|i+1>>>0>1)){x[114414]=0;c=O(2,d+104|0,4497)|0;i=x[114414];x[114414]=0;if((i|0)!=1){Db(l,c);xb(c);break da}e=N()|0;break l}if(!c){x[114414]=0;c=O(2,d+104|0,7913)|0;i=x[114414];x[114414]=0;if((i|0)!=1){Db(l,c);xb(c);break da}e=N()|0;break l}x[114414]=0;c=O(2,d+104|0,5662)|0;i=x[114414];x[114414]=0;if((i|0)==1){break K}Db(l,c);xb(c)}v[d+79|0]=0;ea:{if(z[a+480192>>1]){x[114414]=0;c=O(629,a|0,b|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break ea}v[d+79|0]=c}x[114414]=0;X(630,a|0,b|0,1,d+79|0);b=x[114414];x[114414]=0;if((b|0)==1){break ea}if(!(!y[d+79|0]|A[e>>2]>=18284544)){x[e>>2]=18284544}fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{b=x[e>>2];if(b>>>0>=18284544){x[114414]=0;b=O(2,d- -64|0,13391)|0;c=x[114414];x[114414]=0;if((c|0)==1){break ta}x[114414]=0;P(1034,d+48|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break sa}x[114414]=0;T(3,d+88|0,b|0,d+48|0);c=x[114414];x[114414]=0;if((c|0)==1){break ra}c=d+88|0;Db(l,c);xb(c);xb(d+48|0);xb(b);b=x[e>>2]}ua:{if(!b|A[e>>2]>=19005954){break ua}x[114414]=0;b=a+484344|0;c=O(392,b|0,254)|0;i=x[114414];x[114414]=0;if((i|0)==1){break ea}if(!c){c=Vb(q);x[114414]=0;P(1035,c|0,254);c=x[114414];x[114414]=0;if((c|0)==1){break ea}}x[114414]=0;b=O(392,b|0,255)|0;c=x[114414];x[114414]=0;if((c|0)==1){break ea}if(b){break ua}b=Vb(q);x[114414]=0;c=$(932)|0;i=x[114414];x[114414]=0;if((i|0)==1){break ea}x[114414]=0;T(1036,b|0,255,c|0);b=x[114414];x[114414]=0;if((b|0)==1){break ea}}x[114414]=0;b=O(2,d+32|0,10859)|0;c=x[114414];x[114414]=0;if((c|0)==1){break pa}x[114414]=0;P(187,d+48|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break oa}x[d+28>>2]=y[d+587|0];c=y[d+586|0];x[114414]=0;x[d+12>>2]=c;P(637,d+16|0,d+12|0);c=x[114414];x[114414]=0;if((c|0)==1){break na}x[114414]=0;X(622,d+88|0,d+48|0,d+28|0,d+16|0);c=x[114414];x[114414]=0;if((c|0)==1){break ma}c=a+1304436|0;i=d+88|0;Db(c,i);xb(i);xb(d+16|0);Gb(d+48|0);xb(b);Db(a+1304460|0,l);x[a+1304496>>2]=B?7:x[a+1074308>>2]?7:4;if(!y[d+495|0]){break ga}Db(a+1304472|0,c);x[114414]=0;b=O(2,d+88|0,11111)|0;i=x[114414];x[114414]=0;if((i|0)==1){break ja}Db(c,b);xb(b);x[114414]=0;b=O(2,d+48|0,6082)|0;c=x[114414];x[114414]=0;if((c|0)==1){break ia}Db(a+1304448|0,b);xb(b);x[114414]=0;c=O(2,d+16|0,6083)|0;b=x[114414];x[114414]=0;if((b|0)==1){break ha}Db(a+1304484|0,c);break fa}e=N()|0;break l}e=N()|0;break qa}e=N()|0;xb(d+48|0)}xb(b);break l}e=N()|0;break l}e=N()|0;break ka}e=N()|0;break la}e=N()|0;xb(d+16|0)}Gb(d+48|0)}xb(b);break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}x[114414]=0;c=O(2,d+88|0,6083)|0;b=x[114414];x[114414]=0;if((b|0)==1){break J}Db(a+1304448|0,c)}xb(c);TO(f);xb(l);break b}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0;break l}e=N()|0}TO(f);break c}e=N()|0}xb(l);Q(e|0);p()}e=1}hb=d+608|0;return e|0}function zha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,V=0,W=0,X=0,Y=0;e=hb-512|0;hb=e;Lc(b);n=hb-16|0;hb=n;k=n+8|0;h=e+304|0;eP(k,h);f=Eb(k);k=nc(b,ac(n,k));if((f|0)==(k|0)){cc(b,Eb(n+8|0))}hb=n+16|0;n=(f|0)==(k|0);if(!n){fP(h)}a:{if(!n){break a}if(!kP(e+304|0)){break a}if(!c){d=1;break a}Nd(a,134217728);n=Ub(e+288|0,11321);x[114414]=0;P(187,e+8|0,n|0);d=x[114414];x[114414]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((d|0)!=1){x[114414]=0;q=e+304|4;T(985,e+120|0,e+8|0,q|0);d=x[114414];x[114414]=0;if((d|0)==1){break q}d=e+120|0;Db(a+1304436|0,d);xb(d);Gb(e+8|0);xb(n);d=Ub(d,5095);Db(a+1304448|0,d);xb(d);x[a+480188>>2]=4;x[a+1304496>>2]=2;d=y[e+440|0]|y[e+441|0]<<8;x[a+480196>>2]=(d<<8|d>>>8)&65535;d=y[e+444|0]|y[e+445|0]<<8;d=jP((d<<8|d>>>8)&65535);x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=d;$n(Vb(a+484360|0),e+312|0,y[e+304|6],65535,65535);s=a+480190|0;n=hb-16|0;hb=n;d=e+272|0;x[d>>2]=0;x[d+4>>2]=0;x[114414]=0;x[n+12>>2]=0;U(999,d+8|0,n+12|0,n+8|0)|0;k=x[114414];x[114414]=0;r:{if((k|0)!=1){hb=n+16|0;break r}S(0)|0;zb();p()}n=d;r=jm(e+256|0);if(y[e+504|0]|y[e+505|0]<<8){break o}break n}d=N()|0;break p}d=N()|0;Gb(e+8|0)}xb(n);break d}k=0;while(1){x[114414]=0;d=R(440,b|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break i}w[e+232>>1]=d;if((d-4e3&65535)>>>0<=61536){break c}d=y[e+506|0]|y[e+507|0]<<8;if((y[q|0]|y[q+1|0]<<8)!=512){d=(d<<8|d>>>8)&65535}else{x[114414]=0;d=R(450,b|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break j}d=d-2|0}x[114414]=0;T(307,e+8|0,b|0,d|0);d=x[114414];x[114414]=0;s:{t:{u:{if((d|0)!=1){x[114414]=0;d=O(402,s|0,e+232|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break u}B=z[d>>1];w[a+480190>>1]=B;x[114414]=0;d=D(z[e+232>>1],104)+a|0;f=d+484380|0;P(448,f|0,1);h=x[114414];x[114414]=0;v:{if((h|0)==1){break v}h=y[q|0]|y[q+1|0]<<8;if(((h<<8|h>>>8)&65535)>>>0>1){break t}x[114414]=0;U(986,e+8|0,d+484423|0,31)|0;h=x[114414];x[114414]=0;if((h|0)==1){break v}x[114414]=0;O(304,e+8|0,1)|0;h=x[114414];x[114414]=0;if((h|0)==1){break v}x[114414]=0;U(987,e+8|0,((z[e+232>>1]<<5)+a|0)+946304|0,30)|0;h=x[114414];x[114414]=0;if((h|0)!=1){break s}}d=N()|0;break f}d=N()|0;break e}d=N()|0;break f}h=Wb(e+120|0);x[114414]=0;U(564,e+8|0,h|0,257)|0;g=x[114414];x[114414]=0;w:{x:{if((g|0)==1){break x}x[114414]=0;O(335,d+484423|0,h|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break x}x[114414]=0;O(304,e+8|0,1)|0;g=x[114414];x[114414]=0;if((g|0)==1){break x}x[114414]=0;U(564,e+8|0,h|0,31)|0;g=x[114414];x[114414]=0;if((g|0)==1){break x}x[114414]=0;O(334,((z[e+232>>1]<<5)+a|0)+946304|0,h|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break x}if(!(x[e+16>>2]&1)){break w}x[114414]=0;O(304,e+8|0,1)|0;g=x[114414];x[114414]=0;if((g|0)!=1){break w}}d=N()|0;xb(h);break f}xb(h)}x[114414]=0;O(988,e+8|0,e+120|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break m}x[114414]=0;P(989,e+120|0,f|0);h=x[114414];x[114414]=0;if((h|0)==1){break m}if((y[q|0]|y[q+1|0]<<8)==512){v[d+484417|0]=y[e+138|0]<<3}y:{if(!(y[q|0]|y[q+1|0]<<8)){break y}x[114414]=0;P(349,r|0,B|0);h=x[114414];x[114414]=0;if((h|0)==1){break m}x[114414]=0;P(990,n|0,B|0);h=x[114414];x[114414]=0;if((h|0)==1){break m}h=wd(n,z[e+232>>1]-1|0);zc(h);gP(h);Ht(h);x[114414]=0;g=R(440,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break g}x[114414]=0;f=O(226,b|0,g<<3)|0;j=x[114414];x[114414]=0;if((j|0)==1){break g}if(!f){Ab(e+8|0);break c}x[114414]=0;P(991,h|0,g|0);f=x[114414];x[114414]=0;if((f|0)==1){break g}f=0;x[e+248>>2]=0;if(!g){if(!(y[d+484414|0]&2)){break y}f=x[d+484384>>2];x[e+240>>2]=f;d=x[d+484388>>2];x[114414]=0;x[e+244>>2]=d-f;P(992,h|0,e+240|0);d=x[114414];x[114414]=0;if((d|0)!=1){break y}d=N()|0;break f}while(1){x[114414]=0;d=R(450,b|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break k}x[114414]=0;x[e+240>>2]=d;d=R(450,b|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break k}x[114414]=0;x[e+244>>2]=d;P(992,h|0,e+240|0);d=x[114414];x[114414]=0;if((d|0)==1){break k}f=f+1|0;if(g>>>0>(f&65535)>>>0){continue}break}}Ab(e+8|0);k=k+1|0;d=y[e+504|0]|y[e+505|0]<<8;if((k&65535)>>>0<((d<<8|d>>>8)&65535)>>>0){continue}break}}C=128;if(y[q|0]|y[q+1|0]<<8){break l}x[114414]=0;C=R(440,b|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break l}d=N()|0;break e}d=N()|0;break f}d=a+480188|0;F=y[e+304|7];w[e+238>>1]=4;z:{A:{if(y[q|0]|y[q+1|0]<<8){h=x[b+8>>2];B:{if(!C){break B}while(1){x[114414]=0;k=R(440,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break A}if((k|0)==65535){break B}x[114414]=0;F=R(440,b|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break A}x[114414]=0;k=R(440,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break A}w[e+238>>1]=k;if(k>>>0>127){break c}x[114414]=0;k=O(402,d|0,e+238|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break A}w[d>>1]=z[k>>1];x[114414]=0;O(304,b|0,D(z[e+238>>1],F)<<2)|0;k=x[114414];x[114414]=0;if((k|0)==1){break A}o=o+1|0;if((o&65535)>>>0<C>>>0){continue}break}}x[114414]=0;O(224,b|0,h|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break z}}d=z[d>>1];x[114414]=0;H=O(993,e+240|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){C:{if(!C){break C}L=a+484344|0;W=c&1;I=y[e+443|0];h=0;k=0;while(1){D:{if(!(y[q|0]|y[q+1|0]<<8)){f=z[e+238>>1];d=k;break D}x[114414]=0;d=R(440,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break h}if((d|0)==65535){break C}x[114414]=0;F=R(440,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break h}x[114414]=0;f=R(440,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break h}w[e+238>>1]=f}x[114414]=0;g=f&65535;G=F&65535;f=G<<2;g=O(226,b|0,D(g,f)|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break h}if(!g){break C}E:{F:{if(!W){break F}x[114414]=0;M=d&65535;d=U(363,L|0,M|0,G|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break h}if(!d){break F}if(!G){break E}t=0;while(1){d=Zb(L,M);x[114414]=0;j=O(453,d|0,t|0)|0;d=x[114414];x[114414]=0;G:{if((d|0)!=1){f=0;u=0;H:{I:{switch((I&3)-1|0){case 0:u=!(t&3);break H;case 1:u=!(t&1);break H;case 2:break I;default:break H}}u=(t&3)!=3}J=0;if(!z[e+238>>1]){break G}while(1){d=x[H>>2];x[114414]=0;P(562,e+232|0,b|0);g=x[114414];x[114414]=0;if((g|0)==1){break h}g=D(f,9)+d|0;d=e+232|0;l=ed(d);E=rf(d);i=$h(d);m=D(f,6)+j|0;v[m+1|0]=y[d|0];d=y[l|0];v[m|0]=d;i=y[i|0];v[m+5|0]=i;l=m+5|0;if(d){v[m|0]=d+25;v[g+8|0]=0;v[g|0]=0;v[g+1|0]=0;v[g+2|0]=0;v[g+3|0]=0;v[g+4|0]=0;v[g+5|0]=0;v[g+6|0]=0;v[g+7|0]=0;i=y[l|0]}o=i&255;E=y[E|0];J:{if(E>>>0>=240){d=(E&15)<<8|o;if(d){x[114414]=0;d=R(994,d|0)|0;i=x[114414];x[114414]=0;K:{if((i|0)==1){break K}x[114414]=0;d=na(995,+(+(d>>>0)*1e-4))|0;i=x[114414];x[114414]=0;if((i|0)==1){break K}v[l|0]=d;v[m+3|0]=17;break J}break h}v[m+3|0]=0;break J}K=o>>>4|0;V=o<<4;d=K|V;L:{switch(E|0){case 0:d=D(f,6)+j|0;if(i&255){v[d+3|0]=1;break J}v[d+3|0]=0;break J;case 1:v[(D(f,6)+j|0)+3|0]=2;break J;case 2:v[(D(f,6)+j|0)+3|0]=3;break J;case 3:x[114414]=0;v[e+224|0]=15;d=O(409,l|0,e+224|0)|0;i=x[114414];x[114414]=0;if((i|0)!=1){v[g|0]=y[d|0]|16;v[g+7|0]=0;v[g+1|0]=0;v[g+2|0]=0;v[(D(f,6)+j|0)+3|0]=0;break J}break h;case 4:x[114414]=0;v[e+224|0]=15;d=O(409,l|0,e+224|0)|0;i=x[114414];x[114414]=0;if((i|0)!=1){v[g|0]=y[d|0]|32;v[g+7|0]=0;v[g+1|0]=0;v[g+2|0]=0;v[(D(f,6)+j|0)+3|0]=0;break J}break h;case 5:v[g+7|0]=0;v[g+2|0]=0;v[g+1|0]=i;v[g|0]=0;v[(D(f,6)+j|0)+3|0]=0;break J;case 6:v[g+7|0]=0;v[g+2|0]=i;v[g|0]=0;v[g+1|0]=0;v[(D(f,6)+j|0)+3|0]=0;break J;case 7:v[(D(f,6)+j|0)+3|0]=23;h=0;break J;case 8:v[(D(f,6)+j|0)+3|0]=0;h=d;break J;case 9:v[(D(f,6)+j|0)+3|0]=19;x[114414]=0;v[e+224|0]=15;d=O(409,l|0,e+224|0)|0;i=x[114414];x[114414]=0;if((i|0)!=1){v[l|0]=y[d|0]|16;break J}break h;case 10:v[(D(f,6)+j|0)+3|0]=19;x[114414]=0;v[e+224|0]=15;d=O(409,l|0,e+224|0)|0;i=x[114414];x[114414]=0;if((i|0)!=1){v[l|0]=y[d|0]|32;break J}break h;case 11:v[g+3|0]=d;v[(D(f,6)+j|0)+3|0]=0;break J;case 12:d=D(f,6)+j|0;v[d+4|0]=i;v[d+2|0]=1;v[g+3|0]=0;v[d+3|0]=0;break J;case 13:M:{N:{if((i&255)>>>0>=16){v[(D(f,6)+j|0)+2|0]=4;i=(i&240)>>>4|0;break N}if(!(o&15)){break M}v[(D(f,6)+j|0)+2|0]=3}v[(D(f,6)+j|0)+4|0]=i}v[g+3|0]=0;v[(D(f,6)+j|0)+3|0]=0;break J;case 14:v[(D(f,6)+j|0)+3|0]=19;v[l|0]=!(i&255);break J;case 15:v[(D(f,6)+j|0)+3|0]=16;v[l|0]=(i&240)>>>4;I=i&15;break J;case 16:v[g+5|0]=0;v[g+4|0]=i;v[(D(f,6)+j|0)+3|0]=0;break J;case 17:v[g+6|0]=o&15?i:0;v[(D(f,6)+j|0)+3|0]=0;break J;case 18:v[(D(f,6)+j|0)+3|0]=14;break J;case 19:v[g+8|0]=0;v[g+7|0]=i;v[g+2|0]=0;v[g|0]=0;v[g+1|0]=0;v[(D(f,6)+j|0)+3|0]=0;break J;case 20:v[(D(f,6)+j|0)+3|0]=12;break J;case 22:O:{d=y[m+1|0];P:{if(!d){break P}if(zc(n)>>>0<d>>>0){break P}d=wd(n,y[m+1|0]-1|0);i=y[l|0]-1|0;v[l|0]=i;x[114414]=0;O(996,e+120|0,0)|0;o=x[114414];x[114414]=0;if((o|0)==1){break h}x[e+224>>2]=9;d=zc(d);x[114414]=0;x[e+116>>2]=d;d=O(35,e+224|0,e+116|0)|0;o=x[114414];x[114414]=0;if((o|0)==1){break O}if(A[d>>2]<=(i&255)>>>0){break P}d=D(f,6)+j|0;v[d+2|0]=15;v[d+4|0]=y[l|0]}v[(D(f,6)+j|0)+3|0]=0;break J}break h;case 23:d=y[m+1|0];Q:{if(!d){break Q}if(zc(n)>>>0<d>>>0){break Q}d=wd(n,y[m+1|0]-1|0);i=y[l|0]-1|0;v[l|0]=i;if(zc(d)>>>0<=(i&255)>>>0){break Q}R:{if(z[wd(d,y[l|0])+8>>1]){break R}if(!Wn(a)){break R}i=z[s>>1]+1|0;w[s>>1]=i;X=wd(d,y[l|0]),Y=i,w[X+8>>1]=Y}X=m,Y=y[wd(d,y[l|0])+8|0],v[X+1|0]=Y}v[(D(f,6)+j|0)+3|0]=0;break J;case 24:S:{d=y[m+1|0];T:{if(!d){break T}if(zc(n)>>>0<d>>>0){break T}d=wd(n,y[m+1|0]-1|0);i=y[l|0]-1|0;v[l|0]=i;x[114414]=0;O(996,e+8|0,0)|0;o=x[114414];x[114414]=0;if((o|0)==1){break h}x[e+224>>2]=9;d=zc(d);x[114414]=0;x[e+116>>2]=d;d=O(35,e+224|0,e+116|0)|0;o=x[114414];x[114414]=0;if((o|0)==1){break S}if(A[d>>2]>(i&255)>>>0){d=D(f,6)+j|0;v[d+2|0]=15;v[d+4|0]=y[l|0]}U:{if(z[uc(r,y[m+1|0]-1|0)>>1]){break U}if(!Wn(a)){break U}d=z[s>>1]+1|0;w[s>>1]=d;X=uc(r,y[m+1|0]-1|0),Y=d,w[X>>1]=Y}X=m,Y=y[uc(r,y[m+1|0]-1|0)|0],v[X+1|0]=Y}v[(D(f,6)+j|0)+3|0]=0;break J}break h;case 25:d=y[m+1|0];V:{if(!d){break V}if(zc(n)>>>0<d>>>0){break V}d=wd(n,y[m+1|0]-1|0);i=y[l|0]-1|0;v[l|0]=i;if(zc(d)>>>0<=(i&255)>>>0){break V}W:{if(z[wd(d,y[l|0])+10>>1]){break W}if(!Wn(a)){break W}i=z[s>>1]+1|0;w[s>>1]=i;X=wd(d,y[l|0]),Y=i,w[X+10>>1]=Y}X=m,Y=y[wd(d,y[l|0])+10|0],v[X+1|0]=Y}v[(D(f,6)+j|0)+3|0]=0;break J;case 29:v[(D(f,6)+j|0)+3|0]=11;v[l|0]=d;if(o&15){v[l|0]=V|15;break J}if((i&255)>>>0<16){break J}v[l|0]=K|240;break J;case 32:if((i&255)>>>0>=16){v[g+3|0]=K;v[(D(f,6)+j|0)+3|0]=0;break J}v[(D(f,6)+j|0)+3|0]=19;v[l|0]=i|192;break J;case 33:v[(D(f,6)+j|0)+3|0]=19;x[114414]=0;v[e+224|0]=15;d=O(409,l|0,e+224|0)|0;i=x[114414];x[114414]=0;if((i|0)!=1){v[l|0]=y[d|0]|208;break J}break h;case 34:v[(D(f,6)+j|0)+3|0]=19;x[114414]=0;v[e+224|0]=15;d=O(409,l|0,e+224|0)|0;i=x[114414];x[114414]=0;if((i|0)!=1){v[l|0]=y[d|0]|144;break J}break h;case 73:v[(D(f,6)+j|0)+3|0]=10;break J;case 78:if((i&112|128)==224){v[(D(f,6)+j|0)+3|0]=19;break J}v[(D(f,6)+j|0)+3|0]=0;break J;case 79:d=D(f,6)+j|0;if((i&255)>>>0<=31){v[d+3|0]=16;I=0;break J}v[d+3|0]=17;break J;default:break L}}v[(D(f,6)+j|0)+3|0]=0}o=0;i=y[g+3|0];if(!(y[m+2|0]|!i)){X:{if(i>>>0>=16){v[m+2|0]=5;i=i>>>4|0;break X}v[m+2|0]=6}v[m+4|0]=i;o=1}Y:{if(y[m+3|0]){break Y}d=y[g+1|0];Z:{if(d){v[m+3|0]=2;break Z}d=y[g+2|0];if(d){v[m+3|0]=3;break Z}d=y[g|0];if(d){v[m+3|0]=19;break Z}d=y[g+7|0];if(d){v[m+3|0]=4;v[g+8|0]=d;break Z}d=y[g+4|0];if(d){v[m+3|0]=5;v[g+5|0]=d;break Z}d=y[g+3|0];if(!(!d|o)){v[m+3|0]=11;v[l|0]=d;if(d&15){d=d|-16;break Z}if(d>>>0<16){break Y}d=d|15;break Z}d=y[g+6|0];if(d){v[m+3|0]=8;break Z}if(u){v[m+3|0]=20;u=0;d=97;break Z}u=0;d=h&255;if(!d|J){break Y}v[m+3|0]=24;v[l|0]=h;if(h&15){d=h|-16}else{J=1;if(d>>>0<16){break Y}d=h|15}J=1}v[l|0]=d}f=f+1|0;if(f>>>0<z[e+238>>1]){continue}break}break G}break h}t=t+1|0;if((G|0)!=(t|0)){continue}break}break E}x[114414]=0;O(304,b|0,D(f,z[e+238>>1])|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break E}break h}k=k+1|0;if((k&65535)>>>0<C>>>0){continue}break}}x[a+480228>>2]=256/z[a+480188>>1];x[114414]=0;P(399,a|0,1);d=x[114414];x[114414]=0;if((d|0)==1){break h}if(y[q|0]|y[q+1|0]<<8){_:{while(1){x[114414]=0;d=O(226,b|0,2)|0;k=x[114414];x[114414]=0;if((k|0)==1){break h}if(!d){break _}x[114414]=0;d=R(440,b|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break h}if((d|0)==65535){break _}x[114414]=0;O(304,b|0,2)|0;d=x[114414];x[114414]=0;if((d|0)==1){break h}x[114414]=0;d=R(450,b|0)|0;k=x[114414];x[114414]=0;if((k|0)!=1){x[114414]=0;O(304,b|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){continue}}break}break h}x[114414]=0;O(304,b|0,34)|0;d=x[114414];x[114414]=0;if((d|0)==1){break h}}$:{if(!(!(c&2)|!B)){d=1;k=1;while(1){c=(D(d,104)+a|0)+484380|0;aa:{if(!x[c>>2]){break aa}h=ad(e+232|0,8,1,0,0);x[114414]=0;U(361,h|0,c|0,b|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break $}if(zc(n)>>>0<d>>>0){break aa}d=d-1|0;h=wd(n,d);x[114414]=0;P(997,c|0,h|0);h=x[114414];x[114414]=0;ba:{if((h|0)!=1){if(!z[uc(r,d)>>1]){break ba}h=z[uc(r,d)>>1];f=x[c>>2];x[114414]=0;ba(998,c|0,(D(h,104)+a|0)+484380|0,0,f|0,0);h=x[114414];x[114414]=0;if((h|0)!=1){break ba}}break h}d=wd(n,d);X=e,Y=bc(d),x[X+232>>2]=Y;X=e,Y=dc(d),x[X+224>>2]=Y;if(!Hb(e+232|0,e+224|0)){break aa}while(1){d=x[e+232>>2];h=z[d+8>>1];if(h){f=x[d+4>>2];g=x[d>>2];x[114414]=0;ba(998,c|0,(D(h,104)+a|0)+484380|0,g|0,f|0,1);h=x[114414];x[114414]=0;if((h|0)==1){break h}}h=z[d+10>>1];if(h){f=x[d+4>>2];d=x[d>>2];x[114414]=0;ba(998,c|0,(D(h,104)+a|0)+484380|0,d|0,f|0,0);d=x[114414];x[114414]=0;if((d|0)==1){break h}}d=e+232|0;_j(d);if(Hb(d,e+224|0)){continue}break}}k=k+1|0;d=k&65535;if(B>>>0>=d>>>0){continue}break}}iP(H);d=1;break b}break h}d=N()|0;break e}d=N()|0;break e}d=N()|0;break e}d=N()|0;break f}d=N()|0;break e}d=N()|0;break e}d=N()|0;iP(H);break e}d=N()|0}Ab(e+8|0)}qf(r);hP(n)}Q(d|0);p()}d=0}qf(r);hP(n)}hb=e+512|0;return d|0}function Jha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;d=hb-352|0;hb=d;Lc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!Lt(b,d+256|0)){break h}if(!tP(d+256|0)){break h}if(!Qb(b,jd(sP(d+256|0),lb))){break h}if(!c){t=1;break h}Nd(a,2);x[a+480260>>2]=64;x[a+480264>>2]=32767;k=hd(d+240|0);i:{j:{k:{l:{m:{n:{o:{switch(((y[d+296|0]|y[d+297|0]<<8)&61440)-4096>>>12|0){case 0:p:{if(y[d+318|0]|y[d+319|0]<<8|(y[d+296|0]|y[d+297|0]<<8)!=4896|(y[d+308|0]|y[d+288|0]&15)){break p}if((y[d+294|0]|y[d+295|0]<<8)&65455){break p}q:{if(v[d+307|0]<0){x[a+1074308>>2]=18219008;x[114414]=0;f=O(2,d+224|0,10301)|0;e=x[114414];x[114414]=0;if((e|0)!=1){break q}e=N()|0;break a}x[a+1074308>>2]=16777216;x[114414]=0;f=O(2,d+224|0,9209)|0;e=x[114414];x[114414]=0;if((e|0)==1){break n}}Db(k,f);xb(f);x[114414]=0;e=1;U(434,a+1074312|0,81,1)|0;g=x[114414];x[114414]=0;f=1;if((g|0)!=1){break i}break b}r:{if(y[d+318|0]|y[d+319|0]<<8|(y[d+296|0]|y[d+297|0]<<8)!=4896|(y[d+308|0]|(y[d+294|0]|y[d+295|0]<<8))){break r}if(y[d+309|0]){break r}x[114414]=0;f=O(2,d+224|0,5433)|0;h=x[114414];x[114414]=0;if((h|0)!=1){Db(k,f);break j}e=N()|0;break a}x[114414]=0;e=O(2,d+224|0,4713)|0;j=x[114414];x[114414]=0;h=1;if((j|0)!=1){Db(k,e);xb(e);break k}e=N()|0;break a;case 1:x[114414]=0;e=O(2,d+224|0,3098)|0;j=x[114414];x[114414]=0;f=1;if((j|0)!=1){Db(k,e);xb(e);break k}e=N()|0;break a;case 2:s:{t:{u:{v:{w:{g=y[d+296|0]|y[d+297|0]<<8;x:{if(g>>>0<=12820){x[114414]=0;f=O(2,d+224|0,4760)|0;e=x[114414];x[114414]=0;if((e|0)!=1){Db(k,f);break x}e=N()|0;break a}x[114414]=0;f=O(2,d+208|0,11361)|0;e=x[114414];x[114414]=0;if((e|0)==1){break w}x[114414]=0;P(187,d+224|0,f|0);e=x[114414];x[114414]=0;if((e|0)==1){break v}e=y[d+296|0]|y[d+297|0]<<8;x[114414]=0;x[d+192>>2]=e-12820;T(213,d+32|0,d+224|0,d+192|0);e=x[114414];x[114414]=0;if((e|0)==1){break u}e=d+32|0;Db(k,e);xb(e);Gb(d+224|0)}xb(f);if((y[d+296|0]|y[d+297|0]<<8)>>>0<12807){break l}if(y[d+312|0]|y[d+313|0]<<8|(y[d+314|0]<<16|y[d+315|0]<<24)){break s}break l}e=N()|0;break a}e=N()|0;break t}e=N()|0;Gb(d+224|0)}xb(f);break a}f=y[d+296|0]|y[d+297|0]<<8;e=y[d+312|0]|y[d+313|0]<<8|(y[d+314|0]<<16|y[d+315|0]<<24);x[114414]=0;f=O(638,f|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break m}e=tq(d+32|0);x[e+44>>2]=f;x[114414]=0;P(639,a+1304500|0,e|0);f=x[114414];x[114414]=0;if((f|0)!=1){break l}e=N()|0;break a;case 3:if((y[d+296|0]|y[d+297|0]<<8)==16640){x[114414]=0;h=O(2,d+224|0,4545)|0;j=x[114414];x[114414]=0;f=1;if((j|0)!=1){Db(k,h);xb(h);x[114414]=0;U(434,a+1074312|0,81,1)|0;g=x[114414];x[114414]=0;h=0;j=0;if((g|0)==1){break b}break i}e=N()|0;break a}f=y[d+296|0]|y[d+297|0]<<8;h=y[d+310|0]|y[d+311|0]<<8;x[114414]=0;T(640,d+32|0,f|0,h|0);h=x[114414];x[114414]=0;f=1;if((h|0)!=1){h=d+32|0;Db(k,h);xb(h);x[a+480260>>2]=1;g=y[d+296|0]|y[d+297|0]<<8;h=0;j=1;if((DS(16384)|0)>(g|0)){break i}x[114414]=0;U(434,a+1074312|0,38,1)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}break i}e=N()|0;break a;case 4:if((y[d+296|0]|y[d+297|0]<<8)!=21575){e=(y[d+296|0]|y[d+297|0]<<8)&4095;f=e<<16;if(e>>>0>=297){f=f|(y[d+310|0]|y[d+311|0]<<8)}x[a+1074308>>2]=f;x[114414]=0;f=O(2,d+224|0,13391)|0;e=x[114414];x[114414]=0;y:{z:{A:{if((e|0)!=1){x[114414]=0;P(210,d+192|0,a+1074308|0);e=x[114414];x[114414]=0;if((e|0)==1){break A}e=0;x[114414]=0;T(3,d+32|0,f|0,d+192|0);h=x[114414];x[114414]=0;if((h|0)==1){break z}h=d+32|0;Db(k,h);xb(h);xb(d+192|0);break j}e=N()|0;break a}e=N()|0;break y}e=N()|0;xb(d+192|0)}xb(f);break a}x[114414]=0;f=O(2,d+224|0,4744)|0;h=x[114414];x[114414]=0;if((h|0)!=1){Db(k,f);break j}e=N()|0;break a;case 5:x[114414]=0;f=O(2,d+224|0,4545)|0;h=x[114414];x[114414]=0;if((h|0)!=1){Db(k,f);xb(f);x[114414]=0;U(434,a+1074312|0,81,1)|0;g=x[114414];x[114414]=0;f=0;h=0;if((g|0)==1){break b}break i}e=N()|0;break a;case 6:x[114414]=0;f=O(2,d+224|0,4571)|0;h=x[114414];x[114414]=0;if((h|0)!=1){Db(k,f);break j}e=N()|0;break a;default:break o}}if((y[d+296|0]|y[d+297|0]<<8)!=51712){break i}x[114414]=0;f=O(2,d+224|0,5246)|0;h=x[114414];x[114414]=0;if((h|0)!=1){Db(k,f);break j}e=N()|0;break a}e=N()|0;break a}e=N()|0;break a}x[114414]=0;e=a+1074312|0;U(434,e|0,23,1)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}x[114414]=0;U(434,e|0,38,1)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}x[114414]=0;f=1;U(434,e|0,107,1)|0;e=x[114414];x[114414]=0;if((e|0)==1){break b}x[a+480260>>2]=1;e=0;if(g>>>0>12820){break i}}x[114414]=0;j=O(2,d+176|0,10587)|0;e=x[114414];x[114414]=0;B:{C:{D:{E:{F:{if((e|0)!=1){x[114414]=0;P(187,d+192|0,j|0);e=x[114414];x[114414]=0;if((e|0)==1){break F}x[d+144>>2]=y[d+297|0]&15;e=y[d+296|0];x[114414]=0;x[d+120>>2]=e;P(637,d+160|0,d+120|0);e=x[114414];x[114414]=0;if((e|0)==1){break E}x[114414]=0;ba(978,d+32|0,d+192|0,k|0,d+144|0,d+160|0);e=x[114414];x[114414]=0;if((e|0)==1){break D}e=d+32|0;Db(k,e);xb(e);xb(d+160|0);Gb(d+192|0);xb(j);e=0;j=0;break i}e=N()|0;break a}e=N()|0;break B}e=N()|0;break C}e=N()|0;xb(d+160|0)}Gb(d+192|0)}xb(j);break a}xb(f);f=0;h=0}x[114414]=0;g=O(2,d+192|0,10620)|0;i=x[114414];x[114414]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{if((i|0)!=1){Db(a+1304436|0,g);xb(g);x[114414]=0;g=O(2,d+160|0,6455)|0;i=x[114414];x[114414]=0;if((i|0)==1){break V}Db(a+1304448|0,g);xb(g);Db(a+1304460|0,k);x[a+1304496>>2]=x[a+1074308>>2]?7:4;if(f){x[114414]=0;f=a+1074312|0;O(435,f|0,77)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}x[114414]=0;O(435,f|0,78)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}x[114414]=0;O(435,f|0,79)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}x[114414]=0;O(435,f|0,80)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}x[114414]=0;O(435,f|0,82)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}x[114414]=0;O(435,f|0,96)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}}f=y[d+296|0]|y[d+297|0]<<8;g=f&61440;e=g>>>0<4097|(g|0)==12288&f>>>0<12820?e:1;x[114414]=0;f=a+901404|0;W(979,f|0);g=x[114414];x[114414]=0;if((g|0)==1){break b}if(!e){x[114414]=0;W(611,f|0);f=x[114414];x[114414]=0;if((f|0)==1){break b}}x[114414]=0;T(544,d+144|0,1,d+256|0);f=x[114414];x[114414]=0;if((f|0)==1){break U}x[114414]=0;P(355,d+32|0,d+144|0);f=x[114414];x[114414]=0;if((f|0)==1){break U}f=d+32|0;Db(a+1304400|0,f);xb(f);if(y[d+294|0]&16){x[a+480208>>2]=x[a+480208>>2]|65536}if(v[d+294|0]&1){x[a+480208>>2]=x[a+480208>>2]|131072}if(!(!(y[d+294|0]&64)&(y[d+296|0]|y[d+297|0]<<8)!=4864)){x[a+480208>>2]=x[a+480208>>2]|2}f=y[d+305|0];x[a+480196>>2]=f;if(!(!h|(f|0)!=255?f:0)){x[a+480196>>2]=6}x[a+480204>>2]=D(y[d+306|0],1e4);if(y[d+306|0]<=32){x[a+480204>>2]=h?125e4:32e4}f=y[d+304|0];x[114414]=0;v[d+32|0]=f;v[d+144|0]=64;f=O(409,d+32|0,d+144|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Q}f=y[f|0];x[a+480200>>2]=f<<2;if(!((y[d+296|0]|y[d+297|0]<<8)>>>0>4895|f)){x[a+480200>>2]=256}if((y[d+298|0]|y[d+299|0]<<8)!=1|y[d+307|0]>7){break S}f=y[d+307|0];x[114414]=0;x[d+32>>2]=(f<<4)+16;x[d+144>>2]=127;f=O(414,d+32|0,d+144|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break T}x[a+480228>>2]=x[f>>2];break R}e=N()|0;break a}e=N()|0;break a}e=N()|0;break a}e=N()|0;break a}if(!(y[d+307|0]!=2&y[d+307|0]!=18)){x[a+480228>>2]=32;break R}if(!(y[d+307|0]&127)){x[a+480228>>2]=48;break R}f=y[d+307|0];x[114414]=0;x[d+32>>2]=f&127;x[d+144>>2]=16;f=O(519,d+32|0,d+144|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break P}x[a+480228>>2]=x[f>>2]}n=x[a+1074308>>2]!=0|v[d+307|0]<0;if(!n){f=x[a+480228>>2];x[114414]=0;f=_f(722,Bna(f<<3|5,f>>>29|0,11,0),lb);e=x[114414];x[114414]=0;if((e|0)==1){break O}x[a+480228>>2]=f}x[a+480232>>2]=36;if(!(!j|(y[d+296|0]|y[d+297|0]<<8)>>>0>=19763)){x[a+480232>>2]=64}w[a+480188>>1]=4;j=Xc(d+136|0);e=0;while(1){x[114414]=0;f=(e<<5)+a|0;l=f+480280|0;W(381,l|0);g=x[114414];x[114414]=0;if((g|0)==1){break N}g=d+e|0;i=y[g+320|0];W:{if(y[g+320|0]==255){break W}w[a+480188>>1]=e+1;if(!n){break W}w[f+480284>>1]=i&8?204:51}if(v[g+320|0]<0){x[l>>2]=1024}if(((i&126)-16&255)>>>0<=13){w[f+480284>>1]=128;f=d+32|0;ol(f,j,e);he(f,1)}e=e+1|0;if((e|0)!=32){continue}break}if(!z[a+480188>>1]){w[a+480188>>1]=1}f=Vb(a+484360|0);e=y[d+288|0]|y[d+289|0]<<8;x[114414]=0;aa(548,f|0,b|0,e|0,255,254)|0;f=x[114414];x[114414]=0;if((f|0)==1){break c}r=Cq(d+144|0);f=y[d+290|0]|y[d+291|0]<<8;x[114414]=0;U(358,b|0,r|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break e}n=Cq(d+120|0);f=y[d+292|0]|y[d+293|0]<<8;x[114414]=0;U(358,b|0,n|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){if(y[d+309|0]==252){e=0;x[114414]=0;O(980,b|0,d+32|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break g}while(1){g=(d+32|0)+e|0;f=y[g|0];X:{if(!(f&32)){break X}i=((e<<5)+a|0)+480284|0;if(h){f=d+16|0;ol(f,j,e);if(Ib(f)){break X}f=y[g|0]}w[i>>1]=(((f&15)<<8|8)>>>0)/15}e=e+1|0;if((e|0)!=32){continue}break}}f=y[d+290|0]|y[d+291|0]<<8;x[114414]=0;w[d+32>>1]=f;w[d+16>>1]=3999;f=O(433,d+32|0,d+16|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break M}f=z[f>>1];w[a+480190>>1]=f;if(f){f=c&2;j=d+80|0;e=0;while(1){g=uc(r,e);g=y[g|0]|y[g+1|0]<<8;x[114414]=0;g=O(224,b|0,g<<4)|0;i=x[114414];x[114414]=0;if((i|0)==1){break L}Y:{if(!g){break Y}x[114414]=0;g=O(981,b|0,d+32|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break L}if(!g){break Y}x[114414]=0;g=e+1|0;i=(D(g,104)+a|0)+484380|0;T(982,d+32|0,i|0,h|0);l=x[114414];x[114414]=0;if((l|0)==1){break L}x[114414]=0;T(544,d|0,1,j|0);l=x[114414];x[114414]=0;Z:{_:{$:{if((l|0)==1){break $}x[114414]=0;P(355,d+16|0,d|0);l=x[114414];x[114414]=0;if((l|0)==1){break $}x[114414]=0;O(334,((g<<5)+a|0)+946304|0,d+16|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break _}xb(d+16|0);if(!(y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24))|(!f|y[d+32|0]>1)){break Y}g=y[d+46|0];l=y[d+47|0];o=y[d+45|0];x[114414]=0;g=O(224,b|0,l<<12|g<<4|o<<20)|0;l=x[114414];x[114414]=0;if((l|0)==1){break Z}if(!g){break Y}g=y[d+298|0]|y[d+299|0]<<8;x[114414]=0;T(983,d+16|0,d+32|0,(g|0)==1|0);g=x[114414];x[114414]=0;if((g|0)!=1){x[114414]=0;U(361,d+16|0,i|0,b|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){break Y}}e=N()|0;break f}e=N()|0;break f}e=N()|0;xb(d+16|0);break f}e=N()|0;break f}e=e+1|0;if(e>>>0<z[a+480190>>1]){continue}break}}t=1;if(!(c&1)){break G}f=y[d+296|0]|y[d+297|0]<<8;c=y[d+292|0]|y[d+293|0]<<8;x[114414]=0;w[d+32>>1]=c;w[d+16>>1]=255;c=O(433,d+32|0,d+16|0)|0;e=x[114414];x[114414]=0;aa:{ba:{if((e|0)!=1){s=z[c>>1];x[114414]=0;c=a+484344|0;P(362,c|0,s|0);e=x[114414];x[114414]=0;if((e|0)==1){break ba}u=f>>>0<4896;if(s){break aa}l=0;o=0;break H}e=N()|0;break f}e=N()|0;break f}f=d+32|0;C=f|5;E=f|3;A=f|4;F=f|2;G=f|1;f=0;o=0;l=0;while(1){x[114414]=0;e=U(363,c|0,f&65535,64)|0;h=x[114414];x[114414]=0;if((h|0)==1){break K}ca:{if(!e){break ca}e=uc(n,f);if(!(y[e|0]|y[e+1|0]<<8)){break ca}e=uc(n,f);e=y[e|0]|y[e+1|0]<<8;x[114414]=0;e=O(224,b|0,e<<4)|0;h=x[114414];x[114414]=0;if((h|0)==1){break K}if(!e){break ca}x[114414]=0;O(304,b|0,2)|0;e=x[114414];x[114414]=0;if((e|0)==1){break K}j=0;e=Zb(c,f);x[114414]=0;h=O(453,e|0,0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break J}while(1){x[114414]=0;e=R(403,b|0)|0;g=x[114414];x[114414]=0;da:{ea:{if((g|0)!=1){q=e<<24>>24;if(q){break ea}if((j|0)==63){break ca}e=Zb(c,f);x[114414]=0;j=j+1|0;h=O(453,e|0,j|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){break da}}e=N()|0;break f}g=q&31;e=D(g,6)+h|0;i=_h(d+32|0);g=g>>>0<z[a+480188>>1];B=g?e:i;m=q&255;if(m&32){x[114414]=0;P(428,d+16|0,b|0);i=x[114414];x[114414]=0;fa:{ga:{ha:{if((i|0)!=1){H=ed(d+16|0);i=y[d+16|0];if(i>>>0>239){break ha}i=wu((D(i>>>4|0,12)+(i&15)|0)+13|0);break ga}e=N()|0;break f}ia:{switch(i-254|0){case 0:break ga;case 1:break ia;default:break fa}}i=0}v[B|0]=i}v[(g?e+1|0:G)|0]=y[H|0]}ja:{if(!(m&64)){break ja}x[114414]=0;m=R(403,b|0)|0;i=x[114414];x[114414]=0;ka:{if((i|0)!=1){i=g?e+2|0:F;m=m<<24>>24;v[d+16|0]=m;if((m|0)>-64){break ka}v[i|0]=2;v[(g?e+4|0:A)|0]=y[d+16|0]^128;break ja}e=N()|0;break f}v[i|0]=1;x[114414]=0;v[d|0]=64;i=O(409,d+16|0,d|0)|0;m=x[114414];x[114414]=0;if((m|0)==1){break I}v[(g?e+4|0:A)|0]=y[i|0]}if((q|0)>=0){break da}x[114414]=0;P(428,d+16|0,b|0);i=x[114414];x[114414]=0;la:{ma:{if((i|0)!=1){q=d+16|0;m=ed(q);i=g?e+3|0:E;v[i|0]=y[q|0];g=g?e+5|0:C;v[g|0]=y[m|0];vz(B,0);na:{e=y[i|0];if((e|0)==20){if((y[g|0]&240)!=160){break da}if((y[d+296|0]|y[d+297|0]<<8)>>>0<4896){break na}e=y[i|0]}if((e|0)==10){break la}if((e|0)!=31){break da}e=y[g|0];if(e>>>0<=15){break ma}u=0;break da}v[g|0]=y[g|0]&15^136;break da}e=N()|0;break f}if(e>>>0<=7){o=o+1|0;break da}l=((e|0)!=8)+l|0;break da}if(y[g|0]|(y[d+296|0]|y[d+297|0]<<8)>>>0>4865){break da}v[i|0]=42}if(j>>>0<64){continue}break}}f=f+1|0;if((s|0)!=(f|0)){continue}break}break H}e=N()|0;break f}e=N()|0;break a}e=N()|0;break a}e=N()|0;break a}e=N()|0;break a}e=N()|0;break f}e=N()|0;break f}e=N()|0;break f}e=N()|0;break f}e=N()|0;break f}if(!u){break G}a=z[a+480188>>1];if((a|0)>(l+o|0)|(a|0)<=(l-o|0)){break G}f=Ae(c)-1&65535;a=0;e=0;if(Ae(c)>>>0>f>>>0){while(1){if(xh(Re(c,a))){b=bc(Re(c,a));h=dc(Re(c,a));a=hb-16|0;hb=a;x[a>>2]=h;x[a+8>>2]=b;if(Hb(a+8|0,a)){while(1){h=a+8|0;b=x[h>>2];if(y[b+3|0]==31){v[b+3|0]=20;v[b+5|0]=y[b+5|0]|128}Nj(h);if(Hb(h,a)){continue}break}}hb=a+16|0}e=e+1|0;a=e&65535;if(f>>>0>=a>>>0){continue}break}}}Mj(n);Mj(r);xb(k)}hb=d+352|0;return t|0}e=N()|0}Mj(n);break d}e=N()|0}Mj(r);break a}e=N()|0;break a}e=N()|0}xb(k);Q(e|0);p()}function CH(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;N=hb-144|0;hb=N;a:{b:{if(d>>>0<=e>>>0){F=x[f>>2]+e|0;O=g&4;M=O?-1:F+(d^-1)|0;E=M+1|0;if(!(E&M)){break b}}x[f>>2]=0;x[c>>2]=0;k=-3;break a}G=x[c>>2];t=G+b|0;H=x[a+60>>2];s=x[a+40>>2];j=x[a+36>>2];B=x[a+32>>2];m=x[a+56>>2];i=x[a+4>>2];l=b;q=e;r=-1;k=-1;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{u=x[a>>2];switch(u|0){case 35:break h;case 17:break i;case 21:break j;case 37:break k;case 34:break l;case 42:break p;case 41:break q;case 53:break r;case 52:break s;case 51:break t;case 38:break u;case 27:break v;case 26:break w;case 25:break x;case 24:break y;case 23:break z;case 18:break A;case 16:break B;case 14:break C;case 11:break D;case 9:break E;case 7:break F;case 6:break G;case 3:break H;case 32:break I;case 5:break J;case 2:break L;case 1:break M;case 0:break N;case 36:break e;case 39:break f;case 10:break g;default:break c}}x[a+28>>2]=1;m=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=1;s=0;j=0;B=0;i=0;if(g&1){break M}break K}if((G|0)<=0){x[a>>2]=1;break d}x[a+8>>2]=y[b|0];l=b+1|0}if(l>>>0>=t>>>0){x[a>>2]=2;k=g&2?1:-4;break c}k=y[l|0];x[a+12>>2]=k;j=1;l=l+1|0;u=36;h=x[a+8>>2];if(((k|h<<8)>>>0)%31|k&32){break e}k=h&15;if(!O){h=256<<(h>>>4);if(h>>>0>32768|h>>>0>E>>>0){break e}if((k|0)==8){break K}break e}if((k|0)!=8){break e}}h=0;break o}if((G|0)<=0){x[a>>2]=5;break d}P=i+8|0;l=b+1|0;m=y[b|0]<<i|m;h=2;break o}if((G|0)<=0){x[a>>2]=32;break d}i=i+8|0;l=b+1|0;C=j;break n}h=1;break o}h=4;break o}h=3;break o}h=7;break o}h=9;break o}h=10;break o}h=11;break o}h=12;break o}h=13;break o}h=14;break o}h=15;break o}h=16;break o}h=17;break o}h=8;break o}h=5;break o}h=6;break o}h=18;break o}o=2;break m}o=1;break m}O:while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{switch(h|0){case 0:j=C;if(i>>>0>2){break Ca}h=1;continue;case 17:break ka;case 16:break la;case 15:break ma;case 14:break na;case 13:break oa;case 12:break pa;case 11:break qa;case 10:break ra;case 9:break sa;case 8:break ua;case 7:break va;case 6:break wa;case 5:break xa;case 4:break za;case 3:break Aa;case 2:break Ba;case 1:break Da;default:break ja}}while(1){if(l>>>0>=t>>>0){x[a>>2]=3;k=g&2?1:-4;break c}m=y[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<3){continue}break}C=j}k=m&7;x[a+20>>2]=k;h=k>>>1|0;x[a+24>>2]=h;i=i-3|0;m=m>>>3|0;if(k>>>0>=2){break ta}P=i;break ia}i=P&-8;m=m>>>(P&7)|0;j=0;h=0;break ga}if(l>>>0<t>>>0){break ya}x[a>>2]=7;k=g&2?1:-4;break c}while(1){if(l>>>0>=t>>>0){x[a>>2]=6;k=g&2?1:-4;break c}m=y[l|0]<<i|m;h=i>>>0>4294967287;l=l+1|0;i=i+8|0;if(h){continue}break}h=1;break ga}v[(a+j|0)+10528|0]=y[l|0];l=l+1|0;h=2;break ga}while(1){if(l>>>0>=t>>>0){x[a>>2]=51;k=g&2?1:-4;break c}m=y[l|0]<<i|m;h=i>>>0>4294967287;l=l+1|0;i=i+8|0;if(h){continue}break}break S}if(q>>>0<F>>>0){v[q|0]=B;j=j-1|0;q=q+1|0;break T}r=2;u=52;break e}if(q>>>0<F>>>0){break ha}r=2;u=9;break e}if(l>>>0<t>>>0){k=F-q|0;h=t-l|0;h=h>>>0>k>>>0?k:h;h=h>>>0<j>>>0?h:j;j=j-h|0;q=sc(q,l,h)+h|0;l=h+l|0;break R}x[a>>2]=38;k=g&2?1:-4;break c}k=0;j=C;Ea:{switch(h-1|0){case 0:break Ea;case 2:break g;default:break fa}}x[a+44>>2]=288;x[a+48>>2]=32;h=a+3552|0;x[h>>2]=84215045;x[h+4>>2]=84215045;h=a+3560|0;x[h>>2]=84215045;x[h+4>>2]=84215045;h=a+3568|0;x[h>>2]=84215045;x[h+4>>2]=84215045;h=a+3576|0;x[h>>2]=84215045;x[h+4>>2]=84215045;Sb(a- -64|0,8,144);Sb(a+208|0,9,112);v[a+336|0]=7;v[a+337|0]=7;v[a+338|0]=7;v[a+339|0]=7;v[a+340|0]=7;v[a+341|0]=7;v[a+342|0]=7;v[a+343|0]=7;v[a+328|0]=7;v[a+329|0]=7;v[a+330|0]=7;v[a+331|0]=7;v[a+332|0]=7;v[a+333|0]=7;v[a+334|0]=7;v[a+335|0]=7;v[a+320|0]=7;v[a+321|0]=7;v[a+322|0]=7;v[a+323|0]=7;v[a+324|0]=7;v[a+325|0]=7;v[a+326|0]=7;v[a+327|0]=7;v[a+344|0]=8;v[a+345|0]=8;v[a+346|0]=8;v[a+347|0]=8;v[a+348|0]=8;v[a+349|0]=8;v[a+350|0]=8;v[a+351|0]=8;I=1;break X}while(1){if(l>>>0>=t>>>0){x[a>>2]=11;k=g&2?1:-4;break c}m=y[l|0]<<i|m;l=l+1|0;i=i+8|0;J=v[j+17379|0];if(i>>>0<J>>>0){continue}break}k=j;j=1;break Z}while(1){if(l>>>0>=t>>>0){x[a>>2]=14;k=g&2?1:-4;break c}m=y[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<3){continue}break}h=1;break Y}if(l>>>0>=t>>>0){x[a>>2]=16;k=g&2?1:-4;break c}m=y[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break ea}break da}while(1){if(l>>>0>=t>>>0){x[a>>2]=18;k=g&2?1:-4;break c}m=y[l|0]<<i|m;l=l+1|0;i=i+8|0;if(s>>>0>i>>>0){continue}break}Q=B-16|0;h=3;break W}if(l>>>0>=t>>>0){x[a>>2]=23;k=g&2?1:-4;break c}m=y[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break ca}break ba}if(q>>>0>=F>>>0){r=2;u=24;break e}v[q|0]=j;q=q+1|0;o=m;break V}while(1){if(l>>>0>=t>>>0){x[a>>2]=25;k=g&2?1:-4;break c}m=y[l|0]<<i|m;l=l+1|0;i=i+8|0;if(s>>>0>i>>>0){continue}break}h=3;break U}if(l>>>0>=t>>>0){x[a>>2]=26;k=g&2?1:-4;break c}m=y[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break aa}break $}while(1){if(l>>>0>=t>>>0){x[a>>2]=27;k=g&2?1:-4;break c}m=y[l|0]<<i|m;l=l+1|0;i=i+8|0;if(s>>>0>i>>>0){continue}break}h=6;break U}if(q>>>0>=F>>>0){r=2;u=53;break e}v[q|0]=y[(H-B&M)+d|0];q=q+1|0;H=H+1|0;break _}h=2;continue}h=8;continue}while(1){Fa:{Ga:{Ha:{Ia:{Ja:{switch(h|0){case 0:if(j>>>0>3){break Ia}if(!i){i=0;h=3;continue O}if(i>>>0>7){break Ga}h=4;continue O;case 1:v[(a+j|0)+10528|0]=m;i=i-8|0;m=m>>>8|0;break Fa;default:break Ja}}j=j+1|0;break Ha}j=z[a+10528>>1];if((j|0)==(z[a+10530>>1]^65535)){break T}break f}h=0;continue}h=1;continue}h=2;continue}}j=0;break Z}h=1;break W}h=2;break W}h=0;break U}h=1;break U}h=4;break U}h=5;break U}h=7;break U}while(1){Ka:{La:{Ma:{if(!j){if(k>>>0>2){break Ma}j=k;J=v[j+17379|0];if(J>>>0<=i>>>0){break Ka}h=9;continue O}j=k<<2;x[(j+a|0)+44>>2]=x[j+39344>>2]+((-1<<J^-1)&m);k=k+1|0;i=i-J|0;m=m>>>J|0;break La}j=0;Sb(a+7040|0,0,288);h=0;break Y}j=0;continue}j=1;continue}}while(1){Na:{Oa:{Pa:{if(!h){if(A[a+52>>2]<=j>>>0){break Pa}if(i>>>0>2){break Na}h=10;continue O}v[(y[j+39360|0]+a|0)+7040|0]=m&7;j=j+1|0;i=i-3|0;m=m>>>3|0;break Oa}x[a+52>>2]=19;I=x[a+24>>2];C=j;break X}h=0;continue}h=1;continue}}h=0}while(1){Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{switch(h|0){case 0:j=0;if((I|0)<0){o=m;j=C;break V}K=Sb(N,0,64);h=D(I,3488)+a|0;Sb(h+352|0,0,3200);G=h- -64|0;r=x[a+24>>2];E=x[((r<<2)+a|0)+44>>2];if(E){while(1){h=K+(y[j+G|0]<<2)|0;x[h>>2]=x[h>>2]+1;j=j+1|0;if((E|0)!=(j|0)){continue}break}}x[K+64>>2]=0;x[K+68>>2]=0;k=0;n=0;j=1;while(1){h=j<<2;j=j+1|0;h=x[h+K>>2];k=h+k<<1;x[(K- -64|0)+(j<<2)>>2]=k;n=h+n|0;if((j|0)!=16){continue}break};if(!((k|0)==65536|n>>>0<=1)){j=C;break h}if(E){h=-1;L=0;u=D(I,3488)+a|0;while(1){r=y[G+L|0];Za:{if(!r){break Za}k=(K- -64|0)+(r<<2)|0;j=x[k>>2];x[k>>2]=j+1;k=0;n=r;while(1){E=k<<1;k=E|j&1;j=j>>>1|0;n=n-1|0;if(n){continue}break}if(r>>>0<=10){if(k>>>0>1023){break Za}n=r<<9|L;j=1<<r;while(1){w[(u+(k<<1)|0)+352>>1]=n;k=j+k|0;if(k>>>0<1024){continue}break}break Za}k=u+((k&1023)<<1)|0;j=w[k+352>>1];_a:{if(j){k=h;h=j;break _a}w[k+352>>1]=h;k=h-2|0}j=E>>>9|0;if(r>>>0>=12){while(1){j=j>>>1|0;n=(u+((j&1)+(h^-1)<<1)|0)+2400|0;h=w[n>>1];if(!h){w[n>>1]=k;h=k;k=h-2|0}r=r-1|0;if(r>>>0>11){continue}break}}w[(u+((j>>>1&1)+(h^-1)<<1)|0)+2400>>1]=L;h=k}L=L+1|0;r=x[a+24>>2];if(L>>>0<A[((r<<2)+a|0)+44>>2]){continue}break}}j=0;if((r|0)!=2){break Ra}break Va;case 1:h=w[(((m&1023)<<1)+a|0)+7328>>1];$a:{if((h|0)>=0){if(h>>>0<512|h>>>9>>>0>i>>>0){break $a}break Ua}if(i>>>0<11){break $a}k=10;while(1){h=w[(((m>>>k&1)+(h^-1)<<1)+a|0)+9376>>1];if((h|0)<0){n=k+2|0;k=k+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>=0){break Ua}}h=11;continue O;case 2:k=w[(((m&1023)<<1)+a|0)+7328>>1];if((k|0)>=0){break Xa}h=10;while(1){n=m>>>h|0;h=h+1|0;k=w[(((n&1)+(k^-1)<<1)+a|0)+9376>>1];if((k|0)<0){continue}break};break Wa;default:break Ya}}n=v[Q+13685|0]+((-1<<s^-1)&m)|0;i=i-s|0;m=m>>>s|0;k=a+j|0;Sb(k+10532|0,(B|0)==16?y[k+10531|0]:0,n);j=j+n|0;break Va}h=k>>>9|0;k=k&511}i=i-h|0;m=m>>>h|0;B=k;if(k>>>0>15){break Ta}v[(a+j|0)+10532|0]=B;j=j+1|0}k=x[a+48>>2];n=x[a+44>>2];h=k+n|0;if(h>>>0<=j>>>0){break Sa}if(i>>>0>14){break Ua}if((t-l|0)<=1){h=1;continue}m=y[l|0]<<i|y[l+1|0]<<i+8|m;i=i+16|0;l=l+2|0}h=2;continue}if(!((B|0)!=16|j)){j=0;B=16;break i}Q=B-16|0;s=v[Q+17370|0];if(s>>>0<=i>>>0){break Qa}h=12;continue O}if((h|0)!=(j|0)){break j}h=a+10532|0;sc(a- -64|0,h,n);sc(a+3552|0,h+n|0,k);r=x[a+24>>2];C=j}I=r-1|0;x[a+24>>2]=I;h=0;continue}h=3;continue}}h=2}ab:while(1){bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{switch(h|0){case 0:h=w[(((m&1023)<<1)+a|0)+352>>1];qb:{if((h|0)>=0){if(h>>>0<512|h>>>9>>>0>i>>>0){break qb}break bb}if(i>>>0<11){break qb}k=10;while(1){h=w[(((m>>>k&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){n=k+2|0;k=k+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>=0){break bb}}h=13;continue O;case 1:k=w[(((m&1023)<<1)+a|0)+352>>1];if((k|0)>=0){break ob}h=10;while(1){j=m>>>h|0;h=h+1|0;k=w[(((j&1)+(k^-1)<<1)+a|0)+2400>>1];if((k|0)<0){continue}break};j=k;break nb;case 3:break eb;case 4:break fb;case 5:break jb;case 6:break kb;case 2:break pb;default:break lb}}while(1){m=t-l|0;if(!((F-q|0)>1&(m|0)>=4)){if(i>>>0>14){m=o;break bb}if((m|0)<=1){m=o;h=0;continue ab}m=y[l|0]<<i|y[l+1|0]<<i+8|o;i=i+16|0;l=l+2|0;break bb}if(i>>>0>14){h=l}else{o=(y[l|0]|y[l+1|0]<<8)<<i|o;i=i+16|0;h=l+2|0}j=w[(((o&1023)<<1)+a|0)+352>>1];rb:{if((j|0)<0){l=10;while(1){m=o>>>l|0;l=l+1|0;j=w[(((m&1)+(j^-1)<<1)+a|0)+2400>>1];if((j|0)<0){continue}break}break rb}l=j>>>9|0}i=i-l|0;m=o>>>l|0;if(j&256){l=h;break mb}if(i>>>0>14){k=i}else{m=(y[h|0]|y[h+1|0]<<8)<<i|m;h=h+2|0;k=i+16|0}l=h;h=w[(((m&1023)<<1)+a|0)+352>>1];sb:{if((h|0)<0){o=10;while(1){n=m>>>o|0;o=o+1|0;h=w[(((n&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){continue}break}break sb}o=h>>>9|0}v[q|0]=j;i=k-o|0;o=m>>>o|0;if(!(h&256)){v[q+1|0]=h;q=q+2|0;continue}break}q=q+1|0;m=o;j=h;break mb}h=k>>>9|0;j=k&511}i=i-h|0;m=m>>>h|0;if(j>>>0>255){break mb}h=14;continue O}C=256;k=j&511;if((k|0)==256){break Q}h=k-257<<2;j=x[h+38832>>2];s=0;if(k-285>>>0<4294967276){break db}s=x[h+38960>>2];if(s>>>0>i>>>0){h=15;continue O}h=3;continue}if(!j){o=m;j=-1;break hb}j=j-1|0;h=18;continue O}i=i-s|0;o=m>>>s|0;B=((-1<<s^-1)&m)+B|0;break ib}s=w[(((m&1023)<<1)+a|0)+3840>>1];tb:{if((s|0)<0){h=10;while(1){k=m>>>h|0;h=h+1|0;s=w[(((k&1)+(s^-1)<<1)+a|0)+5888>>1];if((s|0)<0){continue}break}k=s;break tb}h=s>>>9|0;k=s&511}n=k<<2;B=x[n+39088>>2];i=i-h|0;m=m>>>h|0;s=0;if(k-30>>>0<4294967270){o=m;break ib}s=x[n+39216>>2];if(s>>>0<=i>>>0){break gb}h=17;continue O}H=q-d|0;if(!(!O|H>>>0>B-1>>>0)){m=o;break k}h=(H-B&M)+d|0;if((h>>>0<q>>>0?q:h)+j>>>0>F>>>0){m=o;h=7;continue}if(j>>>0>2){while(1){v[q|0]=y[h|0];v[q+1|0]=y[h+1|0];v[q+2|0]=y[h+2|0];h=h+3|0;q=q+3|0;j=j-3|0;if(j>>>0>2){continue}break}}if(!j){break hb}v[q|0]=y[h|0];if((j|0)!=1){v[q+1|0]=y[h+1|0]}q=j+q|0}h=2;continue}h=6;continue}h=w[(((m&1023)<<1)+a|0)+3840>>1];ub:{if((h|0)>=0){if(h>>>0<512|h>>>9>>>0>i>>>0){break ub}break cb}if(i>>>0<11){break ub}k=10;while(1){h=w[(((m>>>k&1)+(h^-1)<<1)+a|0)+5888>>1];if((h|0)<0){n=k+2|0;k=k+1|0;if(i>>>0>=n>>>0){continue}}break}if((h|0)>=0){break cb}}h=16;continue O}i=i-s|0;j=((-1<<s^-1)&m)+j|0;m=m>>>s|0}if(i>>>0>14){break cb}if((t-l|0)<=1){h=4;continue}m=m|(y[l|0]<<i|y[l+1|0]<<i+8);i=i+16|0;l=l+2|0}h=5;continue}h=1;continue}}if(!j|!i){break R}if(i>>>0>7){break S}h=5;continue}i=i-8|0;B=m&255;m=m>>>8|0;h=6;continue}if(j){break P}C=0}if(v[a+20|0]&1){break n}h=0;continue}h=7;continue}}i=i&-8;if(!(!i|b>>>0>=l>>>0)){m=i-8|0;j=m>>>3|0;d=(b^-1)+l|0;d=d>>>0>j>>>0?j:d;l=(d^-1)+l|0;i=m-(d<<3)|0}if(!i){m=0;n=0;h=0;j=C;i=0;if(!(g&1)){break l}o=0;break m}ea(3164,9027,2797,3174);p()}while(1){vb:{wb:{xb:{yb:{zb:{Ab:{switch(o|0){case 0:if(n>>>0>3){j=n;i=h;break l}i=0;if(h){break zb}j=n;o=1;continue;case 1:break Ab;default:break yb}}if(l>>>0<t>>>0){break wb}x[a>>2]=42;k=g&2?1:-4;break c}j=n;i=h;if(h>>>0>7){break xb}o=2;continue}while(1){if(l>>>0>=t>>>0){x[a>>2]=41;k=g&2?1:-4;break c}m=y[l|0]<<i|m;d=i>>>0>4294967287;l=l+1|0;h=i+8|0;i=h;if(d){continue}break}n=j}o=m&255;m=m>>>8|0;h=h-8|0;break vb}o=y[l|0];l=l+1|0;n=j;h=i}x[a+16>>2]=x[a+16>>2]<<8|o;n=n+1|0;o=0;continue}}r=0;u=34;break e}u=37;r=-1;break e}u=21;r=-1;break e}u=17;r=-1;break e}u=35;r=-1;break e}u=10;r=-1;break e}u=39;r=-1}x[a>>2]=u;if(!(i>>>0<8|b>>>0>=l>>>0)){C=i-8|0;h=C>>>3|0;d=(b^-1)+l|0;d=d>>>0>h>>>0?h:d;l=(d^-1)+l|0;i=C-(d<<3)|0}k=r;break c}k=g&2?1:-4}x[a+4>>2]=i;x[a+60>>2]=H;x[a+40>>2]=s;x[a+36>>2]=j;x[a+32>>2]=B;x[a+56>>2]=(((i&63)>>>0<32?-1<<i:0)^-1)&m;x[c>>2]=l-b;h=q-e|0;x[f>>2]=h;if(!(g&9)|(k|0)<0){break a}b=x[a+28>>2];l=b>>>16|0;i=b&65535;if(h){o=(h>>>0)%5552|0;while(1){j=0;if(o>>>0>=8){j=o&8184;m=0;while(1){r=y[e|0]+i|0;n=r+y[e+1|0]|0;C=n+y[e+2|0]|0;f=C+y[e+3|0]|0;d=f+y[e+4|0]|0;c=d+y[e+5|0]|0;b=c+y[e+6|0]|0;i=b+y[e+7|0]|0;l=i+(b+(c+(d+(f+(C+(n+(l+r|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;m=m+8|0;if((m|7)>>>0<o>>>0){continue}break}}if(j>>>0<o>>>0){b=o-j|0;m=e;while(1){i=y[m|0]+i|0;l=l+i|0;m=m+1|0;j=j+1|0;if((o|0)!=(j|0)){continue}break}e=b+e|0}h=h-o|0;l=(l>>>0)%65521|0;i=(i>>>0)%65521|0;o=5552;if(h){continue}break}}b=l<<16|i;x[a+28>>2]=b;if(k){break a}k=0;if(!(g&1)){break a}k=(b|0)!=x[a+16>>2]?-2:0}hb=N+144|0;return k}function xda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,A=E(0),C=0,F=0,G=0,H=0,I=E(0),J=0,K=0,L=0,M=0,N=0,O=E(0),P=E(0),Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=E(0);g=b;n=hb-17168|0;hb=n;x[n+17164>>2]=0;a:{b:{c:{if(y[a+6152|0]!=255|(c|0)<5){break c}if(!dp(a+6152|0,g)){break c}b=dx(g,x[a+6148>>2])+cp(g)|0;x[n+17164>>2]=b;if((b|0)==(c|0)){b=c;break b}d:{if((b+4|0)<=(c|0)){if(dp(g,b+g|0)){break d}}x[n+17164>>2]=0;break c}if(b){break b}}f=g;r=Sb(a,0,6668)+6148|0;l=n+17164|0;e:{if((c|0)>=5){o=c-4|0;while(1){if(yH(f)){k=dx(f,x[r>>2]);b=k+cp(f)|0;q=0;f:{g:{if(k){break g}h=4;N=j+4|0;while(1){if((o|0)<=((h<<1)+j|0)){break f}k=0;s=f+h|0;h:{if(!dp(f,s)){break h}i=h-cp(f)|0;p=cp(s)+i|0;if((p+(h+N|0)|0)>(c|0)){break h}if(!dp(f,p+s|0)){break h}x[r>>2]=i;k=i;b=h}q=!k;if(k){break g}i=h>>>0<2303;h=h+1|0;if(i){continue}break}}if((b+j|0)>(c|0)|q){break f}p=c-j|0;h=0;q=0;i:{while(1){i=f+h|0;h=(dx(i,k)+h|0)+cp(i)|0;i=(q|0)!=0;if((p|0)<(h+4|0)){break i}i=0;if(!dp(f,f+h|0)){break i}q=q+1|0;if((q|0)!=10){continue}break}i=1}if(i){break e}}if(!((b|0)!=(c|0)|j)){j=0;b=c;break e}x[r>>2]=0}f=f+1|0;j=j+1|0;if((o|0)!=(j|0)){continue}break}}b=0;j=c}x[l>>2]=b;b=x[n+17164>>2];f=j;if((f+b|0)<=(c|0)?b:0){break b}x[e>>2]=f;f=0;break a}u=f+g|0;x[a+6152>>2]=y[u|0]|y[u+1|0]<<8|(y[u+2|0]<<16|y[u+3|0]<<24);x[e+4>>2]=f;x[e>>2]=b+f;x[e+8>>2]=y[u+3|0]>191?1:2;_=e,$=BH(u),x[_+12>>2]=$;x[e+16>>2]=4-(y[u+1|0]>>>1&3);_=e,$=cx(u),x[_+20>>2]=$;if(!d){f=bx(u);break a}AH(n+17152|0,u+4|0,b-4|0);if(!(v[u+1|0]&1)){Sd(n+17152|0,16)}j:{if(x[e+16>>2]==3){f=0;o=n+17152|0;T=n+3740|0;b=T;g=0;p=y[u+1|0];c=D((p>>>3&1)+(p>>>4&1)|0,3)+(y[u+2|0]>>>2&3)|0;i=c-((c|0)!=0)|0;j=y[u+3|0]>191?1:2;k:{if(p&8){q=Sd(o,9);j=j<<1;g=Sd(o,j+7|0);break k}q=Sd(o,j|8)>>>j|0}c=D(i,40);s=c+39680|0;l=c+4e4|0;N=D(i,23)+39488|0;h=-1;l:{while(1){p=y[u+3|0];i=Sd(o,12);w[b+4>>1]=i;c=Sd(o,9);w[b+6>>1]=c;if((c&65535)>>>0>288){break l}k=p>>>0>191?g<<4:g;_=b,$=Sd(o,8),v[_+10|0]=$;c=Sd(o,y[u+1|0]&8?4:9);v[b+13|0]=22;v[b+14|0]=0;x[b>>2]=N;w[b+8>>1]=c;m:{if(Sd(o,1)){c=Sd(o,2);v[b+11|0]=c;if(!(c&255)){break l}c=Sd(o,1);w[b+18>>1]=65287;v[b+12|0]=c;if(y[b+11|0]==2){n:{if(!(c&255)){x[b>>2]=s;v[b+18|0]=8;g=0;c=39;break n}x[b>>2]=l;g=y[u+1|0]&8?8:6;c=30}v[b+14|0]=c;v[b+13|0]=g;k=k&3855}c=Sd(o,10);_=b,$=Sd(o,3),v[_+21|0]=$;_=b,$=Sd(o,3),v[_+22|0]=$;_=b,$=Sd(o,3),v[_+23|0]=$;g=c<<5;break m}v[b+11|0]=0;v[b+12|0]=0;g=Sd(o,15);_=b,$=Sd(o,4),v[_+18|0]=$;c=Sd(o,3);v[b+20|0]=255;v[b+19|0]=c}v[b+17|0]=g&31;v[b+15|0]=g>>>10;v[b+16|0]=g>>>5&31;m=(i&65535)+m|0;o:{if(y[u+1|0]&8){c=Sd(o,1);break o}c=z[b+8>>1]>499}v[b+24|0]=c;_=b,$=Sd(o,1),v[_+25|0]=$;c=Sd(o,1);v[b+27|0]=k>>>12&15;v[b+26|0]=c;b=b+28|0;g=k<<4;j=j-1|0;if(j){continue}break}h=(x[o+4>>2]+m|0)>(x[o+8>>2]+(q<<3)|0)?-1:q}if(!((h|0)<0|x[n+17156>>2]>x[n+17160>>2])){p=n+17152|0;g=x[p+4>>2];f=x[p+8>>2];c=n+912|0;j=x[a+6144>>2];b=j-h|0;i=(h|0)>(j|0)?j:h;j=sc(c+12|0,(((b|0)>0?b:0)+a|0)+6156|0,i);b=(f-g|0)/8|0;sc(j+i|0,x[p>>2]+(x[p+4>>2]/8|0)|0,b);AH(c,j,b+i|0);U=x[a+6144>>2]>=(h|0);p:{if(!U){break p}W=a+2304|0;f=x[e+8>>2];X=n+8620|0;Y=n+3852|0;b=1;j=0;while(1){Z=Sb(Y,0,4608);H=n+912|0;K=D(D(f,j),28)+T|0;j=0;N=f;if((f|0)>0){p=H+7548|0;V=a+6152|0;while(1){C=D(j,28)+K|0;r=z[C+4>>1];o=x[H+4>>2];i=(H+D(j,39)|0)+16156|0;l=hb-48|0;hb=l;k=D(!y[C+13|0]+(y[C+14|0]!=0)|0,28)+40320|0;q=y[C+25|0];q:{if(y[V+1|0]&8){h=y[C+27|0];f=y[z[C+8>>1]+40416|0];c=f&3;v[l+47|0]=c;v[l+46|0]=c;c=f>>>2|0;v[l+45|0]=c;v[l+44|0]=c;break q}c=(y[V+3|0]&16)>>>4&(j|0)!=0;f=c?12:0;h=z[C+8>>1]>>>c|0;while(1){F=1;g=3;while(1){c=g;s=y[(c+f|0)+40432|0];v[c+(l+44|0)|0]=((h|0)/(F|0)|0)%(s|0);F=D(s,F);g=c-1|0;if(c){continue}break}f=f+4|0;h=h-F|0;if((h|0)>=0){continue}break}k=f+k|0;h=-16}g=i;f=l;i=f+44|0;t=0;while(1){L=y[k+t|0];if(L){r:{if(h&8){sc(f,g,L);break r}G=y[i+t|0];if(!G){Sb(f,0,L);Sb(g,0,L);break r}c=(h|0)>=0?-1:-1<<G^-1;F=0;while(1){s=Sd(H,G);v[g+F|0]=(c|0)==(s|0)?-1:s;v[f+F|0]=s;F=F+1|0;if((L|0)!=(F|0)){continue}break}}h=h<<1;f=f+L|0;g=g+L|0;t=t+1|0;if((t|0)!=4){continue}}break}v[f+2|0]=0;v[f|0]=0;v[f+1|0]=0;k=y[C+14|0];s:{if(k){c=2-q|0;i=y[C+23|0]<<c;g=y[C+22|0]<<c;f=y[C+21|0]<<c;c=y[C+13|0];F=0;while(1){h=l+(c+F|0)|0;v[h|0]=f+y[h|0];v[h+1|0]=g+y[h+1|0];v[h+2|0]=i+y[h+2|0];F=F+3|0;if(k>>>0>F>>>0){continue}break}break s}if(!y[C+24|0]){break s}h=0;while(1){c=h+l|0;v[c+11|0]=y[c+11|0]+y[h+40456|0];h=h+1|0;if((h|0)!=10){continue}break}}I=ax(E(2048),((((y[V+3|0]&224)==96)<<1)-y[C+10|0]|0)+258|0);h=0;if((k|0)!=(0-y[C+13|0]|0)){c=q+1|0;while(1){_=p+(h<<2)|0,aa=ax(I,y[h+l|0]<<c),B[_>>2]=aa;h=h+1|0;if(h>>>0<y[C+14|0]+y[C+13|0]>>>0){continue}break}}hb=l+48|0;i=(H+D(j,2304)|0)+2940|0;g=p;G=o+r|0;A=E(0);F=0;c=x[H+4>>2];l=x[H>>2]+((c|0)/8|0)|0;f=y[l|0]|y[l+1|0]<<8|(y[l+2|0]<<16|y[l+3|0]<<24);f=(f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))<<(c&7);m=c|-8;t=l+4|0;M=x[C>>2];J=z[C+6>>1];t:{if(!J){J=0;break t}while(1){c=C+F|0;l=y[c+15|0];L=(w[(l<<1)+44880>>1]<<1)+40496|0;R=y[c+18|0];u:{if(l>>>0>=16){r=y[l+44944|0];s=32-r|0;while(1){o=y[M|0]>>>1|0;Q=(o|0)>(J|0)?J:o;A=B[g>>2];while(1){k=w[L+(f>>>26&62)>>1];if((k|0)<0){c=5;while(1){m=c+m|0;f=f<<c;l=k<<16>>16;c=l&7;k=w[L+((f>>>32-c|0)-(l>>3)<<1)>>1];if((k|0)<0){continue}break}}h=k&65535;c=h>>>8|0;m=c+m|0;f=f<<c;S=1;while(1){k=h&15;v:{if((k|0)==15){c=f<<r;k=(f>>>s|0)+15|0;m=m+r|0;if((m|0)>=0){while(1){c=y[t|0]<<m|c;f=m>>>0>7;m=m-8|0;t=t+1|0;if(f){continue}break}}P=E(A*E(c>>31|1));if((k|0)<=128){O=B[(k<<2)+45040>>2]}else{f=k>>>0<1024;q=f?k<<3:k;l=q<<1&64;I=E(E((q&63)-l|0)/E((q&-64)+l|0));O=E(E(E(E(E(E(I*E(.2222222238779068))+E(1.3333333730697632))*I)+E(1))*(f?E(16):E(256)))*B[(l+q>>6<<2)+45040>>2])}P=E(P*O);break v}c=f;P=E(B[(((f>>>27&16|k)^16)<<2)+44976>>2]*A)}B[i>>2]=P;h=h>>>4|0;i=i+4|0;f=(k|0)!=0;m=f+m|0;f=c<<f;c=S&1;S=0;if(c){continue}break}if((m|0)>=0){while(1){f=y[t|0]<<m|f;c=m>>>0>7;m=m-8|0;t=t+1|0;if(c){continue}break}}Q=Q-1|0;if(Q){continue}break}g=g+4|0;M=M+1|0;J=J-o|0;if((J|0)<=0){break u}c=(R|0)>0;R=R-1|0;if(c){continue}break}break u}while(1){h=y[M|0]>>>1|0;S=(h|0)>(J|0)?J:h;A=B[g>>2];while(1){k=w[L+(f>>>26&62)>>1];if((k|0)<0){c=5;while(1){m=c+m|0;f=f<<c;l=k<<16>>16;c=l&7;k=w[L+((f>>>32-c|0)-(l>>3)<<1)>>1];if((k|0)<0){continue}break}}c=k&65535;l=c>>>8|0;m=l+m|0;f=f<<l;k=1;while(1){l=c&15;B[i>>2]=B[(((l|f>>>27&16)^16)<<2)+44976>>2]*A;c=c>>>4|0;i=i+4|0;l=(l|0)!=0;m=l+m|0;f=f<<l;l=k&1;k=0;if(l){continue}break}if((m|0)>=0){while(1){f=y[t|0]<<m|f;c=m>>>0>7;m=m-8|0;t=t+1|0;if(c){continue}break}}S=S-1|0;if(S){continue}break}g=g+4|0;M=M+1|0;J=J-h|0;if((J|0)<=0){break u}c=(R|0)>0;R=R-1|0;if(c){continue}break}}F=F+1|0;if((J|0)>0){continue}break}}k=1-J|0;while(1){w:{l=y[C+26|0]?44864:44832;c=y[l+(f>>>28|0)|0];if(!(c&8)){c=y[l+((f<<4>>>32-(c&3))+(c>>>3)|0)|0]}h=c&7;m=h+m|0;if(((m+(t-x[H>>2]<<3)|0)-24|0)>(G|0)){break w}k=k-1|0;if(!k){l=y[M|0];if(l>>>0<2){break w}k=l>>>1|0;M=M+1|0;A=B[g>>2];g=g+4|0}f=f<<h;if(c>>>0>=128){B[i>>2]=(f|0)<0?E(-A):A;m=m+1|0;f=f<<1}if(c&64){B[i+4>>2]=(f|0)<0?E(-A):A;m=m+1|0;f=f<<1}k=k-1|0;if(!k){l=y[M|0];if(l>>>0<2){break w}k=l>>>1|0;M=M+1|0;A=B[g>>2];g=g+4|0}if(c&32){B[i+8>>2]=(f|0)<0?E(-A):A;m=m+1|0;f=f<<1}if(c&16){B[i+12>>2]=(f|0)<0?E(-A):A;m=m+1|0;f=f<<1}if((m|0)>=0){while(1){f=y[t|0]<<m|f;c=m>>>0>7;m=m-8|0;t=t+1|0;if(c){continue}break}}i=i+16|0;continue}break}x[H+4>>2]=G;j=j+1|0;if((N|0)!=(j|0)){continue}break}}c=y[a+6155|0];x:{if(c&16){G=hb-16|0;hb=G;c=H+2940|0;g=c+2304|0;s=x[K>>2];h=y[K+14|0];k=y[K+13|0];r=h+k|0;f=0;o=G+4|0;x[o+8>>2]=-1;x[o>>2]=-1;x[o+4>>2]=-1;if(r){while(1){j=0;l=f+s|0;i=y[l|0];y:{if(!i){break y}z:{while(1){p=j<<2;if(B[p+g>>2]!=E(0)|B[(p|4)+g>>2]!=E(0)){break z}j=j+2|0;if(i>>>0>j>>>0){continue}break}j=i;break y}x[o+((f>>>0)%3<<2)>>2]=f;j=y[l|0]}g=((j&255)<<2)+g|0;f=f+1|0;if((r|0)!=(f|0)){continue}break}}if(k){g=x[G+4>>2];f=x[G+8>>2];g=(f|0)<(g|0)?g:f;f=x[G+12>>2];f=(f|0)<(g|0)?g:f;x[G+12>>2]=f;x[G+8>>2]=f;x[G+4>>2]=f}g=H+16195|0;s=a+6152|0;p=h?3:1;i=r-p|0;h=0;while(1){j=h+i|0;f=j-p|0;if((f|0)<=x[(G+4|0)+(h<<2)>>2]){f=y[s+1|0]<<28>>31&3}else{f=y[f+g|0]}v[g+j|0]=f;h=h+1|0;if((p|0)!=(h|0)){continue}break}k=w[K+36>>1]&1;q=0;j=x[K>>2];m=y[j|0];if(m){l=G+4|0;p=y[s+1|0]&8?7:64;f=j;while(1){h=y[s+3|0]&32;A:{B:{if(x[l+((q>>>0)%3<<2)>>2]>=(q|0)){break B}i=y[g+q|0];if(i>>>0>=p>>>0){break B}C:{if(y[s+1|0]&8){i=(i<<3)+45568|0;A=B[i>>2];O=B[i+4>>2];break C}I=ax(E(1),i+1>>>1<<k);i=i&1;O=i?E(1):I;A=i?I:E(1)}t=0;if(m){I=h?E(1.4142135381698608):E(1);P=E(A*I);I=E(O*I);while(1){i=(t<<2)+c|0;O=B[i>>2];B[i+2304>>2]=O*I;B[i>>2]=O*P;t=t+1|0;if((t|0)!=(m|0)){continue}break}}break A}if(!h){break A}xH(c,m)}c=(y[f|0]<<2)+c|0;q=q+1|0;f=j+q|0;m=y[f|0];if(m){continue}break}}hb=G+16|0;break x}if((c&224)!=96){break x}xH(H+2940|0,576)}if((N|0)>0){p=H+7708|0;j=0;while(1){c=y[a+6153|0];r=(y[K+12|0]!=0)<<1<<((D((c>>>3&1)+(c>>>4&1)|0,3)+(y[a+6154|0]>>>2&3)|0)==2);i=(H+D(j,2304)|0)+2940|0;k=i;if(y[K+14|0]){g=((H+D(j,2304)|0)+D(r,72)|0)+2940|0;f=p;Q=x[K>>2]+y[K+13|0]|0;h=y[Q|0];if(h){c=g;while(1){s=h<<1;t=0;while(1){B[f>>2]=B[c>>2];B[f+4>>2]=B[(h<<2)+c>>2];l=s<<2;B[f+8>>2]=B[l+c>>2];c=c+4|0;f=f+12|0;t=t+1|0;if((t|0)!=(h|0)){continue}break}c=c+l|0;h=y[Q+3|0];Q=Q+3|0;if(h){continue}break}}sc(g,p,f-p|0);f=r-1|0}else{f=31}if((f|0)>0){while(1){h=0;while(1){c=h<<2;g=c+k|0;c=c+45632|0;A=B[c>>2];O=B[g+72>>2];P=B[c+32>>2];c=(17-h<<2)+k|0;I=B[c>>2];B[g+72>>2]=E(A*O)-E(P*I);B[c>>2]=E(P*O)+E(A*I);h=h+1|0;if((h|0)!=8){continue}break}k=k+72|0;c=(f|0)>1;f=f-1|0;if(c){continue}break}}c=i;f=D(j,1152)+a|0;g=y[K+11|0];if(r){wH(c,f,45696,r);f=D(r,36)+f|0;c=D(r,72)+c|0}D:{if((g|0)==2){o=hb-80|0;hb=o;k=32-r|0;if((k|0)>0){s=o|8;h=o|4;while(1){l=sc(o,c,72);g=x[f+20>>2];x[c+16>>2]=x[f+16>>2];x[c+20>>2]=g;g=x[f+12>>2];x[c+8>>2]=x[f+8>>2];x[c+12>>2]=g;g=x[f+4>>2];x[c>>2]=x[f>>2];x[c+4>>2]=g;g=f+24|0;_w(l,c+24|0,g);_w(h,c+48|0,g);_w(s,f,g);c=c+72|0;f=f+36|0;g=k>>>0>1;k=k-1|0;if(g){continue}break}}hb=o+80|0;break D}wH(c,f,D((g|0)==3,72)+45696|0,32-r|0)}f=0;q=i+72|0;while(1){c=1;while(1){g=(c<<2)+q|0;B[g>>2]=-B[g>>2];g=c>>>0<16;c=c+2|0;if(g){continue}break}q=q+144|0;c=f>>>0<30;f=f+2|0;if(c){continue}break}K=K+28|0;j=j+1|0;if((N|0)!=(j|0)){continue}break}}zH(W,Z,18,x[e+8>>2],d,X);if(!(y[u+1|0]&8)){break p}f=x[e+8>>2];d=D(f,1152)+d|0;c=b&1;b=0;j=1;if(c){continue}break}}e=n+912|0;c=x[e+8>>2]>>>3|0;b=x[e+4>>2]+7>>>3|0;f=c-b|0;d=(f|0)>=511?511:f;if((f|0)>0){Bg(a+6156|0,(e+(f>>>0>511?c-511|0:b)|0)+12|0,d)}x[a+6144>>2]=d;break j}ex(a);break a}h=n+17152|0;g=0;f=0;q=0;E:{F:{G:{b=y[u+3|0];c=b>>>6|0;switch(c-1|0){case 2:break E;case 0:break G;default:break F}}f=(b>>>2&12)+4|0;break E}f=32}b=y[u+1|0];H:{if((b&6)==6){c=47100;b=32;break H}if(!(b&8)){c=47103;b=30;break H}j=y[u+2|0]>>>2&3;b=cx(u)>>>((c|0)!=3)|0;b=b?b:192;if(b>>>0<=55){c=47124;b=(j|0)==2?12:8;break H}c=47112;b=b>>>0<=95?27:(j|0)!=1?30:27}v[n+768|0]=b;v[n+769|0]=(b|0)>(f|0)?f:b;b=c;I:{if(!y[n+768|0]){b=0;break I}j=47008;while(1){if((g|0)==(q|0)){j=y[b|0]+47008|0;q=y[b+2|0]+q|0;m=y[b+1|0];b=b+3|0}i=g<<1;f=y[Sd(h,m)+j|0];v[(i+n|0)+770|0]=f;c=y[n+769|0];if(g>>>0<c>>>0){f=y[Sd(h,m)+j|0];c=y[n+769|0]}v[((i|1)+n|0)+770|0]=c?f:0;f=y[n+768|0];g=g+1|0;if(f>>>0>g>>>0){continue}break}if(!f){b=f<<1;break I}g=0;while(1){c=g+n|0;J:{if(!y[c+770|0]){b=6;break J}b=2;if((y[u+1|0]&6)==6){break J}b=Sd(h,2);f=y[n+768|0]}v[c+834|0]=b;b=f<<1&510;g=g+1|0;if(b>>>0>g>>>0){continue}break}}f=n+770|0;c=n;j=0;if((b|0)>0){l=n+834|0;while(1){g=y[f|0];i=g?19>>>y[j+l|0]&3|4:0;f=f+1|0;N=D(g,3)-6|0;g=4;A=E(0);while(1){if(g&i){p=Sd(h,6);k=(p|0)/3|0;A=E(B[(N+(p-D(k,3)|0)<<2)+47136>>2]*E(2097152>>>k|0))}B[c>>2]=A;c=c+4|0;p=g>>>0>1;g=g>>>1|0;if(p){continue}break}j=j+1|0;if((j|0)!=(b|0)){continue}break}}g=y[n+769|0];b=y[n+768|0];if(g>>>0<b>>>0){while(1){v[((g<<1)+n|0)+771|0]=0;g=g+1|0;if(b>>>0>g>>>0){continue}break}}j=0;i=Sb(n+3852|0,0,4608);k=a+2304|0;l=n+8620|0;c=0;K:{while(1){N=i+(c<<2)|0;o=n+17152|0;r=x[e+16>>2]|1;m=0;f=y[n+768|0];b=576;while(1){L:{if(!(f&255)){f=0;break L}q=N+(D(m,r)<<2)|0;h=0;while(1){g=b;p=y[(h+n|0)+770|0];M:{if(!p){break M}if(p>>>0<=16){if((r|0)<=0){break M}f=(-1<<p-1)+1|0;b=0;while(1){_=(b<<2)+q|0,aa=E(Sd(o,p)+f|0),B[_>>2]=aa;b=b+1|0;if((r|0)!=(b|0)){continue}break}break M}f=2<<p-17;b=Sd(o,(f-(f>>>3|0)|0)+3|0);if((r|0)<=0){break M}s=f|1;p=f>>>1|0;f=0;while(1){T=b;b=(b>>>0)/(s>>>0)|0;B[(f<<2)+q>>2]=(T-D(s,b)|0)-p|0;f=f+1|0;if((r|0)!=(f|0)){continue}break}}b=18-g|0;q=(g<<2)+q|0;h=h+1|0;f=y[n+768|0];if(h>>>0<f<<1>>>0){continue}break}}m=m+1|0;if((m|0)!=4){continue}break}c=(r<<2)+c|0;if((c|0)==12){c=(j<<2)+n|0;b=i;g=y[n+769|0];f=b+D(g,72)|0;sc(f+2304|0,f,D(y[n+768|0]-g|0,72));if(y[n+768|0]){f=0;while(1){h=0;while(1){g=(h<<2)+b|0;B[g>>2]=B[g>>2]*B[c>>2];g=g+2304|0;B[g>>2]=B[g>>2]*B[c+12>>2];h=h+1|0;if((h|0)!=12){continue}break}c=c+24|0;b=b+72|0;f=f+1|0;if(f>>>0<y[n+768|0]){continue}break}}zH(k,i,12,x[e+8>>2],d,l);Sb(i,0,4608);d=D(x[e+8>>2],768)+d|0;c=0}if(x[n+17156>>2]<=x[n+17160>>2]){j=j+1|0;if((j|0)==3){break K}continue}break}ex(a);f=0;break a}U=1}f=D(bx(a+6152|0),U)}hb=n+17168|0;return f|0}function v4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=hb-32|0;hb=g;a:{b:{c:{d:{e:{f:{if(Td(b,17386)){Wb(a);break f}if(Td(b,5867)){b=hb-128|0;hb=b;d=Wb(a);x[114414]=0;W(204,b+96|0);a=x[114414];x[114414]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){x[114414]=0;x[b+64>>2]=0;P(2151,b+80|0,b- -64|0);a=x[114414];x[114414]=0;if((a|0)==1){break p}x[114414]=0;O(1251,d|0,b+80|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break o}xb(b+80|0);x[114414]=0;O(2029,d|0,12715)|0;a=x[114414];x[114414]=0;q:{if((a|0)==1){break q}x[114414]=0;x[b+64>>2]=5;P(2151,b+80|0,b- -64|0);a=x[114414];x[114414]=0;if((a|0)==1){break n}x[114414]=0;O(1251,d|0,b+80|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break m}xb(b+80|0);x[114414]=0;O(2029,d|0,12715)|0;a=x[114414];x[114414]=0;if((a|0)==1){break q}x[114414]=0;x[b+64>>2]=22;P(2151,b+80|0,b- -64|0);a=x[114414];x[114414]=0;if((a|0)==1){break l}x[114414]=0;O(1251,d|0,b+80|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break k}a=b+80|0;xb(a);x[114414]=0;a=O(118,a|0,17386)|0;c=x[114414];x[114414]=0;if((c|0)==1){break j}c=Bb(a);xb(a);if(!c){break i}x[114414]=0;O(2029,d|0,17386)|0;a=x[114414];x[114414]=0;if((a|0)!=1){break i}}a=N()|0;break h}a=N()|0;break c}a=N()|0;break h}a=N()|0;xb(b+80|0);break h}a=N()|0;break h}a=N()|0;xb(b+80|0);break h}a=N()|0;break h}a=N()|0;xb(b+80|0);break h}a=N()|0;break h}c=oh(b- -64|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(x[b+108>>2]){a=x[b+108>>2];x[114414]=0;x[b+16>>2]=a;P(2151,b+32|0,b+16|0);a=x[114414];x[114414]=0;if((a|0)==1){break D}x[114414]=0;T(2152,b+48|0,5085,b+32|0);a=x[114414];x[114414]=0;if((a|0)==1){break C}x[114414]=0;P(1547,c|0,b+48|0);a=x[114414];x[114414]=0;if((a|0)==1){break B}xb(b+48|0);xb(b+32|0)}if(!y[b+112|0]){break x}x[114414]=0;f=O(118,b+48|0,8610)|0;a=x[114414];x[114414]=0;if((a|0)==1){break z}x[114414]=0;P(1547,c|0,f|0);a=x[114414];x[114414]=0;if((a|0)==1){break y}xb(f);break w}a=N()|0;break r}a=N()|0;break A}a=N()|0;xb(b+48|0)}xb(b+32|0);break r}a=N()|0;break r}a=N()|0;xb(f);break r}if(!y[b+113|0]){break w}x[114414]=0;f=O(118,b+48|0,8356)|0;a=x[114414];x[114414]=0;if((a|0)==1){break v}x[114414]=0;P(1547,c|0,f|0);a=x[114414];x[114414]=0;if((a|0)==1){break u}xb(f)}if(y[b+114|0]){break t}break s}a=N()|0;break r}a=N()|0;xb(f);break r}x[114414]=0;f=O(118,b+32|0,7007)|0;a=x[114414];x[114414]=0;E:{if((a|0)!=1){x[114414]=0;P(1547,c|0,f|0);a=x[114414];x[114414]=0;if((a|0)==1){break E}xb(f);break s}a=N()|0;break r}a=N()|0;xb(f);break r}if(od(c)){break g}x[114414]=0;O(2029,d|0,12745)|0;a=x[114414];x[114414]=0;if((a|0)!=1){x[114414]=0;f=O(118,b|0,12715)|0;a=x[114414];x[114414]=0;F:{G:{H:{if((a|0)!=1){x[114414]=0;T(2153,b+16|0,c|0,f|0);a=x[114414];x[114414]=0;if((a|0)==1){break H}x[114414]=0;O(1251,d|0,b+16|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break G}xb(b+16|0);xb(f);break g}a=N()|0;break r}a=N()|0;break F}a=N()|0;xb(b+16|0)}xb(f);break r}a=N()|0}qd(c)}ef(b+96|0);break c}qd(c);ef(b+96|0);hb=b+128|0;break f}if(Td(b,4337)){x[g>>2]=0;As(a,g);break f}if(Td(b,4315)){x[g>>2]=5;As(a,g);break f}if(Td(b,6793)){x[g>>2]=22;As(a,g);break f}if(Td(b,6577)){c=hb-16|0;hb=c;b=hb-16|0;hb=b;x[b+12>>2]=17386;Ub(a,x[b+12>>2]);hb=b+16|0;hb=c+16|0;break f}if(Td(b,7283)){b=Ub(g,17386);c=Bb(b);x[114414]=0;O(118,a|0,(c?11801:11563)|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break e}xb(b);break f}if(Td(b,3624)){b=hb-48|0;hb=b;AD(b+16|0);x[114414]=0;c=O(2,b|0,17365)|0;d=x[114414];x[114414]=0;I:{J:{K:{L:{if((d|0)!=1){x[114414]=0;T(219,b+32|0,b+16|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break L}x[114414]=0;T(9,a|0,0,b+32|0);a=x[114414];x[114414]=0;if((a|0)==1){break K}xb(b+32|0);xb(c);xb(b+16|0);hb=b+48|0;break f}a=N()|0;break I}a=N()|0;break J}a=N()|0;xb(b+32|0)}xb(c)}xb(b+16|0);break a}if(Td(b,5895)){b=hb-16|0;hb=b;h=hb-16|0;hb=h;x[h+8>>2]=53;c=hb-176|0;hb=c;f=qw(c+160|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{d=x[h+8>>2];if(d&1){x[114414]=0;x[c+144>>2]=19469590;P(210,c+96|0,c+144|0);d=x[114414];x[114414]=0;if((d|0)==1){break $}x[114414]=0;P(166,f|0,c+96|0);d=x[114414];x[114414]=0;if((d|0)==1){break _}xb(c+96|0);d=x[h+8>>2]}if(!(d&4)){break Y}x[114414]=0;d=$(211)|0;e=x[114414];x[114414]=0;if((e|0)==1){break X}if(!d){break Z}break Y}a=N()|0;break N}a=N()|0;xb(c+96|0);break N}x[114414]=0;W(212,c+96|0);d=x[114414];x[114414]=0;aa:{if((d|0)!=1){x[114414]=0;P(166,f|0,c+96|0);d=x[114414];x[114414]=0;if((d|0)==1){break aa}xb(c+96|0);break Y}a=N()|0;break N}a=N()|0;xb(c+96|0);break N}ba:{d=x[h+8>>2];if(!(d&8)){break ba}x[114414]=0;d=O(2,c+128|0,2508)|0;e=x[114414];x[114414]=0;ca:{da:{ea:{fa:{ga:{if((e|0)!=1){x[114414]=0;P(187,c+144|0,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break ga}x[114414]=0;T(213,c+96|0,c+144|0,22724);e=x[114414];x[114414]=0;if((e|0)==1){break fa}x[114414]=0;P(166,f|0,c+96|0);e=x[114414];x[114414]=0;if((e|0)==1){break ea}xb(c+96|0);Gb(c+144|0);xb(d);d=x[h+8>>2];break ba}a=N()|0;break N}a=N()|0;break ca}a=N()|0;break da}a=N()|0;xb(c+96|0)}Gb(c+144|0)}xb(d);break N}ha:{if(!(d&16)){break ha}x[114414]=0;W(204,c+96|0);d=x[114414];x[114414]=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{if((d|0)!=1){x[114414]=0;P(214,c+144|0,c+96|0);d=x[114414];x[114414]=0;if((d|0)==1){break ja}d=c+144|0;e=Wc(d);xb(d);if(!e){x[114414]=0;d=O(2,c- -64|0,11561)|0;e=x[114414];x[114414]=0;if((e|0)==1){break Ga}x[114414]=0;P(187,c+80|0,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break Fa}x[114414]=0;P(214,c+48|0,c+96|0);e=x[114414];x[114414]=0;if((e|0)==1){break Ea}x[114414]=0;T(215,c+144|0,c+80|0,c+48|0);e=x[114414];x[114414]=0;if((e|0)==1){break Da}x[114414]=0;P(166,f|0,c+144|0);e=x[114414];x[114414]=0;if((e|0)==1){break Ca}xb(c+144|0);xb(c+48|0);Gb(c+80|0);xb(d)}if(!Wc(ah(c+96|0))){x[114414]=0;d=O(2,c+32|0,13159)|0;e=x[114414];x[114414]=0;if((e|0)==1){break ya}x[114414]=0;P(187,c+80|0,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break xa}e=ah(c+96|0);x[114414]=0;T(215,c+144|0,c+80|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break wa}x[114414]=0;P(166,f|0,c+144|0);e=x[114414];x[114414]=0;if((e|0)==1){break va}xb(c+144|0);Gb(c+80|0);xb(d)}x[114414]=0;P(216,c+144|0,c+96|0);d=x[114414];x[114414]=0;if((d|0)==1){break sa}d=c+144|0;e=Wc(d);xb(d);if(!e){x[114414]=0;d=O(2,c+16|0,11561)|0;e=x[114414];x[114414]=0;if((e|0)==1){break ra}x[114414]=0;P(187,c+80|0,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break qa}x[114414]=0;P(216,c+48|0,c+96|0);e=x[114414];x[114414]=0;if((e|0)==1){break pa}x[114414]=0;T(215,c+144|0,c+80|0,c+48|0);e=x[114414];x[114414]=0;if((e|0)==1){break oa}x[114414]=0;P(166,f|0,c+144|0);e=x[114414];x[114414]=0;if((e|0)==1){break na}xb(c+144|0);xb(c+48|0);Gb(c+80|0);xb(d)}ef(c+96|0);d=x[h+8>>2];break ha}a=N()|0;break N}a=N()|0;break ia}a=N()|0;break za}a=N()|0;break Aa}a=N()|0;break Ba}a=N()|0;xb(c+144|0)}xb(c+48|0)}Gb(c+80|0)}xb(d);break ia}a=N()|0;break ia}a=N()|0;break ta}a=N()|0;break ua}a=N()|0;xb(c+144|0)}Gb(c+80|0)}xb(d);break ia}a=N()|0;break ia}a=N()|0;break ia}a=N()|0;break ka}a=N()|0;break la}a=N()|0;break ma}a=N()|0;xb(c+144|0)}xb(c+48|0)}Gb(c+80|0)}xb(d);break ia}a=N()|0}ef(c+96|0);break N}Ha:{if(!(d&32)){break Ha}x[114414]=0;d=$(211)|0;e=x[114414];x[114414]=0;if((e|0)==1){break X}if(d){break Ha}d=c+96|0;hd(d);x[114414]=0;P(166,f|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break O}xb(c+96|0)}if(y[h+8|0]&64){x[114414]=0;W(217,c+96|0);d=x[114414];x[114414]=0;if((d|0)==1){break W}x[114414]=0;P(166,f|0,c+96|0);d=x[114414];x[114414]=0;if((d|0)==1){break V}xb(c+96|0)}x[114414]=0;d=O(2,c+96|0,17386)|0;e=x[114414];x[114414]=0;if((e|0)==1){break U}x[114414]=0;T(218,c|0,f|0,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break T}x[114414]=0;e=O(2,c+144|0,17365)|0;i=x[114414];x[114414]=0;if((i|0)==1){break S}x[114414]=0;T(219,b|0,c|0,e|0);i=x[114414];x[114414]=0;if((i|0)==1){break R}xb(e);xb(c);xb(d);vl(f);hb=c+176|0;break M}a=N()|0;break N}a=N()|0;break N}a=N()|0;xb(c+96|0);break N}a=N()|0;break N}a=N()|0;break P}a=N()|0;break Q}a=N()|0;xb(e)}xb(c)}xb(d);break N}a=N()|0;xb(c+96|0)}vl(f);break a}hb=h+16|0;x[114414]=0;T(9,a|0,0,b|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break b}if(Td(b,6506)){b=hb-48|0;hb=b;jr(b);x[114414]=0;P(214,b+32|0,b|0);c=x[114414];x[114414]=0;Ia:{Ja:{if((c|0)!=1){x[114414]=0;T(9,a|0,0,b+32|0);a=x[114414];x[114414]=0;if((a|0)==1){break Ja}xb(b+32|0);ef(b);hb=b+48|0;break f}a=N()|0;break Ia}a=N()|0;xb(b+32|0)}ef(b);break a}if(Td(b,7246)){b=hb-32|0;hb=b;jr(b);c=ah(b);x[114414]=0;T(9,a|0,0,c|0);a=x[114414];x[114414]=0;if((a|0)!=1){ef(b);hb=b+32|0;break f}a=N()|0;ef(b);break a}if(Td(b,5908)){b=hb-48|0;hb=b;jr(b+16|0);Ka:{if(x[b+28>>2]){c=x[b+28>>2];x[114414]=0;x[b+12>>2]=c;P(2151,a|0,b+12|0);a=x[114414];x[114414]=0;if((a|0)!=1){break Ka}a=N()|0;ef(b+16|0);break a}Wb(a)}ef(b+16|0);hb=b+48|0;break f}if(Td(b,8600)){jr(g);b=y[g+16|0];x[114414]=0;O(118,a|0,(b?11563:11801)|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){ef(g);break f}a=N()|0;ef(g);break a}if(Td(b,5924)){jr(g);b=y[g+17|0];x[114414]=0;O(118,a|0,(b?11563:11801)|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){ef(g);break f}a=N()|0;ef(g);break a}if(Td(b,8047)){jr(g);b=y[g+18|0];x[114414]=0;O(118,a|0,(b?11563:11801)|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){ef(g);break f}a=N()|0;ef(g);break a}if(Td(b,8330)){b=hb-16|0;hb=b;c=hb-32|0;hb=c;d=hd(b);x[114414]=0;W(204,c|0);f=x[114414];x[114414]=0;La:{Ma:{Na:{if((f|0)!=1){f=ah(c);x[114414]=0;O(205,d|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break Na}ef(c);hb=c+32|0;break La}a=N()|0;break Ma}a=N()|0;ef(c)}xb(d);break a}x[114414]=0;T(9,a|0,0,b|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break b}if(Td(b,4458)){b=hb-16|0;hb=b;c=hb+-64|0;hb=c;f=hd(b);x[114414]=0;d=O(2,c+16|0,10557)|0;h=x[114414];x[114414]=0;Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((h|0)!=1){x[114414]=0;P(187,c+32|0,d|0);h=x[114414];x[114414]=0;if((h|0)==1){break Ua}x[114414]=0;x[c+12>>2]=17;x[c+8>>2]=0;x[c+4>>2]=0;ba(207,c+48|0,c+32|0,c+12|0,c+8|0,c+4|0);h=x[114414];x[114414]=0;if((h|0)==1){break Ta}x[114414]=0;O(160,f|0,c+48|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break Sa}xb(c+48|0);Gb(c+32|0);xb(d);hb=c- -64|0;break Oa}a=N()|0;break Pa}a=N()|0;break Qa}a=N()|0;break Ra}a=N()|0;xb(c+48|0)}Gb(c+32|0)}xb(d)}xb(f);break a}x[114414]=0;T(9,a|0,0,b|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break b}if(Td(b,3147)){b=hb-16|0;hb=b;Tn(b,0,15369);x[114414]=0;T(9,a|0,0,b|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break b}if(Td(b,2809)){b=hb-48|0;hb=b;d=Ub(b+16|0,13516);x[114414]=0;P(2154,b|0,2);c=x[114414];x[114414]=0;Va:{Wa:{Xa:{Ya:{if((c|0)!=1){x[114414]=0;T(3,b+32|0,d|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break Ya}x[114414]=0;T(9,a|0,0,b+32|0);a=x[114414];x[114414]=0;if((a|0)==1){break Xa}xb(b+32|0);xb(b);xb(d);hb=b+48|0;break f}a=N()|0;break Va}a=N()|0;break Wa}a=N()|0;xb(b+32|0)}xb(b)}break c}if(Td(b,7269)){b=hb-16|0;hb=b;Tn(b,0,13832);x[114414]=0;T(9,a|0,0,b|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break b}if(Td(b,6513)){b=hb-16|0;hb=b;hr(b,0);x[114414]=0;T(9,a|0,0,b|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break b}if(Td(b,6488)){b=hb-16|0;hb=b;hr(b,2);x[114414]=0;T(9,a|0,0,b|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break b}if(Td(b,6473)){b=hb-16|0;hb=b;hr(b,3);x[114414]=0;T(9,a|0,0,b|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(b);hb=b+16|0;break f}break b}Wb(a)}hb=g+32|0;break d}a=N()|0;xb(b);break a}return}xb(d);break a}a=N()|0;xb(b)}Q(a|0);p()}function nU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;f=hb-320|0;hb=f;Lc(b);a:{if(tB(b,13673)){o=Wb(f+304|0);x[114414]=0;e=U(379,b|0,o|0,-1)|0;g=x[114414];x[114414]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((g|0)!=1){if(!e){break b}x[114414]=0;e=O(395,b|0,f+296|0)|0;g=x[114414];x[114414]=0;s:{if((g|0)==1){break s}if(!e){break b}if(!sB(f+296|0)){break b}d=rB(f+296|0);x[114414]=0;d=_f(396,d,lb);e=x[114414];x[114414]=0;if((e|0)==1){break s}x[114414]=0;e=O(226,b|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break s}d=0;if(!e){break b}if(!c){break c}x[114414]=0;P(397,a|0,4096);d=x[114414];x[114414]=0;if((d|0)==1){break s}x[114414]=0;O(398,a+1304400|0,o|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break s}d=y[f+296|2];w[a+480188>>1]=32;w[a+480192>>1]=d;x[114414]=0;P(399,a|0,1);d=x[114414];x[114414]=0;if((d|0)==1){break s}x[114414]=0;d=O(2,f+280|0,5433)|0;e=x[114414];x[114414]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((e|0)!=1){Db(a+1304436|0,d);xb(d);x[114414]=0;d=O(2,f+264|0,3356)|0;e=x[114414];x[114414]=0;if((e|0)==1){break D}Db(a+1304448|0,d);xb(d);x[114414]=0;d=O(2,f+248|0,11064)|0;e=x[114414];x[114414]=0;if((e|0)==1){break C}x[114414]=0;P(187,f+48|0,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break B}v[f+216|0]=y[f+296|1];e=y[f+296|0];x[114414]=0;v[f+8|0]=e;P(400,f+232|0,f+8|0);e=x[114414];x[114414]=0;if((e|0)==1){break A}x[114414]=0;X(401,f+96|0,f+48|0,f+216|0,f+232|0);e=x[114414];x[114414]=0;if((e|0)==1){break z}e=f+96|0;Db(a+1304460|0,e);xb(e);xb(f+232|0);Gb(f+48|0);xb(d);x[a+1304496>>2]=4;if(y[f+296|0]<2){break u}x[114414]=0;w[f+96>>1]=8192;d=R(321,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break w}x[114414]=0;w[f+48>>1]=d;d=O(402,f+96|0,f+48|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break w}x[a+480204>>2]=D(z[d>>1],1e4)>>>8;x[114414]=0;v[f+96|0]=1;d=R(403,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break v}x[114414]=0;v[f+48|0]=d;d=O(404,f+96|0,f+48|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break v}x[a+480196>>2]=y[d|0];x[114414]=0;O(304,b|0,3)|0;d=x[114414];x[114414]=0;if((d|0)!=1){x[114414]=0;d=R(321,b|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){break t}}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}b=N()|0;break x}b=N()|0;break y}b=N()|0;xb(f+232|0)}Gb(f+48|0)}xb(d);break d}b=N()|0;break d}b=N()|0;break d}x[114414]=0;v[f+96|0]=32;d=R(403,b|0)|0;e=x[114414];x[114414]=0;E:{F:{if((e|0)==1){break F}x[114414]=0;v[f+48|0]=d;d=O(404,f+96|0,f+48|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break F}x[a+480204>>2]=D(y[d|0],1e4);x[114414]=0;v[f+96|0]=1;d=R(403,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break E}x[114414]=0;v[f+48|0]=d;d=O(404,f+96|0,f+48|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break E}x[a+480196>>2]=y[d|0];x[114414]=0;d=R(403,b|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){break t}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}x[a+480208>>2]=d>>>2&16|12;n=jm(f+232|0);l=jm(f+216|0);G:{H:{I:{J:{K:{L:{M:{if(!z[a+480192>>1]){break M}i=f+80|1;q=f+96|12;h=1;while(1){x[114414]=0;e=U(405,a|0,h&65535,0)|0;d=x[114414];x[114414]=0;N:{O:{P:{if((d|0)==1){break P}if(!e){break M}x[114414]=0;d=U(380,b|0,e+492|0,-1)|0;g=x[114414];x[114414]=0;if((g|0)==1){break P}if(!d){break M}x[114414]=0;j=R(403,b|0)|0;d=x[114414];x[114414]=0;Q:{R:{S:{T:{if((d|0)!=1){Sb(f+96|0,0,120);if(!j){break N}if(y[f+296|0]){x[114414]=0;d=O(406,b|0,f+96|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break T}if(!d){break N}}if(!y[f+296|0]){x[114414]=0;d=U(229,b|0,q|0,96)|0;g=x[114414];x[114414]=0;if((g|0)==1){break T}if(!d){break N}}g=e+236|0;d=0;while(1){k=y[(f+96|0)+d|0];m=z[a+480190>>1];s=fd(g,d),t=(k+m|0)+1|0,w[s>>1]=t;d=d+1|0;if((d|0)!=120){continue}break}x[114414]=0;d=e+48|0;T(407,f+8|0,d|0,b|0);g=x[114414];x[114414]=0;if((g|0)==1){break S}x[114414]=0;g=e+68|0;T(407,f+32|0,g|0,b|0);k=x[114414];x[114414]=0;if((k|0)==1){break S}x[114414]=0;k=e+88|0;T(407,f+88|0,k|0,b|0);m=x[114414];x[114414]=0;if((m|0)==1){break S}x[114414]=0;O(408,b|0,f+80|0)|0;m=x[114414];x[114414]=0;if((m|0)==1){break R}x[e>>2]=(y[i|0]|y[i+1|0]<<8)&4095;m=y[i|0]|y[i+1|0]<<8;e=f+80|0;Ju(e,d,0);Ju(e,g,1);Ju(e,k,2);s=f,t=bc(d),x[s+48>>2]=t;s=f,t=dc(d),x[s+72>>2]=t;if(Hb(f+48|0,f+72|0)){break Q}break O}b=N()|0;break e}b=N()|0;break e}b=N()|0;break e}b=N()|0;break e}while(1){U:{d=x[f+48>>2];v[f+68|0]=64;e=y[d+2|0];x[114414]=0;v[f+71|0]=((e<<6)- -64>>>0)/127;e=O(409,f+68|0,f+71|0)|0;r=x[114414];x[114414]=0;if((r|0)==1){break U}v[d+2|0]=y[e|0];d=f+48|0;fe(d);if(Hb(d,f+72|0)){continue}break O}break}b=N()|0;break e}b=N()|0;break e}s=f,t=bc(g),x[s+48>>2]=t;s=f,t=dc(g),x[s+72>>2]=t;V:{if(!Hb(f+48|0,f+72|0)){break V}while(1){W:{d=x[f+48>>2];v[f+68|0]=64;e=y[d+2|0];x[114414]=0;v[f+71|0]=((e<<6)+128>>>0)/255;e=O(409,f+68|0,f+71|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break W}v[d+2|0]=y[e|0];d=f+48|0;fe(d);if(Hb(d,f+72|0)){continue}break V}break}b=N()|0;break e}s=f,t=bc(k),x[s+48>>2]=t;s=f,t=dc(k),x[s+72>>2]=t;if(Hb(f+48|0,f+72|0)){g=1<<(m>>>12&3);while(1){k=x[f+48>>2];d=v[k+2|0];d=yna(d^-128,d>>31^-1,g,0);e=lb;X:{if((e|0)>=-1&d>>>0>=4294967292|(e|0)>=0){d=d+4|0;d=(((d>>>0<4?e+1|0:e)&7)<<29|d>>>3)&536870911;e=0;break X}e=0-((d>>>0>3)+e|0)|0;d=3-d|0;e=((e&7)<<29|d>>>3)&536870911;d=0-e|0;e=0-((e|0)!=0)|0}x[114414]=0;d=_f(410,d,e);e=x[114414];x[114414]=0;if((e|0)==1){break f}v[k+2|0]=d^128;d=f+48|0;fe(d);if(Hb(d,f+72|0)){continue}break}}w[f+68>>1]=z[a+480190>>1]+1;e=0;d=0;while(1){Y:{g=z[f+68>>1]+e|0;if(g>>>0>=4e3){x[114414]=0;O(304,b|0,20)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break Y}b=N()|0;break e}x[114414]=0;U(380,b|0,((g<<5)+a|0)+946304|0,-1)|0;g=x[114414];x[114414]=0;if((g|0)==1){break G}x[114414]=0;O(411,b|0,f+48|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break L}x[114414]=0;P(412,f+48|0,(D(z[f+68>>1]+e|0,104)+a|0)+484380|0);e=x[114414];x[114414]=0;if((e|0)==1){break L}e=y[f+80|0];g=y[f+67|0];x[114414]=0;w[f+72>>1]=e|d<<8&32512|((g&3)!=0)<<15;P(413,l|0,f+72|0);e=x[114414];x[114414]=0;if((e|0)==1){break K}d=d+1|0;e=d&65535;if(j>>>0>e>>>0){continue}}break}x[114414]=0;P(413,n|0,f+68|0);d=x[114414];x[114414]=0;if((d|0)==1){break g}x[f+48>>2]=3999;d=z[a+480190>>1];x[114414]=0;x[f+72>>2]=d+j;d=O(414,f+48|0,f+72|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break H}w[a+480190>>1]=x[d>>2]}h=h+1|0;if(z[a+480192>>1]>=(h&65535)>>>0){continue}break}}d=Wb(f+96|0);x[114414]=0;e=U(379,b|0,d|0,-1)|0;g=x[114414];x[114414]=0;if((g|0)==1){break n}if(e){x[114414]=0;T(13,f+48|0,6,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break n}e=f+48|0;Db(a+1304412|0,e);xb(e)}xb(d);e=0;while(1){x[114414]=0;d=(e<<5)+a|0;W(381,d+480280|0);g=x[114414];x[114414]=0;if((g|0)==1){break J}x[114414]=0;U(382,b|0,d+480289|0,-1)|0;d=x[114414];x[114414]=0;if((d|0)==1){break J}e=e+1|0;if((e|0)!=32){continue}break}x[114414]=0;d=O(415,b|0,f+32|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break l}if(!d){break i}if((y[f+32|0]|y[f+33|0]<<8|(y[f+34|0]<<16|y[f+35|0]<<24))>>>0<12){break m}d=y[f+32|0]|y[f+33|0]<<8|(y[f+34|0]<<16|y[f+35|0]<<24);x[114414]=0;d=O(226,b|0,d-11|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break l}if(d){break I}break m}b=N()|0;break e}b=N()|0;break e}b=N()|0;break e}x[f+88>>2]=(y[f+32|0]|y[f+33|0]<<8|(y[f+34|0]<<16|y[f+35|0]<<24))-11;i=Qq(f+96|0);x[114414]=0;U(385,b|0,i|0,x[f+88>>2])|0;d=x[114414];x[114414]=0;if((d|0)==1){break p}x[114414]=0;x[f+48>>2]=50529027;d=O(297,f+88|0,f+48|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break q}x[f+80>>2]=D(x[d>>2],85);g=Wb(f+48|0);d=f+32|4;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[114414]=0;x[f+8>>2]=d;d=O(297,f+80|0,f+8|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break r}d=x[d>>2];x[114414]=0;P(108,g|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break r}if(x[f+88>>2]){e=0;while(1){Z:{h=y[Bc(i,e)|0];d=e+1|0;if(!((h|0)!=255|x[f+88>>2]-d>>>0<2)){d=v[Bc(i,d)|0];h=y[Bc(i,e+2|0)|0];s=f,t=jf(g),x[s+8>>2]=t;j=x[td(f+24|0,f+8|0)>>2];x[114414]=0;Z(386,g|0,j|0,h|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){d=e+3|0;break Z}break r}x[114414]=0;P(107,g|0,h<<24>>24);e=x[114414];x[114414]=0;if((e|0)!=1){break Z}break r}e=d;if(A[f+88>>2]>d>>>0){continue}break}}x[114414]=0;X(387,f+8|0,4,6,g|0);d=x[114414];x[114414]=0;_:{if((d|0)!=1){d=f+8|0;Db(g,d);xb(d);d=Rb(g);x[114414]=0;d=R(388,d|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break _}e=Bb(g);x[114414]=0;aa(389,a+1304424|0,d|0,e|0,74,0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break _}xb(g);$d(i);break m}break r}break r}b=N()|0;break e}b=N()|0;break e}b=N()|0;break d}b=N()|0;break d}b=N()|0;xb(g);break o}b=N()|0;break o}b=N()|0}$d(i);break e}b=N()|0;xb(d);break e}d=Vb(a+484360|0);e=f+296|5;e=y[e|0]|y[e+1|0]<<8;x[114414]=0;aa(390,d|0,b|0,e|0,65535,65535)|0;d=x[114414];x[114414]=0;if((d|0)==1){break l}i=c&1;if(i){d=f+296|3;d=y[d|0]|y[d+1|0]<<8;x[114414]=0;P(362,a+484344|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break l}}d=f+296|3;if(!(y[d|0]|y[d+1|0]<<8)){break j}g=a+484344|0;e=0;while(1){x[114414]=0;h=O(226,b|0,4)|0;j=x[114414];x[114414]=0;$:{if((j|0)!=1){if(h){break $}break j}b=N()|0;break e}x[114414]=0;h=R(391,b|0)|0;j=x[114414];x[114414]=0;aa:{ba:{ca:{da:{if((j|0)!=1){x[114414]=0;T(307,f+96|0,b|0,h|0);h=x[114414];x[114414]=0;if((h|0)==1){break da}if(!i){break ba}x[114414]=0;h=R(403,f+96|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break aa}x[114414]=0;O(304,f+96|0,1)|0;j=x[114414];x[114414]=0;if((j|0)==1){break aa}x[114414]=0;h=U(363,g|0,e&65535,h+1|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break aa}if(!h){break ba}x[114414]=0;h=U(383,f+96|0,f+48|0,-1)|0;j=x[114414];x[114414]=0;if((j|0)==1){break k}if(!h){break ca}h=Zb(g,e);x[114414]=0;O(384,h|0,f+48|0)|0;h=x[114414];x[114414]=0;if((h|0)!=1){break ca}break k}b=N()|0;break e}b=N()|0;break e}h=Zb(g,e);x[114414]=0;T(393,h|0,1,f+96|0);h=x[114414];x[114414]=0;if((h|0)==1){break k}}Ab(f+96|0);e=e+1|0;if(e>>>0<(y[d|0]|y[d+1|0]<<8)>>>0){continue}break j}break}break k}b=N()|0;break e}b=N()|0;Ab(f+96|0);break e}if(!(c&2)){break i}ea:{if(!z[a+480190>>1]){break ea}d=0;while(1){fa:{if(y[uc(l,d)|0]){c=d+1|0}else{c=d+1|0;e=D(c,104)+a|0;d=ad(f+96|0,w[e+484414>>1]&1?16:8,1,0,w[uc(l,d)>>1]<0?6:0);x[114414]=0;U(361,d|0,e+484380|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break fa}}d=c;if(d>>>0<z[a+480190>>1]){continue}break ea}break}b=N()|0;break e}if(!z[a+480190>>1]){break i}b=0;while(1){c=y[uc(l,b)|0];ga:{if(!c){break ga}c=c-1&65535;if(qc(n)>>>0<=c>>>0){break ga}c=(y[uc(l,b)+1|0]&127)+z[uc(n,c)>>1]&65535;if(c>>>0>z[a+480190>>1]){break ga}e=D(c,104);g=e+a|0;d=g+484380|0;if(!Be(d)){break ga}i=a+484380|0;h=D(b+1|0,104);c=i+h|0;w[c+34>>1]=z[c+34>>1]&65534|w[(e+i|0)+34>>1]&1;x[c>>2]=x[d>>2];x[114414]=0;c=R(416,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break h}if(!c){break ga}c=x[(a+h|0)+484400>>2];x[114414]=0;c=R(417,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break a}e=x[g+484400>>2];x[114414]=0;e=R(417,e|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}sc(c,e,Kj(d))}b=b+1|0;if(b>>>0<z[a+480190>>1]){continue}break}}qf(l);qf(n);break c}b=N()|0;break e}b=N()|0;break e}b=N()|0}qf(l);qf(n)}xb(o);Q(b|0);p()}d=1}xb(o)}hb=f+320|0;return d|0}S(0)|0;zb();p()}function Gma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0;f=hb-176|0;hb=f;Lc(a);a:{b:{if(b>>>0<=2){b=f+168|0;C=b,E=pe(a),v[C|0]=E;cc(a,2);e=b|2;g=pg(a);v[e|0]=g;v[e+1|0]=g>>>8;b=b|4;e=Gf(a);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;break b}If(a,f+168|0);if(b>>>0>5){break a}}v[f+168|1]=0}c:{n=d+484344|0;b=f+168|2;s=Md(y[b|0]|y[b+1|0]<<8,1,1024);m=Qx(n,s,0);if((m|0)!=65535){g=mm(Zb(n,m),0);w[f+104>>1]=z[d+480188>>1]-1;w[f+88>>1]=y[f+168|0];t=z[Cf(f+104|0,f+88|0)>>1];e=t+1|0;if(z[d+480188>>1]>(e&65535)>>>0){b=e&65535;while(1){v[g+D(b,6)|0]=254;b=b+1|0;if(b>>>0<z[d+480188>>1]){continue}break}}v[c+13|0]=y[f+168|1]>>>4;b=y[c+12|0];v[f+104|0]=0;o=xu(f+152|0,e,f+104|0);if(s){b=(b|0)!=0;while(1){d:{e:{f:{if(!y[Bc(o,0)|0]){x[114414]=0;e=R(403,a|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break c}e=e<<24>>24;if((e|0)<0){x[114414]=0;g=R(403,a|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break c}C=Bc(o,0),E=g,v[C|0]=E}v[f+148|0]=0;g:{e=e&63;if(!e){break g}x[114414]=0;j=R(403,a|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break c}v[f+148|0]=j;h:{i:{switch(e-1|0){case 0:v[c+12|0]=0;x[114414]=0;v[f+144|0]=1;b=O(404,f+144|0,f+148|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){v[c+14|0]=y[b|0];v[c+15|0]=0;break h}break c;case 1:if(!j){break g}v[c+15|0]=j;v[c+12|0]=1;b=y[c+13|0];if(!b){break h}v[c+14|0]=D(D(b,j),15);break h;case 2:v[c+13|0]=j>>>4;if(j>>>0<16){break f}b=y[c+12|0];j=0;x[f+148>>2]=0;x[f+144>>2]=0;q=0;if(b){break e}break d;case 3:q=0;x[f+148>>2]=0;x[f+144>>2]=0;if(b&1){break e}break d;case 5:if(!j){break g}e=(y[c+12|0]?15:14)+c|0;b=y[e|0];v[e|0]=b>>>0>=256-j>>>0?-1:b+j|0;break h;case 6:break i;default:break g}}if(!j){break g}e=(y[c+12|0]?15:14)+c|0;b=y[e|0];v[e|0]=b>>>0<=j+1>>>0?1:b-j|0}j=0;x[f+148>>2]=0;x[f+144>>2]=0;break e}j=0;x[f+148>>2]=0;x[f+144>>2]=0;q=0;if(b&1){break e}break d}j=0;e=Bc(o,0);v[e|0]=y[e|0]-1;x[f+148>>2]=0;x[f+144>>2]=0;q=0;if(!(b&1)){break d}break e}j=0;v[c+12|0]=0;x[f+148>>2]=0;x[f+144>>2]=0;q=0;if(b&1){break e}break d}b=y[c+13|0];e=y[c+12|0];if(e){q=0;if(!b){break d}}j:{if(e){x[f+136>>2]=1;e=y[c+15|0];x[114414]=0;x[f+132>>2]=D(b,e)<<1;b=O(519,f+136|0,f+132|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break c}e=x[b>>2];break j}e=D(y[c+14|0],30)+30|0}b=255;k:{while(1){g=D(b,e);if(g-1536>>>0<10752){e=g;break k}g=b>>>0>1;b=b-1|0;if(g){continue}break}b=0}x[f+148>>2]=b;x[f+144>>2]=(e|0)/48;_d(f+144|0,32,255);x[114414]=0;x[f+136>>2]=1;b=O(519,f+136|0,f+148|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){v[c+16|0]=x[b>>2];q=1;break d}break c}b=Zb(n,m);x[114414]=0;b=U(427,b|0,l|0,1)|0;e=x[114414];x[114414]=0;if((e|0)==1){break c}if(t){u=l-1|0;g=1;r=1;while(1){l:{m:{n:{o:{if(!y[Bc(o,g)|0]){x[114414]=0;e=R(403,a|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break c}e=e<<24>>24;if((e|0)<0){x[114414]=0;h=R(403,a|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break c}C=Bc(o,g),E=h,v[C|0]=E}A=1;k=e&255;if(k&64){x[114414]=0;e=R(403,a|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break c}v[b+1|0]=e;A=!e}if(!(k&32)){break o}x[114414]=0;e=R(403,a|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break c}v[b|0]=e;if((e-1&255)>>>0<=107){e=wu(e+24|0);v[b|0]=e;C=Qc(c,g),E=e,v[C+1|0]=E;break o}if((e+127&255)>>>0<=107){e=wu((e&127)+24|0);v[b|0]=e;C=Qc(c,g),E=e,v[C|0]=E;v[b|0]=0;break n}if((e|0)!=255){break o}v[b|0]=254;break m}e=Bc(o,g);v[e|0]=y[e|0]-1;break l}if(y[b|0]){break m}}if(!y[b+1|0]){break m}e=y[Qc(c,g)+1|0];v[b+1|0]=0;v[b|0]=e}x[114414]=0;e=R(520,b|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break c}if(e){C=Qc(c,g),E=0,v[C+5|0]=E}v[f+131|0]=0;v[f+130|0]=0;v[f+129|0]=0;v[f+128|0]=0;v[f+127|0]=0;v[f+126|0]=0;if(k&16){v[b+2|0]=1;x[114414]=0;e=R(403,a|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break c}v[b+4|0]=e+2>>>2}p:{if(!(k&8)){break p}x[114414]=0;e=R(403,a|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break c}x[114414]=0;v[f+131|0]=e;e=R(403,a|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break c}v[f+128|0]=e;q:{r:{s:{t:{u:{v:{w:{x:{h=y[f+131|0];switch(h-1|0){case 0:break r;case 9:break s;case 5:case 6:case 7:case 8:break t;case 4:break u;case 3:break v;case 2:break w;case 1:break x;default:break q}}v[b|0]=255;break q}C=b,E=y[Qc(c,g)+1|0],v[C|0]=E;C=Qc(c,g),E=0,v[C+5|0]=E;break q}e=vu(e,y[c+16|0]);v[f+131|0]=e?20:0;v[f+128|0]=e?e|208:0;if(y[b|0]){break p}C=b,E=y[Qc(c,g)+1|0],v[C|0]=E;C=Qc(c,g),E=0,v[C+5|0]=E;break p}v[f+136|0]=1;e=vu(e,y[c+16|0]);x[114414]=0;v[f+132|0]=e;e=O(404,f+136|0,f+132|0)|0;h=x[114414];x[114414]=0;if((h|0)!=1){v[f+128|0]=y[e|0];v[f+131|0]=15;C=Qc(c,g),E=0,v[C+5|0]=E;break p}break c}y:{if(!l){break y}if((h|0)==y[Qc(c,g)+4|0]){break y}e=Zb(n,m);x[114414]=0;h=U(454,f+104|0,20,(y[f+131|0]+122|160)&255)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}h=Zn(Yn(Ie(h,u),r&65535));x[114414]=0;e=O(455,e|0,h|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break c}if(!e){break y}e=y[f+131|0];C=Qc(c,g),E=e,v[C+4|0]=E}v[f+131|0]=10;if(!y[b|0]){C=b,E=y[Qc(c,g)+1|0],v[C|0]=E}C=Qc(c,g),E=0,v[C+5|0]=E;break p}v[f+131|0]=20;C=f,E=y[Qc(c,g)+5|0]?-98:-97,v[C+128|0]=E;e=y[Qc(c,g)+5|0];C=Qc(c,g),E=e^1,v[C+5|0]=E;break p}v[b|0]=254}v[f+131|0]=0}h=0;e=0;z:{if(!(k&4)){break z}x[114414]=0;e=R(403,a|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}x[114414]=0;v[f+130|0]=e;e=R(403,a|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}e=e<<24>>24;v[f+127|0]=e;A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{i=y[f+130|0];switch(i-1|0){case 11:break C;case 10:break D;case 7:case 8:case 9:break E;case 6:break F;case 5:break G;case 3:case 4:break H;case 2:break I;case 1:break J;case 0:break K;default:break B}}i=(e|0)>=0;v[f+130|0]=i?2:3;if(!i){e=0-e|0;v[f+127|0]=e}L:{if((e&255)>>>0<16){break L}x[114414]=0;e=R(520,b|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}if(!e){break L}M:{if(y[f+130|0]==2){e=y[b|0];x[114414]=0;x[f+136>>2]=e+(y[f+127|0]>>>4|0);x[f+132>>2]=120;e=O(414,f+136|0,f+132|0)|0;i=x[114414];x[114414]=0;if((i|0)!=1){break M}break c}e=y[b|0];x[114414]=0;x[f+136>>2]=e-(y[f+127|0]>>>4|0);x[f+132>>2]=1;e=O(519,f+136|0,f+132|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}}v[b|0]=x[e>>2];v[f+127|0]=y[f+127|0]&15}x[114414]=0;v[f+136|0]=15;e=O(409,f+136|0,f+127|0)|0;i=x[114414];x[114414]=0;if((i|0)!=1){v[f+127|0]=y[e|0]|240;e=0;break z}break c}e=vu(e&255,y[c+16|0]);v[f+127|0]=e;if(e){v[f+130|0]=20;v[f+127|0]=e|208;e=1;break z}v[f+130|0]=0;e=1;break z}e=1;break A}i=y[c+16|0];x[114414]=0;e=U(521,e&255,i|0,1)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}v[f+127|0]=e;v[f+130|0]=y[f+130|0]==4?2:3;e=1;break z}if(!y[b|0]){C=b,E=y[Qc(c,g)|0],v[C|0]=E;e=y[f+127|0]}i=y[c+16|0];x[114414]=0;e=U(521,e&255,i|0,0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}v[f+130|0]=4;v[f+127|0]=e;e=1;break z}C=b,E=wu((e&255)+25|0),v[C|0]=E;v[f+127|0]=255;v[f+130|0]=4;e=1;break z}N:{if(!l){break N}if((i|0)==y[Qc(c,g)+2|0]){break N}e=Zb(n,m);x[114414]=0;i=U(454,f+88|0,20,(y[f+130|0]-8|48)&255)|0;B=x[114414];x[114414]=0;if((B|0)==1){break c}i=Zn(Yn(Ie(i,u),r&65535));x[114414]=0;e=O(455,e|0,i|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}if(!e){break N}e=y[f+130|0];C=Qc(c,g),E=e,v[C+2|0]=E}v[f+130|0]=5;e=y[c+16|0];x[114414]=0;e=O(522,y[f+127|0],e|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}v[f+127|0]=e;e=1;break z}e=AT(e&255,y[c+16|0]);v[f+130|0]=18;v[f+127|0]=e;e=1;break z}e=vu(e&255,y[c+16|0]);v[f+127|0]=e;if(e){v[f+130|0]=20;v[f+127|0]=e|192;e=1;break z}v[f+130|0]=0;v[b|0]=254;e=1;break z}e=0}v[f+130|0]=e}O:{if(!(k&2)){break O}x[114414]=0;k=R(403,a|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}x[114414]=0;v[f+129|0]=k;k=R(403,a|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}v[f+126|0]=k;P:{Q:{R:{S:{T:{U:{V:{i=y[f+129|0];switch(i-1|0){case 9:break Q;case 7:case 8:break R;case 6:break S;case 3:case 4:case 5:break T;case 2:break U;case 0:case 1:break V;default:break P}}g=y[c+16|0];x[114414]=0;g=U(523,k|0,g|0,(i|0)==1|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break c}v[f+129|0]=11;v[f+126|0]=g;h=1;break O}g=AT(k,y[c+16|0]);v[f+129|0]=18;v[f+126|0]=g;h=1;break O}W:{if(!l){break W}if((i|0)==y[Qc(c,g)+3|0]){break W}h=Zb(n,m);x[114414]=0;k=U(454,f+72|0,20,(y[f+129|0]-4|64)&255)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}k=Zn(Yn(Ie(k,u),r&65535));x[114414]=0;h=O(455,h|0,k|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break c}if(!h){break W}h=y[f+129|0];C=Qc(c,g),E=h,v[C+3|0]=E}v[f+129|0]=8;g=y[c+16|0];x[114414]=0;g=O(522,y[f+126|0],g|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break c}v[f+126|0]=g;h=1;break O}v[f+129|0]=9;break O}g=y[c+16|0];x[114414]=0;g=U(523,k|0,g|0,(i|0)==8|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break c}v[f+129|0]=29;v[f+126|0]=g;h=1;break O}v[f+129|0]=27;g=y[c+16|0];x[114414]=0;g=O(522,k|0,g|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break c}v[f+126|0]=g;h=1;break O}v[f+129|0]=0}if(e){zT(b,l,z[d+480188>>1],y[f+130|0],f+127|0)}if(h){zT(b,l,z[d+480188>>1],y[f+129|0],f+126|0)}X:{if(!A){break X}x[114414]=0;e=R(520,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break c}if(!e){break X}e=y[f+130|0];if(!e){v[f+127|0]=255;v[f+130|0]=4;break X}if(y[f+129|0]|(e|0)==4){break X}v[f+126|0]=255;v[f+129|0]=4}Y:{if(y[b+2|0]!=1){break Y}Z:{if(!y[f+130|0]){v[f+130|0]=13;v[f+127|0]=y[b+4|0];break Z}if(y[f+129|0]){break Y}v[f+129|0]=13;v[f+126|0]=y[b+4|0]}v[b+2|0]=0}x[114414]=0;ba(456,f+136|0,f+130|0,f+127|0,f+129|0,f+126|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}_:{if(y[b+2|0]){break _}e=y[f+130|0];if(!e){break _}v[b+2|0]=e;v[b+4|0]=y[f+127|0]}$:{if(y[f+131|0]){x[114414]=0;ba(456,f+136|0,f+129|0,f+126|0,f+131|0,f+128|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}aa:{if(y[b+2|0]){break aa}e=y[f+129|0];if(!e){break aa}v[b+2|0]=e;v[b+4|0]=y[f+126|0]}g=f+128|0;e=y[f+131|0];break $}g=f+126|0;e=y[f+129|0];if(!e){break l}}v[b+3|0]=e;v[b+5|0]=y[g|0]}b=b+6|0;r=r+1|0;g=r&65535;if(t>>>0>=g>>>0){continue}break}}ba:{if(!q){break ba}b=Zb(n,m);x[114414]=0;e=U(454,f+56|0,17,y[f+144|0])|0;g=x[114414];x[114414]=0;if((g|0)==1){break c}e=ai(Yn(Ie(e,l),0));x[114414]=0;O(455,b|0,e|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}b=Zb(n,m);x[114414]=0;e=U(454,f+40|0,16,y[f+148|0])|0;g=x[114414];x[114414]=0;if((g|0)!=1){e=ai(Ie(e,l));x[114414]=0;O(455,b|0,e|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break ba}}break c}ca:{if(j>>>0<16){break ca}b=Zb(n,m);x[114414]=0;e=U(454,f+24|0,20,j>>>4|224)|0;g=x[114414];x[114414]=0;if((g|0)!=1){e=yT(Ie(e,l));x[114414]=0;O(455,b|0,e|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break ca}}break c}da:{b=j&15;if(!b){break da}e=y[c+16|0];g=Zb(n,m);b=Md((D(b,e)>>>0)/15&255,1,15);x[114414]=0;b=U(454,f+8|0,20,b|96)|0;e=x[114414];x[114414]=0;if((e|0)!=1){b=yT(Ie(b,l));x[114414]=0;O(455,g|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break da}}break c}b=0;l=l+1|0;if((s|0)!=(l|0)){continue}break}}$d(o)}hb=f+176|0;return m|0}a=N()|0;$d(o);Q(a|0);p()}function r3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=hb-48|0;hb=f;e=Ub(f+32|0,7480);d=yf(c,e);xb(e);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(d){rj(a,0,x[b+24>>2]+1304448|0);break k}e=Ub(f+32|0,6945);d=yf(c,e);xb(e);if(d){rj(a,0,x[b+24>>2]+1304436|0);break k}e=Ub(f+32|0,7310);d=yf(c,e);xb(e);if(d){rj(a,0,x[b+24>>2]+1304484|0);break k}e=Ub(f+32|0,6937);d=yf(c,e);xb(e);if(d){rj(a,0,x[b+24>>2]+1304472|0);break k}e=Ub(f+32|0,4448);d=yf(c,e);xb(e);if(d){c=f+32|0;e=x[x[b+24>>2]+480184>>2];b=77744;l:{m:{while(1){if((e|0)==x[b>>2]){break m}b=b+12|0;if((b|0)!=77792){continue}break}hd(c);break l}Tn(c,0,x[b+8>>2])}x[114414]=0;T(9,a|0,0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break j}xb(f+32|0);break k}e=Ub(f+32|0,6922);d=yf(c,e);xb(e);if(d){g=f+32|0;j=x[x[b+24>>2]+480184>>2];e=hb+-64|0;hb=e;b=77744;i=hb-16|0;hb=i;h=i+8|0;d=hb-16|0;hb=d;x[114414]=0;c=e+48|0;R(1537,c+4|0)|0;k=x[114414];x[114414]=0;n:{o:{if((k|0)==1){break o}x[114414]=0;x[d+12>>2]=0;U(1538,c+8|0,d+12|0,h|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break o}r=c,s=mc(c),x[r>>2]=s;hb=d+16|0;break n}S(0)|0;zb();p()}hb=i+16|0;d=hd(g);while(1){if(x[b>>2]==(j|0)){x[114414]=0;i=O(2,e+32|0,x[b+4>>2])|0;h=x[114414];x[114414]=0;p:{q:{r:{s:{t:{u:{if((h|0)!=1){x[114414]=0;T(1536,e+24|0,c|0,i|0);h=x[114414];x[114414]=0;if((h|0)==1){break s}if(!y[e+28|0]){break p}if(!Wc(d)){x[114414]=0;h=O(2,e+8|0,13627)|0;k=x[114414];x[114414]=0;if((k|0)==1){break u}x[114414]=0;O(160,d|0,h|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break t}xb(h)}x[114414]=0;O(160,d|0,i|0)|0;h=x[114414];x[114414]=0;if((h|0)!=1){break p}b=N()|0;break r}b=N()|0;break q}b=N()|0;break r}b=N()|0;xb(h);break r}b=N()|0}xb(i)}xb(d);tL(c);Q(b|0);p()}xb(i)}b=b+12|0;if((b|0)!=77792){continue}break}tL(c);hb=e- -64|0;x[114414]=0;T(9,a|0,0,g|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(f+32|0);break k}c=N()|0;xb(f+32|0);break a}e=Ub(f+32|0,4514);d=yf(c,e);xb(e);if(d){rj(a,0,x[b+24>>2]+1304460|0);break k}e=Ub(f+32|0,2106);d=yf(c,e);xb(e);if(d){rj(a,0,x[b+24>>2]+1304412|0);break k}e=Ub(f+32|0,7848);d=yf(c,e);xb(e);if(d){c=f+32|0;Uf(c,x[b+24>>2]+1304400|0);x[114414]=0;T(2213,a|0,b|0,c|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(f+32|0);break k}c=N()|0;xb(f+32|0);break a}e=Ub(f+32|0,7253);d=yf(c,e);xb(e);if(d){v:{if(!od(ox(x[b+24>>2]))){if(x[uI(ox(x[b+24>>2]))+12>>2]){break v}}Wb(a);break k}b=uI(ox(x[b+24>>2]));j=hb-144|0;hb=j;sc(j+96|0,b,44);i=x[b+44>>2];if(i){sc(j+44|0,b,44);c=hb-16|0;hb=c;h=c+8|0;b=Dw(x[j+64>>2]+1900|0,x[j+60>>2]+1|0,x[j+56>>2])-Dw(1970,1,1)|0;b=yna(b,b>>31,86400,0);e=D(x[j+52>>2],3600);b=b+e|0;d=lb+(e>>31)|0;d=b>>>0<e>>>0?d+1|0:d;e=b;b=D(x[j+48>>2],60);g=b;e=e+b|0;b=(b>>31)+d|0;b=e>>>0<g>>>0?b+1|0:b;d=x[j+44>>2];g=d;e=d+e|0;d=(d>>31)+b|0;b=sG(h,e,e>>>0<g>>>0?d+1|0:d);e=x[b>>2];b=x[b+4>>2];hb=c+16|0;x[j+88>>2]=e;x[j+92>>2]=b;k=j+96|0;e=j+88|0;h=x[j+88>>2];d=x[j+92>>2];c=2147483647;m=Qd(+(i>>>0)*.054945054945054944);g=-1;w:{if(!(m<0x8000000000000000)){break w}c=-2147483648;g=0;if(!(m>-0x8000000000000000)){break w}if(F(m)<0x8000000000000000){c=F(m)>=1?~~(m>0?H(J(m*2.3283064365386963e-10),4294967295):K((m-+(~~m>>>0>>>0))*2.3283064365386963e-10))>>>0:0;g=~~m>>>0;break w}g=0}b=g;d=c+d|0;b=b+h|0;d=g>>>0>b>>>0?d+1|0:d;b=sG(e,b,d);c=hb-16|0;hb=c;h=x[b>>2];b=x[b+4>>2];o=b;x[c+12>>2]=0;x[c+8>>2]=0;x[c+4>>2]=0;i=Dw(1970,1,1)+zna(h,b,86400,0)|0;g=i>>31;e=yna(i,g,1e4,0);b=lb;e=e+14780|0;b=e>>>0<14780?b+1|0:b;l=zna(e,b,-14609700,-1);d=g+lb|0;l=i+l|0;d=l>>>0<i>>>0?d+1|0:d;n=zna(e,b,365242500,0);l=n+l|0;d=lb+d|0;d=l>>>0<n>>>0?d+1|0:d;n=zna(e,b,-146097e4,-1);l=n+l|0;d=lb+d|0;d=l>>>0<n>>>0?d+1|0:d;b=zna(e,b,3652425,0);e=lb;n=e;q=l;l=yna(b,e,-365,-1);e=q+l|0;d=lb+d|0;d=e>>>0<l>>>0?d+1|0:d;if(!((d|0)>0|(d|0)>=0)){e=b-1|0;b=yna(e,n-!b|0,-365,-1);d=g+lb|0;b=b+i|0;d=b>>>0<i>>>0?d+1|0:d;g=b;b=e;i=(b|0)/-4|0;e=g+i|0;d=(i>>31)+d|0;d=e>>>0<i>>>0?d+1|0:d;i=(b|0)/100|0;e=i+e|0;d=(i>>31)+d|0;d=e>>>0<i>>>0?d+1|0:d;i=(b|0)/-400|0;e=i+e|0;d=(i>>31)+d|0;d=e>>>0<i>>>0?d+1|0:d}i=b;d=yna(e,d,100,0);b=lb;d=d+52|0;b=d>>>0<52?b+1|0:b;g=i;b=zna(d,b,3060,0);d=b+2|0;i=(d|0)/12|0;x[c+12>>2]=g+i;x[c+8>>2]=(d-D(i,12)|0)+1;b=yna(b,lb,306,0);d=lb;b=b+5|0;d=b>>>0<5?d+1|0:d;b=zna(b,d,-10,-1)+e|0;x[c+4>>2]=b+1;pG(k);x[k+20>>2]=x[c+12>>2]-1900;x[k+16>>2]=x[c+8>>2]-1;b=x[c+4>>2];r=k,s=Ana(zna(h,o,3600,0),lb,24),x[r+8>>2]=s;x[k+12>>2]=b;b=zna(h,o,60,0);e=lb;r=k,s=Ana(b,e,60),x[r+4>>2]=s;r=k,s=h-yna(b,e,60,0)|0,x[r>>2]=s;hb=c+16|0}i=f+32|0;c=sc(j,j+96|0,44);b=hb-176|0;hb=b;e=hd(b+160|0);x[114414]=0;d=O(2,b+144|0,9325)|0;h=x[114414];x[114414]=0;x:{y:{z:{A:{B:{if((h|0)!=1){h=x[c+20>>2];if(!h){break y}x[114414]=0;x[b+112>>2]=h+1900;P(159,b+128|0,b+112|0);h=x[114414];x[114414]=0;if((h|0)!=1){x[114414]=0;O(160,e|0,b+128|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break B}xb(b+128|0);if(A[c+16>>2]>11){break y}x[114414]=0;h=O(2,b+112|0,12743)|0;g=x[114414];x[114414]=0;C:{D:{E:{F:{G:{H:{if((g|0)!=1){g=x[c+16>>2];x[114414]=0;x[b+80>>2]=g+1;P(161,b+96|0,b+80|0);g=x[114414];x[114414]=0;if((g|0)==1){break H}x[114414]=0;T(3,b+128|0,h|0,b+96|0);g=x[114414];x[114414]=0;if((g|0)==1){break G}x[114414]=0;O(160,e|0,b+128|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break F}xb(b+128|0);xb(b+96|0);xb(h);if(x[c+12>>2]-32>>>0>=4294967265){break C}break y}a=N()|0;break A}a=N()|0;break D}a=N()|0;break E}a=N()|0;xb(b+128|0)}xb(b+96|0)}xb(h);break A}x[114414]=0;h=O(2,b+96|0,12743)|0;g=x[114414];x[114414]=0;I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((g|0)!=1){x[114414]=0;P(161,b+80|0,c+12|0);g=x[114414];x[114414]=0;if((g|0)==1){break fa}x[114414]=0;T(3,b+128|0,h|0,b+80|0);g=x[114414];x[114414]=0;if((g|0)==1){break ea}x[114414]=0;O(160,e|0,b+128|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break da}xb(b+128|0);xb(b+80|0);xb(h);h=x[c+8>>2];g=x[c+4>>2];if(!(x[c>>2]|(h|g))|h>>>0>23|g>>>0>59){break y}x[114414]=0;h=O(2,b+128|0,9486)|0;g=x[114414];x[114414]=0;if((g|0)==1){break aa}x[114414]=0;O(160,e|0,h|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break $}xb(h);if(x[c+32>>2]>0){x[114414]=0;h=O(2,b+80|0,11629)|0;g=x[114414];x[114414]=0;if((g|0)==1){break _}Db(d,h);xb(h)}x[114414]=0;P(161,b+32|0,c+8|0);h=x[114414];x[114414]=0;if((h|0)==1){break Z}x[114414]=0;h=O(2,b+16|0,10181)|0;g=x[114414];x[114414]=0;if((g|0)==1){break Y}x[114414]=0;T(3,b+48|0,b+32|0,h|0);g=x[114414];x[114414]=0;if((g|0)==1){break X}x[114414]=0;P(161,b|0,c+4|0);g=x[114414];x[114414]=0;if((g|0)==1){break W}x[114414]=0;T(3,b- -64|0,b+48|0,b|0);g=x[114414];x[114414]=0;if((g|0)==1){break V}x[114414]=0;O(160,e|0,b- -64|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break U}xb(b- -64|0);xb(b);xb(b+48|0);xb(h);xb(b+32|0);if(A[c>>2]<62){break P}x[114414]=0;T(162,i|0,e|0,d|0);h=x[114414];x[114414]=0;if((h|0)==1){break O}break x}a=N()|0;break A}a=N()|0;break ba}a=N()|0;break ca}a=N()|0;xb(b+128|0)}xb(b+80|0)}xb(h);break A}a=N()|0;break A}a=N()|0;xb(h);break A}a=N()|0;break A}a=N()|0;break A}a=N()|0;break Q}a=N()|0;break R}a=N()|0;break S}a=N()|0;break T}a=N()|0;xb(b- -64|0)}xb(b)}xb(b+48|0)}xb(h)}xb(b+32|0);break A}x[114414]=0;h=O(2,b+48|0,10181)|0;g=x[114414];x[114414]=0;if((g|0)==1){break N}x[114414]=0;P(161,b+32|0,c|0);g=x[114414];x[114414]=0;if((g|0)==1){break M}x[114414]=0;T(3,b- -64|0,h|0,b+32|0);g=x[114414];x[114414]=0;if((g|0)==1){break L}x[114414]=0;O(160,e|0,b- -64|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break K}xb(b- -64|0);xb(b+32|0);xb(h);x[114414]=0;O(160,e|0,d|0)|0;h=x[114414];x[114414]=0;if((h|0)!=1){break y}}a=N()|0;break A}a=N()|0;break A}a=N()|0;break I}a=N()|0;break J}a=N()|0;xb(b- -64|0)}xb(b+32|0)}xb(h);break A}a=N()|0;break A}a=N()|0;break z}a=N()|0;xb(b+128|0)}xb(d)}xb(e);Q(a|0);p()}Jd(i,e)}xb(d);xb(e);hb=b+176|0;hb=c+144|0;x[114414]=0;T(9,a|0,0,i|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(f+32|0);break k}c=N()|0;xb(f+32|0);break a}e=Ub(f+32|0,8039);d=yf(c,e);xb(e);if(d){c=f+32|0;HO(c,x[b+24>>2]+1304424|0);ga:{ha:{ia:{if(!Wc(c)){break ia}c=x[b+24>>2];x[114414]=0;c=R(2214,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break ga}ja:{switch(c|0){case 0:x[114414]=0;P(2215,f+16|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){c=f+16|0;Db(f+32|0,c);xb(c);break ia}c=N()|0;break b;case 1:x[114414]=0;P(2216,f+16|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){c=f+16|0;Db(f+32|0,c);xb(c);break ia}c=N()|0;break b;case 2:if(Wc(f+32|0)){x[114414]=0;P(2215,f+16|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break i}c=f+16|0;Db(f+32|0,c);xb(c)}if(!Wc(f+32|0)){break ia}x[114414]=0;P(2216,f+16|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){c=f+16|0;Db(f+32|0,c);xb(c);break ia}c=N()|0;break b;case 3:if(Wc(f+32|0)){x[114414]=0;P(2216,f+16|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break h}c=f+16|0;Db(f+32|0,c);xb(c)}if(!Wc(f+32|0)){break ia}x[114414]=0;P(2215,f+16|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){c=f+16|0;Db(f+32|0,c);xb(c);break ia}c=N()|0;break b;case 4:x[114414]=0;P(2215,f+16|0,b|0);c=x[114414];x[114414]=0;ka:{la:{if((c|0)!=1){x[114414]=0;P(2216,f|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break ka}if(Wc(f+16|0)){break la}x[114414]=0;O(1251,f+32|0,f+16|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break la}break d}c=N()|0;break b}if(!Wc(f)){x[114414]=0;O(1251,f+32|0,f|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break d}}xb(f);xb(f+16|0);break ia}c=N()|0;break c;case 5:break ja;default:break ia}}x[114414]=0;P(2215,f+16|0,b|0);c=x[114414];x[114414]=0;ma:{if((c|0)!=1){x[114414]=0;P(2216,f|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break ha}if(Wc(f)){break ma}x[114414]=0;O(1251,f+32|0,f|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break ma}break f}c=N()|0;break b}if(!Wc(f+16|0)){x[114414]=0;O(1251,f+32|0,f+16|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}}xb(f);xb(f+16|0)}x[114414]=0;T(2213,a|0,b|0,f+32|0);a=x[114414];x[114414]=0;if((a|0)==1){break ga}xb(f+32|0);break k}c=N()|0;break e}c=N()|0;break b}e=Ub(f+32|0,1958);d=yf(c,e);xb(e);if(d){c=f+32|0;HO(c,x[b+24>>2]+1304424|0);x[114414]=0;T(2213,a|0,b|0,c|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(f+32|0);break k}c=N()|0;xb(f+32|0);break a}e=c;c=Ub(f+32|0,3559);e=yf(e,c);xb(c);if(e){a=Wb(a);b=b+68|0;r=f,s=bc(b),x[r+32>>2]=s;r=f,s=dc(b),x[r+16>>2]=s;if(!Hb(f+32|0,f+16|0)){break k}c=1;while(1){b=x[f+32>>2];if(!(c&1)){x[114414]=0;O(2029,a|0,17363)|0;c=x[114414];x[114414]=0;if((c|0)==1){break g}}x[114414]=0;O(1251,a|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break g}b=f+32|0;_j(b);c=0;if(Hb(b,f+16|0)){continue}break}break k}Ub(a,17386)}hb=f+48|0;return}c=N()|0;xb(f+32|0);break a}c=N()|0;break b}c=N()|0;break b}c=N()|0;xb(a);break a}c=N()|0;xb(f)}xb(f+16|0);break b}c=N()|0;xb(f)}xb(f+16|0)}xb(f+32|0)}Q(c|0);p()}function $U(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=yh(b,9630);a:{if(!l){break a}if(!Qb(b,6)){break a}while(1){b:{e=Gf(b);c:{if((e|0)==(Qj(9493)|0)){break c}d=y[17374]|y[17375]<<8|(y[17376]<<16|y[17377]<<24);if(!(e&1616928864)|e&-2139062144){break c}if((d|0)!=(e|0)){break b}}ng(b,4);break a}k=1;c=pg(b);if(z[a+480192>>1]){while(1){f=x[(((k&65535)<<2)+a|0)+900380>>2];if(f){d:{if((Qj(12699)|0)==(e|0)){cc(b,c);break d}d=0;g=hb-32|0;hb=g;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!f){break n}o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((e|0)<=1347628589){if((e|0)<=1297100333){if((e|0)<=1179931727){if((e|0)<=1145263149){if((e|0)==1095062094){break y}if((e|0)==1095126087){break v}if((e|0)!=1129524782|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+23|0]=n;d=1;break n}if((e|0)<=1179463213){if((e|0)==1145263150){break N}if((e|0)!=1145979182|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+18|0]=n;d=1;break n}if((e|0)==1179463214){break B}if((e|0)!=1179594286|c>>>0>4){break n}if(!Qb(b,c)){break n}m=f,n=_u(b,c),x[m>>2]=n;d=1;break n}if((e|0)<=1229345325){if((e|0)==1179931728){break o}if((e|0)==1196830254){break X}if((e|0)!=1229341486|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+21|0]=n;d=1;break n}if((e|0)<=1296182829){if((e|0)==1229345326){break K}if((e|0)!=1264266798|c>>>0>256){break n}h=f+236|0;Bd(g+16|0,b,c);while(1){x[114414]=0;i=R(338,g+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break F}m=fd(h,d),n=i,w[m>>1]=n;d=d+1|0;if(d>>>0<128){continue}break}Ab(g+16|0);d=1;break n}if((e|0)==1296182830){break J}if((e|0)!=1296248366|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+31|0]=n;d=1;break n}if((e|0)<=1346720333){if((e|0)<=1313692461){if((e|0)==1297100334){break I}if((e|0)==1297110852){break t}if((e|0)!=1298747438|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+34|0]=n;d=1;break n}if((e|0)<=1345203757){if((e|0)==1313692462){break G}if((e|0)!=1313751342|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+16|0]=n;d=1;break n}if((e|0)==1345203758){break W}if((e|0)!=1346711086){break n}x[g+16>>2]=240;m=g,n=no(b,c),x[m>>2]=n;Mg(f+68|0,x[Mb(g+16|0,g)>>2]);d=1;break n}if((e|0)<=1347179309){if((e|0)<=1346784326){if((e|0)==1346720334){break z}if((e|0)!=1346722606){break n}Bd(g+16|0,b,c);x[114414]=0;h=O(339,f|0,1)|0;i=x[114414];x[114414]=0;if((i|0)==1){break k}if(Lb(h)){while(1){x[114414]=0;i=R(340,g+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break k}m=Pb(h,d),n=i,v[m+2|0]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Ab(g+16|0);d=1;break n}if((e|0)==1346784327){break w}if((e|0)!=1347175726|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+82|0]=n;d=1;break n}if((e|0)<=1347441453){if((e|0)==1347179310){break T}if((e|0)!=1347437358|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+27|0]=n;d=1;break n}if((e|0)==1347441454){break H}if((e|0)!=1347443502){break n}Bd(g+16|0,b,c);x[114414]=0;h=O(339,f|0,1)|0;i=x[114414];x[114414]=0;if((i|0)==1){break h}if(Lb(h)){while(1){x[114414]=0;i=R(338,g+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break h}m=Pb(h,d),n=i,w[m>>1]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Ab(g+16|0);d=1;break n}if((e|0)<=1447374381){if((e|0)<=1349078084){if((e|0)<=1347831111){if((e|0)<=1347634477){if((e|0)==1347628590){break M}if((e|0)!=1347633710|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+83|0]=n;d=1;break n}if((e|0)==1347634478){break S}if((e|0)!=1347703884){break n}m=f,n=D(Zu(b,c),1e4)+(A[f+40>>2]%1e4|0)|0,x[m+40>>2]=n;d=1;break n}if((e|0)<=1349076269){if((e|0)==1347831112){break A}if((e|0)!=1347833672|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+36|0]=n;d=1;break n}if((e|0)==1349076270){break q}if((e|0)!=1349076315){break n}Bd(g+16|0,b,c);x[114414]=0;h=O(339,f|0,2)|0;i=x[114414];x[114414]=0;if((i|0)==1){break l}if(Lb(h)){while(1){x[114414]=0;i=R(340,g+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break l}m=Pb(h,d),n=i,v[m+2|0]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Ab(g+16|0);d=1;break n}if((e|0)<=1349079873){if((e|0)==1349078085){break Q}if((e|0)==1349078099){break R}if((e|0)!=1349079131){break n}Bd(g+16|0,b,c);x[114414]=0;h=O(339,f|0,2)|0;i=x[114414];x[114414]=0;if((i|0)==1){break i}if(Lb(h)){while(1){x[114414]=0;i=R(338,g+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break i}m=Pb(h,d),n=i,w[m>>1]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Ab(g+16|0);d=1;break n}Y:{switch(e-1349079874|0){case 1:case 2:break n;case 3:break O;case 0:break P;default:break Y}}if((e|0)==1378758190){break s}if((e|0)!=1381183022|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+24|0]=n;d=1;break n}if((e|0)<=1448226349){if((e|0)<=1447447622){if((e|0)==1447374382){break r}if((e|0)==1447383630){break x}if((e|0)!=1447385902){break n}Bd(g+16|0,b,c);x[114414]=0;h=O(339,f|0,0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break j}if(Lb(h)){while(1){x[114414]=0;i=R(340,g+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break j}m=Pb(h,d),n=i,v[m+2|0]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Ab(g+16|0);d=1;break n}if((e|0)<=1447842605){if((e|0)==1447447623){break u}if((e|0)!=1447839022|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+62|0]=n;d=1;break n}if((e|0)==1447842606){break V}if((e|0)!=1448106798){break n}Bd(g+16|0,b,c);x[114414]=0;h=O(339,f|0,0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break g}if(Lb(h)){while(1){x[114414]=0;i=R(338,g+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break g}m=Pb(h,d),n=i,w[m>>1]=n;d=d+1|0;if(Lb(h)>>>0>d>>>0){continue}break}}Ab(g+16|0);d=1;break n}if((e|0)<=1448297773){if((e|0)==1448226350){break C}if((e|0)==1448291886){break L}if((e|0)!=1448297006|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+63|0]=n;d=1;break n}if((e|0)<=1718508333){if((e|0)==1448297774){break U}if((e|0)!=1682320942|c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+15|0]=n;d=1;break n}if((e|0)==1718508334){break D}if((e|0)!=1851469358|c>>>0>32){break n}Bd(g+16|0,b,c);h=Wb(g);if(c){while(1){x[114414]=0;i=R(341,g+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break E}x[114414]=0;O(342,h|0,i|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break E}d=d+1|0;if((c|0)!=(d|0)){continue}break}}x[114414]=0;O(334,f+492|0,h|0)|0;i=x[114414];x[114414]=0;d=1;if((i|0)==1){break E}xb(h);Ab(g+16|0);break n}if(c>>>0>4){break n}if(!Qb(b,c)){break n}m=f,n=_u(b,c),x[m+4>>2]=n;d=1;break n}if(c>>>0>4){break n}if(!Qb(b,c)){break n}m=f,n=_u(b,c),x[m+8>>2]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+61|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f- -64|0,n=md(b,c),v[m|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+81|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+84|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+101|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+102|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+103|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+104|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+17|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+19|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+20|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+22|0]=n;d=1;break n}if(c>>>0>2){break n}if(!Qb(b,c)){break n}m=f,n=gC(b,c),w[m+28>>1]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+30|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=fC(b,c),v[m+26|0]=n;d=1;break n}if(c>>>0>128){break n}h=f+108|0;Bd(g+16|0,b,c);while(1){x[114414]=0;i=R(340,g+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break p}m=gc(h,d),n=i,v[m|0]=n;d=d+1|0;if(d>>>0<128){continue}break}Ab(g+16|0);d=1;break n}d=N()|0;break f}d=N()|0;xb(h);break f}if(c>>>0>32){break n}Bd(g+16|0,b,c);h=Wb(g);if(c){while(1){x[114414]=0;i=R(341,g+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break m}x[114414]=0;O(342,h|0,i|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break m}d=d+1|0;if((c|0)!=(d|0)){continue}break}}x[114414]=0;O(334,f+524|0,h|0)|0;i=x[114414];x[114414]=0;d=1;if((i|0)!=1){xb(h);Ab(g+16|0);break n}break m}if(c>>>0>2){break n}if(!Qb(b,c)){break n}m=f,n=gC(b,c),w[m+12>>1]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+25|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+35|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+105|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+85|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+65|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+100|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+80|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=md(b,c),v[m+60|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Qb(b,c)){break n}m=f,n=fC(b,c),v[m+33|0]=n;d=1;break n}d=1;h=no(b,c);if(!mo(h)){break n}v[f+14|0]=h;break n}x[g+16>>2]=240;m=g,n=no(b,c),x[m>>2]=n;Mg(f+48|0,x[Mb(g+16|0,g)>>2]);d=1;break n}x[g+16>>2]=240;m=g,n=no(b,c),x[m>>2]=n;Mg(f+88|0,x[Mb(g+16|0,g)>>2]);d=1;break n}d=N()|0;break f}h=(Zu(b,c)>>>0)%1e4|0;d=x[f+40>>2];x[f+40>>2]=h+d-(d>>>0)%1e4;d=1}hb=g+32|0;break e}d=N()|0;xb(h);break f}d=N()|0;break f}d=N()|0;break f}d=N()|0;break f}d=N()|0;break f}d=N()|0;break f}d=N()|0}Ab(g+16|0);Q(d|0);p()}if(!d){cc(b,c);break d}if((Qj(12704)|0)==(e|0)){d=y[f+15|0];v[f+15|0]=0;v[f+100|0]=y[f+100|0]&224|(d>>>5&4|d>>>6&1);v[f+60|0]=d>>>1&2|(d<<1&4|(y[f+60|0]&240|d&1));v[f+80|0]=y[f+80|0]&240|(d>>>4&2|(d>>>2&4|d>>>3&1))}}}k=k+1|0;if(z[a+480192>>1]>=(k&65535)>>>0){continue}break}}if(Qb(b,6)){continue}break}}return l|0}function Oaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,n=0,o=0,s=0,t=0,u=0,B=0,C=0,F=0,G=E(0),H=0,I=0,J=0,K=0,L=E(0),M=0,P=0;h=hb-48|0;hb=h;f=a+1074308|0;if(!(x[f>>2]==18284544|A[a+1074308>>2]>=18285126)){Ig(a+1074312|0,0)}b=h+32|0;k=a+1074312|0;Kb(b,k,0);if(Ib(b)){B=(x[a+480180>>2]&16777248)!=0}b=h+32|0;Kb(b,k,0);if(Ib(b)){K=x[a+480180>>2]==4}if(A[f>>2]<18874368){a:{if(!z[a+480192>>1]){break a}c=1;while(1){b:{b=x[(((c&65535)<<2)+a|0)+900380>>2];if(!b){break b}x[h+32>>2]=D(y[b+20|0],100)>>>6;x[h+16>>2]=100;M=b,P=x[Mb(h+32|0,h+16|0)>>2],v[M+20|0]=P;c:{d:{if(B){if(A[f>>2]<18350080){e=v[b+26|0];v[b+26|0]=((e>>31|1)+e|0)/2}if(A[f>>2]<18285314){break d}break c}e=v[b+26|0];v[b+26|0]=((e>>31|1)+e|0)/2}lz(hC(b,2),4,x[a+480180>>2])}e:{if(!y[b+34|0]|(A[f>>2]<18284544|A[f>>2]>=18285136)){break e}if(!Ki(b)){break e}Nb(k,2,1)}if(!(y[b+24|0]|(y[b+23|0]|(y[b+19|0]|y[b+20|0])))|A[f>>2]>=18285136){break b}Nb(k,1,1);break a}c=c+1|0;if(z[a+480192>>1]>=(c&65535)>>>0){continue}break}}if(!(!z[a+480190>>1]|(!(x[a+480180>>2]&16777248)|A[f>>2]>=18285314&B))){b=1;while(1){c=D(b&65535,104)+a|0;e=c+484419|0;if(!(y[e|0]|!(y[c+484421|0]|y[c+484420|0]))){v[e|0]=255}b=b+1|0;if(z[a+480190>>1]>=(b&65535)>>>0){continue}break}}b=a+901404|0;i=LO(b);if((b|0)!=(i|0)){while(1){g=0;c=b;while(1){e=y[c|0];f:{g:{if((e-97&255)>>>0<=5){d=e-32|0;break g}d=99;h:{if(e>>>0<=106){if(e-88>>>0<2){break h}if((e|0)==75){break g}break f}if(e-120>>>0<2){break h}if((e|0)==107){break g}break f}d=122}v[c|0]=d}g=g+1|0;c=g+b|0;if((g|0)!=32){continue}break}b=b+32|0;if((i|0)!=(b|0)){continue}break}}}i:{if(x[f>>2]==18874368|A[f>>2]>=18874896|(!(x[a+480180>>2]&16777252)|!z[a+480192>>1])){break i}b=1;c=0;while(1){j:{e=x[(((b&65535)<<2)+a|0)+900380>>2];if(!(y[e+31|0]?e:0)){b=b+1|0;if(z[a+480192>>1]>=(b&65535)>>>0){continue}if(c){break j}break i}v[e+33|0]=13;c=1;b=b+1|0;if(z[a+480192>>1]>=(b&65535)>>>0){continue}}break}Nb(k,3,1)}k:{if(!(x[a+480180>>2]&16777248)|(x[f>>2]==19005440|A[f>>2]>=19006226)){break k}b=h+32|0;Kb(b,k,0);if(!Ib(b)){b=h+16|0;Kb(b,k,1);if(!Ib(b)){break k}}if(!z[a+480192>>1]){break k}b=1;while(1){c=x[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|!y[c+19|0]|!(v[c+80|0]&1))){v[c+19|0]=0}b=b+1|0;if(z[a+480192>>1]>=(b&65535)>>>0){continue}break}}l:{m:{n:{if(A[f>>2]<19007233){e=a+946300|0;b=a+906300|0;while(1){c=hb-16|0;hb=c;d=b+80|0;Bu(c,1,d);i=h+16|0;Ic(i,c);hb=c+16|0;x[114414]=0;X(387,h+32|0,0,7,i|0);c=x[114414];x[114414]=0;if((c|0)==1){break m}xb(h+16|0);x[114414]=0;O(463,d|0,h+32|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break n}xb(h+32|0);b=b+160|0;if((e|0)!=(b|0)){continue}break}}if(!(x[a+480180>>2]!=4|A[f>>2]<19007257|(x[a+1074372>>2]!=4|A[f>>2]>=19071236))){wy(a,5)}if(!(!z[a+480192>>1]|(x[f>>2]==19202048|A[f>>2]>=19202055))){c=1;while(1){d=(((c&65535)<<2)+a|0)+900380|0;b=x[d>>2];o:{if(!b|!y[b+20|0]|!y[b+31|0]){break o}b=b+236|0;e=Et(b);if((b|0)!=(e|0)){while(1){if(z[b>>1]){break o}b=b+2|0;if((e|0)!=(b|0)){continue}break}}v[x[d>>2]+20|0]=0}c=c+1|0;if(z[a+480192>>1]>=(c&65535)>>>0){continue}break}}if(!(!z[a+480192>>1]|A[f>>2]>=19267584)){c=1;while(1){b=x[(((c&65535)<<2)+a|0)+900380>>2];p:{if(!b){break p}e=v[b+26|0];v[b+26|0]=((e>>31|1)+e|0)/2;if(A[f>>2]>=18350080&B){break p}v[b+19|0]=y[b+19|0]+3>>>2}c=c+1|0;if(z[a+480192>>1]>=(c&65535)>>>0){continue}break}}q:{if(!z[a+480192>>1]|A[f>>2]>=19398674){break q}b=1;while(1){c=x[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|y[c+65|0]==255)){Nb(k,94,1);break q}b=b+1|0;if(z[a+480192>>1]>=(b&65535)>>>0){continue}break}}r:{if(!z[a+480192>>1]|A[f>>2]>=19399428){break r}b=1;while(1){c=x[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|y[c+36|0]>1)){Nb(k,101,1);break r}b=b+1|0;if(z[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=hb-16|0;hb=b;w[h+12>>1]=0;x[h+8>>2]=a;c=b+8|0;Kb(c,a+1074312|0,0);M=h,P=Ib(c),v[M+14|0]=P;hb=b+16|0;b=x[h+12>>2];x[h>>2]=x[h+8>>2];x[h+4>>2]=b;n=hb-16|0;hb=n;s=a+484344|0;e=Ae(s);c=x[h+4>>2];b=x[h>>2];x[n>>2]=b;x[n+4>>2]=c;x[n+8>>2]=b;x[n+12>>2]=c;b=hb-32|0;hb=b;H=e-1&65535;if(Ae(s)>>>0>H>>>0){e=x[n>>2];I=x[n+4>>2];while(1){c=C&65535;if(xh(Re(s,c))){d=bc(Re(s,c));c=dc(Re(s,c));x[b+24>>2]=e;x[b+28>>2]=I;x[b+8>>2]=e;x[b+12>>2]=I;m=b+8|0;o=hb-16|0;hb=o;x[o>>2]=c;x[o+8>>2]=d;if(Hb(o+8|0,o)){while(1){F=o+8|0;d=x[F>>2];t=z[m+4>>1];c=t+1|0;w[m+4>>1]=c;if(z[x[m>>2]+480188>>1]<=(c&65535)>>>0){w[m+4>>1]=0}s:{if(xn(d)){break s}c=x[m>>2];i=x[c+1074308>>2];u=x[c+480180>>2];t:{if((u|0)==2){if(y[d+3|0]!=23|i>>>0>=18415616){break t}_e(d+5|0,64);break t}if(u&16777248){u:{if(y[m+6|0]|i>>>0>=18874368?i>>>0>=18285314:0){break u}v:{switch(y[d+3|0]-20|0){case 3:_e(d+5|0,128);break u;case 0:break v;default:break u}}c=y[d+5|0];if((c|0)!=208){if((c|0)!=192){break u}v[d|0]=254;v[d+3|0]=0;break u}v[d+3|0]=0}w:{if(i>>>0>=18350080){c=0;if(y[m+6|0]|i>>>0>=18874368){break w}}g=y[d+3|0];c=0;if(g>>>0>29){break w}c=536873152>>>g&1}if(i>>>0<18874368){g=y[d+3|0];g=(g|0)==24|(g|0)==22}else{g=0}x:{if(!(g|c)){break x}g=y[d+5|0];c=g&15;if(!c|(c|0)==15){break x}g=g&240;if(!g|(g|0)==240){break x}v[d+5|0]=y[d+3|0]==24?g:c}if(!(!z[x[m>>2]+480192>>1]|((i|0)==19005440|i>>>0>=19005700)|(y[m+6|0]|z[x[m>>2]+480192>>1]>=y[d+1|0]))){v[d+4|0]=0;v[d+2|0]=1}if(y[d+5|0]!=17|i>>>0>=19468802|y[d+3|0]!=18){break t}if(!$b(x[m>>2]+1074312|0,22)|y[x[m>>2]+480208|0]&4){break t}v[d+5|0]=0;break t}if((u|0)!=4){break t}y:{if(!(y[m+6|0]?i>>>0>=18285314:0)&i>>>0<18874368|(y[d+3|0]!=23|i>>>0>=19137026)){break y}if(y[d+5|0]<65){break y}v[d+3|0]=0}if(!(y[d+3|0]!=10|(y[m+6|0]|i>>>0>=18874368?i>>>0>=18415616:0)|y[d+2|0]!=11)){v[d+3|0]=0}z:{if(y[d+2|0]!=11|i>>>0>=18874640|y[d+3|0]!=4){break z}c=y[d+4|0];if(!(c|y[m+6|0])){break z}g=y[d+5|0];if(!g){break z}v[d+2|0]=0;M=d,P=vR(g+(c<<4)|0),v[M+5|0]=P}if(y[d+5|0]|(y[d+3|0]!=16|i>>>0>=19007241)){break t}v[d+3|0]=0}A:{if(i>>>0>=18874368){break A}g=y[d+3|0];c=y[d+5|0]&240;B:{C:{if((g|0)!=28|(c|0)!=96){J=0}else{if(!y[m+6|0]|(u|0)!=4){break C}J=i>>>0<18350080}if(!(J|(g|0)==20&(c|0)==96)){break B}}if(!t){break B}g=d+D(t,-6)|0;while(1){if(!((y[g+3|0]|8)!=28|(y[g+5|0]&240)!=96)){v[g+3|0]=0}g=g+6|0;if(d>>>0>g>>>0){continue}break}}if(!t|(y[d+5|0]&240)!=224|y[d+3|0]!=20){break A}g=d+D(t,-6)|0;while(1){if(!(y[g+3|0]!=20|(y[g+5|0]&240)!=224)){v[g+3|0]=0}g=g+6|0;if(d>>>0>g>>>0){continue}break}}D:{if(y[d+2|0]!=8|i>>>0>=19333175|(i|0)==19333120){break D}i=y[d+4|0];c=y[d+3|0];if(!(!i|(c|0)!=7)){v[d+3|0]=11;break D}E:{F:{switch(c-5|0){default:if((c|0)!=26){break D}break;case 1:break D;case 2:break E;case 0:break F}}g=y[d+5|0];if(!(g&15)){v[d+2|0]=0;v[d+3|0]=5;v[d+5|0]=g|i&15;break D}G:{switch(c-5|0){case 1:break D;case 0:case 2:break E;default:break G}}if((c|0)!=26){break D}}v[d+2|0]=0}if(y[d+3|0]|((u|0)==16777216|y[d+2|0]!=15)){break s}v[d+2|0]=0;v[d+3|0]=10;v[d+5|0]=y[d+4|0]<<3}Nj(F);if(Hb(F,o)){continue}break}}c=x[m+4>>2];x[b+16>>2]=x[m>>2];x[b+20>>2]=c;hb=o+16|0}C=C+1|0;if((C&65535)>>>0<=H>>>0){continue}break}}c=x[n+4>>2];x[h+32>>2]=x[n>>2];x[h+36>>2]=c;hb=b+32|0;hb=n+16|0;H:{if(!(!B|A[f>>2]>=19267584)){b=35040;while(1){c=x[f>>2];e=x[b+4>>2];Nb(k,x[b>>2],c>>>0>=e>>>0|(c|0)==(e&-65536));b=b+8|0;if((b|0)!=35384){continue}break}break H}if(!K|A[f>>2]>=19267584){break H}b=35392;while(1){Nb(k,x[b>>2],A[f>>2]>=A[b+4>>2]);b=b+8|0;if((b|0)!=35632){continue}break}}I:{if(x[a+480180>>2]&16777248){b=35632;while(1){c=x[f>>2];e=x[b+4>>2];d=e&-65536;if(!(c>>>0>=d>>>0&(c>>>0<=d>>>0|c>>>0>=e>>>0))){Ig(k,x[b>>2])}b=b+8|0;if((b|0)!=35680){continue}break}break I}if(x[a+480180>>2]==4){b=35680;while(1){if(A[f>>2]<A[b+4>>2]){Ig(k,x[b>>2])}b=b+8|0;if((b|0)!=35736){continue}break}break I}if(x[a+480180>>2]!=2){break I}b=35744;while(1){if(A[f>>2]<A[b+4>>2]){Ig(k,x[b>>2])}b=b+8|0;if((b|0)!=35824){continue}break}}if(!(x[a+480180>>2]!=4|A[f>>2]>=18415616)){Nb(k,98,1)}if(!(A[f>>2]<19333159|A[f>>2]>=19333193)){b=0;while(1){c=h+32|0;e=b+77|0;Kb(c,k,e);Nb(k,b+86|0,Ib(c));Ig(k,e);b=b+1|0;if((b|0)!=5){continue}break}}c=8;J:{if(A[f>>2]>=18284544){if(A[f>>2]<18284544|A[f>>2]>18874627){break J}c=6;if(x[f>>2]==18874368){break J}}Nb(k,c,1)}K:{if(A[f>>2]<19136512){Ig(k,7);break K}if(!(x[a+480180>>2]&16777248)|(A[f>>2]<19136512|A[f>>2]>=19267584)){break K}Nb(k,7,1)}b=h+32|0;Kb(b,k,31);L:{if(!Ib(b)|A[f>>2]<19071234|(!z[a+480192>>1]|A[f>>2]>=19398723)){break L}b=1;while(1){M:{c=x[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break M}e=y[c+65|0];if(!(y[c+60|0]&4)|(e|0)==255|e>>>0<=y[c- -64|0]){break M}Nb(k,97,1);break L}b=b+1|0;if(z[a+480192>>1]>=(b&65535)>>>0){continue}break}}N:{if(!(x[a+480180>>2]&16777218)|!z[a+480190>>1]){break N}b=1;while(1){if(!(y[(D(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if(z[a+480190>>1]>=(b&65535)>>>0){continue}break N}break}if(!(!z[a+480192>>1]|x[a+480180>>2]!=16777216|(A[f>>2]<19398688|A[f>>2]>19464277))){Nb(k,109,1)}if(!(x[a+480180>>2]!=2|A[f>>2]>=19464192)){Nb(k,108,1);break N}if(x[a+480180>>2]==2){break N}Ig(k,108)}if(!(!(x[a+480180>>2]&16777252)|(A[f>>2]<19333120|A[f>>2]>=19924480))){e=a+946300|0;a=a+906300|0;while(1){O:{if((y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))!=1146637647|(y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))!=-281111764){break O}if((wc(a+4|0)|0)!=24){break O}b=x[a+4>>2];G=(l(2,y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24)),r());b=x[a+4>>2];L=nf(E(E((l(2,y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24)),r())*E(1.0005003213882446))+E(-.0005002501420676708)),E(0));G=nf(E(E(G*E(1.0005003213882446))+E(-.0005002501420676708)),E(0));b=x[a+4>>2];c=(q(L),j(2));v[b+12|0]=c;v[b+13|0]=c>>>8;v[b+14|0]=c>>>16;v[b+15|0]=c>>>24;b=x[a+4>>2];c=(q(G),j(2));v[b+16|0]=c;v[b+17|0]=c>>>8;v[b+18|0]=c>>>16;v[b+19|0]=c>>>24}a=a+160|0;if((e|0)!=(a|0)){continue}break}}hb=h+48|0;return}a=N()|0;xb(h+32|0);break l}a=N()|0;xb(h+16|0)}Q(a|0);p()}function sd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=hb-16|0;hb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(a>>>0<=244){g=x[114290];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=g>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+457200|0;d=x[a+457208>>2];a=x[d+8>>2];j:{if((b|0)==(a|0)){m=457160,n=Cna(-2,c)&g,x[m>>2]=n;break j}x[a+12>>2]=b;x[b+8>>2]=a}a=d+8|0;b=c<<3;x[d+4>>2]=b|3;b=b+d|0;x[b+4>>2]=x[b+4>>2]|1;break a}k=x[114292];if(k>>>0>=h>>>0){break i}if(b){a=2<<c;a=(0-a|a)&b<<c;d=xna(0-a&a);a=d<<3;b=a+457200|0;e=x[a+457208>>2];a=x[e+8>>2];k:{if((b|0)==(a|0)){g=Cna(-2,d)&g;x[114290]=g;break k}x[a+12>>2]=b;x[b+8>>2]=a}x[e+4>>2]=h|3;c=e+h|0;a=d<<3;d=a-h|0;x[c+4>>2]=d|1;x[a+e>>2]=d;if(k){b=(k&-8)+457200|0;f=x[114295];a=1<<(k>>>3);l:{if(!(a&g)){x[114290]=a|g;a=b;break l}a=x[b+8>>2]}x[b+8>>2]=f;x[a+12>>2]=f;x[f+12>>2]=b;x[f+8>>2]=a}a=e+8|0;x[114295]=c;x[114292]=d;break a}j=x[114291];if(!j){break i}c=x[(xna(0-j&j)<<2)+457464>>2];f=(x[c+4>>2]&-8)-h|0;b=c;while(1){m:{a=x[b+16>>2];if(!a){a=x[b+20>>2];if(!a){break m}}b=(x[a+4>>2]&-8)-h|0;d=b>>>0<f>>>0;f=d?b:f;c=d?a:c;b=a;continue}break}i=x[c+24>>2];d=x[c+12>>2];if((d|0)!=(c|0)){a=x[c+8>>2];x[a+12>>2]=d;x[d+8>>2]=a;break b}b=c+20|0;a=x[b>>2];if(!a){a=x[c+16>>2];if(!a){break h}b=c+16|0}while(1){e=b;d=a;b=a+20|0;a=x[b>>2];if(a){continue}b=d+16|0;a=x[d+16>>2];if(a){continue}break}x[e>>2]=0;break b}h=-1;if(a>>>0>4294967231){break i}a=a+11|0;h=a&-8;j=x[114291];if(!j){break i}f=0-h|0;g=0;n:{if(h>>>0<256){break n}g=31;if(h>>>0>16777215){break n}a=G(a>>>8|0);g=((h>>>38-a&1)-(a<<1)|0)+62|0}b=x[(g<<2)+457464>>2];o:{p:{q:{if(!b){a=0;break q}a=0;c=h<<((g|0)!=31?25-(g>>>1|0)|0:0);while(1){r:{e=(x[b+4>>2]&-8)-h|0;if(e>>>0>=f>>>0){break r}d=b;f=e;if(e){break r}f=0;a=b;break p}e=x[b+20>>2];b=x[((c>>>29&4)+b|0)+16>>2];a=e?(e|0)==(b|0)?a:e:a;c=c<<1;if(b){continue}break}}if(!(a|d)){d=0;a=2<<g;a=(0-a|a)&j;if(!a){break i}a=x[(xna(a&0-a)<<2)+457464>>2]}if(!a){break o}}while(1){b=(x[a+4>>2]&-8)-h|0;c=b>>>0<f>>>0;f=c?b:f;d=c?a:d;b=x[a+16>>2];if(b){a=b}else{a=x[a+20>>2]}if(a){continue}break}}if(!d|x[114292]-h>>>0<=f>>>0){break i}g=x[d+24>>2];c=x[d+12>>2];if((d|0)!=(c|0)){a=x[d+8>>2];x[a+12>>2]=c;x[c+8>>2]=a;break c}b=d+20|0;a=x[b>>2];if(!a){a=x[d+16>>2];if(!a){break g}b=d+16|0}while(1){e=b;c=a;b=a+20|0;a=x[b>>2];if(a){continue}b=c+16|0;a=x[c+16>>2];if(a){continue}break}x[e>>2]=0;break c}a=x[114292];if(a>>>0>=h>>>0){d=x[114295];b=a-h|0;s:{if(b>>>0>=16){c=d+h|0;x[c+4>>2]=b|1;x[a+d>>2]=b;x[d+4>>2]=h|3;break s}x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;c=0;b=0}x[114292]=b;x[114295]=c;a=d+8|0;break a}i=x[114293];if(i>>>0>h>>>0){b=i-h|0;x[114293]=b;c=x[114296];a=c+h|0;x[114296]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;if(x[114408]){c=x[114410]}else{x[114411]=-1;x[114412]=-1;x[114409]=4096;x[114410]=4096;x[114408]=l+12&-16^1431655768;x[114413]=0;x[114401]=0;c=4096}e=j+c|0;f=0-c|0;b=e&f;if(b>>>0<=h>>>0){break a}d=x[114400];if(d){c=x[114398];g=c+b|0;if(d>>>0<g>>>0|c>>>0>=g>>>0){break a}}t:{if(!(y[457604]&4)){u:{v:{w:{x:{d=x[114296];if(d){a=457608;while(1){c=x[a>>2];if(c>>>0<=d>>>0&d>>>0<c+x[a+4>>2]>>>0){break x}a=x[a+8>>2];if(a){continue}break}}c=$m(0);if((c|0)==-1){break u}g=b;d=x[114409];a=d-1|0;if(a&c){g=(b-c|0)+(a+c&0-d)|0}if(g>>>0<=h>>>0){break u}d=x[114400];if(d){a=x[114398];f=a+g|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break u}}a=$m(g);if((c|0)!=(a|0)){break w}break t}g=f&e-i;c=$m(g);if((c|0)==(x[a>>2]+x[a+4>>2]|0)){break v}a=c}if((a|0)==-1){break u}if(h+48>>>0<=g>>>0){c=a;break t}c=x[114410];c=c+(j-g|0)&0-c;if(($m(c)|0)==-1){break u}g=c+g|0;c=a;break t}if((c|0)!=-1){break t}}x[114401]=x[114401]|4}c=$m(b);a=$m(0);if((c|0)==-1|(a|0)==-1|a>>>0<=c>>>0){break d}g=a-c|0;if(g>>>0<=h+40>>>0){break d}}a=x[114398]+g|0;x[114398]=a;if(a>>>0>A[114399]){x[114399]=a}y:{e=x[114296];if(e){a=457608;while(1){d=x[a>>2];b=x[a+4>>2];if((d+b|0)==(c|0)){break y}a=x[a+8>>2];if(a){continue}break}break f}a=x[114294];if(!(a>>>0<=c>>>0?a:0)){x[114294]=c}a=0;x[114403]=g;x[114402]=c;x[114298]=-1;x[114299]=x[114408];x[114405]=0;while(1){d=a<<3;b=d+457200|0;x[d+457208>>2]=b;x[d+457212>>2]=b;a=a+1|0;if((a|0)!=32){continue}break}d=g-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[114293]=b;a=a+c|0;x[114296]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[114297]=x[114412];break e}if(y[a+12|0]&8|d>>>0>e>>>0|c>>>0<=e>>>0){break f}x[a+4>>2]=b+g;a=e+8&7?-8-e&7:0;c=a+e|0;x[114296]=c;b=x[114293]+g|0;a=b-a|0;x[114293]=a;x[c+4>>2]=a|1;x[(b+e|0)+4>>2]=40;x[114297]=x[114412];break e}d=0;break b}c=0;break c}if(A[114294]>c>>>0){x[114294]=c}b=c+g|0;a=457608;z:{A:{B:{C:{D:{E:{while(1){if((b|0)!=x[a>>2]){a=x[a+8>>2];if(a){continue}break E}break}if(!(y[a+12|0]&8)){break D}}a=457608;while(1){b=x[a>>2];if(b>>>0<=e>>>0){f=b+x[a+4>>2]|0;if(f>>>0>e>>>0){break C}}a=x[a+8>>2];continue}}x[a>>2]=c;x[a+4>>2]=x[a+4>>2]+g;j=(c+8&7?-8-c&7:0)+c|0;x[j+4>>2]=h|3;g=b+(b+8&7?-8-b&7:0)|0;i=h+j|0;a=g-i|0;if((e|0)==(g|0)){x[114296]=i;a=x[114293]+a|0;x[114293]=a;x[i+4>>2]=a|1;break A}if(x[114295]==(g|0)){x[114295]=i;a=x[114292]+a|0;x[114292]=a;x[i+4>>2]=a|1;x[a+i>>2]=a;break A}f=x[g+4>>2];if((f&3)==1){e=f&-8;F:{if(f>>>0<=255){d=x[g+8>>2];b=f>>>3|0;c=x[g+12>>2];if((c|0)==(d|0)){m=457160,n=x[114290]&Cna(-2,b),x[m>>2]=n;break F}x[d+12>>2]=c;x[c+8>>2]=d;break F}h=x[g+24>>2];c=x[g+12>>2];G:{if((g|0)!=(c|0)){b=x[g+8>>2];x[b+12>>2]=c;x[c+8>>2]=b;break G}H:{f=g+20|0;b=x[f>>2];if(b){break H}f=g+16|0;b=x[f>>2];if(b){break H}c=0;break G}while(1){d=f;c=b;f=c+20|0;b=x[f>>2];if(b){continue}f=c+16|0;b=x[c+16>>2];if(b){continue}break}x[d>>2]=0}if(!h){break F}d=x[g+28>>2];b=(d<<2)+457464|0;I:{if(x[b>>2]==(g|0)){x[b>>2]=c;if(c){break I}m=457164,n=x[114291]&Cna(-2,d),x[m>>2]=n;break F}x[h+(x[h+16>>2]==(g|0)?16:20)>>2]=c;if(!c){break F}}x[c+24>>2]=h;b=x[g+16>>2];if(b){x[c+16>>2]=b;x[b+24>>2]=c}b=x[g+20>>2];if(!b){break F}x[c+20>>2]=b;x[b+24>>2]=c}g=e+g|0;f=x[g+4>>2];a=a+e|0}x[g+4>>2]=f&-2;x[i+4>>2]=a|1;x[a+i>>2]=a;if(a>>>0<=255){b=(a&-8)+457200|0;c=x[114290];a=1<<(a>>>3);J:{if(!(c&a)){x[114290]=a|c;a=b;break J}a=x[b+8>>2]}x[b+8>>2]=i;x[a+12>>2]=i;x[i+12>>2]=b;x[i+8>>2]=a;break A}f=31;if(a>>>0<=16777215){b=G(a>>>8|0);f=((a>>>38-b&1)-(b<<1)|0)+62|0}x[i+28>>2]=f;x[i+16>>2]=0;x[i+20>>2]=0;b=(f<<2)+457464|0;d=x[114291];c=1<<f;K:{if(!(d&c)){x[114291]=c|d;x[b>>2]=i;break K}f=a<<((f|0)!=31?25-(f>>>1|0)|0:0);c=x[b>>2];while(1){b=c;if((x[c+4>>2]&-8)==(a|0)){break B}c=f>>>29|0;f=f<<1;d=(c&4)+b|0;c=x[d+16>>2];if(c){continue}break}x[d+16>>2]=i}x[i+24>>2]=b;x[i+12>>2]=i;x[i+8>>2]=i;break A}d=g-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[114293]=b;a=a+c|0;x[114296]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[114297]=x[114412];a=(f+(f-39&7?39-f&7:0)|0)-47|0;d=a>>>0<e+16>>>0?e:a;x[d+4>>2]=27;a=x[114405];x[d+16>>2]=x[114404];x[d+20>>2]=a;a=x[114403];x[d+8>>2]=x[114402];x[d+12>>2]=a;x[114404]=d+8;x[114403]=g;x[114402]=c;x[114405]=0;a=d+24|0;while(1){x[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((d|0)==(e|0)){break e}x[d+4>>2]=x[d+4>>2]&-2;f=d-e|0;x[e+4>>2]=f|1;x[d>>2]=f;if(f>>>0<=255){b=(f&-8)+457200|0;c=x[114290];a=1<<(f>>>3);L:{if(!(c&a)){x[114290]=a|c;a=b;break L}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break e}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+457464|0;d=x[114291];c=1<<a;M:{if(!(d&c)){x[114291]=c|d;x[b>>2]=e;break M}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);d=x[b>>2];while(1){b=d;if((f|0)==(x[b+4>>2]&-8)){break z}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;d=x[c+16>>2];if(d){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break e}a=x[b+8>>2];x[a+12>>2]=i;x[b+8>>2]=i;x[i+24>>2]=0;x[i+12>>2]=b;x[i+8>>2]=a}a=j+8|0;break a}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=x[114293];if(a>>>0<=h>>>0){break d}b=a-h|0;x[114293]=b;c=x[114296];a=c+h|0;x[114296]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}x[114240]=48;a=0;break a}N:{if(!g){break N}b=x[d+28>>2];a=(b<<2)+457464|0;O:{if(x[a>>2]==(d|0)){x[a>>2]=c;if(c){break O}j=Cna(-2,b)&j;x[114291]=j;break N}x[g+(x[g+16>>2]==(d|0)?16:20)>>2]=c;if(!c){break N}}x[c+24>>2]=g;a=x[d+16>>2];if(a){x[c+16>>2]=a;x[a+24>>2]=c}a=x[d+20>>2];if(!a){break N}x[c+20>>2]=a;x[a+24>>2]=c}P:{if(f>>>0<=15){a=f+h|0;x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;break P}x[d+4>>2]=h|3;e=d+h|0;x[e+4>>2]=f|1;x[e+f>>2]=f;if(f>>>0<=255){b=(f&-8)+457200|0;c=x[114290];a=1<<(f>>>3);Q:{if(!(c&a)){x[114290]=a|c;a=b;break Q}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break P}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+457464|0;R:{c=1<<a;S:{if(!(c&j)){x[114291]=c|j;x[b>>2]=e;break S}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);h=x[b>>2];while(1){b=h;if((x[b+4>>2]&-8)==(f|0)){break R}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=x[c+16>>2];if(h){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break P}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=d+8|0;break a}T:{if(!i){break T}b=x[c+28>>2];a=(b<<2)+457464|0;U:{if(x[a>>2]==(c|0)){x[a>>2]=d;if(d){break U}m=457164,n=Cna(-2,b)&j,x[m>>2]=n;break T}x[i+(x[i+16>>2]==(c|0)?16:20)>>2]=d;if(!d){break T}}x[d+24>>2]=i;a=x[c+16>>2];if(a){x[d+16>>2]=a;x[a+24>>2]=d}a=x[c+20>>2];if(!a){break T}x[d+20>>2]=a;x[a+24>>2]=d}V:{if(f>>>0<=15){a=f+h|0;x[c+4>>2]=a|3;a=a+c|0;x[a+4>>2]=x[a+4>>2]|1;break V}x[c+4>>2]=h|3;d=c+h|0;x[d+4>>2]=f|1;x[d+f>>2]=f;if(k){b=(k&-8)+457200|0;e=x[114295];a=1<<(k>>>3);W:{if(!(a&g)){x[114290]=a|g;a=b;break W}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a}x[114295]=d;x[114292]=f}a=c+8|0}hb=l+16|0;return a}function Haa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=hb-752|0;hb=d;Lc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!If(b,d+744|0)){break k}if(!jL(d+744|0)){break k}if(!iu(b,d+736|0)){break k}if(!iL(d+736|0)){break k}k=y[d+736|0]|y[d+737|0]<<8|(y[d+738|0]<<16|y[d+739|0]<<24);l:{if((k|0)==1179012417){h=1;e=1313423693;break l}if((k|0)!=538987841){break k}h=2;e=1414090313}l=fm(d+720|0,b);i=$x(d+704|0);m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!c){x[114414]=0;X(1548,d+128|0,l|0,h|0,e|0);b=x[114414];x[114414]=0;if((b|0)!=1){break u}a=N()|0;break a}x[114414]=0;T(1549,d+128|0,l|0,h|0);b=x[114414];x[114414]=0;if((b|0)==1){break t}}if(x[i>>2]){xd(i);gL(i);Yp(i);Hf(yb(i),x[i>>2],af(i));n=yb(i),o=0,x[n>>2]=o;x[i>>2]=0;x[i+4>>2]=0}b=d+128|0;Wl(i,b);x[i>>2]=x[b>>2];x[i+4>>2]=x[b+4>>2];h=x[yb(b)>>2];n=yb(i),o=h,x[n>>2]=o;n=yb(b),o=0,x[n>>2]=o;x[b>>2]=0;x[b+4>>2]=0;Ml(b);x[114414]=0;T(1550,d+688|0,i|0,e|0);b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;b=R(303,d+688|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break o}h=0;if(!b){break m}x[114414]=0;b=O(1551,d+688|0,d+608|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break o}if(!b|!y[d+673|0]){break m}b=y[d+673|0];x[114414]=0;h=O(226,d+688|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break o}if(!((c|0)!=0&h)){break m}x[114414]=0;P(397,a|0,8388608);b=x[114414];x[114414]=0;if((b|0)==1){break o}x[a+480208>>2]=12;x[a+480208>>2]=x[a+480208>>2]&-17|(y[d+672|0]^-1)<<4&16;b=y[d+673|0];x[114414]=0;w[d+128>>1]=b;w[d+496>>1]=127;b=O(433,d+128|0,d+496|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break s}w[a+480188>>1]=z[b>>1];x[a+480196>>2]=y[d+674|0];x[a+480204>>2]=D(y[d+675|0],1e4);x[a+480200>>2]=y[d+680|0]<<1;x[114414]=0;O(206,a+1304436|0,((k|0)!=1179012417?12814:12848)|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break o}x[114414]=0;b=O(2,d+592|0,9118)|0;e=x[114414];x[114414]=0;if((e|0)==1){break q}Db(a+1304448|0,b);xb(b);x[a+1304496>>2]=4;x[114414]=0;T(1552,d+496|0,2,d+608|0);b=x[114414];x[114414]=0;if((b|0)==1){break r}x[114414]=0;P(355,d+128|0,d+496|0);b=x[114414];x[114414]=0;if((b|0)==1){break r}b=d+128|0;Db(a+1304400|0,b);xb(b);if(!z[a+480188>>1]){break p}b=0;j=(k|0)==1179012417;while(1){x[114414]=0;h=(b<<5)+a|0;f=h+480280|0;W(381,f|0);e=x[114414];x[114414]=0;v:{w:{x:{y:{z:{if((e|0)!=1){x[114414]=0;e=R(403,d+688|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break z}if(j){break y}if(e>>>0<129){break x}break w}a=N()|0;break b}a=N()|0;break b}if(e<<24>>24<0){break w}x[114414]=0;x[d+128>>2]=e<<2;x[d+496>>2]=256;e=O(414,d+128|0,d+496|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){w[h+480284>>1]=x[e>>2];break v}a=N()|0;break b}w[h+480284>>1]=e<<1;break v}x[f>>2]=1024}b=b+1|0;if(b>>>0<z[a+480188>>1]){continue}break}break p}a=N()|0;break a}a=N()|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}x[114414]=0;b=O(1553,i|0,1380209231)|0;e=x[114414];x[114414]=0;if((e|0)!=1){break n}}a=N()|0;break b}if(b){x[114414]=0;T(1550,d+128|0,i|0,1380209231);b=x[114414];x[114414]=0;if((b|0)==1){break c}x[114414]=0;b=R(403,d+128|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break d}e=Vb(a+484360|0);x[114414]=0;aa(548,e|0,d+128|0,b+1&255,255,254)|0;b=x[114414];x[114414]=0;if((b|0)==1){break d}Ab(d+128|0)}if(c&1){x[114414]=0;w[d+56>>1]=0;T(1554,d+496|0,i|0,1414807888);b=x[114414];x[114414]=0;if((b|0)==1){break e}b=rd(d+496|0);x[114414]=0;e=a+484344|0;P(362,e|0,b&65535);b=x[114414];x[114414]=0;if((b|0)==1){break h}b=d+496|0;n=d,o=bc(b),x[n+560>>2]=o;n=d,o=dc(b),x[n+80>>2]=o;if(Hb(d+560|0,d+80|0)){h=(k|0)!=1179012417;while(1){b=df(d+128|0,x[d+560>>2]);x[114414]=0;j=R(403,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break g}x[114414]=0;w[d+480>>1]=j;j=R(391,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break g}x[114414]=0;T(307,d+576|0,b|0,j|0);j=x[114414];x[114414]=0;if((j|0)==1){break g}x[114414]=0;j=x[d+588>>2];x[d+16>>2]=x[d+584>>2];x[d+20>>2]=j;j=x[d+580>>2];x[d+8>>2]=x[d+576>>2];x[d+12>>2]=j;X(1555,d+8|0,z[d+480>>1],h|0,a|0);j=x[114414];x[114414]=0;if((j|0)==1){break g}x[114414]=0;j=O(402,d+56|0,d+480|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break g}w[d+56>>1]=z[j>>1];Ab(b);b=d+560|0;of(b);if(Hb(b,d+80|0)){continue}break}}if(z[d+56>>1]){b=0;while(1){x[114414]=0;h=b&65535;j=O(392,e|0,h|0)|0;f=x[114414];x[114414]=0;A:{if((f|0)!=1){if(j){break A}x[114414]=0;U(363,e|0,h|0,64)|0;h=x[114414];x[114414]=0;if((h|0)!=1){break A}}a=N()|0;break f}b=b+1|0;if(z[d+56>>1]>(b&65535)>>>0){continue}break}}id(d+496|0)}B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{if((k|0)==1179012417){x[114414]=0;T(1554,d+80|0,i|0,1414745673);b=x[114414];x[114414]=0;if((b|0)==1){break Q}b=d+80|0;n=d,o=bc(b),x[n+112>>2]=o;n=d,o=dc(b),x[n+40>>2]=o;R:{if(Hb(d+112|0,d+40|0)){h=c&2;k=d+504|0;j=d+128|1;while(1){c=df(d+560|0,x[d+112>>2]);x[114414]=0;b=O(1556,c|0,d+128|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break R}S:{if(!b){break S}b=y[j|0];if((b|0)==255){break S}x[114414]=0;b=U(405,a|0,b+1|0,0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break P}if(!b){break S}e=z[a+480190>>1];x[114414]=0;T(1557,d+128|0,b|0,e|0);b=x[114414];x[114414]=0;if((b|0)==1){break P}b=0;if(!y[d+158|0]){break S}while(1){T:{if(!Wn(a)){break T}x[114414]=0;e=O(1558,c|0,d+496|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break O}if(!e){break T}e=z[a+480190>>1]+1|0;w[a+480190>>1]=e;if((y[d+496|0]|y[d+497|0]<<8|(y[d+498|0]<<16|y[d+499|0]<<24))!=1347240275){break T}x[114414]=0;T(544,d+480|0,2,k|0);f=x[114414];x[114414]=0;U:{V:{W:{if((f|0)==1){break W}x[114414]=0;P(355,d+56|0,d+480|0);f=x[114414];x[114414]=0;if((f|0)==1){break W}x[114414]=0;e=e&65535;O(334,((e<<5)+a|0)+946304|0,d+56|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break V}xb(d+56|0);x[114414]=0;e=(D(e,104)+a|0)+484380|0;T(1559,d+496|0,d+128|0,e|0);f=x[114414];x[114414]=0;if((f|0)==1){break j}if(!h){break U}x[114414]=0;P(1560,d+56|0,d+496|0);f=x[114414];x[114414]=0;if((f|0)!=1){x[114414]=0;U(361,d+56|0,e|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){break T}}a=N()|0;break i}a=N()|0;break i}a=N()|0;xb(d+56|0);break i}e=Kj(e);x[114414]=0;O(304,c|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break j}}b=b+1|0;if(b>>>0<y[d+158|0]){continue}break}}Ab(c);b=d+112|0;of(b);if(Hb(b,d+40|0)){continue}break}}id(d+80|0);break B}a=N()|0;break i}x[114414]=0;T(1554,d+480|0,i|0,1179011410);b=x[114414];x[114414]=0;if((b|0)==1){break N}b=d+480|0;n=d,o=bc(b),x[n+472>>2]=o;n=d,o=dc(b),x[n+464>>2]=o;X:{if(Hb(d+472|0,d+464|0)){h=c&2;k=d+496|4;e=d+72|4;j=d+128|5;while(1){c=fm(d+560|0,x[d+472>>2]);x[114414]=0;b=R(391,c|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break M}Y:{if((b|0)!=538986817){break Y}x[114414]=0;b=O(1561,c|0,d+456|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break L}if(!b|(y[d+456|0]|y[d+457|0]<<8|(y[d+458|0]<<16|y[d+459|0]<<24))!=1414745673){break Y}x[114414]=0;b=O(1562,c|0,d+128|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break K}if(!b){break Y}b=y[j|0];if((b|0)==255){break Y}x[114414]=0;b=U(405,a|0,b+1|0,0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break J}if(!b){break Y}f=z[a+480190>>1];x[114414]=0;T(1563,d+128|0,b|0,f|0);b=x[114414];x[114414]=0;if((b|0)==1){break J}x[114414]=0;T(1549,d+496|0,c|0,2);b=x[114414];x[114414]=0;if((b|0)==1){break X}x[114414]=0;T(1554,d+112|0,d+496|0,1179011410);b=x[114414];x[114414]=0;if((b|0)==1){break I}Ml(d+496|0);b=d+112|0;n=d,o=bc(b),x[n+104>>2]=o;n=d,o=dc(b),x[n+96>>2]=o;Z:{if(!Hb(d+104|0,d+96|0)){break Z}_:{while(1){b=df(d+80|0,x[d+104>>2]);x[114414]=0;f=R(391,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break H}$:{aa:{if((f|0)!=538989377){break aa}if(!Wn(a)){break aa}f=y[d+452|0]|y[d+453|0]<<8;g=f-1|0;v[d+452|0]=g;v[d+453|0]=g>>>8;if(!f){Ab(b);break Z}f=z[a+480190>>1]+1|0;w[a+480190>>1]=f;x[114414]=0;g=O(1561,b|0,d+72|0)|0;m=x[114414];x[114414]=0;if((m|0)==1){break G}if(!g|(y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24))!=1347240275){break _}g=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[114414]=0;T(307,d+56|0,b|0,g|0);g=x[114414];x[114414]=0;ba:{ca:{if((g|0)!=1){x[114414]=0;g=O(1564,d+56|0,d+496|0)|0;m=x[114414];x[114414]=0;if((m|0)==1){break $}if(!g){break ba}x[114414]=0;T(354,d+24|0,2,k|0);g=x[114414];x[114414]=0;if((g|0)!=1){x[114414]=0;P(355,d+40|0,d+24|0);g=x[114414];x[114414]=0;if((g|0)!=1){break ca}}a=N()|0;break E}a=N()|0;break D}x[114414]=0;f=f&65535;O(334,((f<<5)+a|0)+946304|0,d+40|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break F}xb(d+40|0);x[114414]=0;f=(D(f,104)+a|0)+484380|0;T(1565,d+496|0,d+128|0,f|0);g=x[114414];x[114414]=0;if((g|0)==1){break $}da:{if(!h){break da}g=y[d+496|0]|y[d+497|0]<<8|(y[d+498|0]<<16|y[d+499|0]<<24);x[114414]=0;O(224,d+56|0,g+4|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break $}x[114414]=0;P(1566,d+40|0,d+496|0);g=x[114414];x[114414]=0;if((g|0)!=1){x[114414]=0;U(361,d+40|0,f|0,d+56|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){break da}}a=N()|0;break E}Ab(d+56|0);break aa}Ab(d+56|0);Ab(b);break Z}Ab(b);b=d+104|0;of(b);if(Hb(b,d+96|0)){continue}break Z}break}a=N()|0;break E}Ab(b)}id(d+112|0)}Ab(c);b=d+472|0;of(b);if(Hb(b,d+464|0)){continue}break}}id(d+480|0);break B}a=N()|0;break C}a=N()|0;break b}a=N()|0;break i}a=N()|0;break i}a=N()|0;break b}a=N()|0;break C}a=N()|0;break C}a=N()|0;break C}a=N()|0;break C}a=N()|0;Ml(d+496|0);break C}a=N()|0;break D}a=N()|0;break D}a=N()|0;xb(d+40|0)}Ab(d+56|0)}Ab(b);id(d+112|0)}Ab(c);id(d+480|0);break b}h=1}Ab(d+688|0);Ml(i);Ab(l)}hb=d+752|0;return h|0}a=N()|0}Ab(c);id(d+80|0);break b}a=N()|0;break f}a=N()|0;Ab(b)}id(d+496|0);break b}a=N()|0;break b}a=N()|0;Ab(d+128|0);break b}a=N()|0}Ab(d+688|0)}Ml(i);Ab(l);Q(a|0);p()}function JF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,F=0,G=E(0),H=0;d=hb-144|0;hb=d;e=Sb(d,0,144);x[e+76>>2]=-1;x[e+44>>2]=a;x[e+32>>2]=2478;x[e+84>>2]=a;d=b;t=c;a=0;j=hb-304|0;hb=j;a:{b:{c:{d:{if(x[e+4>>2]){break d}Iw(e);if(x[e+4>>2]){break d}break c}b=y[d|0];if(!b){break a}e:{f:{g:{h:{while(1){i:{j:{if(kk(b&255)){while(1){b=d;d=d+1|0;if(kk(y[b+1|0])){continue}break}Jh(e,0,0);while(1){c=x[e+4>>2];k:{if((c|0)!=x[e+104>>2]){x[e+4>>2]=c+1;c=y[c|0];break k}c=Zc(e)}if(kk(c)){continue}break}d=x[e+4>>2];c=x[e+116>>2];if((c|0)>0|(c|0)>=0){d=d-1|0;x[e+4>>2]=d}c=d-x[e+44>>2]|0;g=c;i=l+x[e+124>>2]|0;f=m+x[e+120>>2]|0;c=(c>>31)+(f>>>0<m>>>0?i+1|0:i)|0;m=f+g|0;l=m>>>0<f>>>0?c+1|0:c;break j}l:{m:{n:{if(y[d|0]==37){b=y[d+1|0];if((b|0)==42){break n}if((b|0)!=37){break m}}Jh(e,0,0);o:{if(y[d|0]==37){while(1){b=x[e+4>>2];p:{if((b|0)!=x[e+104>>2]){x[e+4>>2]=b+1;b=y[b|0];break p}b=Zc(e)}if(kk(b)){continue}break}d=d+1|0;break o}b=x[e+4>>2];if((b|0)!=x[e+104>>2]){x[e+4>>2]=b+1;b=y[b|0];break o}b=Zc(e)}if(y[d|0]!=(b|0)){c=x[e+116>>2];if((c|0)>0|(c|0)>=0){x[e+4>>2]=x[e+4>>2]-1}if((b|0)>=0){break a}h=0;if(u){break a}break c}b=x[e+4>>2]-x[e+44>>2]|0;g=b;l=l+x[e+124>>2]|0;c=b>>31;b=m+x[e+120>>2]|0;h=c+(b>>>0<m>>>0?l+1|0:l)|0;m=b+g|0;l=m>>>0<b>>>0?h+1|0:h;b=d;break j}k=0;b=d+2|0;break l}if(!(!ih(b)|y[d+2|0]!=36)){c=y[d+1|0]-48|0;b=hb-16|0;x[b+12>>2]=t;g=b;b=(c>>>0>1?(c<<2)-4|0:0)+t|0;x[g+8>>2]=b+4;k=x[b>>2];b=d+3|0;break l}k=x[t>>2];t=t+4|0;b=d+1|0}s=0;d=0;if(ih(y[b|0])){while(1){d=(y[b|0]+D(d,10)|0)-48|0;c=y[b+1|0];b=b+1|0;if(ih(c)){continue}break}}p=y[b|0];if((p|0)==109){q=0;s=(k|0)!=0;p=y[b+1|0];a=0;b=b+1|0}c=b;b=c+1|0;f=3;h=s;q:{r:{switch(p-65|0){case 39:g=c+2|0;c=y[c+1|0]==104;b=c?g:b;f=c?-2:-1;break q;case 43:g=c+2|0;c=y[c+1|0]==108;b=c?g:b;f=c?3:1;break q;case 51:case 57:f=1;break q;case 11:f=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}f=0;b=c}g=y[b|0];c=(g&47)==3;z=c?1:f;r=c?g|32:g;s:{if((r|0)==91){break s}t:{if((r|0)!=110){if((r|0)!=99){break t}d=(d|0)<=1?1:d;break s}KF(k,z,m,l);break j}Jh(e,0,0);while(1){c=x[e+4>>2];u:{if((c|0)!=x[e+104>>2]){x[e+4>>2]=c+1;c=y[c|0];break u}c=Zc(e)}if(kk(c)){continue}break}c=x[e+4>>2];g=x[e+116>>2];if((g|0)>0|(g|0)>=0){c=c-1|0;x[e+4>>2]=c}c=c-x[e+44>>2]|0;f=c;i=l+x[e+124>>2]|0;g=c>>31;c=m+x[e+120>>2]|0;l=g+(c>>>0<m>>>0?i+1|0:i)|0;m=c+f|0;l=m>>>0<c>>>0?l+1|0:l}g=d;o=d>>31;Jh(e,d,o);c=x[e+4>>2];v:{if((c|0)!=x[e+104>>2]){x[e+4>>2]=c+1;break v}if((Zc(e)|0)<0){break f}}c=x[e+116>>2];if((c|0)>0|(c|0)>=0){x[e+4>>2]=x[e+4>>2]-1}c=16;w:{x:{y:{z:{A:{switch(r-88|0){default:c=r-65|0;if(c>>>0>6|!(1<<c&113)){break w}case 9:case 13:case 14:case 15:NF(j+8|0,e,z,0);d=x[e+4>>2]-x[e+44>>2]|0;if(x[e+120>>2]!=(0-d|0)|x[e+124>>2]!=(0-((d>>31)+((d|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((r|16)==115){Sb(j+32|0,-1,257);v[j+32|0]=0;if((r|0)!=115){break x}v[j+65|0]=0;v[j+46|0]=0;w[j+42>>1]=0;w[j+44>>1]=0;break x}h=y[b+1|0];f=(h|0)==94;Sb(j+32|0,f,257);v[j+32|0]=0;c=f?b+2|0:b+1|0;B:{C:{D:{b=y[(f?2:1)+b|0];if((b|0)!=45){if((b|0)==93){break D}f=(h|0)!=94;b=c;break B}f=(h|0)!=94;v[j+78|0]=f;break C}f=(h|0)!=94;v[j+126|0]=f}b=c+1|0}while(1){c=y[b|0];E:{if((c|0)!=45){if(!c){break f}if((c|0)==93){break x}break E}c=45;i=y[b+1|0];if(!i|(i|0)==93){break E}h=b+1|0;b=y[b-1|0];F:{if(i>>>0<=b>>>0){c=i;break F}while(1){b=b+1|0;v[b+(j+32|0)|0]=f;c=y[h|0];if(c>>>0>b>>>0){continue}break}}b=h}v[(c+j|0)+33|0]=f;b=b+1|0;continue};case 23:c=8;break z;case 12:case 29:c=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}c=0}g=0;i=0;f=0;h=0;p=0;A=hb-16|0;hb=A;G:{if(!((c|0)!=1&c>>>0<=36)){x[114240]=28;break G}while(1){d=x[e+4>>2];H:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break H}d=Zc(e)}if(kk(d)){continue}break}I:{J:{switch(d-43|0){case 0:case 2:break J;default:break I}}p=(d|0)==45?-1:0;d=x[e+4>>2];if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break I}d=Zc(e)}K:{L:{M:{N:{if(!((c|0)!=0&(c|0)!=16|(d|0)!=48)){d=x[e+4>>2];O:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break O}d=Zc(e)}if((d&-33)==88){c=16;d=x[e+4>>2];P:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break P}d=Zc(e)}if(y[d+61169|0]<16){break M}c=x[e+116>>2];if((c|0)>0|(c|0)>=0){x[e+4>>2]=x[e+4>>2]-1}Jh(e,0,0);break G}if(c){break N}c=8;break M}c=c?c:10;if(c>>>0>y[d+61169|0]){break N}c=x[e+116>>2];if((c|0)>0|(c|0)>=0){x[e+4>>2]=x[e+4>>2]-1}Jh(e,0,0);x[114240]=28;break G}if((c|0)!=10){break M}f=d-48|0;if(f>>>0<=9){c=0;while(1){c=D(c,10)+f|0;g=c>>>0<429496729;d=x[e+4>>2];Q:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break Q}d=Zc(e)}f=d-48|0;if(g&f>>>0<=9){continue}break}g=c}R:{if(f>>>0>9){break R}h=yna(g,0,10,0);c=lb;n=f;while(1){g=h+n|0;i=g>>>0<n>>>0?c+1|0:c;c=(i|0)==429496729&g>>>0>=2576980378|i>>>0>429496729;d=x[e+4>>2];S:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break S}d=Zc(e)}f=d-48|0;if(c|f>>>0>9){break R}h=yna(g,i,10,0);n=f;c=lb;if((c|0)==-1&(f^-1)>>>0>=h>>>0|(c|0)!=-1){continue}break}c=10;break L}c=10;if(f>>>0<=9){break L}break K}if(c-1&c){h=y[d+61169|0];if(h>>>0<c>>>0){while(1){f=D(c,f)+h|0;g=f>>>0<119304647;d=x[e+4>>2];T:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break T}d=Zc(e)}h=y[d+61169|0];if(g&h>>>0<c>>>0){continue}break}g=f}if(c>>>0<=h>>>0){break L}o=c;while(1){f=yna(g,i,o,0);n=lb;h=h&255;if((n|0)==-1&(h^-1)>>>0<f>>>0){break L}i=n;g=f+h|0;i=g>>>0<h>>>0?i+1|0:i;d=x[e+4>>2];U:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break U}d=Zc(e)}h=y[d+61169|0];if(c>>>0<=h>>>0){break L}Ve(A,o,0,0,0,g,i,0,0);if(!(x[A+8>>2]|x[A+12>>2])){continue}break}break L}n=v[(D(c,23)>>>5&7)+61425|0];f=y[d+61169|0];if(f>>>0<c>>>0){while(1){h=h<<n|f;g=h>>>0<134217728;d=x[e+4>>2];V:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break V}d=Zc(e)}f=y[d+61169|0];if(g&f>>>0<c>>>0){continue}break}g=h}if(c>>>0<=f>>>0){break L}o=n&31;if((n&63)>>>0>=32){h=0;o=-1>>>o|0}else{h=-1>>>o|0;o=h|(1<<o)-1<<32-o}if(!h&g>>>0>o>>>0){break L}while(1){d=g;g=n&31;if((n&63)>>>0>=32){i=d<<g;d=0}else{i=(1<<g)-1&d>>>32-g|i<<g;d=d<<g}g=d|f&255;d=x[e+4>>2];W:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break W}d=Zc(e)}f=y[d+61169|0];if(c>>>0<=f>>>0){break L}if((h|0)==(i|0)&g>>>0<=o>>>0|h>>>0>i>>>0){continue}break}}if(y[d+61169|0]>=c>>>0){break K}while(1){d=x[e+4>>2];X:{if((d|0)!=x[e+104>>2]){x[e+4>>2]=d+1;d=y[d|0];break X}d=Zc(e)}if(y[d+61169|0]<c>>>0){continue}break}x[114240]=68;p=0;g=-1;i=-1}c=x[e+116>>2];if((c|0)>0|(c|0)>=0){x[e+4>>2]=x[e+4>>2]-1}if(!(p|1)&(g&i)==-1){x[114240]=68;g=-2;i=-1;break G}d=g^p;g=d-p|0;c=p>>31;i=(c^i)-((d>>>0<p>>>0)+c|0)|0}hb=A+16|0;d=x[e+4>>2]-x[e+44>>2]|0;if(x[e+120>>2]==(0-d|0)&x[e+124>>2]==(0-((d>>31)+((d|0)!=0)|0)|0)){break g}if(!(!k|(r|0)!=112)){x[k>>2]=g;break w}KF(k,z,g,i);break w}if(!k){break w}d=x[j+16>>2];f=x[j+20>>2];c=x[j+8>>2];g=x[j+12>>2];Y:{switch(z|0){case 0:F=k,G=LF(c,g,d,f),B[F>>2]=G;break w;case 1:F=k,H=Jw(c,g,d,f),C[F>>3]=H;break w;case 2:break Y;default:break w}}x[k>>2]=c;x[k+4>>2]=g;x[k+8>>2]=d;x[k+12>>2]=f;break w}n=(r|0)!=99;f=n?31:d+1|0;Z:{if((z|0)==1){c=k;if(s){c=sd(f<<2);if(!c){break h}}x[j+296>>2]=0;x[j+300>>2]=0;d=0;while(1){a=c;_:{while(1){c=x[e+4>>2];$:{if((c|0)!=x[e+104>>2]){x[e+4>>2]=c+1;c=y[c|0];break $}c=Zc(e)}if(!y[(c+j|0)+33|0]){break _}v[j+27|0]=c;c=Wo(j+28|0,j+27|0,1,j+296|0);if((c|0)==-2){continue}q=0;if((c|0)==-1){break f}if(a){x[(d<<2)+a>>2]=x[j+28>>2];d=d+1|0}if(!s|(d|0)!=(f|0)){continue}break}h=1;f=f<<1|1;c=$r(a,f<<2);if(c){continue}break e}break}q=0;f=a;if(j+296|0?x[j+296>>2]:0){break f}break Z}if(s){d=0;c=sd(f);if(!c){break h}while(1){a=c;while(1){c=x[e+4>>2];aa:{if((c|0)!=x[e+104>>2]){x[e+4>>2]=c+1;c=y[c|0];break aa}c=Zc(e)}if(!y[(c+j|0)+33|0]){f=0;q=a;break Z}v[a+d|0]=c;d=d+1|0;if((f|0)!=(d|0)){continue}break}h=1;f=f<<1|1;c=$r(a,f);if(c){continue}break}q=a;a=0;break e}d=0;if(k){while(1){a=x[e+4>>2];ba:{if((a|0)!=x[e+104>>2]){x[e+4>>2]=a+1;a=y[a|0];break ba}a=Zc(e)}if(y[(a+j|0)+33|0]){v[d+k|0]=a;d=d+1|0;continue}else{f=0;a=k;q=a;break Z}}}while(1){a=x[e+4>>2];ca:{if((a|0)!=x[e+104>>2]){x[e+4>>2]=a+1;a=y[a|0];break ca}a=Zc(e)}if(y[(a+j|0)+33|0]){continue}break}a=0;q=0;f=0}c=x[e+4>>2];h=x[e+116>>2];if((h|0)>0|(h|0)>=0){c=c-1|0;x[e+4>>2]=c}c=c-x[e+44>>2]|0;h=c+x[e+120>>2]|0;i=x[e+124>>2]+(c>>31)|0;i=c>>>0>h>>>0?i+1|0:i;if(!(i|h)|!(n|(g|0)==(h|0)&(i|0)==(o|0))){break i}if(s){x[k>>2]=a}da:{if((r|0)==99){break da}if(f){x[(d<<2)+f>>2]=0}if(!q){q=0;break da}v[d+q|0]=0}a=f}c=x[e+4>>2]-x[e+44>>2]|0;g=c;l=l+x[e+124>>2]|0;f=m+x[e+120>>2]|0;c=(c>>31)+(f>>>0<m>>>0?l+1|0:l)|0;m=f+g|0;l=m>>>0<f>>>0?c+1|0:c;u=((k|0)!=0)+u|0}d=b+1|0;b=y[b+1|0];if(b){continue}break a}break}a=f;break g}h=1;q=0;a=0;break e}h=s;break b}h=s}if(u){break b}}u=-1}if(!h){break a}_b(q);_b(a)}hb=j+304|0;hb=e+144|0;return u}function Fia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;d=hb-304|0;hb=d;Lc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!Lt(b,d+208|0)){break k}if(!dQ(d+208|0)){break k}if(!Qb(b,jd(cQ(d+208|0),lb))){break k}if(!c){B=1;break k}if(!Rc(b,y[d+208|4])){break k}Nd(a,268435456);Gi(a);x[a+480208>>2]=4;f=d+88|0;h=Ub(f,11161);Db(a+1304436|0,h);xb(h);h=Ub(f,6263);Db(a+1304448|0,h);xb(h);x[a+1304496>>2]=4;h=d+16|0;cf(h,d+208|6,48,3);Ic(f,h);Db(a+1304400|0,f);xb(f);w[a+480188>>1]=y[d+262|0]+1;x[a+480228>>2]=y[d+265|0];x[a+480204>>2]=D(y[d+266|0],1e4);x[a+480196>>2]=y[d+267|0];if(y[d+262|0]){f=0;while(1){w[((f<<5)+a|0)+480284>>1]=D(y[(d+f|0)+268|0],17);f=f+1|0;if(f>>>0<y[d+262|0]){continue}break}}w[a+480190>>1]=y[d+300|0];f=y[d+302|0]|y[d+303|0]<<8;h=hb-16|0;hb=h;k=d+192|0;e=k;x[e>>2]=0;x[e+4>>2]=0;x[h+12>>2]=0;Xc(e+8|0);if(f){_Q(k,f);aQ(k,f)}hb=h+16|0;f=y[d+302|0]|y[d+303|0]<<8;x[114414]=0;U(910,b|0,k|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break j}t=kq(d+176|0);q=kq(d+160|0);f=y[d+301|0];x[114414]=0;U(605,b|0,t|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break f}f=y[d+300|0];x[114414]=0;U(605,b|0,q|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break f}if(y[d+300|0]){l=c&2;f=d+88|0;o=f|4;s=d+126|0;r=f|6;f=0;while(1){x[114414]=0;h=f;f=f+1|0;i=D(f,104)+a|0;g=i+484380|0;P(448,g|0,0);e=x[114414];x[114414]=0;l:{m:{if((e|0)!=1){e=Pb(q,h);if(!(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))){break l}e=Pb(q,h);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[114414]=0;e=O(224,b|0,e|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break c}if(!e){break l}x[114414]=0;e=O(911,b|0,d+88|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break c}if(!e){break l}x[114414]=0;T(354,d+72|0,2,r|0);e=x[114414];x[114414]=0;if((e|0)!=1){x[114414]=0;P(355,d+16|0,d+72|0);e=x[114414];x[114414]=0;if((e|0)!=1){break m}}f=N()|0;break b}f=N()|0;break b}x[114414]=0;O(334,((f<<5)+a|0)+946304|0,d+16|0)|0;e=x[114414];x[114414]=0;n:{o:{if((e|0)!=1){xb(d+16|0);x[114414]=0;T(912,d+72|0,2,s|0);e=x[114414];x[114414]=0;if((e|0)==1){break o}x[114414]=0;P(355,d+16|0,d+72|0);e=x[114414];x[114414]=0;if((e|0)==1){break o}x[114414]=0;O(335,i+484423|0,d+16|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break n}xb(d+16|0);if(y[d+138|0]<=15){e=i+484414|0;w[e>>1]=z[e>>1]|32;w[i+484408>>1]=D(y[d+138|0],17)}e=y[d+139|0];x[114414]=0;v[d+16|0]=e;v[d+72|0]=64;e=O(409,d+16|0,d+72|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break g}w[i+484412>>1]=y[e|0];x[i+484404>>2]=y[d+141|0]|y[d+142|0]<<8;m=i+484384|0;x[m>>2]=y[d+147|0]|y[d+148|0]<<8|(y[d+149|0]<<16|y[d+150|0]<<24);n=i+484388|0;x[n>>2]=y[d+151|0]|y[d+152|0]<<8|(y[d+153|0]<<16|y[d+154|0]<<24);x[g>>2]=y[d+155|0]|y[d+156|0]<<8|(y[d+157|0]<<16|y[d+158|0]<<24);e=x[m>>2];j=x[n>>2];if(v[d+140|0]&1){e=e>>>1|0;x[m>>2]=e;j=j>>>1|0;x[n>>2]=j;x[g>>2]=x[g>>2]>>>1}p:{if(e>>>0>=j>>>0){break p}e=i+484414|0;w[e>>1]=z[e>>1]|2;if(!(y[d+140|0]&2)){break p}w[e>>1]=z[e>>1]|4}x[114414]=0;W(913,g|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}if(!l){break l}h=Pb(q,h);h=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);e=y[o|0];x[114414]=0;O(224,b|0,e+h|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break c}h=ad(d+16|0,v[d+140|0]&1?16:8,1,0,1);x[114414]=0;U(361,h|0,g|0,b|0)|0;h=x[114414];x[114414]=0;if((h|0)!=1){break l}f=N()|0;break b}f=N()|0;xb(d+16|0);break b}f=N()|0;break b}f=N()|0;xb(d+16|0);break b}if(y[d+300|0]>f>>>0){continue}break}}B=1;q:{if(!(c&1)){break q}x[d+68>>2]=0;i=a+484360|0;wq(Vb(i));G=d,H=bc(k),x[G+64>>2]=H;G=d,H=dc(k),x[G+56>>2]=H;if(Hb(d- -64|0,d+56|0)){j=a+484344|0;c=d+88|0;s=c|5;m=c|4;while(1){h=x[d- -64>>2];c=h;r:{if(y[c+3|0]>=y[d+301|0]|y[c+2|0]>y[d+262|0]){break r}c=Pb(t,y[c+3|0]);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[114414]=0;c=O(224,b|0,c|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break h}if(!c){break r}x[114414]=0;O(914,b|0,d+88|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break i}if(!y[m|0]){break r}f=y[h|0]|y[h+1|0]<<8;c=f;v[d+16|0]=y[s|0];e=y[d+262|0];g=y[h+2|0];x[114414]=0;v[d+72|0]=e-g;e=O(409,d+16|0,d+72|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}n=y[e|0];e=y[h|0]|y[h+1|0]<<8;g=y[m|0];x[114414]=0;x[d+52>>2]=e+g;e=O(915,d+68|0,d+52|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break e}x[d+68>>2]=x[e>>2];x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;if(!y[m|0]){break r}r=c>>>6|0;e=f&63;A=0;while(1){s:{t:{u:{v:{w:{x:{y:{f=e>>>0>63;r=f+r|0;c=r&65535;if(qc(Vb(i))>>>0<=c>>>0){g=Vb(i);x[114414]=0;P(901,g|0,r+1&65535);g=x[114414];x[114414]=0;if((g|0)==1){break y}x[114414]=0;g=U(791,j|0,64,0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break y}G=uc(Vb(i),c),H=g,w[G>>1]=H}l=z[uc(Vb(i),c)>>1];x[114414]=0;c=O(392,j|0,l|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break w}if(!c){break r}c=Zb(j,l);g=y[h+2|0];x[114414]=0;u=f?0:e;f=U(427,c|0,u|0,g|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break t}o=0;if(n){break x}break u}f=N()|0;break b}while(1){x[114414]=0;P(916,d+72|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break v}c=d+72|0;g=ed(c);E=rf(c);C=$h(c);F=mc(c);e=0;c=y[c|0];if((c-1&255)>>>0<=142){e=(D((c&240)>>>4|0,12)+(c&15)|0)+13|0;v[(d+16|0)+o|0]=e}v[f|0]=e;c=y[g|0];v[f+2|0]=1;v[f+1|0]=c;c=y[E|0];z:{if((c|0)!=255){v[f+4|0]=c;break z}v[f+2|0]=0}c=y[C|0];A:{if(c>>>0>22){break A}v[f+3|0]=y[c+23968|0];g=y[F|0];v[f+5|0]=g;c=f+5|0;B:{switch(y[C|0]-4|0){case 3:v[c|0]=g&3|64;break A;case 4:v[c|0]=g&3|48;break A;case 7:if(Lb(k)>>>0<=g>>>0){break A}g=c;c=Pb(k,y[c|0]);e=y[c|0]|y[c+1|0]<<8;v[g|0]=e>>>6;c=Zb(j,l);g=z[a+480188>>1];x[114414]=0;c=U(427,c|0,u|0,g-1&65535)|0;g=x[114414];x[114414]=0;if((g|0)!=1){v[c+3|0]=14;v[c+5|0]=e&63;break A}f=N()|0;break b;case 8:v[c|0]=x[d+52>>2]>>>6;c=Zb(j,l);e=z[a+480188>>1];x[114414]=0;c=U(427,c|0,u|0,e-1&65535)|0;e=x[114414];x[114414]=0;if((e|0)!=1){v[c+3|0]=14;v[c+5|0]=y[d+52|0]&63;break A}f=N()|0;break b;case 10:v[c|0]=g&15|128;break A;case 12:x[114414]=0;v[d+15|0]=15;e=O(409,c|0,d+15|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){v[c|0]=y[e|0]|208;break A}f=N()|0;break b;case 13:x[114414]=0;v[d+15|0]=15;e=O(409,c|0,d+15|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){v[c|0]=y[e|0]|192;break A}f=N()|0;break b;case 14:x[114414]=0;v[d+15|0]=15;e=O(409,c|0,d+15|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){v[c|0]=y[e|0]|224;break A}f=N()|0;break b;case 0:case 16:case 17:if(!(g&15)){break A}e=g&240;if(!e|(e|0)==240){break A}v[c|0]=g|15;break A;case 9:case 18:break B;default:break A}}if(e&255){break A}v[f|0]=y[(d+16|0)+o|0]}f=f+6|0;o=o+1|0;if((n|0)!=(o|0)){continue}break}break u}f=N()|0;break b}f=N()|0;break b}if(n>>>0>=y[s|0]){break s}c=y[s|0];x[114414]=0;O(304,b|0,D(c-n|0,5)|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break s}}f=N()|0;break b}e=u+1|0;A=A+1|0;if(A>>>0<y[m|0]){continue}break}}c=d- -64|0;fe(c);if(Hb(c,d+56|0)){continue}break}}C:{b=x[d+68>>2];c=b&63;if(!c){break C}f=Vb(i);x[114414]=0;b=b>>>6|0;f=O(513,f|0,b&65535)|0;h=x[114414];x[114414]=0;if((h|0)!=1){if(!f){break C}b=Zb(a+484344|0,z[uc(Vb(i),b&65535)>>1]);x[114414]=0;Z(917,b|0,c|0,0,1)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break C}}f=N()|0;break b}b=Vb(i);G=d,H=bc(b),x[G+88>>2]=H;G=d,H=dc(b),x[G+16>>2]=H;if(!Hb(d+88|0,d+16|0)){break q}a=a+484344|0;e=65535;while(1){b=x[d+88>>2];if(z[b>>1]==65535){D:{if((e&65535)!=65535){break D}x[114414]=0;e=U(791,a|0,64,0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break D}f=N()|0;break b}w[b>>1]=e}b=d+88|0;ge(b);if(Hb(b,d+16|0)){continue}break}}Ui(q);Ui(t);bQ(k)}hb=d+304|0;return B|0}f=N()|0;break a}f=N()|0;break b}f=N()|0;break b}f=N()|0;break b}f=N()|0;break b}f=N()|0;break b}f=N()|0;break b}f=N()|0}Ui(q);Ui(t)}bQ(k);Q(f|0);p()}function Nma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-288|0;hb=e;Lc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!KA(b,e+216|0)){break j}if(!GT(e+216|0)){break j}if(!c){d=1;break j}Nd(a,131072);f=Ub(e+200|0,11298);x[114414]=0;P(187,e+80|0,f|0);h=x[114414];x[114414]=0;k:{l:{m:{n:{o:{p:{q:{if((h|0)!=1){x[114414]=0;T(504,e+152|0,e+80|0,e+216|4);h=x[114414];x[114414]=0;if((h|0)==1){break q}h=e+152|0;Db(a+1304436|0,h);xb(h);d=e+80|0;Gb(d);xb(f);f=Ub(h,7019);Db(a+1304448|0,f);xb(f);x[a+1304496>>2]=4;YT(d,3,e+229|0);Ic(h,d);Db(a+1304400|0,h);xb(h);f=e+120|0;_n(f,3,e+259|0);Ic(d,f);x[114414]=0;T(13,h|0,4,d|0);h=x[114414];x[114414]=0;if((h|0)==1){break i}h=e+152|0;Db(a+1304412|0,h);xb(h);xb(e+80|0);h=tq(h);m=h,n=Md(y[e+279|0],1,31),x[m+12>>2]=n;m=h,n=Md(y[e+280|0],1,12)-1|0,x[m+16>>2]=n;x[h+20>>2]=y[e+281|0];d=a+1304500|0;JA(d);FT(d,h);j=e+120|4;d=hb-16|0;hb=d;h=e+136|0;x[h>>2]=0;x[h+4>>2]=0;x[114414]=0;x[d+12>>2]=0;U(526,h+8|0,d+12|0,d+8|0)|0;f=x[114414];x[114414]=0;r:{if((f|0)!=1){hb=d+16|0;break r}S(0)|0;zb();p()}while(1){x[114414]=0;d=O(226,b|0,8)|0;f=x[114414];x[114414]=0;if((f|0)==1){break o}if(!d){break k}x[114414]=0;O(505,b|0,e+120|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break n}f=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);d=y[e+220|0];s:{if((d|0)==3){g=2;if((y[e+120|0]|y[e+121|0]<<8|(y[e+122|0]<<16|y[e+123|0]<<24))==1431389523){break s}d=y[e+220|0]}if((d&255)==4){g=4;if((y[e+120|0]|y[e+121|0]<<8|(y[e+122|0]<<16|y[e+123|0]<<24))==1431389523){break s}d=y[e+220|0]}g=0;if((d&255)>>>0>7){break s}f=(y[e+120|0]|y[e+121|0]<<8|(y[e+122|0]<<16|y[e+123|0]<<24))==1146113363?-1:f}x[114414]=0;T(307,e+80|0,b|0,f|0);d=x[114414];x[114414]=0;if((d|0)==1){break m}x[114414]=0;U(506,h|0,e+120|0,e+80|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break l}Ab(e+80|0);x[114414]=0;O(304,b|0,g|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}d=N()|0;break b}d=N()|0;break p}d=N()|0;Gb(e+80|0)}xb(f);break a}d=N()|0;break b}d=N()|0;break b}d=N()|0;break b}d=N()|0;Ab(e+80|0);break b}x[114414]=0;b=R(239,e+120|0)|0;d=x[114414];x[114414]=0;t:{u:{v:{if((d|0)!=1){x[114414]=0;T(507,e+80|0,h|0,1431389523);d=x[114414];x[114414]=0;if((d|0)==1){break v}d=e+80|0;Ud(b,d);Ab(d);w[e+118>>1]=0;w[e+116>>1]=65534;if(y[e+220|0]<3){break t}x[114414]=0;d=R(321,b|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){break u}break d}d=N()|0;break b}d=N()|0;break c}w[e+118>>1]=d;if(y[e+220|0]<4){break t}x[114414]=0;d=R(321,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}w[e+116>>1]=y[e+220|0]==4?d?d:-2:d}d=a+484360|0;f=Vb(d);x[114414]=0;g=R(296,b|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break d}x[114414]=0;aa(390,f|0,b|0,g>>>1|0,65535,65535)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}f=Vb(d);x[114414]=0;f=R(508,f|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}sg(e+118|0,f);f=Vb(d);x[114414]=0;f=R(508,f|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}sg(e+116|0,f);x[114414]=0;T(507,e+80|0,h|0,1414807888);f=x[114414];x[114414]=0;w:{x:{y:{z:{A:{B:{C:{D:{if((f|0)!=1){f=e+80|0;Ud(b,f);Ab(f);x[114414]=0;f=R(303,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}if(!(c&1)|f^1){break w}x[114414]=0;O(509,b|0,e+32|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break D}m=a,n=Md(y[e+32|2],1,32)+1|0,w[m+480188>>1]=n;f=y[e+32|0]|y[e+33|0]<<8;x[114414]=0;f=O(360,e+104|0,f|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break C}m=e,n=bc(f),x[m+64>>2]=n;m=e,n=dc(f),x[m+48>>2]=n;if(Hb(e- -64|0,e+48|0)){while(1){j=x[e- -64>>2];x[114414]=0;g=y[e+220|0]<3?9:8;O(304,b|0,g-4|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break B}x[114414]=0;i=R(391,b|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break A}ng(b,g);x[114414]=0;T(307,e+80|0,b|0,g+i|0);g=x[114414];x[114414]=0;if((g|0)==1){break z}g=e+80|0;Ud(j,g);Ab(g);g=e- -64|0;of(g);if(Hb(g,e+48|0)){continue}break}}g=z[a+480188>>1];x[114414]=0;g=O(510,e+80|0,g|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break y}j=Vb(d);x[114414]=0;i=R(511,j|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break f}x[114414]=0;j=a+484344|0;P(362,j|0,i|0);i=x[114414];x[114414]=0;if((i|0)==1){break f}i=Vb(d);m=e,n=bc(i),x[m+64>>2]=n;m=e,n=dc(i),x[m+48>>2]=n;if(Hb(e- -64|0,e+48|0)){while(1){i=x[e- -64>>2];k=z[i>>1];if(rd(f)>>>0>k>>>0){k=vc(f,z[i>>1]);x[114414]=0;k=Z(512,k|0,y[e+220|0],g|0,a|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break f}w[i>>1]=k}i=e- -64|0;ge(i);if(Hb(i,e+48|0)){continue}break}}i=Vb(d);x[114414]=0;i=O(513,i|0,z[e+116>>1])|0;k=x[114414];x[114414]=0;if((k|0)==1){break f}if(!i){break x}if(!z[e+118>>1]){i=z[e+116>>1];k=Vb(d);x[114414]=0;k=R(508,k|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break f}if(i>>>0>=k>>>0){break x}}d=z[uc(Vb(d),z[e+116>>1])>>1];i=Zb(j,d);x[114414]=0;k=U(454,e- -64|0,12,y[e+118|0])|0;l=x[114414];x[114414]=0;if((l|0)!=1){d=Zn(Ie(k,x[Zb(j,d)+12>>2]-1|0));x[114414]=0;O(455,i|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break x}}break f}d=N()|0;break c}d=N()|0;break c}d=N()|0;break c}d=N()|0;break e}d=N()|0;break e}d=N()|0;break e}d=N()|0;break e}xT(g);id(f)}x[114414]=0;T(507,e+48|0,h|0,1196641603);d=x[114414];x[114414]=0;if((d|0)==1){break h}d=e+48|0;Ud(b,d);Ab(d);x[114414]=0;d=R(303,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}if(d){x[114414]=0;O(304,b|0,1)|0;d=x[114414];x[114414]=0;if((d|0)==1){break d}x[114414]=0;d=R(296,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}x[114414]=0;aa(514,a+1304424|0,b|0,d|0,40,0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break d}}x[114414]=0;T(507,e+48|0,h|0,1146113363);d=x[114414];x[114414]=0;if((d|0)==1){break g}x[114414]=0;T(507,e+32|0,h|0,1229999443);d=x[114414];x[114414]=0;E:{F:{if((d|0)!=1){d=e+32|0;Ud(b,d);Ab(d);x[114414]=0;d=R(403,b|0)|0;f=x[114414];x[114414]=0;G:{if((f|0)!=1){w[a+480190>>1]=d;if(z[a+480190>>1]){j=!(c&2);d=1;c=1;while(1){g=30;H:{I:{J:{if(y[e+220|0]>=2){x[114414]=0;g=R(403,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break J}}x[114414]=0;U(515,b|0,((d<<5)+a|0)+946304|0,g|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break J}x[114414]=0;O(516,b|0,e+32|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break I}x[114414]=0;d=D(d,104)+a|0;g=d+484380|0;P(517,e+32|0,g|0);f=x[114414];x[114414]=0;if((f|0)==1){break I}f=y[e+220|0];if(f>>>0>=8){x[114414]=0;U(518,b|0,d+484423|0,8)|0;f=x[114414];x[114414]=0;if((f|0)==1){break I}f=y[e+220|0]}x[114414]=0;O(304,b|0,((f&255)>>>0>1?6:2)|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break I}x[114414]=0;f=R(391,e+48|0)|0;i=x[114414];x[114414]=0;if((i|0)!=1){x[114414]=0;T(307,e+16|0,e+48|0,f|0);f=x[114414];x[114414]=0;if((f|0)!=1){break H}}d=N()|0;break F}d=N()|0;break F}d=N()|0;break F}x[114414]=0;f=R(303,e+16|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break G}K:{if(j|f^1){break K}d=ad(e+8|0,w[d+484414>>1]&1?16:8,1,0,(y[e+47|0]&12)==4?7:0);x[114414]=0;U(361,d|0,g|0,e+16|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break K}break G}Ab(e+16|0);c=c+1|0;d=c&65535;if(d>>>0<=z[a+480190>>1]){continue}break}}x[114414]=0;W(432,a|0);c=x[114414];x[114414]=0;d=1;if((c|0)!=1){break E}}d=N()|0;break F}d=N()|0;Ab(e+16|0);break F}d=N()|0}Ab(e+48|0);break c}x[a+480204>>2]=12e5;x[a+480208>>2]=24;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+480228>>2]=48;x[a+480232>>2]=48;Ab(e+48|0);Ab(b);ET(h)}hb=e+288|0;return d|0}d=N()|0;xb(e+80|0);break a}d=N()|0;break c}d=N()|0;break c}d=N()|0;xT(g)}id(f);break c}d=N()|0}Ab(b)}ET(h)}Q(d|0);p()}function oI(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=hb-272|0;hb=h;a:{b:{if(g){Lj(h+256|0,f,32);x[114414]=0;U(779,h+240|0,f|0,32)|0;i=x[114414];x[114414]=0;if((i|0)!=1){break b}c=N()|0;break a}Wb(h+256|0);Wb(h+240|0)}c:{d:{e:{f:{g:{h:{if(ws(c)){i=b+24|0;b=x[i>>2];x[114414]=0;b=O(392,b+484344|0,c&65535)|0;j=x[114414];x[114414]=0;if((j|0)==1){break h}if(b){break g}}x[114414]=0;T(2223,a|0,h+256|0,h+240|0);a=x[114414];x[114414]=0;if((a|0)!=1){break f}}c=N()|0;break c}b=Zb(x[i>>2]+484344|0,c);if(!(!((e|0)<0|x[b+12>>2]<=(d|0)|(d|0)<0)&z[x[i>>2]+480188>>1]>e>>>0)){x[114414]=0;T(2223,a|0,h+256|0,h+240|0);a=x[114414];x[114414]=0;if((a|0)!=1){break f}c=N()|0;break c}x[114414]=0;c=U(2224,b|0,d|0,e&65535)|0;b=x[114414];x[114414]=0;if((b|0)==1){break e}He(h+256|0);He(h+240|0);x[114414]=0;b=R(520,c|0)|0;d=x[114414];x[114414]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((d|0)!=1){A:{B:{if(!b){if(!Ss(c)){break B}}b=x[i>>2];d=y[c+1|0];e=y[c|0];x[114414]=0;X(2225,h+208|0,b|0,e|0,d|0);d=x[114414];x[114414]=0;b=1;if((d|0)==1){break z}x[114414]=0;T(9,h+224|0,0,h+208|0);d=x[114414];x[114414]=0;if((d|0)!=1){break A}c=N()|0;break w}b=0;x[114414]=0;O(118,h+224|0,12709)|0;d=x[114414];x[114414]=0;if((d|0)==1){break y}}x[114414]=0;O(1251,h+256|0,h+224|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break x}xb(h+224|0);if(b){xb(h+208|0)}x[114414]=0;b=R(520,c|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break v}if(b){b=5954}else{b=Ss(c)?6259:12709}x[114414]=0;b=O(118,h+224|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break v}x[114414]=0;O(1251,h+240|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break u}xb(b);if(f-6>>>0>4294967290){break m}x[114414]=0;b=O(118,h+192|0,13671)|0;d=x[114414];x[114414]=0;if((d|0)==1){break t}x[114414]=0;O(1251,h+256|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break s}xb(b);x[114414]=0;b=O(118,h+176|0,13671)|0;d=x[114414];x[114414]=0;if((d|0)==1){break r}x[114414]=0;O(1251,h+240|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break q}xb(b);b=c+1|0;C:{if(y[c+1|0]){x[114414]=0;P(816,h+160|0,b|0);d=x[114414];x[114414]=0;if((d|0)!=1){break C}break d}x[114414]=0;O(118,h+160|0,12714)|0;d=x[114414];x[114414]=0;if((d|0)==1){break d}}x[114414]=0;O(1251,h+256|0,h+160|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break p}d=h+160|0;xb(d);b=y[b|0];x[114414]=0;b=O(118,d|0,(b?6741:12714)|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break o}x[114414]=0;O(1251,h+240|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break n}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;break c}c=N()|0;break c}c=N()|0;xb(h+224|0);if(!b){break c}}xb(h+208|0);break c}c=N()|0;break c}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;xb(b);break c}c=N()|0;xb(h+160|0);break c}c=N()|0;break c}xb(b);if(f-9>>>0>4294967287){break m}x[114414]=0;b=R(1345,c|0)|0;d=x[114414];x[114414]=0;D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{if((d|0)!=1){O:{if(b){x[114414]=0;e=O(118,h+128|0,13671)|0;d=x[114414];x[114414]=0;if((d|0)==1){break N}x[114414]=0;j=R(1347,c|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break M}d=0;x[114414]=0;x[h+96>>2]=j&255;P(815,h+112|0,h+96|0);j=x[114414];x[114414]=0;if((j|0)==1){break M}x[114414]=0;T(137,h+144|0,e|0,h+112|0);e=x[114414];x[114414]=0;if((e|0)!=1){break O}c=N()|0;break H}if(y[c+2|0]){d=x[x[i>>2]+8>>2];e=y[c+2|0];x[114414]=0;d=O(2226,d|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break F}x[114414]=0;e=U(779,h+128|0,1,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break F}x[114414]=0;P(816,h+112|0,c+4|0);j=x[114414];x[114414]=0;d=1;if((j|0)==1){break L}x[114414]=0;T(137,h+144|0,e|0,h+112|0);e=x[114414];x[114414]=0;if((e|0)!=1){break O}c=N()|0;break J}d=0;x[114414]=0;O(118,h+144|0,12713)|0;e=x[114414];x[114414]=0;if((e|0)==1){break l}}x[114414]=0;O(1251,h+256|0,h+144|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break K}xb(h+144|0);if(d){xb(h+112|0);xb(h+128|0)}if(b){xb(h+112|0);xb(h+128|0)}x[114414]=0;b=R(1345,c|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break E}b=b?1974:y[c+2|0]?1970:12713;x[114414]=0;b=O(118,h+144|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break E}x[114414]=0;O(1251,h+240|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break D}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;break c}c=N()|0;break G}c=N()|0;xb(e);break c}c=N()|0;xb(h+144|0);if(!d){break I}}xb(h+112|0);xb(h+128|0)}if(!b){break c}}xb(h+112|0)}xb(h+128|0);break c}c=N()|0;break c}c=N()|0;break c}xb(b);if(f-13>>>0>4294967283){break m}x[114414]=0;b=O(118,h+96|0,13671)|0;d=x[114414];x[114414]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{if((d|0)!=1){x[114414]=0;O(1251,h+256|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break _}xb(b);x[114414]=0;b=O(118,h+80|0,13671)|0;d=x[114414];x[114414]=0;if((d|0)==1){break Z}x[114414]=0;O(1251,h+240|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break Y}xb(b);x[114414]=0;b=R(1345,c|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break X}$:{if(b){b=0;x[114414]=0;d=R(1346,c|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){x[114414]=0;x[h+16>>2]=d&4095;P(1046,h- -64|0,h+16|0);d=x[114414];x[114414]=0;if((d|0)!=1){break $}}c=N()|0;break c}if(y[c+3|0]){b=x[x[i>>2]+8>>2];d=y[c+3|0];x[114414]=0;b=O(2227,b|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break W}x[114414]=0;d=U(779,h+48|0,1,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break W}x[114414]=0;P(816,h+32|0,c+5|0);e=x[114414];x[114414]=0;b=1;if((e|0)==1){break V}x[114414]=0;T(137,h- -64|0,d|0,h+32|0);d=x[114414];x[114414]=0;if((d|0)!=1){break $}c=N()|0;break S}b=0;x[114414]=0;O(118,h- -64|0,12709)|0;d=x[114414];x[114414]=0;if((d|0)==1){break U}}x[114414]=0;O(1251,h+256|0,h- -64|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break T}xb(h- -64|0);if(b){xb(h+32|0);xb(h+48|0)}x[114414]=0;b=R(1345,c|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break Q}b=b?7027:y[c+3|0]?7027:12709;x[114414]=0;b=O(118,h- -64|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break Q}x[114414]=0;O(1251,h+240|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break P}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;break c}c=N()|0;break R}c=N()|0;break c}c=N()|0;xb(h- -64|0);if(!b){break c}}xb(h+32|0)}xb(h+48|0);break c}c=N()|0;break c}xb(b);if(!f){break i}}aa:{ba:{if(Bb(h+256|0)>>>0>f>>>0){x[114414]=0;X(200,h+16|0,h+256|0,0,f|0);b=x[114414];x[114414]=0;if((b|0)!=1){break ba}c=N()|0;break c}if(g){b=Bb(h+256|0);x[114414]=0;b=U(779,h+16|0,f-b|0,32)|0;c=x[114414];x[114414]=0;if((c|0)==1){break k}x[114414]=0;O(1251,h+256|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){c=N()|0;xb(b);break c}xb(b);if(Bb(h+240|0)>>>0>f>>>0){break j}break aa}if(Bb(h+240|0)>>>0<=f>>>0){break i}break j}b=h+16|0;Db(h+256|0,b);xb(b);if(Bb(h+240|0)>>>0>f>>>0){break j}if(!g){break i}}b=Bb(h+240|0);x[114414]=0;b=U(779,h|0,f-b|0,32)|0;c=x[114414];x[114414]=0;ca:{if((c|0)!=1){x[114414]=0;O(1251,h+240|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break ca}xb(b);break i}c=N()|0;break c}c=N()|0;xb(b);break c}c=N()|0;break c}c=N()|0;break c}x[114414]=0;X(200,h|0,h+240|0,0,f|0);b=x[114414];x[114414]=0;if((b|0)!=1){Db(h+240|0,h);xb(h);break i}c=N()|0;break c}x[114414]=0;T(2223,a|0,h+256|0,h+240|0);a=x[114414];x[114414]=0;if((a|0)==1){break e}}xb(h+240|0);xb(h+256|0);hb=h+272|0;return}c=N()|0;break c}c=N()|0}xb(h+240|0)}xb(h+256|0);Q(c|0);p()}function PF(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;k=hb-336|0;hb=k;n=h;p=i&65535;o=d;m=e&65535;u=(e^i)&-2147483648;s=i>>>16&32767;q=e>>>16&32767;a:{b:{if(s-32767>>>0>4294934529&q-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){r=d;u=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){r=h;u=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;u=2147450880;break a}u=u|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));r=b?0:r;u=b?2147450880:u;b=0;c=0;break a}if(!(f|h|(e|g))){u=u|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){d=!(m|o);i=d;j=d?b:o;d=d<<6;h=d;i=G(i?c:m);d=d+((i|0)==32?G(j)+32|0:i)|0;gf(k+320|0,b,c,o,m,d-15|0);v=16-d|0;o=x[k+328>>2];m=x[k+332>>2];c=x[k+324>>2];b=x[k+320>>2]}if(e>>>0>65535){break b}d=!(n|p);h=d;i=d?f:n;d=d<<6;e=d;h=G(h?g:p);d=d+((h|0)==32?G(i)+32|0:h)|0;gf(k+304|0,f,g,n,p,d-15|0);v=(d+v|0)-16|0;n=x[k+312>>2];p=x[k+316>>2];f=x[k+304>>2];g=x[k+308>>2]}e=p|65536;C=e;D=n;d=n;j=e<<15|d>>>17;e=d<<15|g>>>17;d=e;i=0-d|0;h=j;j=1963258675-(j+((d|0)!=0)|0)|0;Ve(k+288|0,d,h,0,0,i,j,0,0);d=x[k+296>>2];Ve(k+272|0,0-d|0,0-(x[k+300>>2]+((d|0)!=0)|0)|0,0,0,i,j,0,0);d=x[k+280>>2];i=d<<1|x[k+276>>2]>>>31;d=x[k+284>>2]<<1|d>>>31;Ve(k+256|0,i,d,0,0,e,h,0,0);j=x[k+264>>2];Ve(k+240|0,i,d,0,0,0-j|0,0-(x[k+268>>2]+((j|0)!=0)|0)|0,0,0);i=x[k+248>>2];j=i<<1|x[k+244>>2]>>>31;d=x[k+252>>2]<<1|i>>>31;Ve(k+224|0,j,d,0,0,e,h,0,0);i=x[k+232>>2];Ve(k+208|0,j,d,0,0,0-i|0,0-(x[k+236>>2]+((i|0)!=0)|0)|0,0,0);d=x[k+216>>2];i=d<<1|x[k+212>>2]>>>31;d=x[k+220>>2]<<1|d>>>31;Ve(k+192|0,i,d,0,0,e,h,0,0);j=x[k+200>>2];Ve(k+176|0,i,d,0,0,0-j|0,0-(x[k+204>>2]+((j|0)!=0)|0)|0,0,0);i=e;e=x[k+184>>2];d=h;n=e<<1|x[k+180>>2]>>>31;h=n-1|0;e=(x[k+188>>2]<<1|e>>>31)-!n|0;Ve(k+160|0,i,d,0,0,h,e,0,0);d=h;Ve(k+144|0,f<<15,g<<15|f>>>17,0,0,d,e,0,0);t=k+112|0;z=x[k+168>>2];h=x[k+172>>2];n=x[k+160>>2];i=x[k+152>>2];l=n+i|0;p=x[k+164>>2];j=p+x[k+156>>2]|0;j=i>>>0>l>>>0?j+1|0:j;i=j;j=(p|0)==(j|0)&l>>>0<n>>>0|j>>>0<p>>>0;p=j+z|0;j=j>>>0>p>>>0?h+1|0:h;n=!i&l>>>0>1|(i|0)!=0;h=n+p|0;j=n>>>0>h>>>0?j+1|0:j;Ve(t,d,e,0,0,0-h|0,0-(((h|0)!=0)+j|0)|0,0,0);Ve(k+128|0,1-l|0,0-((l>>>0>1)+i|0)|0,0,0,d,e,0,0);K=(q-s|0)+v|0;e=x[k+116>>2];t=e;d=x[k+112>>2];j=e<<1|d>>>31;n=d<<1;q=j;d=j;h=x[k+140>>2];B=h;e=x[k+136>>2];j=h<<1|e>>>31;i=e<<1|x[k+132>>2]>>>31;h=i+n|0;d=d+j|0;d=h>>>0<i>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;y=d;z=d;l=0;j=m|65536;L=j;M=o;d=o;j=j<<1|d>>>31;O=d<<1;P=j;F=j;d=yna(y,l,j,0);j=lb;H=d;w=j;v=b<<1;d=c<<1|b>>>31;s=d;j=0;p=j;i=h-13927|0;y=(e|0)==(y|0)&i>>>0<h>>>0|e>>>0>y>>>0;e=(e|0)==(q|0)&h>>>0<n>>>0|e>>>0<q>>>0;d=x[k+120>>2];h=x[k+124>>2]<<1|d>>>31;d=d<<1|t>>>31;j=h;l=B>>>31|0;d=l+d|0;j=d>>>0<l>>>0?j+1|0:j;h=d;d=d+e|0;l=h>>>0>d>>>0?j+1|0:j;e=d;d=d+y|0;l=e>>>0>d>>>0?l+1|0:l;e=d-1|0;y=l-!d|0;q=0;j=yna(s,p,y,q);d=j+H|0;h=lb+w|0;h=d>>>0<j>>>0?h+1|0:h;t=(w|0)==(h|0)&d>>>0<H>>>0|h>>>0<w>>>0;j=0;B=e;N=c>>>31|0;E=N|o<<1;w=0;e=yna(e,j,E,w);o=e+d|0;j=lb+h|0;l=0;j=e>>>0>o>>>0?j+1|0:j;n=j;d=(j|0)==(h|0)&d>>>0>o>>>0|h>>>0>j>>>0;e=d;d=d+t|0;l=e>>>0>d>>>0?1:l;e=yna(F,p,y,q);d=e+d|0;j=lb+l|0;t=d;d=d>>>0<e>>>0?j+1|0:j;e=yna(F,p,B,w);m=lb;h=e;e=yna(E,w,y,q);l=h+e|0;j=lb+m|0;j=e>>>0>l>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&h>>>0>l>>>0|j>>>0<m>>>0;m=t+e|0;d=d+j|0;d=m>>>0<e>>>0?d+1|0:d;t=m;m=d;e=0;d=e+o|0;j=l+n|0;j=d>>>0<e>>>0?j+1|0:j;e=j;h=(j|0)==(n|0)&d>>>0<o>>>0|j>>>0<n>>>0;j=m;l=h;h=h+t|0;j=l>>>0>h>>>0?j+1|0:j;I=h;l=j;t=d;m=d;o=e;H=i;d=yna(i,0,E,w);h=lb;e=d;i=yna(z,r,s,r);d=d+i|0;j=lb+h|0;j=d>>>0<i>>>0?j+1|0:j;i=(h|0)==(j|0)&d>>>0<e>>>0|h>>>0>j>>>0;h=j;J=v&-2;e=yna(B,w,J,0);n=e+d|0;j=lb+j|0;j=e>>>0>n>>>0?j+1|0:j;e=j;d=(j|0)==(h|0)&d>>>0>n>>>0|h>>>0>j>>>0;h=0;i=d+i|0;d=(i>>>0<d>>>0?1:h)+o|0;j=l;m=i+m|0;d=m>>>0<i>>>0?d+1|0:d;i=d;d=(d|0)==(o|0)&m>>>0<t>>>0|d>>>0<o>>>0;h=d;d=d+I|0;j=h>>>0>d>>>0?j+1|0:j;Q=d;t=j;d=yna(F,p,H,r);I=lb;F=d;h=yna(y,q,J,r);d=d+h|0;j=lb+I|0;o=d;p=yna(z,r,E,w);l=d+p|0;h=d>>>0<h>>>0?j+1|0:j;d=h+lb|0;d=l>>>0<p>>>0?d+1|0:d;q=l;j=yna(s,r,B,w);p=l+j|0;l=lb+d|0;l=j>>>0>p>>>0?l+1|0:l;B=0;E=(d|0)==(l|0)&p>>>0<q>>>0|d>>>0>l>>>0;j=(h|0)==(I|0)&o>>>0<F>>>0|h>>>0<I>>>0;d=(d|0)==(h|0)&o>>>0>q>>>0|d>>>0<h>>>0;d=d+j|0;d=d+E|0;h=l;q=h+m|0;j=(d|B)+i|0;j=h>>>0>q>>>0?j+1|0:j;o=j;d=(i|0)==(j|0)&m>>>0>q>>>0|i>>>0>j>>>0;j=t;h=d;d=d+Q|0;j=h>>>0>d>>>0?j+1|0:j;B=d;i=j;d=yna(z,r,J,r);z=lb;m=d;h=yna(s,r,H,r);d=d+h|0;j=lb+z|0;j=d>>>0<h>>>0?j+1|0:j;t=0;h=(j|0)==(z|0)&d>>>0<m>>>0|j>>>0<z>>>0;m=j;d=j+n|0;j=(h|t)+e|0;j=d>>>0<m>>>0?j+1|0:j;h=j;m=(e|0)==(j|0)&d>>>0<n>>>0|e>>>0>j>>>0;j=p;p=0;n=p+d|0;l=h+j|0;j=0;l=n>>>0<p>>>0?l+1|0:l;d=(h|0)==(l|0)&d>>>0>n>>>0|h>>>0>l>>>0;e=d;d=d+m|0;j=(e>>>0>d>>>0?1:j)+o|0;l=i;e=d;d=d+q|0;j=e>>>0>d>>>0?j+1|0:j;e=j;h=(o|0)==(j|0)&d>>>0<q>>>0|j>>>0<o>>>0;i=h;h=h+B|0;l=i>>>0>h>>>0?l+1|0:l;i=l;c:{if((l|0)==131071|l>>>0<131071){M=O|N;L=w|P;Ve(k+80|0,d,e,h,i,f,g,D,C);l=x[k+84>>2];p=l;j=b<<17;n=0;m=x[k+88>>2];c=n-m|0;b=x[k+80>>2];l=(l|b)!=0;o=c-l|0;m=(j-(x[k+92>>2]+(m>>>0>n>>>0)|0)|0)-(c>>>0<l>>>0)|0;n=0-b|0;p=0-(((b|0)!=0)+p|0)|0;b=K+16382|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;Ve(k+96|0,d,e,h,i,f,g,D,C);o=x[k+100>>2];s=o;v=x[k+104>>2];n=0-v|0;l=x[k+96>>2];m=(o|l)!=0;o=n-m|0;m=((b<<16)-(x[k+108>>2]+(p>>>0<v>>>0)|0)|0)-(m>>>0>n>>>0)|0;n=0-l|0;p=0-(((l|0)!=0)+s|0)|0;v=b;s=c;b=K+16383|0}if((b|0)>=32767){u=u|2147418112;b=0;c=0;break a}d:{if((b|0)>0){l=m<<1|o>>>31;o=o<<1|p>>>31;m=l;v=h;s=i&65535|b<<16;l=p<<1|n>>>31;i=n<<1;break d}if((b|0)<=-113){b=0;c=0;break a}Al(k- -64|0,d,e,h,i,1-b|0);gf(k+48|0,v,s,M,L,b+112|0);d=x[k+64>>2];e=x[k+68>>2];v=x[k+72>>2];s=x[k+76>>2];Ve(k+32|0,f,g,D,C,d,e,v,s);b=x[k+40>>2];c=x[k+56>>2];l=x[k+36>>2];o=b<<1|l>>>31;n=c-o|0;m=x[k+60>>2]-((x[k+44>>2]<<1|b>>>31)+(c>>>0<o>>>0)|0)|0;b=x[k+32>>2];h=l<<1|b>>>31;j=b<<1;i=x[k+52>>2];c=x[k+48>>2];b=(h|0)==(i|0)&j>>>0>c>>>0|h>>>0>i>>>0;o=n-b|0;m=m-(b>>>0>n>>>0)|0;l=i-((c>>>0<j>>>0)+h|0)|0;i=c-j|0}b=i;Ve(k+16|0,f,g,D,C,3,0,0,0);Ve(k,f,g,D,C,5,0,0,0);c=0;h=l+c|0;j=d&1;b=b+j|0;h=i>>>0>b>>>0?h+1|0:h;i=b;g=(g|0)==(h|0)&b>>>0>f>>>0|g>>>0<h>>>0;l=m;b=(c|0)==(h|0)&b>>>0<j>>>0|c>>>0>h>>>0;f=b+o|0;l=b>>>0>f>>>0?l+1|0:l;j=e;b=(l|0)==(C|0);b=b&(f|0)==(D|0)?g:b&f>>>0>D>>>0|l>>>0>C>>>0;c=b;b=b+d|0;j=c>>>0>b>>>0?j+1|0:j;c=j;d=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;j=s;e=d;d=d+v|0;j=e>>>0>d>>>0?j+1|0:j;g=d;e=x[k+20>>2];m=(e|0)==(h|0)&A[k+16>>2]<i>>>0|e>>>0<h>>>0;e=x[k+28>>2];d=x[k+24>>2];e=j>>>0<2147418112&((d|0)==(f|0)&(e|0)==(l|0)?m:(e|0)==(l|0)&d>>>0<f>>>0|e>>>0<l>>>0);d=c;m=e;e=b+e|0;d=m>>>0>e>>>0?d+1|0:d;b=(c|0)==(d|0)&b>>>0>e>>>0|c>>>0>d>>>0;c=b;b=b+g|0;j=c>>>0>b>>>0?j+1|0:j;g=b;c=x[k+4>>2];h=(c|0)==(h|0)&A[k>>2]<i>>>0|c>>>0<h>>>0;c=x[k+12>>2];b=x[k+8>>2];b=j>>>0<2147418112&((b|0)==(f|0)&(c|0)==(l|0)?h:(c|0)==(l|0)&b>>>0<f>>>0|c>>>0<l>>>0);c=b;b=b+e|0;l=c>>>0>b>>>0?d+1|0:d;c=l;e=(d|0)==(l|0)&b>>>0<e>>>0|d>>>0>l>>>0;d=j;f=e;e=e+g|0;d=f>>>0>e>>>0?d+1|0:d;r=e|r;u=d|u}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=r;x[a+12>>2]=u;hb=k+336|0}function Pla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;d=hb-272|0;hb=d;Lc(b);f=hb-16|0;hb=f;g=f+8|0;j=d+112|0;QS(g,j);h=Eb(g);g=nc(b,ac(f,g));if((h|0)==(g|0)){cc(b,Eb(f+8|0))}hb=f+16|0;f=(g|0)==(h|0);if(!f){RS(j)}a:{b:{c:{d:{e:{f:{g:{if(!f){break g}if(!TS(d+112|0)){break g}if(!c){e=1;break g}Nd(a,x[((y[d+228|0]|y[d+229|0]<<8)<<2)+23504>>2]);x[a+480208>>2]=x[a+480208>>2]|16777216;e=d+16|0;f=Ub(e,8972);Db(a+1304436|0,f);xb(f);e=Ub(e,6294);Db(a+1304448|0,e);xb(e);g=Ub(d+80|0,11095);x[114414]=0;P(187,d+96|0,g|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;X(376,d+16|0,d+96|0,d+191|0,d+188|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}e=d+16|0;Db(a+1304460|0,e);xb(e);f=d+96|0;Gb(f);xb(g);Pc(a+1304484|0,((y[d+228|0]|y[d+229|0]<<8)<<2)+23552|0);Pc(a+1304472|0,x[((y[d+228|0]|y[d+229|0]<<8)<<2)+76272>>2]);x[a+1304496>>2]=4;Kg(f,2,d+112|4);Ic(e,f);Db(a+1304400|0,e);xb(e);Kg(f,2,d+148|0);Ic(e,f);h:{i:{j:{if(ku(e,5662)){x[114414]=0;T(13,d+96|0,4,d+16|0);e=x[114414];x[114414]=0;if((e|0)==1){break j}e=d+96|0;Db(a+1304412|0,e);xb(e)}xb(d+16|0);w[a+480188>>1]=32;f=0;k:{while(1){g=(f<<5)+a|0;j=g+480280|0;Lg(j);l:{e=d+f|0;if(y[e+193|0]<=15){x[d+16>>2]=y[e+193|0]<<4|8;x[d+96>>2]=256;s=g+480284|0,t=x[be(d+16|0,d+96|0)>>2],w[s>>1]=t;break l}if(y[e+193|0]==16){w[g+480284>>1]=128;x[j>>2]=256;break l}if(y[e+193|0]!=255){break l}w[a+480188>>1]=f;break k}f=f+1|0;if((f|0)!=32){continue}break}f=z[a+480188>>1]}e=0;if(!(f&65535)){break g}x[d+16>>2]=y[d+225|0]<<2;x[d+96>>2]=256;s=a,t=x[Mb(d+16|0,d+96|0)>>2],x[s+480200>>2]=t;x[a+480196>>2]=y[d+226|0];x[a+480204>>2]=D(y[d+227|0],1e4);if(Rc(b,y[d+230|0]|y[d+231|0]<<8|(y[d+232|0]<<16|y[d+233|0]<<24))){oq(Vb(a+484360|0),b,y[d+234|0]+1|0,255,254)}if(!Rc(b,y[d+240|0]|y[d+241|0]<<8|(y[d+242|0]<<16|y[d+243|0]<<24))){break g}w[a+480190>>1]=y[d+248|0]+1;h=d+48|0;f=1;j=1;while(1){e=hb-16|0;hb=e;i=hb-16|0;hb=i;g=e+8|0;k=d+16|0;jc(g,k,62);hb=i+16|0;i=Eb(g);g=nc(b,ac(e,g));if((i|0)==(g|0)){cc(b,Eb(e+8|0))}hb=e+16|0;e=(g|0)==(i|0);if(!e){g=hb-16|0;hb=g;Sb(k,0,62);hb=g+16|0}if(e){e=D(f,104)+a|0;g=e+484380|0;Ad(g,0);Kg(d,2,d+16|0);i=d+96|0;Ic(i,d);x[114414]=0;O(334,((f<<5)+a|0)+946304|0,i|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break e}f=d+96|0;xb(f);Wk(d,2,h);Ic(f,d);x[114414]=0;O(335,e+484423|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break f}xb(d+96|0);f=e+484404|0;x[f>>2]=y[d+74|0]|y[d+75|0]<<8;m:{if(!lq(a)){break m}i=x[f>>2];f=0;while(1){if((i|0)==z[(f<<1)+23600>>1]){v[e+484417|0]=f<<4;break m}f=f+1|0;if((f|0)!=16){continue}break}}w[e+484412>>1]=64;x[g>>2]=y[d+61|0]|y[d+62|0]<<8|(y[d+63|0]<<16|y[d+64|0]<<24);if(y[d+73|0]&2){f=e+484414|0;w[f>>1]=z[f>>1]|1;x[g>>2]=x[g>>2]>>>1}x[e+484384>>2]=y[d+65|0]|y[d+66|0]<<8|(y[d+67|0]<<16|y[d+68|0]<<24);x[e+484388>>2]=(y[d+69|0]|y[d+70|0]<<8|(y[d+71|0]<<16|y[d+72|0]<<24))-1;if(v[d+73|0]&1){f=e+484414|0;w[f>>1]=z[f>>1]|2}n:{if(y[d+73|0]&4){v[d+96|0]=y[d+76|0];v[d|0]=64;s=e+484410|0,t=y[rc(d+96|0,d)|0]<<2,w[s>>1]=t;break n}f=e+484414|0;w[f>>1]=z[f>>1]|32768}o:{if(!(y[d+73|0]&8)){w[e+484408>>1]=128;break o}f=e+484414|0;w[f>>1]=z[f>>1]|32;m=e+484408|0;if(y[d+77|0]<=15){e=y[d+77|0];x[d>>2]=256;x[d+96>>2]=e<<4|8;e=x[be(d+96|0,d)>>2]}else{e=128}w[m>>1]=e;w[f>>1]=z[f>>1]&65279|(y[d+77|0]==16)<<8}j=j+1|0;f=j&65535;if(f>>>0<=z[a+480190>>1]){continue}}break}p:{if(!(c&2)){break p}if(!Rc(b,y[d+244|0]|y[d+245|0]<<8|(y[d+246|0]<<16|y[d+247|0]<<24))|!z[a+480190>>1]){break p}f=1;while(1){e=D(f&65535,104)+a|0;Eg(ad(d+16|0,w[e+484414>>1]&1?16:8,1,0,1),e+484380|0,b);f=f+1|0;if(z[a+480190>>1]>=(f&65535)>>>0){continue}break}}n=a+484344|0;cg(n,y[d+239|0]+1|0);f=up(a);e=hb-16|0;hb=e;x[e+12>>2]=0;Xs(e+12|0,f);i=x[e+12>>2];hb=e+16|0;Rc(b,y[d+235|0]|y[d+236|0]<<8|(y[d+237|0]<<16|y[d+238|0]<<24));q=c&1;j=0;k=1;while(1){c=pg(b);if(c>>>0>=3){Bd(d+16|0,b,c-2|0);q:{if(!q){break q}x[114414]=0;c=R(303,d+16|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break i}if(!c){break q}x[114414]=0;c=U(363,n|0,j&65535,64)|0;e=x[114414];x[114414]=0;if((e|0)==1){break i}l=0;if(!c){break q}while(1){c=Zb(n,j);x[114414]=0;r=O(453,c|0,l|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break i}r:{s:while(1){t:{x[114414]=0;c=R(403,d+16|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break t}if(!c){break r}e=c&31;if(e>>>0>=z[a+480188>>1]){break r}f=D(e,6)+r|0;if(c&32){x[114414]=0;P(428,d+96|0,d+16|0);e=x[114414];x[114414]=0;if((e|0)==1){break i}g=ed(d+96|0);e=y[d+96|0];if(e){e=(e&127)-1|0;v[d+96|0]=e;v[f|0]=(D((e&240)>>>4|0,12)+(e&15)|0)+13;x[114414]=0;e=R(588,f|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break i}k=e&k}v[f+1|0]=y[g|0]}if(!(c&64)){continue}v[f+2|0]=0;v[f+3|0]=0;g=f+5|0;while(1){x[114414]=0;c=O(226,d+16|0,2)|0;e=x[114414];x[114414]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((e|0)!=1){if(!c){continue s}o=y[f+5|0];c=y[f+3|0];x[114414]=0;P(428,d+96|0,d+16|0);e=x[114414];x[114414]=0;if((e|0)==1){break i}e=d+96|0;m=e;h=y[ed(e)|0];v[g|0]=h;e=y[(y[e|0]&31)+23632|0];v[f+3|0]=e;switch(e-2|0){case 4:case 5:break y;case 18:break z;case 13:break A;case 17:break B;case 11:break C;case 1:break D;case 0:break E;default:break w}}break i}if(h>>>0<224){break u}break v}if(h>>>0>=224){break v}break u}x[114414]=0;v[d|0]=64;e=O(409,g|0,d|0)|0;h=x[114414];x[114414]=0;if((h|0)!=1){v[g|0]=y[e|0];x[114414]=0;e=O(589,i|0,1)|0;h=x[114414];x[114414]=0;if((h|0)==1){break i}if(!e){break x}v[f+2|0]=1;v[f+4|0]=y[g|0];v[f+3|0]=c;v[g|0]=o;e=c;break w}break i}F:{switch(((h&240)>>>4|0)-8|0){case 0:v[f+3|0]=2;v[g|0]=h&15|224;break u;case 1:v[f+3|0]=3;v[g|0]=h&15|224;break u;default:break F}}x[114414]=0;e=O(590,i|0,19)|0;h=x[114414];x[114414]=0;if((h|0)==1){break i}if(e){break x}x[114414]=0;W(591,f|0);e=x[114414];x[114414]=0;if((e|0)!=1){break x}break i}x[114414]=0;e=O(590,i|0,15)|0;h=x[114414];x[114414]=0;if((h|0)==1){break i}if(e){break x}x[114414]=0;e=O(590,i|0,19)|0;h=x[114414];x[114414]=0;if((h|0)==1){break i}if(!e){break x}v[f+3|0]=19;v[g|0]=y[g|0]&15|144;break u}if((h|0)==1){v[g|0]=145;break u}if((h&240)==128){x[114414]=0;e=O(590,i|0,20)|0;h=x[114414];x[114414]=0;if((h|0)==1){break i}if(e){break x}v[f+3|0]=19;break u}v[f+3|0]=0;break u}e=h&240;if(!e){break u}v[g|0]=e}e=y[f+3|0]}if((e&255)!=20){break u}e=y[g|0];if(y[f+2|0]|(e&240)!=128){break u}v[f+2|0]=2;v[f+4|0]=(((e&15)<<6|8)>>>0)/15;v[f+3|0]=c;v[g|0]=o;break u}v[g|0]=223}if(y[m|0]&32){continue}break}continue}break}break i}l=l+1|0;if((l|0)!=64){continue}break}}Ab(d+16|0)}c=y[d+239|0]>j>>>0;j=j+1|0;if(c){continue}break}break h}e=N()|0;xb(d+16|0);break a}e=N()|0;Ab(d+16|0);break a}if(x[a+480180>>2]!=1){c=x[a+480208>>2]&-8454145}else{c=x[a+480208>>2]&-8454145|(z[a+480188>>1]==4?k&1?8454144:0:0)}x[a+480208>>2]=c;e=1;if(!(y[d+253|0]|y[d+254|0]<<8|(y[d+255|0]<<16|y[d+256|0]<<24))){break g}if(!Rc(b,y[d+249|0]|y[d+250|0]<<8|(y[d+251|0]<<16|y[d+252|0]<<24))){break g}pz(a+1304424|0,b,y[d+253|0]|y[d+254|0]<<8|(y[d+255|0]<<16|y[d+256|0]<<24),4)}hb=d+272|0;return e|0}e=N()|0;xb(d+96|0);break a}e=N()|0;xb(d+96|0);break a}e=N()|0;Gb(d+96|0);break b}e=N()|0}xb(g)}Q(e|0);p()}function nja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,S=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;e=hb-352|0;hb=e;a:{if(!Rc(b,1080)){break a}if(!Un(b,e+348|0)){break a}Nd(a,1);l=VQ(e+328|0);if(!UQ(e+348|0,l)){break a}i=z[l+10>>1];d=i;if(!d|d>>>0>127){break a}b:{if(!c){break b}w[a+480188>>1]=i;q=y[l+14|0];K=y[l+13|0];d=y[l+12|0];I=1;if(!Yd(e+348|0,23928)){I=Yd(e+348|0,23933)}if(y[l+15|0]){Nb(a+1074312|0,5,1);i=z[a+480188>>1]}f=e+348|0;s=Yd(f,12601);n=1;if(!Yd(f,13268)){n=Yd(e+348|0,9453)}Rc(b,0);tA(b,a+1304400|0,20);w[a+480190>>1]=31;k=(d|0)!=0;h=1;g=s;d=0;while(1){o=D(h,104)+a|0;f=o+484380|0;t=Pz(b,e+192|0,f,((h<<5)+a|0)+946304|0,z[a+480188>>1]==4);f=x[f>>2];c:{if(n){v[o+484417|0]=0-(y[e+216|0]<<3);break c}k=f>>>0<65536&k}d:{if(!(!(y[e+214|0]|y[e+215|0]<<8)|(y[e+220|0]|y[e+221|0]<<8))){$=1;break d}if(y[e+214|0]|y[e+215|0]<<8){break d}L=y[e+217|0]==64|L}o=g&1;g=0;e:{if(!o){break e}B=m;m=y[e+214|0]|y[e+215|0]<<8;m=B+(((m<<8|m>>>8)&65535)<<1)|0;if(y[e+216|0]){break e}if(!(y[e+214|0]|y[e+215|0]<<8)){g=1;break e}g=y[e+217|0]==64}d=d+t|0;j=f+j|0;h=h+1|0;if((h|0)!=32){continue}break}h=0;if(A[l+4>>2]<d>>>0){break a}F=a+480188|0;t=(i&65535)==8&(K|0)!=0;d=e+192|0;Oz(b,d);Rc(b,z[l+8>>1]);o=d|1;h=y[o|0];f=128;i=a+484360|0;$n(Vb(i),d|2,128,65535,65535);h=!h&g;n=h?m:0;d=y[d|0];f:{if(d>>>0>128){break f}f=d;if(d){break f}g=128;while(1){d=g-1|0;if(!z[uc(Vb(i),d)>>1]){f=1;g=d;if(d>>>0>1){continue}break f}break}f=g}G=(q|0)!=0;q=SQ(b,Vb(i),f&65535,j,F,n,0);if(!(!h|z[a+480188>>1]!=8)){x[l>>2]=7143;G=1}g:{if(!t){break g}d=Vb(i);ba=e,ca=bc(d),x[ba+176>>2]=ca;ba=e,ca=dc(d),x[ba+160>>2]=ca;if(!Hb(e+176|0,e+160|0)){break g}while(1){d=e+176|0;g=x[d>>2];w[g>>1]=z[g>>1]>>>1;ge(d);if(Hb(d,e+160|0)){continue}break}}Se(Vb(i),y[o|0]);M=f-1&65535;h:{if(M>>>0>=y[o|0]){h=z[F>>1];if(y[o|0]!=120|(h|0)!=4){break h}}Se(Vb(i),0);h=z[F>>1]}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;d=Xb(256/((h&65535)>>>0)|0,32,128);x[a+480208>>2]=0;x[a+480228>>2]=d;uj(a,0);v[e+191|0]=0;h=1;O=1;if(!(k&1)){i:{if(!q){d=s;f=0;break i}u=e+176|5;k=0;d=s;m=0;n=0;while(1){f=0;E=0;while(1){g=_h(e+176|0);St(b,g);i=SS(g);j:{k:{l:{m:{j=y[e+179|0];if((j-7&255)>>>0<3){d=0;break m}g=y[e+181|0];if(!((j|0)!=14|g>>>0<=1)){d=0;break l}if(!((j|0)==15&(g&255)>>>0>31)){d=i?d:0;if((j|0)!=13){break m}E=E+1|0;if((E&65535)>>>0<2){break j}}d=0;break j}if((j|0)==8){break k}if((j|0)!=14){break j}g=y[e+181|0]}if((g&240)!=128){break j}v[e+160|0]=g<<4;ba=e,ca=y[Xg(e+191|0,e+160|0)|0],v[ba+191|0]=ca;break j}ba=e,ca=y[Xg(e+191|0,u)|0],v[ba+191|0]=ca;g=v[e+181|0];if((g|0)>=0){n=1;break j}m=(g|0)!=-92&g>>>0>4294967183|m}h=h&i;f=f+1|0;if((f|0)!=256){continue}break}k=k+1|0;if(q>>>0>(k&65535)>>>0){continue}break}f=0;if((n^-1|m)&1){break i}f=y[e+191|0]>47}O=d&1;E=f}Rc(b,z[l+8>>1]);d=z[a+480188>>1];u=a+484344|0;f=q+t|0;g=f&65535;cg(u,g);S=t?4:d;n:{o:{if(!g){m=0;n=0;break o}V=S&65535;W=f&65535;aa=a+1074312|0;B=c&1;k=0;n=0;m=0;p:{while(1){f=!B;q:{if(t){d=(k&65534)>>>1|0;g=k&1;if(!g){if(!Tg(u,d,64)){break o}}d=Df(Zb(u,d),0,g<<2);break q}if(!Tg(u,k&65535,64)){break o}d=Df(Zb(u,k),0,0)}j=d;if(f|!j){break o}d=z[a+480188>>1];v[e+96|0]=0;f=d;d=e+96|0;q=xu(e+176|0,f,d);f=z[a+480188>>1];x[114414]=0;v[e+96|0]=0;H=U(858,e+160|0,f|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){J=0;while(1){d=0;X=0;i=0;if(V){while(1){x[114414]=0;g=D(i,6)+j|0;P(859,b|0,g|0);f=x[114414];x[114414]=0;r:{s:{t:{if((f|0)==1){break t}f=y[g+3|0];u:{v:{w:{if(!f){if(y[g+5|0]){break w}break v}if(!K){break w}x:{switch(f-14|0){case 0:v[g+3|0]=0;v[g+5|0]=0;break w;case 1:break x;default:break w}}if(y[g+5|0]<32){break w}v[g+5|0]=31}Fj(g);f=1;y:{z:{A:{r=y[g+3|0];switch(r-14|0){case 2:break u;case 0:break z;case 3:break A;default:break y}}m=y[g+5|0]<100|m;X=1;break v}if(!O){break v}v[g+5|0]=0;break v}if((r|0)==9&E){f=y[g+5|0];if((f|0)==164){v[g+3|0]=20;v[g+5|0]=145;break v}x[114414]=0;f=R(860,f<<1)|0;r=x[114414];x[114414]=0;if((r|0)==1){break t}v[g+5|0]=f;break v}if((r|0)!=19){break v}f=y[g+5|0];if(f>>>0>15){break v}r=!(f&1);f=(r^Y)&1;Y=f?r:Y;n=f+n|0}f=d}if(y[g|0]){break s}if(t|!y[g+1|0]){break r}if(!y[Bc(q,i)|0]){break r}if(y[Bc(q,i)|0]==y[g+1|0]){break r}r=Bc(H,i);d=y[r|0]+1|0;v[r|0]=d;if((d&255)>>>0<4){break r}x[114414]=0;U(434,aa|0,85,1)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break r}}h=N()|0;$d(H);break p}ba=Bc(H,i),ca=0,v[ba|0]=ca}d=y[g+1|0];if(d){ba=Bc(q,i),ca=d,v[ba|0]=ca}d=f;i=i+1|0;if((V|0)!=(i|0)){continue}break}}Z=d&X|Z;j=D(z[F>>1],6)+j|0;J=J+1|0;if((J|0)!=64){continue}break}$d(H);$d(q);k=k+1|0;if((W|0)==(k|0)){break o}continue}break}h=N()|0}$d(q);break n}B:{C:{D:{if((h^-1|$)&1){break D}E:{if(Yd(e+348|0,12601)){break E}if(Yd(e+348|0,13273)){break E}if(!Yd(e+348|0,9448)){break D}}x[a+480208>>2]=x[a+480208>>2]|2162688;d=a+1074312|0;Nb(d,85,1);Nb(d,91,1);Nb(d,92,1);F:{if(y[e+191|0]>47){break F}Nb(d,84,1);if(y[o|0]==127){break F}Nb(d,83,1)}if(!((n|0)>6|G)){break C}break B}if(!h){if(s^1|y[o|0]!=127|y[o|0]+1>>>0<M>>>0){break B}x[l>>2]=4557;break B}if((n|0)>6|G){break B}}x[a+480208>>2]=x[a+480208>>2]|8388608}if((s|G)==1){Nb(a+1074312|0,89,1)}if(I){Nb(a+1074312|0,84,1)}if(c&2){Rc(b,z[l+8>>1]+(D(S&65535,W)<<8)|0);f=(h&s^1|L)&1;h=1;while(1){g=D(h,104)+a|0;c=g+484380|0;if(x[c>>2]){d=e+176|0;if(I){B=2}else{B=RQ(b,9645)?11:0}d=ad(d,8,1,0,B);j=x[b+8>>2]+IS(d,x[c>>2])|0;if(!f){ba=c,ca=x[_c(c,g+484388|0)>>2],x[ba>>2]=ca}Eg(d,c,b);Rc(b,j)}h=h+1|0;if((h|0)!=32){continue}break}}G:{if((m&s^-1|Z)&1){break G}b=QQ(e+136|0,0);c=x[b+20>>2];x[e+40>>2]=x[b+16>>2];x[e+44>>2]=c;c=x[b+12>>2];x[e+32>>2]=x[b+8>>2];x[e+36>>2]=c;c=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=c;b=e+176|0;ht(b,a,0,e+24|0);_=C[x[b>>2]>>3];_l(b);if(_<480){break G}c=a+1074312|0;Nb(c,5,1);b=PQ(e+112|0,_);d=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=d;d=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=d;d=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=d;b=e+176|0;ht(b,a,0,e);d=y[x[b>>2]+26|0];_l(b);if(d){Ig(c,5);break G}x[l>>2]=12957}c=e+348|0;b=c;d=mc(b);if((b|0)!=(d|0)){while(1){f=y[c|0];v[b|0]=f>>>0<=32?32:f;b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}b=Ub(e+80|0,13145);x[114414]=0;P(187,e+96|0,b|0);c=x[114414];x[114414]=0;H:{I:{J:{K:{L:{M:{if((c|0)!=1){c=e+348|0;d=mc(c);x[114414]=0;c=U(861,e+48|0,c|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break M}x[114414]=0;T(13,e- -64|0,1,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break L}x[114414]=0;T(215,e+176|0,e+96|0,e- -64|0);d=x[114414];x[114414]=0;if((d|0)==1){break K}d=e+176|0;Db(a+1304436|0,d);xb(d);xb(e- -64|0);xb(c);Gb(e+96|0);xb(b);b=Ub(d,8133);Db(a+1304448|0,b);xb(b);b=x[l>>2];if(b){Pc(a+1304460|0,b)}x[a+1304496>>2]=2;break b}h=N()|0;break H}h=N()|0;break I}h=N()|0;break J}h=N()|0;xb(e- -64|0)}xb(c)}Gb(e+96|0)}xb(b)}Q(h|0);p()}h=1}hb=e+352|0;return h|0}function SU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;e=hb-208|0;hb=e;Lc(b);a:{b:{c:{d:{e:{if(!RB(b,e+160|0)){break e}if(!SB(e+160|0)){break e}if(!c){o=1;break e}Nd(a,2048);Gi(a);d=Ub(e+128|0,11312);x[114414]=0;P(187,e+144|0,d|0);f=x[114414];x[114414]=0;if((f|0)==1){break c}x[114414]=0;k=e+160|3;T(348,e+48|0,e+144|0,k|0);f=x[114414];x[114414]=0;if((f|0)==1){break d}f=e+48|0;Db(a+1304436|0,f);xb(f);g=e+144|0;Gb(g);xb(d);d=Ub(f,7023);Db(a+1304448|0,d);xb(d);x[a+1304496>>2]=4;w[a+480188>>1]=y[e+200|0];w[a+480190>>1]=y[e+196|0];Kg(g,2,e+160|4);Ic(f,g);Db(a+1304400|0,f);xb(f);if(y[k|0]<=8){w[a+480188>>1]=4;ng(b,1);uj(a,1)}f=y[k|0];f:{if(y[k|0]>=11){f=f>>>0>11?32:16;d=0;while(1){g=Yu(b);g:{if((g|0)==100){x[((d<<5)+a|0)+480280>>2]=256;break g}x[e+48>>2]=(g<<1)+128;x[e+144>>2]=0;x[e+32>>2]=256;u=((d<<5)+a|0)+480284|0,A=x[dl(e+48|0,e+144|0,e+32|0)>>2],w[u>>1]=A}d=d+1|0;if((f|0)!=(d|0)){continue}break}break f}if(f>>>0<9){break f}QB(b,e+48|0);d=0;while(1){w[((d<<5)+a|0)+480284>>1]=v[(e+48|0)+d|0]&1?64:192;d=d+1|0;if((d|0)!=16){continue}break}}h:{if(y[k|0]>=13){d=e+48|0;Ru(d,b);g=ed(d);f=y[d|0];if(f>>>0<=31){v[d|0]=125;f=125}x[a+480204>>2]=D(f,1e4);x[a+480196>>2]=y[g|0];break h}x[a+480196>>2]=6;x[a+480204>>2]=125e4}f=a+484360|0;mg(Vb(f),y[e+197|0]);l=jm(e+144|0);q=x[b+8>>2];r=y[k|0];i:{j:{k:{l:{if(y[k|0]<14){break l}d=y[e+197|0];x[114414]=0;P(349,l|0,d|0);d=x[114414];x[114414]=0;if((d|0)!=1){break l}a=N()|0;break k}m:{n:{o:{p:{q:{r:{s:{t:{u:{if(y[e+197|0]){d=0;while(1){u=uc(Vb(f),d),A=d,w[u>>1]=A;if(y[k|0]>=14){x[114414]=0;g=R(321,b|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break u}u=uc(l,d),A=g,w[u>>1]=A}g=z[a+480188>>1];x[114414]=0;O(304,b|0,g<<1)|0;g=x[114414];x[114414]=0;if((g|0)==1){break u}d=d+1|0;if(d>>>0<y[e+197|0]){continue}break}}f=0;v:{w:{if(y[k|0]==10){m=x[b+8>>2];f=0;x:{if(!z[a+480190>>1]){break x}g=1;while(1){x[114414]=0;f=O(350,b|0,e+48|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break w}y:{if(!f){break y}j=y[e+196|0];h=0;d=e+48|0;z:{if(y[d|0]>1){break z}f=d+46|0;if(j>>>0<(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24))>>>0){break z}f=d+50|0;if((y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24))>>>0>1048576|y[d+56|0]>64){break z}j=d+57|0;if((y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24))>>>0>(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24))>>>0){break z}d=d+61|0;h=(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))>>>0<=(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24))>>>0}if(h){break y}f=1;break x}g=g+1|0;if(z[a+480190>>1]>=(g&65535)>>>0){continue}break}f=0}x[114414]=0;O(224,b|0,m|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break v}}d=z[a+480190>>1];x[114414]=0;x[e+48>>2]=0;m=U(351,e+32|0,d|0,e+48|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){if(z[a+480190>>1]){j=f?59:65;h=e+48|1;d=1;g=1;while(1){A:{if(y[k|0]<=9){x[114414]=0;O(352,b|0,e+48|0)|0;i=x[114414];x[114414]=0;B:{C:{D:{if((i|0)==1){break D}x[114414]=0;P(353,e+48|0,(D(d,104)+a|0)+484380|0);i=x[114414];x[114414]=0;if((i|0)==1){break D}x[114414]=0;T(354,e|0,2,h|0);i=x[114414];x[114414]=0;if((i|0)==1){break C}x[114414]=0;P(355,e+16|0,e|0);i=x[114414];x[114414]=0;if((i|0)==1){break C}x[114414]=0;O(334,((d<<5)+a|0)+946304|0,e+16|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break B}break A}a=N()|0;break m}a=N()|0;break m}a=N()|0;xb(e+16|0);break m}x[114414]=0;U(356,b|0,e+48|0,j|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break n}x[114414]=0;T(357,e+48|0,(D(d,104)+a|0)+484380|0,f|0);i=x[114414];x[114414]=0;if((i|0)==1){break n}x[114414]=0;T(354,e|0,2,h|0);i=x[114414];x[114414]=0;if((i|0)==1){break o}x[114414]=0;P(355,e+16|0,e|0);i=x[114414];x[114414]=0;if((i|0)==1){break o}x[114414]=0;O(334,((d<<5)+a|0)+946304|0,e+16|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break p}}xb(e+16|0);i=y[e+94|0]|y[e+95|0]<<8|(y[e+96|0]<<16|y[e+97|0]<<24);u=Pb(m,d-1|0),A=i,x[u>>2]=A;g=g+1|0;d=g&65535;if(d>>>0<=z[a+480190>>1]){continue}break}}j=Cq(e+16|0);f=y[e+198|0]|y[e+199|0]<<8;x[114414]=0;o=U(358,b|0,j|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break t}if(!o){break i}f=0;E:{if(!od(j)){f=bc(j);d=dc(j);x[114414]=0;f=O(359,f|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break E}x[e+48>>2]=f;f=x[e+48>>2];f=y[f|0]|y[f+1|0]<<8}x[114414]=0;i=O(360,e|0,f|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){F:{if(f){g=0;while(1){x[114414]=0;d=R(321,b|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break s}x[114414]=0;O(304,b|0,1)|0;h=x[114414];x[114414]=0;if((h|0)==1){break s}if(d){h=y[k|0];x[114414]=0;T(307,e+48|0,b|0,D(d,3)+((h|0)==1?3:0)|0);d=x[114414];x[114414]=0;if((d|0)==1){break F}d=e+48|0;Ud(vc(i,g),d);Ab(d)}g=g+1|0;if((f|0)!=(g|0)){continue}break}}G:{if(!(c&2)){break G}h=1;n=ad(e+48|0,8,1,0,1);if(!z[a+480190>>1]){break G}g=1;while(1){x[114414]=0;d=O(226,b|0,1)|0;s=x[114414];x[114414]=0;H:{I:{if((s|0)!=1){if(!d){break G}d=0;if(!z[a+480190>>1]){break H}s=x[b+8>>2];while(1){J:{if(x[Pb(m,d)>>2]!=(h|0)){d=d+1|0;break J}x[114414]=0;O(224,b|0,s|0)|0;t=x[114414];x[114414]=0;if((t|0)==1){break I}x[114414]=0;d=d+1|0;U(361,n|0,(D(d,104)+a|0)+484380|0,b|0)|0;t=x[114414];x[114414]=0;if((t|0)==1){break I}}if(z[a+480190>>1]>d>>>0){continue}break}break H}a=N()|0;break r}a=N()|0;break r}g=g+1|0;h=g&65535;if(h>>>0<=z[a+480190>>1]){continue}break}}if(!(c&1)){break j}c=y[e+197|0];h=0;x[114414]=0;n=a+484344|0;P(362,n|0,c|0);c=x[114414];x[114414]=0;K:{if((c|0)!=1){if(!y[e+197|0]){break j}q=q+((r>>>0>13)<<1)|0;while(1){L:{g=64;if(qc(l)>>>0>h>>>0){g=z[uc(l,h)>>1]}x[114414]=0;c=U(363,n|0,h&65535,g&65535)|0;d=x[114414];x[114414]=0;if((d|0)==1){break K}M:{if(c){c=z[a+480188>>1];d=y[k|0];x[114414]=0;O(224,b|0,q+D(((d>>>0>13)<<1)+(c<<1)|0,h)|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break K}c=Cq(e+48|0);d=z[a+480188>>1];x[114414]=0;d=U(358,b|0,c|0,d|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break M}N:{if(!d){break N}d=0;if(!z[a+480188>>1]){break N}while(1){O:{g=uc(c,d);if(!(y[g|0]|y[g+1|0]<<8)){break O}g=uc(c,d);if((y[g|0]|y[g+1|0]<<8)>>>0>(y[e+198|0]|y[e+199|0]<<8)>>>0){break O}g=uc(c,d);g=uc(j,(y[g|0]|y[g+1|0]<<8)-1|0);g=(y[g|0]|y[g+1|0]<<8)-1&65535;if(g>>>0>=f>>>0){break O}r=Zb(n,h);g=vc(i,g);x[114414]=0;T(364,r|0,d&65535,g|0);g=x[114414];x[114414]=0;if((g|0)!=1){break O}break L}d=d+1|0;if(d>>>0<z[a+480188>>1]){continue}break}}Mj(c)}h=h+1|0;if(h>>>0>=y[e+197|0]){break j}continue}}break}a=N()|0;Mj(c);break r}a=N()|0;break r}a=N()|0;break r}a=N()|0;break r}a=N()|0;break q}a=N()|0;break q}a=N()|0;break k}a=N()|0;break k}a=N()|0;break k}a=N()|0;break k}a=N()|0;break q}a=N()|0}id(i)}Mj(j);break m}a=N()|0;xb(e+16|0);break m}a=N()|0;break m}a=N()|0}Ge(m)}qf(l);break a}id(i)}Mj(j);Ge(m);qf(l)}hb=e+208|0;return o|0}a=N()|0;Gb(e+144|0);break b}a=N()|0}xb(d)}Q(a|0);p()}function gia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=hb-272|0;hb=d;Lc(b);e=hb-16|0;hb=e;h=e+8|0;j=d+120|0;yP(h,j);i=Eb(h);h=nc(b,ac(e,h));if((i|0)==(h|0)){cc(b,Eb(e+8|0))}hb=e+16|0;e=(h|0)==(i|0);if(!e){zP(j)}a:{b:{c:{d:{e:{if(!e){break e}if(!NP(d+120|0)){break e}if(!c){f=1;break e}Nd(a,4194304);e=d+40|0;f=Ub(e,12916);Db(a+1304436|0,f);xb(f);f=Ub(e,6118);Db(a+1304448|0,f);xb(f);x[a+1304496>>2]=4;m=a,n=Md(y[d+198|0]|y[d+199|0]<<8,y[d+200|0]|y[d+201|0]<<8,127),w[m+480188>>1]=n;f=y[d+189|0];x[a+480228>>2]=(f|0)==255?48:f;x[a+480196>>2]=y[d+187|0];x[a+480204>>2]=D(y[d+188|0],1e4);f=d+104|0;cf(f,d+120|4,59,3);Ic(e,f);Db(a+1304400|0,e);xb(e);f:{if((y[d+202|0]|y[d+203|0]<<8|(y[d+204|0]<<16|y[d+205|0]<<24))>>>0<5){break f}if(!Rc(b,(y[d+202|0]|y[d+203|0]<<8|(y[d+204|0]<<16|y[d+205|0]<<24))-4|0)){break f}if(!yh(b,9948)){break f}oq(Vb(a+484360|0),b,y[d+192|0]|y[d+193|0]<<8,65535,65535)}g:{if((y[d+206|0]|y[d+207|0]<<8|(y[d+208|0]<<16|y[d+209|0]<<24))>>>0<5){break g}if(!Rc(b,(y[d+206|0]|y[d+207|0]<<8|(y[d+208|0]<<16|y[d+209|0]<<24))-4|0)){break g}if(!yh(b,9604)){break g}f=0;while(1){e=(f<<5)+a|0;Lg(e+480280|0);m=e+480284|0,n=((((pe(b)^-1)&15)<<8|8)>>>0)/15|0,w[m>>1]=n;f=f+1|0;if((f|0)!=32){continue}break}}h:{if((y[d+214|0]|y[d+215|0]<<8|(y[d+216|0]<<16|y[d+217|0]<<24))>>>0<5){break h}if(!Rc(b,(y[d+214|0]|y[d+215|0]<<8|(y[d+216|0]<<16|y[d+217|0]<<24))-4|0)){break h}if(!yh(b,9880)){break h}Bd(d+104|0,b,(y[d+196|0]|y[d+197|0]<<8)<<6);i:{if(!(y[d+196|0]|y[d+197|0]<<8)){break i}f=c&2;h=a+480190|0;j=d+53|0;while(1){x[114414]=0;e=O(950,d+104|0,d+40|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}if(!e){break i}e=y[d+85|0]|y[d+86|0]<<8;w[d+38>>1]=e;j:{if((e-1&65535)>>>0>3998){break j}if(Be((D(e,104)+a|0)+484380|0)){break j}x[114414]=0;e=O(402,h|0,d+38|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}w[a+480190>>1]=z[e>>1];x[114414]=0;P(951,d+40|0,(D(z[d+38>>1],104)+a|0)+484380|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;T(952,d+8|0,1,j|0);e=x[114414];x[114414]=0;k:{l:{if((e|0)==1){break l}x[114414]=0;P(355,d+24|0,d+8|0);e=x[114414];x[114414]=0;if((e|0)==1){break l}x[114414]=0;O(334,((z[d+38>>1]<<5)+a|0)+946304|0,d+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break k}xb(d+24|0);if(!f){break j}e=y[d+77|0]|y[d+78|0]<<8|(y[d+79|0]<<16|y[d+80|0]<<24);x[114414]=0;O(224,b|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;P(953,d+24|0,d+40|0);e=x[114414];x[114414]=0;if((e|0)!=1){x[114414]=0;U(361,d+24|0,(D(z[d+38>>1],104)+a|0)+484380|0,b|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){break j}}b=N()|0;break b}b=N()|0;break b}b=N()|0;xb(d+24|0);break b}k=k+1|0;if((k&65535)>>>0<(y[d+196|0]|y[d+197|0]<<8)>>>0){continue}break}}Ab(d+104|0)}f=1;if(!(c&1)){break e}m:{if((y[d+210|0]|y[d+211|0]<<8|(y[d+212|0]<<16|y[d+213|0]<<24))>>>0<5){break m}if(!Rc(b,(y[d+210|0]|y[d+211|0]<<8|(y[d+212|0]<<16|y[d+213|0]<<24))-4|0)){break m}if(!yh(b,9483)){break m}i=a+484344|0;cg(i,y[d+194|0]|y[d+195|0]<<8);if(!(y[d+194|0]|y[d+195|0]<<8)){break m}j=d+24|2;h=0;while(1){if(!iu(b,d+24|0)){break m}if((y[d+24|0]|y[d+25|0]<<8)>>>0>3){Bd(d+40|0,b,((y[d+24|0]|y[d+25|0]<<8)+15&131056)-4|0);c=y[j|0];x[114414]=0;c=U(363,i|0,h&65535,c|0)|0;e=x[114414];x[114414]=0;n:{if((e|0)!=1){o:{k=0;if(!c){break n}while(1){x[114414]=0;c=O(226,d+40|0,1)|0;e=x[114414];x[114414]=0;p:{q:{r:{if((e|0)!=1){if(!c|y[j|0]<=k>>>0){break q}x[114414]=0;c=R(403,d+40|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break o}e=c<<24>>24;if(e){break r}k=k+1|0;continue}break o}c=Zb(i,h);w[d+8>>1]=e&31;g=z[a+480188>>1];x[114414]=0;w[d+38>>1]=g-1;g=O(433,d+8|0,d+38|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break o}g=z[g>>1];x[114414]=0;c=U(427,c|0,k|0,g|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break o}if((e|0)<0){x[114414]=0;P(428,d+8|0,d+40|0);g=x[114414];x[114414]=0;if((g|0)==1){break o}g=ed(d+8|0);v[c|0]=y[d+8|0]+36;v[c+1|0]=y[g|0]}e=e&255;if(!(e&64)){break p}v[c+2|0]=1;x[114414]=0;g=R(403,d+40|0)|0;l=x[114414];x[114414]=0;s:{if((l|0)!=1){x[114414]=0;v[d+8|0]=g;v[d+38|0]=64;g=O(409,d+8|0,d+38|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break s}v[c+4|0]=y[g|0];break p}break o}break o}if(y[j|0]==64){break n}c=Zb(i,h);x[114414]=0;e=U(454,d+104|0,14,0)|0;k=x[114414];x[114414]=0;if((k|0)!=1){e=ai(Ie(e,y[j|0]-1|0));x[114414]=0;O(455,c|0,e|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break n}}break o}if(!(e&32)){continue}x[114414]=0;P(428,d+8|0,d+40|0);e=x[114414];x[114414]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{if((e|0)!=1){g=d+8|0;e=y[ed(g)|0];v[c+5|0]=e;switch(y[g|0]-1|0){case 71:break u;case 70:break v;case 69:break w;case 60:break x;case 59:break y;case 52:break z;case 51:break A;case 50:break B;case 49:break C;case 42:break D;case 41:break E;case 40:break F;case 39:break G;case 30:break H;case 29:break I;case 22:break J;case 21:break K;case 20:break L;case 19:break M;case 16:break N;case 15:break O;case 14:break P;case 13:break Q;case 12:break R;case 11:break S;case 10:break T;case 9:break U;case 3:break V;case 2:break W;case 1:break X;case 0:break Y;default:break t}}break o}v[c+3|0]=11;v[c+5|0]=e<<4|15;continue}v[c+3|0]=11;v[c+5|0]=e<<4;continue}v[c+3|0]=11;v[c+5|0]=e|240;continue}v[c+3|0]=11;v[c+5|0]=e&15;continue}v[c+3|0]=2;v[c+5|0]=e|240;continue}v[c+3|0]=2;continue}v[c+3|0]=3;v[c+5|0]=e|240;continue}v[c+3|0]=3;continue}v[c+3|0]=4;continue}v[c+3|0]=20;v[c+5|0]=e|16;continue}v[c+3|0]=6;v[c+5|0]=e<<4;continue}v[c+3|0]=6;v[c+5|0]=e&15;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=e|48;continue}v[c+3|0]=7;v[c+5|0]=e<<4;continue}v[c+3|0]=7;v[c+5|0]=e&15;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=e|64;continue}v[c+3|0]=10;x[114414]=0;e=R(403,d+40|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){v[c+5|0]=e;x[114414]=0;O(304,d+40|0,1)|0;c=x[114414];x[114414]=0;if((c|0)!=1){continue}}break o}v[c+3|0]=15;v[c+5|0]=e&15;continue}v[c+3|0]=20;v[c+5|0]=e|192;continue}v[c+3|0]=20;v[c+5|0]=e|208;continue}v[c+3|0]=12;continue}v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=e|176;continue}v[c+3|0]=20;v[c+5|0]=e|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=e&15|32;continue}v[c+3|0]=20;v[c+5|0]=e&15|128;continue}v[c+3|0]=0;continue}}}b=N()|0;Ab(d+40|0);break a}Ab(d+40|0)}h=h+1|0;if(h>>>0<(y[d+194|0]|y[d+195|0]<<8)>>>0){continue}break}}if(!(y[d+218|0]|y[d+219|0]<<8|(y[d+220|0]<<16|y[d+221|0]<<24))){break e}Rc(b,y[d+218|0]|y[d+219|0]<<8|(y[d+220|0]<<16|y[d+221|0]<<24));pz(a+1304424|0,b,pg(b),4)}hb=d+272|0;return f|0}b=N()|0;break b}b=N()|0}Ab(d+104|0)}Q(b|0);p()}function gW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=hb-1424|0;hb=g;Lc(b);gr(a);a:{if(!wD(b,g+1408|0)){break a}if(!yD(g+1408|0)){break a}if(!vD(b,g+1392|0)){break a}if(!xD(g+1392|0)){break a}b:{if(!c){break b}r=g+1400|0;c=r;if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))>>>0>fj(b)>>>0){break a}u=g+1392|2;if((y[r|0]|y[r+1|0]<<8|(y[r+2|0]<<16|y[r+3|0]<<24))+((y[u|0]|y[u+1|0]<<8)<<2)>>>0>fj(b)>>>0){break a}Fv(a);F=g,G=Ev(),x[F+40>>2]=G;c=g+40|0;Dv($g(a)+28|0,c);fr(c);o=x[$g(a)+28>>2];c=g+1392|4;Kv(o,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));Sb(g+1136|0,0,256);c:{d:{e:{f:{if(y[u|0]|y[u+1|0]<<8){l=g+1112|4;m=g+1128|0;B=g+1130|0;w=g+1126|0;h=g+1124|0;while(1){d=0;if(!Rc(b,(y[r|0]|y[r+1|0]<<8|(y[r+2|0]<<16|y[r+3|0]<<24))+(C<<2)|0)){break a}if(!Qb(b,4)){break a}j=Gf(b);if(!Rc(b,j)){break a}if(!Cv(b,g+1112|0)){break a}c=y[h|0]|y[h+1|0]<<8;i=hb-16|0;hb=i;n=g+1096|0;x[n>>2]=0;x[n+4>>2]=0;x[i+12>>2]=0;Xc(n+8|0);if(c){d=hb-16|0;hb=d;if(sv(n)>>>0<c>>>0){Vc();p()}UC(d+8|0,yb(n),c);e=x[d+8>>2];x[n+4>>2]=e;x[n>>2]=e;k=x[d+12>>2];F=yb(n),G=e+(k<<3)|0,x[F>>2]=G;rv(n,0);hb=d+16|0;d=hb-16|0;hb=d;g:{h:{c=Yq(d,n,c);e=x[c+4>>2];k=x[c+8>>2];if((e|0)!=(k|0)){while(1){q=yb(n);x[114414]=0;P(235,q|0,e|0);q=x[114414];x[114414]=0;if((q|0)==1){break h}e=e+8|0;x[c+4>>2]=e;if((e|0)!=(k|0)){continue}break}}Jb(c);hb=d+16|0;break g}a=N()|0;Jb(c);Q(a|0);p()}}hb=i+16|0;c=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(!(y[h|0]|y[h+1|0]<<8)){break x}while(1){y:{d=ll(n,c);x[114414]=0;d=O(222,b|0,d|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break y}if(!d){break w}c=c+1|0;if(c>>>0<(y[h|0]|y[h+1|0]<<8)>>>0){continue}break x}break}d=N()|0;break c}d=y[h|0]|y[h+1|0]<<8?x[n>>2]:0;c=y[h|0]|y[h+1|0]<<8;x[114414]=0;e=R(223,b|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break v}f=c<<3;c=j+20|0;if(e>>>0<=f+c>>>0){break w}c=c+((y[h|0]|y[h+1|0]<<8)<<3)|0;if(!(v[w|0]&1)){e=0;if(!(y[h|0]|y[h+1|0]<<8)){break i}while(1){if(!d){break w}if(!Io(o,d)){break w}x[114414]=0;i=O(224,b|0,c|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break u}if(!i){break w}i=Bc(o,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));j=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[114414]=0;i=U(225,b|0,i|0,j|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break u}if((i|0)!=(y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))){break w}d=d+8|0;e=e+1|0;if(e>>>0<(y[h|0]|y[h+1|0]<<8)>>>0){continue}break}break i}z:{if(y[w|0]&4){if(!d){break w}if(!Io(o,d)){break w}q=Bc(o,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));s=(y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))&-2;if(!s){break w}i=y[B|0]|y[B+1|0]<<8;e=y[m|0]|y[m+1|0]<<8;x[114414]=0;c=O(224,b|0,c+e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break t}if(!c){break w}c=y[l|0]|y[l+1|0]<<8|(y[l+2|0]<<16|y[l+3|0]<<24);e=y[m|0]|y[m+1|0]<<8;x[114414]=0;c=O(226,b|0,c-e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break t}if(!c){break w}c=y[l|0]|y[l+1|0]<<8|(y[l+2|0]<<16|y[l+3|0]<<24);e=y[m|0]|y[m+1|0]<<8;x[114414]=0;T(227,g+24|0,b|0,c-e|0);c=x[114414];x[114414]=0;if((c|0)==1){break d}c=g+24|0;k=Cm(g+40|0,c);Ab(c);A=0;e=0;j=0;if(!(y[h|0]|y[h+1|0]<<8)){break j}while(1){A:{x[114414]=0;c=O(228,k|0,i+1|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break A}f=i&15;t=z[(f<<1)+22768>>1];B:{C:{if(t>>>0<=c>>>0){x[114414]=0;f=y[f+22816|0];D=O(228,k|0,f|0)|0;E=x[114414];x[114414]=0;if((E|0)==1){break l}c=D+(c-t<<f)|0;if((c|0)!=(i|0)){i=c&15;break B}x[114414]=0;c=O(228,k|0,4)|0;f=x[114414];x[114414]=0;if((f|0)==1){break l}if((c|0)==15){x[114414]=0;f=O(228,k|0,1)|0;c=x[114414];x[114414]=0;if((c|0)==1){break l}c=65535;if(!f){break C}break j}c=c+65520|0}if(c>>>0>65535){break B}}c=c&1?0-(c+1>>>1|0)|0:c>>>1|0;f=e+q|0;D:{if(y[w|0]&2){A=c+A|0;c=A;break D}c=y[w+1|0]&2?c:c^32768}v[f|0]=c;v[f+1|0]=c>>>8;e=e+2|0}if(e>>>0>=s>>>0){j=j+1|0;if(j>>>0>=(y[h|0]|y[h+1|0]<<8)>>>0){break j}c=(j<<3)+d|0;if(!Io(o,c)){break z}s=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))&-2;if(!s){break z}q=Bc(o,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));e=0}if((y[h|0]|y[h+1|0]<<8)>>>0>j>>>0){continue}break j}break}d=S(75884)|0;break k}if(!d){break w}if(!Io(o,d)){break w}A=Bc(o,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));s=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);i=y[B|0]|y[B+1|0]<<8;if((y[m|0]|y[m+1|0]<<8)>>>0>256){break w}x[114414]=0;c=O(224,b|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break s}if(!c){break w}c=y[m|0]|y[m+1|0]<<8;x[114414]=0;c=U(229,b|0,g+1136|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break s}if(c>>>0<(y[m|0]|y[m+1|0]<<8)>>>0){break w}c=y[l|0]|y[l+1|0]<<8|(y[l+2|0]<<16|y[l+3|0]<<24);e=y[m|0]|y[m+1|0]<<8;x[114414]=0;c=O(226,b|0,c-e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break s}if(!c){break w}c=y[l|0]|y[l+1|0]<<8|(y[l+2|0]<<16|y[l+3|0]<<24);e=y[m|0]|y[m+1|0]<<8;x[114414]=0;T(227,g+24|0,b|0,c-e|0);c=x[114414];x[114414]=0;if((c|0)==1){break m}c=g+24|0;k=Cm(g+40|0,c);Ab(c);q=0;e=0;j=0;if(!(y[h|0]|y[h+1|0]<<8)){break p}E:{while(1){F:{x[114414]=0;c=O(228,k|0,i+1|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break F}f=i&7;t=y[f+22800|0];G:{H:{if(t>>>0<=c>>>0){x[114414]=0;f=y[f+22808|0];D=O(228,k|0,f|0)|0;E=x[114414];x[114414]=0;if((E|0)==1){break r}c=D+(c-t<<f)|0;if((c|0)!=(i|0)){i=c&7;break G}x[114414]=0;c=O(228,k|0,3)|0;f=x[114414];x[114414]=0;if((f|0)==1){break r}if((c|0)==7){x[114414]=0;f=O(228,k|0,1)|0;c=x[114414];x[114414]=0;if((c|0)==1){break r}c=255;if(!f){break H}break p}c=c+248|0}if(c>>>0>255){break G}}c=y[(g+1136|0)+c|0];f=c+q|0;t=c;c=(y[w|0]|y[w+1|0]<<8)&2;v[e+A|0]=c?f:t;q=c?f:q;e=e+1|0}if(e>>>0>=s>>>0){j=j+1|0;if(j>>>0>=(y[h|0]|y[h+1|0]<<8)>>>0){break p}c=(j<<3)+d|0;if(!Io(o,c)){break E}s=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);A=Bc(o,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));e=0}if((y[h|0]|y[h+1|0]<<8)>>>0>j>>>0){continue}break p}break}d=S(75884)|0;break q}Ab(k);break w}Ab(k)}Av(n);d=0;break a}d=N()|0;break c}d=N()|0;break c}d=N()|0;break c}d=N()|0;break c}d=S(75884)|0}if((ib|0)!=(ca(75884)|0)){break n}Y(d|0)|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)==1){break o}}Ab(k);break i}d=N()|0}Ab(k);break c}d=N()|0;break c}d=S(75884)|0}if((ib|0)!=(ca(75884)|0)){break e}Y(d|0)|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)==1){break f}}Ab(k)}Av(n);C=C+1|0;if(C>>>0<(y[u|0]|y[u+1|0]<<8)>>>0){continue}break}}b=g+8|0;ej(b,o);c=g+16|0;zv(c,b);b=Ho(g+40|0,c,0);Ud($g(a)+12|0,b);Ab(b);break b}d=N()|0}Ab(k);break c}d=N()|0}Av(n);Q(d|0);p()}d=1}hb=g+1424|0;return d|0}function Dba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-224|0;hb=g;w[a+480212>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;mM(a+900380|0);x[114414]=0;W(1403,a+946304|0);d=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)==1){break i}d=a+906300|0;e=d;f=d+4e4|0;x[114414]=0;d=R(1398,g- -64|0)|0;h=x[114414];x[114414]=0;j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){x[114414]=0;T(1416,e|0,f|0,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break p}vp(d);x[114414]=0;d=R(303,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break i}if(!d){break k}e=0;f=hb-16|0;hb=f;d=g+48|0;x[d>>2]=0;x[d+4>>2]=0;x[114414]=0;x[f+12>>2]=0;U(1431,d+8|0,f+12|0,f+8|0)|0;h=x[114414];x[114414]=0;q:{if((h|0)!=1){hb=f+16|0;break q}break a}f=d;h=0;if(c&16){break n}x[114414]=0;i=(c|0)!=0;h=U(1417,f|0,b|0,i|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break m}d=4;r:{if(h){break r}x[114414]=0;h=U(1418,f|0,b|0,i|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break m}d=5;if(h){break r}x[114414]=0;h=U(1419,f|0,b|0,i|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break m}d=6;if(h){break r}h=0;x[114414]=0;i=U(1420,f|0,b|0,i|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break m}d=3;if(!i){break n}}if(c){break o}e=1;break c}a=N()|0;break d}a=N()|0;vp(d);break d}if(!od(f)){HQ(b,Vu(f,0)+12|0)}h=d}if(c&32){break c}d=76752;s:{t:{while(1){j=x[d+8>>2];i=(j>>1)+a|0;e=x[d+4>>2];e=j&1?x[x[i>>2]+e>>2]:e;x[114414]=0;e=U(e|0,i|0,b|0,c|0)|0;i=x[114414];x[114414]=0;if((i|0)!=1){if(e){break s}d=d+12|0;if((d|0)==77208){break t}continue}break}a=S(74968)|0;break l}x[a+480180>>2]=0;x[a+480184>>2]=0}if(!c){break c}if(!(x[a+480184>>2]|!h)){x[a+480184>>2]=h}uy(f);break j}a=S(74968)|0}c=ib;uy(f);if((ca(74968)|0)!=(c|0)){break d}Y(a|0)|0;x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)==1){a=N()|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)!=1){break d}S(0)|0;zb()}p()}x[114414]=0;P(397,a|0,0);d=x[114414];x[114414]=0;if((d|0)==1){break i}x[a+1074304>>2]=19469590}d=0;while(1){e=(d<<5)+a|0;sg(e+480286|0,64);f=e+480284|0;if(z[f>>1]>=257){w[f>>1]=128}e=e+480288|0;if(y[e|0]>=251){v[e|0]=0}x[114414]=0;ba(1421,(D(d,896)+a|0)+1074984|0,7,a|0,d&65535,1024);e=x[114414];x[114414]=0;if((e|0)==1){break f}d=d+1|0;if((d|0)!=127){continue}break}if(z[a+480190>>1]){h=a+1304392|0;e=1;while(1){f=D(e&65535,104)+a|0;d=f+484380|0;u:{if(Be(d)){x[114414]=0;T(1242,d|0,a|0,0);d=x[114414];x[114414]=0;if((d|0)!=1){break u}break e}i=f+484414|0;j=z[i>>1];if(j&16384){break u}x[d>>2]=0;x[d+4>>2]=0;x[d+16>>2]=0;x[d+8>>2]=0;x[d+12>>2]=0;w[i>>1]=j&65505}d=f+484412|0;if(z[d>>1]>=65){w[d>>1]=64}v:{if(!(y[f+484415|0]&2)){break v}if(!Aj(h)){break v}x[114414]=0;W(1422,a|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}}e=e+1|0;if(z[a+480190>>1]>=(e&65535)>>>0){continue}break}}d=0;e=0;while(1){w:{f=x[(((d&65535)<<2)+a|0)+900380>>2];if(!f){break w}e=x[a+480180>>2];x[114414]=0;P(1423,f|0,e|0);f=x[114414];x[114414]=0;e=d;if((f|0)!=1){break w}a=N()|0;break d}d=d+1|0;if(z[a+480192>>1]>=(d&65535)>>>0){continue}break}w[a+480192>>1]=e;d=a+480204|0;x:{if(A[a+480204>>2]<1e4){x[d>>2]=125e4;break x}xc(d,65535e4)}if(!x[a+480196>>2]){x[a+480196>>2]=6}d=a+480220|0;e=x[a+480216>>2];if(e>>>0>A[a+480220>>2]){x[d>>2]=e}e=a+480216|0;xc(e,65536);xc(d,65536);xc(a+480200|0,256);d=a+480248|0;if(!od(d)){e=x[e>>2];x[114414]=0;T(1424,d|0,e|0,16777216);d=x[114414];x[114414]=0;if((d|0)==1){break g}}x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];e=x[a+480220>>2];d=a+1074408|0;x[d>>2]=x[a+480216>>2];x[d+4>>2]=e;x[a+1074444>>2]=x[a+480200>>2];Ly(a+1074376|0);x[a+1074440>>2]=-65536;x[a+1074392>>2]=-2;d=a+1074384|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074380>>2]=0;d=a+1074424|0;x[d>>2]=0;x[d+4>>2]=0;d=a+1074432|0;x[d>>2]=0;x[d+4>>2]=0;d=a+1074396|0;x[d>>2]=0;x[d+4>>2]=0;w[a+480276>>1]=0;x[114414]=0;W(1425,a|0);d=x[114414];x[114414]=0;if((d|0)==1){break g}x[114414]=0;P(1222,a+1304360|0,1);d=x[114414];x[114414]=0;if((d|0)==1){break g}d=a+484360|0;k=g,l=bc(d),x[k+48>>2]=l;k=g,l=dc(d),x[k+32>>2]=l;if(Hb(g+48|0,g+32|0)){while(1){d=x[g+48>>2];x[114414]=0;W(1426,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break h}e=z[d+28>>1];if(qc(d)>>>0<=e>>>0){Se(d,0)}d=g+48|0;Ao(d);if(Hb(d,g+32|0)){continue}break}}e=hb-16|0;hb=e;d=g+48|0;x[d>>2]=0;x[d+4>>2]=0;x[114414]=0;x[e+12>>2]=0;U(1432,d+8|0,e+12|0,e+8|0)|0;f=x[114414];x[114414]=0;y:{if((f|0)!=1){hb=e+16|0;break y}break a}f=d;z:{A:{B:{C:{D:{E:{F:{G:{H:{if((c&12)==12){d=0;while(1){j=D(d,160)+a|0;h=j+906300|0;c=h+16|0;e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=h+20|0;I:{if(!(e|(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)))){break I}x[114414]=0;O(1427,h|0,a|0)|0;c=x[114414];x[114414]=0;J:{if((c|0)!=1){c=x[h>>2];if(!c){break J}e=x[j+906448>>2];h=x[x[c>>2]+56>>2];x[114414]=0;P(h|0,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)!=1){break I}}a=N()|0;break z}e=bc(f);i=dc(f);c=hb-32|0;hb=c;x[c+16>>2]=i;x[c+24>>2]=e;x[c+8>>2]=h;K:{if(!Hb(c+24|0,c+16|0)){break K}while(1){e=x[x[c+24>>2]>>2];i=x[c+8>>2];if((y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24))==(y[i+20|0]|y[i+21|0]<<8|(y[i+22|0]<<16|y[i+23|0]<<24))){i=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);e=x[c+8>>2];e=(i|0)==(y[e+16|0]|y[e+17|0]<<8|(y[e+18|0]<<16|y[e+19|0]<<24))}else{e=0}if(e){break K}e=c+24|0;fe(e);if(Hb(e,c+16|0)){continue}break}}hb=c+32|0;x[g+32>>2]=x[c+24>>2];k=g,l=dc(f),x[k>>2]=l;if(Hb(g+32|0,g)){break I}x[114414]=0;x[g+32>>2]=j+906316;P(1428,f|0,g+32|0);c=x[114414];x[114414]=0;if((c|0)==1){break A}x[114414]=0;c=O(2,g+16|0,13556)|0;e=x[114414];x[114414]=0;if((e|0)==1){break H}e=bM(h);x[114414]=0;T(6,g|0,0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break G}x[114414]=0;T(3,g+32|0,c|0,g|0);e=x[114414];x[114414]=0;if((e|0)==1){break F}x[114414]=0;T(623,a|0,2,g+32|0);e=x[114414];x[114414]=0;if((e|0)==1){break E}xb(g+32|0);xb(g);xb(c)}d=d+1|0;if((d|0)!=250){continue}break}}c=x[a+1074372>>2];x[114414]=0;P(1429,a|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break B}c=x[a+480180>>2];L:{if(!c){break L}Xs(a+8|0,up(a));if(!x[a+1074308>>2]){break L}x[114414]=0;W(1430,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break B}}e=(c|0)!=0;aM(f);break b}a=N()|0;break z}a=N()|0;break C}a=N()|0;break D}a=N()|0;xb(g+32|0)}xb(g)}xb(c);break z}a=N()|0;break z}a=N()|0}aM(f);break d}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}a=N()|0;break d}a=N()|0}Ab(b);Q(a|0);p()}uy(f)}Ab(b);hb=g+224|0;return e|0}S(0)|0;zb();p()}function Nla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;d=hb-1328|0;hb=d;Lc(b);l=hb-16|0;hb=l;h=l+8|0;k=d+752|0;LS(h,k);f=Eb(h);h=nc(b,ac(l,h));if((f|0)==(h|0)){cc(b,Eb(l+8|0))}hb=l+16|0;h=(f|0)==(h|0);if(!h){MS(k)}a:{if(!h){break a}if(!PS(d+752|0)){break a}if(!Qb(b,jd(OS(d+752|0),lb))){break a}if(!c){s=1;break a}t=Xc(d+744|0);b:{c:{while(1){m=(e<<5)+a|0;l=m+480280|0;Lg(l);k=(d+752|0)+(e<<4)|0;w[m+480284>>1]=((y[k+78|0]<<8&65280)>>>0)/255;f=d+480|0;Wk(f,1,k- -64|0);h=d+96|0;Ic(h,f);x[114414]=0;O(343,m+480289|0,h|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break c}xb(d+96|0);d:{e:{switch(y[k+79|0]){case 0:n=e+1|0;break d;case 1:x[l>>2]=1024;n=j+1|0;break d;case 2:break e;default:break a}}x[l>>2]=1024;h=d+96|0;ol(h,t,e);he(h,1)}s=e>>>0>30;j=j+1|0;e=e+1|0;if((e|0)!=32){continue}break}Nd(a,33554432);w[a+480188>>1]=n&255;h=d+96|0;e=Ub(h,3098);Db(a+1304436|0,e);xb(e);e=Ub(h,7015);Db(a+1304448|0,e);xb(e);x[a+1304496>>2]=4;f:{if(y[d+831|0]){break f}m=1;while(1){if(y[((m<<4)+d|0)+831|0]!=1){break f}e=1;m=m+1|0;if((m|0)!=16){continue}break}while(1){h=((e<<5)+a|0)+480280|0;x[h>>2]=x[h>>2]&-1025;e=e+1|0;if((e|0)!=16){continue}break}}h=d+480|0;Kg(h,1,d+752|0);e=d+96|0;Ic(e,h);Db(a+1304400|0,e);xb(e);x[a+480208>>2]=x[a+480208>>2]&-17|(y[d+790|0]|y[d+791|0]<<8)<<4&16;x[a+480196>>2]=y[d+800|0];x[a+480204>>2]=D(y[d+801|0],1e4);x[a+480200>>2]=y[d+802|0]<<2;x[a+480228>>2]=y[d+803|0];e=y[d+788|0]|y[d+789|0]<<8;w[a+480190>>1]=0;w[a+480192>>1]=e;Su(b,h);Dq(Vb(a+484360|0),h,y[d+784|0]|y[d+785|0]<<8,65535,255);i=c&1;if(i){cg(a+484344|0,y[d+786|0]|y[d+787|0]<<8)}if(y[d+786|0]|y[d+787|0]<<8){u=a+484344|0;n=0;while(1){e=pg(b);q=pg(b);Bd(d+96|0,b,e-4|0);g:{if(!i){break g}x[114414]=0;h=U(363,u|0,n&65535,q|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){h:{if(!h){break g}o=0;h=_h(d+16|0);if(!q){break g}while(1){i:{x[114414]=0;l=R(403,d+96|0)|0;e=x[114414];x[114414]=0;j:{k:{if((e|0)!=1){if(l){break k}o=o+1|0;break j}break h}e=h;r=l&31;if(r>>>0<z[a+480188>>1]){e=Zb(u,n);x[114414]=0;e=U(427,e|0,o|0,r|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break h}}l:{if(!(l&32)){break l}x[114414]=0;P(428,d+32|0,d+96|0);f=x[114414];x[114414]=0;m:{n:{if((f|0)!=1){f=ed(d+32|0);k=y[d+32|0];v[e|0]=k;v[e+1|0]=y[f|0];if((k|0)!=160){break n}f=255;break m}break h}if((k|0)!=255){v[e|0]=(D(k>>>4|0,12)+(k&15)|0)+13;x[114414]=0;k=R(592,e|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){f=0;if(!k){break m}break l}break h}f=0}v[e|0]=f}f=l&192;o:{if(!f){break o}if((f|0)==192){x[114414]=0;P(562,d+32|0,d+96|0);f=x[114414];x[114414]=0;p:{q:{r:{if((f|0)!=1){f=d+32|0;k=f;l=ed(f);m=rf(f);j=$h(f);g=y[f|0];if((g|0)!=12){break r}x[114414]=0;v[d+8|0]=64;k=O(409,l|0,d+8|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break h}v[e+4|0]=y[k|0];f=1;break q}break h}f=y[m|0];s:{if((f|0)==12){x[114414]=0;v[d+8|0]=64;j=O(409,j|0,d+8|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){v[e+4|0]=y[j|0];f=1;break s}break h}if((g|0)==10){v[e+4|0]=(y[l|0]<<6>>>0)/255;f=2;break q}if((f|0)!=10){break p}v[e+4|0]=(y[j|0]<<6>>>0)/255;f=2}m=k;j=l}v[e+2|0]=f;f=y[m|0]}v[e+3|0]=f;v[e+5|0]=y[j|0];break o}x[114414]=0;P(428,d+32|0,d+96|0);f=x[114414];x[114414]=0;if((f|0)==1){break h}f=ed(d+32|0);v[e+3|0]=y[d+32|0];v[e+5|0]=y[f|0]}if(y[e+3|0]){x[114414]=0;W(593,e|0);f=x[114414];x[114414]=0;if((f|0)==1){break h}}f=d+32|0;ol(f,t,r);if(!Ib(f)){break j}x[114414]=0;k=R(594,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break i}if(!k){break j}v[e+3|0]=0}if(o>>>0<q>>>0){continue}break g}break}}}e=N()|0;Ab(d+96|0);break b}Ab(d+96|0);n=n+1|0;if(n>>>0<(y[d+786|0]|y[d+787|0]<<8)>>>0){continue}break}}if(!z[a+480192>>1]){break a}l=c&2;m=0;n=1;while(1){m=m+1|0;k=m&65535;i=SL(a,k,0);f=!i;g=hb-16|0;hb=g;c=hb-16|0;hb=c;j=g+8|0;h=d+96|0;jc(j,h,384);hb=c+16|0;e=Eb(j);c=nc(b,ac(g,j));if((e|0)==(c|0)){cc(b,Eb(g+8|0))}hb=g+16|0;e=(c|0)==(e|0);if(!e){c=hb-16|0;hb=c;Sb(h,0,384);hb=c+16|0}if(!(!e|f)){h=n&65535;g=hb-32|0;hb=g;j=d+96|0;Kg(g,1,j);c=g+16|0;Ic(c,g);x[114414]=0;O(334,i+492|0,c|0)|0;c=x[114414];x[114414]=0;t:{if((c|0)!=1){xb(g+16|0);u:{if(!(y[j+378|0]|y[j+379|0]<<8)){break u}x[g+16>>2]=120;x[g>>2]=116;if(!x[Mb(g+16|0,g)>>2]){break u}e=i+236|0;f=0;while(1){c=y[(f+j|0)+32|0];B=fd(e,f+12|0),C=c+h|0,w[B>>1]=C;x[g+16>>2]=120;x[g>>2]=116;f=f+1|0;if(f>>>0<A[Mb(g+16|0,g)>>2]){continue}break}}x[i>>2]=y[j+376|0]|y[j+377|0]<<8;xA(j,i+48|0,0);xA(j,i+68|0,1);xA(j,i+88|0,2);c=y[i+100|0];if(c&1){v[i+100|0]=c|16}if(!(x[i>>2]|v[i+60|0]&1)){x[i>>2]=32767}hb=g+32|0;break t}a=N()|0;xb(g+16|0);Q(a|0);p()}e=0;v:{if(!(y[d+474|0]|y[d+475|0]<<8)){break v}while(1){w:{pq(b,d+32|0);x:{if((y[d+92|0]|y[d+93|0]<<8|(y[d+94|0]<<16|y[d+95|0]<<24))!=808538953){break x}c=e+n|0;f=c&65535;if(f>>>0>3999){break x}w[a+480190>>1]=c;j=hb-32|0;hb=j;h=D(f,104)+a|0;i=h+484380|0;Ad(i,0);g=d+32|0;zh(j,1,g);c=j+16|0;Ic(c,j);x[114414]=0;O(335,i+43|0,c|0)|0;c=x[114414];x[114414]=0;y:{if((c|0)!=1){xb(j+16|0);x[i>>2]=y[g+16|0]|y[g+17|0]<<8|(y[g+18|0]<<16|y[g+19|0]<<24);x[i+4>>2]=y[g+20|0]|y[g+21|0]<<8|(y[g+22|0]<<16|y[g+23|0]<<24);x[i+8>>2]=y[g+24|0]|y[g+25|0]<<8|(y[g+26|0]<<16|y[g+27|0]<<24);x[i+24>>2]=y[g+28|0]|y[g+29|0]<<8|(y[g+30|0]<<16|y[g+31|0]<<24);w[i+30>>1]=y[g+32|0]<<2;w[i+28>>1]=y[g+33|0];if(v[g+48|0]&1){w[i+34>>1]=z[i+34>>1]|2}if(y[g+48|0]&2){w[i+34>>1]=z[i+34>>1]|4}if(y[g+48|0]&4){w[i+34>>1]=z[i+34>>1]|1;x[i>>2]=x[i>>2]>>>1;x[i+4>>2]=x[i+4>>2]>>>1;x[i+8>>2]=x[i+8>>2]>>>1}if(y[g+48|0]&8){w[i+34>>1]=z[i+34>>1]|32}hb=j+32|0;break y}a=N()|0;xb(j+16|0);Q(a|0);p()}c=d+16|0;oC(c,h+484423|0);x[114414]=0;O(334,((f<<5)+a|0)+946304|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break w}xb(d+16|0);if(!(y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24))){break x}Bd(d+16|0,b,y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24));z:{if(!l){break z}c=ad(d+8|0,w[h+484414>>1]&1?16:8,1,0,0);x[114414]=0;U(361,c|0,i|0,d+16|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break z}e=N()|0;Ab(d+16|0);break b}Ab(d+16|0)}e=e+1|0;if(e>>>0<(y[d+474|0]|y[d+475|0]<<8)>>>0){continue}break v}break}e=N()|0;xb(d+16|0);break b}n=(y[d+474|0]|y[d+475|0]<<8)+n|0}if(k>>>0<z[a+480192>>1]){continue}break}break a}e=N()|0;xb(d+96|0)}Q(e|0);p()}hb=d+1328|0;return s|0}function e_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0;l=hb-560|0;hb=l;x[l+548>>2]=k;x[l+552>>2]=b;a:{b:{if(hh(a,l+552|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+96>>2]=2542;b=l+96|0;q=Pd(l+136|0,l+144|0,b);k=x[q>>2];x[l+132>>2]=k;x[l+128>>2]=k+400;s=Wb(b);m=Cg(l+80|0);o=Cg(l- -64|0);n=Cg(l+48|0);r=Cg(l+32|0);x[114414]=0;ja(2555,c|0,d|0,l+120|0,l+116|0,l+112|0,s|0,m|0,o|0,n|0,l+28|0);b=x[114414];x[114414]=0;if((b|0)!=1){x[j>>2]=x[i>>2];u=e&512;e=0;k=0;while(1){c=k;c:{d:{e:{f:{if((e|0)==4){break f}x[114414]=0;b=O(2515,a|0,l+552|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}if(b){break f}b=0;g:{h:{i:{j:{k:{switch(v[(l+120|0)+e|0]){case 1:if((e|0)==3){break d}x[114414]=0;b=R(2516,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}x[114414]=0;b=U(2556,h|0,1,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}if(b){x[114414]=0;T(2557,l+16|0,a|0,0);b=x[114414];x[114414]=0;if((b|0)!=1){b=x[l+16>>2];x[114414]=0;P(109,r|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break j}}break a}x[f>>2]=x[f>>2]|4;a=0;break e;case 4:break g;case 2:break h;case 3:break i;case 0:break k;default:break c}}if((e|0)==3){break d}}while(1){x[114414]=0;b=O(2515,a|0,l+552|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}if(b){break d}x[114414]=0;b=R(2516,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}x[114414]=0;b=U(2556,h|0,1,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}if(!b){break d}x[114414]=0;T(2557,l+16|0,a|0,0);b=x[114414];x[114414]=0;if((b|0)!=1){b=x[l+16>>2];x[114414]=0;P(109,r|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}}break}break a}l:{if(!Bb(o)){break l}x[114414]=0;b=R(2516,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}if((b|0)!=x[Rb(o)>>2]){break l}x[114414]=0;R(2518,a|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}v[g|0]=0;k=Bb(o)>>>0>1?o:c;break c}m:{if(!Bb(n)){break m}x[114414]=0;b=R(2516,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}if((b|0)!=x[Rb(n)>>2]){break m}x[114414]=0;R(2518,a|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}v[g|0]=1;k=Bb(n)>>>0>1?n:c;break c}n:{if(!Bb(o)){break n}if(!Bb(n)){break n}x[f>>2]=x[f>>2]|4;a=0;break e}if(!Bb(o)){if(!Bb(n)){break d}}w=g,z=!Bb(n),v[w|0]=z;break d}if(!(c|e>>>0<2|u)){k=0;if(!((e|0)==2&y[l+123|0]!=0)){break c}}w=l,z=ud(m),x[w+8>>2]=z;b=td(l+16|0,l+8|0);o:{if(!e|y[(e+l|0)+119|0]>1){break o}p:{while(1){w=l,z=gk(m),x[w+8>>2]=z;if(!Hb(b,l+8|0)){break p}d=x[x[b>>2]>>2];x[114414]=0;d=U(2556,h|0,1,d|0)|0;k=x[114414];x[114414]=0;if((k|0)!=1){if(!d){break p}fe(b);continue}break}break a}w=l,z=ud(m),x[w+8>>2]=z;d=Zt(b,l+8|0);if(Bb(r)>>>0>=d>>>0){w=l,z=gk(r),x[w+8>>2]=z;d=xO(l+8|0,d);k=gk(r);t=ud(m);x[114414]=0;d=bF(d,k,t);k=x[114414];x[114414]=0;if((k|0)==1){break a}if(d){break o}}w=l,z=ud(m),x[w>>2]=z;w=b,z=x[td(l+8|0,l)>>2],x[w>>2]=z}x[l+8>>2]=x[b>>2];q:{while(1){w=l,z=gk(m),x[w>>2]=z;if(!Hb(l+8|0,l)){break q}x[114414]=0;b=O(2515,a|0,l+552|0)|0;d=x[114414];x[114414]=0;r:{if((d|0)==1){break r}if(b){break q}x[114414]=0;b=R(2516,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break r}if((b|0)!=x[x[l+8>>2]>>2]){break q}x[114414]=0;R(2518,a|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}fe(l+8|0);continue}break}break a}if(!u){break d}w=l,z=gk(m),x[w>>2]=z;if(!Hb(l+8|0,l)){break d}x[f>>2]=x[f>>2]|4;a=0;break e}s:{while(1){t:{x[114414]=0;d=O(2515,a|0,l+552|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break t}if(d){break s}x[114414]=0;k=R(2516,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}x[114414]=0;d=U(2556,h|0,64,k|0)|0;t=x[114414];x[114414]=0;if((t|0)==1){break a}u:{if(d){d=x[j>>2];if((d|0)==x[l+548>>2]){x[114414]=0;T(2559,i|0,j|0,l+548|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}d=x[j>>2]}x[j>>2]=d+4;x[d>>2]=k;b=b+1|0;break u}if(!Bb(s)|!b|(k|0)!=x[l+112>>2]){break s}k=x[l+132>>2];if((k|0)==x[l+128>>2]){x[114414]=0;T(2550,q|0,l+132|0,l+128|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}k=x[l+132>>2]}x[l+132>>2]=k+4;x[k>>2]=b;b=0}x[114414]=0;R(2518,a|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){continue}}break}break a}k=x[l+132>>2];if(!(!b|(k|0)==x[q>>2])){if(x[l+128>>2]==(k|0)){x[114414]=0;T(2550,q|0,l+132|0,l+128|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}k=x[l+132>>2]}x[l+132>>2]=k+4;x[k>>2]=b}v:{if(x[l+28>>2]<=0){break v}x[114414]=0;b=O(2515,a|0,l+552|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}w:{if(!b){x[114414]=0;b=R(2516,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}if((b|0)==x[l+116>>2]){break w}}x[f>>2]=x[f>>2]|4;a=0;break e}x[114414]=0;R(2518,a|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}while(1){if(x[l+28>>2]<=0){break v}x[114414]=0;b=O(2515,a|0,l+552|0)|0;d=x[114414];x[114414]=0;x:{if((d|0)==1){break x}y:{if(!b){x[114414]=0;b=R(2516,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break x}x[114414]=0;b=U(2556,h|0,64,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break x}if(b){break y}}x[f>>2]=x[f>>2]|4;a=0;break e}if(x[j>>2]==x[l+548>>2]){x[114414]=0;T(2559,i|0,j|0,l+548|0);b=x[114414];x[114414]=0;if((b|0)==1){break x}}x[114414]=0;b=R(2516,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break x}d=x[j>>2];x[j>>2]=d+4;x[d>>2]=b;x[114414]=0;x[l+28>>2]=x[l+28>>2]-1;R(2518,a|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){continue}}break}break a}k=c;if(x[i>>2]!=x[j>>2]){break c}x[f>>2]=x[f>>2]|4;a=0;break e}z:{if(!c){break z}k=1;while(1){if(Bb(c)>>>0<=k>>>0){break z}x[114414]=0;b=O(2515,a|0,l+552|0)|0;d=x[114414];x[114414]=0;A:{if((d|0)==1){break A}B:{if(!b){x[114414]=0;b=R(2516,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break A}if((b|0)==x[qj(c,k)>>2]){break B}}x[f>>2]=x[f>>2]|4;a=0;break e}x[114414]=0;R(2518,a|0)|0;b=x[114414];x[114414]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}C:{if(x[q>>2]==x[l+132>>2]){break C}x[l+16>>2]=0;a=x[q>>2];x[114414]=0;De(s,a,x[l+132>>2],l+16|0);a=x[114414];x[114414]=0;if((a|0)!=1){if(!x[l+16>>2]){break C}x[f>>2]=x[f>>2]|4;a=0;break e}break a}a=1}Nc(r);Nc(n);Nc(o);Nc(m);xb(s);Jc(q);break b}k=c}e=e+1|0;continue}}break a}hb=l+560|0;return a|0}a=N()|0;Nc(r);Nc(n);Nc(o);Nc(m);xb(s);Jc(q);Q(a|0);p()}function l_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0;l=hb-560|0;hb=l;x[l+548>>2]=k;x[l+552>>2]=b;a:{b:{if(Ag(a,l+552|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+104>>2]=2542;b=l+104|0;q=Pd(l+136|0,l+144|0,b);k=x[q>>2];x[l+132>>2]=k;x[l+128>>2]=k+400;s=Wb(b);m=Wb(l+88|0);o=Wb(l+72|0);n=Wb(l+56|0);r=Wb(l+40|0);x[114414]=0;ja(2545,c|0,d|0,l+120|0,l+119|0,l+118|0,s|0,m|0,o|0,n|0,l+36|0);b=x[114414];x[114414]=0;if((b|0)!=1){x[j>>2]=x[i>>2];u=e&512;e=0;k=0;while(1){c=k;c:{d:{e:{f:{if((e|0)==4){break f}x[114414]=0;b=O(2486,a|0,l+552|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}if(b){break f}b=0;g:{h:{i:{j:{k:{switch(v[(l+120|0)+e|0]){case 1:if((e|0)==3){break d}x[114414]=0;b=R(2487,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}x[114414]=0;b=zg(h,1,b);d=x[114414];x[114414]=0;if((d|0)==1){break a}if(b){x[114414]=0;T(2547,l+24|0,a|0,0);b=x[114414];x[114414]=0;if((b|0)!=1){b=v[l+24|0];x[114414]=0;P(107,r|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break j}}break a}x[f>>2]=x[f>>2]|4;a=0;break e;case 4:break g;case 2:break h;case 3:break i;case 0:break k;default:break c}}if((e|0)==3){break d}}while(1){x[114414]=0;b=O(2486,a|0,l+552|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}if(b){break d}x[114414]=0;b=R(2487,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}x[114414]=0;b=zg(h,1,b);d=x[114414];x[114414]=0;if((d|0)==1){break a}if(!b){break d}x[114414]=0;T(2547,l+24|0,a|0,0);b=x[114414];x[114414]=0;if((b|0)!=1){b=v[l+24|0];x[114414]=0;P(107,r|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}}break}break a}l:{if(!Bb(o)){break l}x[114414]=0;b=R(2487,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}if(y[pc(o,0)|0]!=(b&255)){break l}x[114414]=0;R(2489,a|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}v[g|0]=0;k=Bb(o)>>>0>1?o:c;break c}m:{if(!Bb(n)){break m}x[114414]=0;b=R(2487,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}if(y[pc(n,0)|0]!=(b&255)){break m}x[114414]=0;R(2489,a|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}v[g|0]=1;k=Bb(n)>>>0>1?n:c;break c}n:{if(!Bb(o)){break n}if(!Bb(n)){break n}x[f>>2]=x[f>>2]|4;a=0;break e}if(!Bb(o)){if(!Bb(n)){break d}}w=g,z=!Bb(n),v[w|0]=z;break d}if(!(c|e>>>0<2|u)){k=0;if(!((e|0)==2&y[l+123|0]!=0)){break c}}w=l,z=ud(m),x[w+16>>2]=z;b=td(l+24|0,l+16|0);o:{if(!e|y[(e+l|0)+119|0]>1){break o}p:{while(1){w=l,z=jf(m),x[w+16>>2]=z;if(!Hb(b,l+16|0)){break p}d=v[x[b>>2]];x[114414]=0;d=zg(h,1,d);k=x[114414];x[114414]=0;if((k|0)!=1){if(!d){break p}bg(b);continue}break}break a}w=l,z=ud(m),x[w+16>>2]=z;d=qm(b,l+16|0);if(Bb(r)>>>0>=d>>>0){w=l,z=jf(r),x[w+16>>2]=z;d=Tz(l+16|0,d);k=jf(r);t=ud(m);x[114414]=0;d=hF(d,k,t);k=x[114414];x[114414]=0;if((k|0)==1){break a}if(d){break o}}w=l,z=ud(m),x[w+8>>2]=z;w=b,z=x[td(l+16|0,l+8|0)>>2],x[w>>2]=z}x[l+16>>2]=x[b>>2];q:{while(1){w=l,z=jf(m),x[w+8>>2]=z;if(!Hb(l+16|0,l+8|0)){break q}x[114414]=0;b=O(2486,a|0,l+552|0)|0;d=x[114414];x[114414]=0;r:{if((d|0)==1){break r}if(b){break q}x[114414]=0;b=R(2487,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break r}if(y[x[l+16>>2]]!=(b&255)){break q}x[114414]=0;R(2489,a|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}bg(l+16|0);continue}break}break a}if(!u){break d}w=l,z=jf(m),x[w+8>>2]=z;if(!Hb(l+16|0,l+8|0)){break d}x[f>>2]=x[f>>2]|4;a=0;break e}s:{while(1){t:{x[114414]=0;d=O(2486,a|0,l+552|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break t}if(d){break s}x[114414]=0;k=R(2487,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}x[114414]=0;d=zg(h,64,k);t=x[114414];x[114414]=0;if((t|0)==1){break a}u:{if(d){d=x[j>>2];if((d|0)==x[l+548>>2]){x[114414]=0;T(2549,i|0,j|0,l+548|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}d=x[j>>2]}x[j>>2]=d+1;v[d|0]=k;b=b+1|0;break u}if(!Bb(s)|!b|y[l+118|0]!=(k&255)){break s}k=x[l+132>>2];if((k|0)==x[l+128>>2]){x[114414]=0;T(2550,q|0,l+132|0,l+128|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}k=x[l+132>>2]}x[l+132>>2]=k+4;x[k>>2]=b;b=0}x[114414]=0;R(2489,a|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){continue}}break}break a}k=x[l+132>>2];if(!(!b|(k|0)==x[q>>2])){if(x[l+128>>2]==(k|0)){x[114414]=0;T(2550,q|0,l+132|0,l+128|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}k=x[l+132>>2]}x[l+132>>2]=k+4;x[k>>2]=b}v:{if(x[l+36>>2]<=0){break v}x[114414]=0;b=O(2486,a|0,l+552|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}w:{if(!b){x[114414]=0;b=R(2487,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}if(y[l+119|0]==(b&255)){break w}}x[f>>2]=x[f>>2]|4;a=0;break e}x[114414]=0;R(2489,a|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}while(1){if(x[l+36>>2]<=0){break v}x[114414]=0;b=O(2486,a|0,l+552|0)|0;d=x[114414];x[114414]=0;x:{if((d|0)==1){break x}y:{if(!b){x[114414]=0;b=R(2487,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break x}x[114414]=0;b=zg(h,64,b);d=x[114414];x[114414]=0;if((d|0)==1){break x}if(b){break y}}x[f>>2]=x[f>>2]|4;a=0;break e}if(x[j>>2]==x[l+548>>2]){x[114414]=0;T(2549,i|0,j|0,l+548|0);b=x[114414];x[114414]=0;if((b|0)==1){break x}}x[114414]=0;b=R(2487,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break x}d=x[j>>2];x[j>>2]=d+1;v[d|0]=b;x[114414]=0;x[l+36>>2]=x[l+36>>2]-1;R(2489,a|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){continue}}break}break a}k=c;if(x[i>>2]!=x[j>>2]){break c}x[f>>2]=x[f>>2]|4;a=0;break e}z:{if(!c){break z}k=1;while(1){if(Bb(c)>>>0<=k>>>0){break z}x[114414]=0;b=O(2486,a|0,l+552|0)|0;d=x[114414];x[114414]=0;A:{if((d|0)==1){break A}B:{if(!b){x[114414]=0;b=R(2487,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break A}if(y[pc(c,k)|0]==(b&255)){break B}}x[f>>2]=x[f>>2]|4;a=0;break e}x[114414]=0;R(2489,a|0)|0;b=x[114414];x[114414]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}C:{if(x[q>>2]==x[l+132>>2]){break C}x[l+24>>2]=0;a=x[q>>2];x[114414]=0;De(s,a,x[l+132>>2],l+24|0);a=x[114414];x[114414]=0;if((a|0)!=1){if(!x[l+24>>2]){break C}x[f>>2]=x[f>>2]|4;a=0;break e}break a}a=1}xb(r);xb(n);xb(o);xb(m);xb(s);Jc(q);break b}k=c}e=e+1|0;continue}}break a}hb=l+560|0;return a|0}a=N()|0;xb(r);xb(n);xb(o);xb(m);xb(s);Jc(q);Q(a|0);p()}function e7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),j=E(0),k=0,l=E(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=E(0),w=E(0),z=0,A=0,C=0,D=E(0),F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=E(0),R=0,S=0,T=0,U=0,V=0,W=E(0),X=0,Y=0,Z=0,_=E(0);a:{if(!y[a+5046|0]){break a}j=B[a+4268>>2];rJ(a);if(j==B[a+4268>>2]){break a}Ax(a)}b:{if(!y[a+5045|0]){break b}o=a+44|0;if(!Bh(o)){break b}p=Od(o,0);t=Od(o,1);m=ld(o,0);n=ld(o,1);c:{if(!(!y[a+5044|0]|(!d|y[a+4264|0]&2))){B[m>>2]=B[a+5036>>2];B[n>>2]=B[a+5040>>2];v[a+5044|0]=0;t=t+4|0;p=p+4|0;n=n+4|0;m=m+4|0;k=d-1|0;break c}k=d}q=k;d:{if(!q){break d}F=a+4648|0;G=a+4672|0;R=a+4936|0;H=a+4696|0;I=a+4720|0;J=a+4744|0;K=a+4768|0;S=a+4840|0;L=a+4528|0;T=a+4912|0;M=a+4552|0;N=a+4576|0;O=a+4600|0;P=a+4624|0;U=a+4816|0;r=a+4888|0;s=a+4864|0;C=a+4504|0;V=a+4960|0;while(1){j=B[p>>2];j=E(E(E(B[a+5008>>2]-j)*B[a+4276>>2])+j);B[a+5008>>2]=j;Z=Ec(s,x[a+4880>>2]),_=j,B[Z>>2]=_;j=B[t>>2];j=E(E(E(B[a+5012>>2]-j)*B[a+4276>>2])+j);B[a+5012>>2]=j;Z=Ec(r,x[a+4904>>2]),_=j,B[Z>>2]=_;j=mh(s,x[a+4356>>2]);f=mh(s,x[a+4360>>2]);e=mh(s,x[a+4364>>2]);g=mh(s,x[a+4368>>2]);j=E(E(E(j*E(.6800000071525574))+E(E(e+mh(s,x[a+4372>>2]))*E(-.6200000047683716)))+E(E(g+f)*E(-.5)));if(v[a+4264|0]&1){f=j;j=E(B[Ec(U,x[a+4836>>2])>>2]+E(f*E(.6180340051651001)));Z=Ec(U,x[a+4832>>2]),_=E(f-E(j*E(.6180340051651001))),B[Z>>2]=_}W=B[a+4280>>2];Z=a,_=E(mh(s,x[a+4352>>2])+B[a+5020>>2]),B[Z+5020>>2]=_;f=E(mh(r,x[a+4376>>2])+B[a+5024>>2]);B[a+5024>>2]=f;e=B[a+5020>>2];g=B[a+4980>>2];i=B[Ec(P,x[a+4644>>2])>>2];u=B[a+4444>>2];g=E(B[Ec(P,x[a+4644>>2])>>2]+E(u*E(g-i)));B[a+4980>>2]=g;i=B[a+4272>>2];h=E(e*E(-.7070000171661377));l=E(f*E(.7070000171661377));e=E(h+l);f=E(E(i*e)+E(B[a+4440>>2]*g));Z=Ec(P,x[a+4640>>2]),_=E(e-E(i*f)),B[Z>>2]=_;e=B[a+4976>>2];g=B[Ec(O,x[a+4620>>2])>>2];i=B[a+4436>>2];e=E(B[Ec(O,x[a+4620>>2])>>2]+E(i*E(e-g)));B[a+4976>>2]=e;g=B[a+4272>>2];e=E(E(g*f)+E(B[a+4432>>2]*e));Z=Ec(O,x[a+4616>>2]),_=E(f-E(g*e)),B[Z>>2]=_;u=E(E(f*E(-.15000000596046448))+E(e*E(-.20000000298023224)));if(v[a+4264|0]&1){f=B[a+4972>>2];g=B[Ec(N,x[a+4596>>2])>>2];i=B[a+4428>>2];f=E(B[Ec(N,x[a+4596>>2])>>2]+E(i*E(f-g)));B[a+4972>>2]=f;g=B[a+4272>>2];f=E(E(g*e)+E(B[a+4424>>2]*f));Z=Ec(N,x[a+4592>>2]),_=E(e-E(g*f)),B[Z>>2]=_;e=B[a+4968>>2];g=B[Ec(M,x[a+4572>>2])>>2];i=B[a+4420>>2];e=E(B[Ec(M,x[a+4572>>2])>>2]+E(i*E(e-g)));B[a+4968>>2]=e;g=B[a+4272>>2];e=E(E(g*f)+E(B[a+4416>>2]*e));Z=Ec(M,x[a+4568>>2]),_=E(f-E(g*e)),B[Z>>2]=_;u=E(E(E(f*E(.3499999940395355))+u)+E(e*E(-.3799999952316284)))}Z=Ec(T,x[a+4928>>2]),_=e,B[Z>>2]=_;k=Ec(T,x[a+4932>>2]);f=E(B[a+4496>>2]*B[k>>2]);B[a+5028>>2]=E(E(B[a+5028>>2]-f)*B[a+4500>>2])+f;f=B[a+4964>>2];e=B[Ec(L,x[a+4548>>2])>>2];g=B[a+4412>>2];f=E(B[Ec(L,x[a+4548>>2])>>2]+E(g*E(f-e)));B[a+4964>>2]=f;g=E(B[a+4408>>2]*f);f=B[a+4272>>2];e=B[a+5028>>2];g=E(g+E(f*e));Z=Ec(L,x[a+4544>>2]),_=E(e-E(f*g)),B[Z>>2]=_;f=B[a+4960>>2];e=B[Ec(C,x[a+4524>>2])>>2];i=B[a+4404>>2];f=E(B[Ec(C,x[a+4524>>2])>>2]+E(i*E(f-e)));B[a+4960>>2]=f;e=B[a+4272>>2];Q=E(E(e*g)+E(B[a+4400>>2]*f));Z=Ec(C,x[a+4520>>2]),_=E(g-E(e*Q)),B[Z>>2]=_;B[a+5020>>2]=Q;f=mh(r,x[a+4380>>2]);e=mh(r,x[a+4384>>2]);i=mh(r,x[a+4388>>2]);w=mh(r,x[a+4392>>2]);f=E(E(E(f*E(.7070000171661377))+E(E(i+mh(r,x[a+4396>>2]))*E(-.5)))+E(E(w+e)*E(-.6000000238418579)));if(v[a+4264|0]&1){e=f;f=E(B[Ec(S,x[a+4860>>2])>>2]+E(e*E(.6180340051651001)));Z=Ec(S,x[a+4856>>2]),_=E(e-E(f*E(.6180340051651001))),B[Z>>2]=_}w=B[a+4280>>2];e=B[a+5004>>2];i=B[Ec(K,x[a+4788>>2])>>2];D=B[a+4492>>2];e=E(B[Ec(K,x[a+4788>>2])>>2]+E(D*E(e-i)));B[a+5004>>2]=e;D=B[a+4272>>2];h=E(h-l);i=E(E(D*h)+E(B[a+4488>>2]*e));Z=Ec(K,x[a+4784>>2]),_=E(h-E(D*i)),B[Z>>2]=_;e=B[a+5e3>>2];h=B[Ec(J,x[a+4764>>2])>>2];l=B[a+4484>>2];e=E(B[Ec(J,x[a+4764>>2])>>2]+E(l*E(e-h)));B[a+5e3>>2]=e;h=B[a+4272>>2];e=E(E(h*i)+E(B[a+4480>>2]*e));Z=Ec(J,x[a+4760>>2]),_=E(i-E(h*e)),B[Z>>2]=_;i=E(E(e*E(-.20000000298023224))+E(E(g*E(.3799999952316284))+E(i*E(-.15000000596046448))));if(v[a+4264|0]&1){g=B[a+4996>>2];h=B[Ec(I,x[a+4740>>2])>>2];l=B[a+4476>>2];g=E(B[Ec(I,x[a+4740>>2])>>2]+E(l*E(g-h)));B[a+4996>>2]=g;h=B[a+4272>>2];g=E(E(h*e)+E(B[a+4472>>2]*g));Z=Ec(I,x[a+4736>>2]),_=E(e-E(h*g)),B[Z>>2]=_;e=B[a+4992>>2];h=B[Ec(H,x[a+4716>>2])>>2];l=B[a+4468>>2];e=E(B[Ec(H,x[a+4716>>2])>>2]+E(l*E(e-h)));B[a+4992>>2]=e;h=B[a+4272>>2];e=E(E(h*g)+E(B[a+4464>>2]*e));Z=Ec(H,x[a+4712>>2]),_=E(g-E(h*e)),B[Z>>2]=_;i=E(E(E(g*E(.3499999940395355))+i)+E(e*E(-.3799999952316284)))}X=t+4|0;Y=p+4|0;g=E(w*f);Z=Ec(R,x[a+4952>>2]),_=e,B[Z>>2]=_;k=Ec(R,x[a+4956>>2]);f=E(B[a+4496>>2]*B[k>>2]);B[a+5032>>2]=E(E(B[a+5032>>2]-f)*B[a+4500>>2])+f;f=B[a+4988>>2];e=B[Ec(G,x[a+4692>>2])>>2];h=B[a+4460>>2];f=E(B[Ec(G,x[a+4692>>2])>>2]+E(h*E(f-e)));B[a+4988>>2]=f;e=B[a+4272>>2];h=B[a+5032>>2];f=E(E(B[a+4456>>2]*f)+E(e*h));Z=Ec(G,x[a+4688>>2]),_=E(h-E(e*f)),B[Z>>2]=_;h=B[a+4284>>2];e=B[a+4984>>2];l=B[Ec(F,x[a+4668>>2])>>2];w=B[a+4452>>2];e=E(B[Ec(F,x[a+4668>>2])>>2]+E(w*E(e-l)));B[a+4984>>2]=e;l=B[a+4272>>2];e=E(E(l*f)+E(B[a+4448>>2]*e));Z=Ec(F,x[a+4664>>2]),_=E(f-E(l*e)),B[Z>>2]=_;B[a+5024>>2]=e;e=E(e*E(.3799999952316284));j=E(E(h*E(E(E(f-Q)*E(.3799999952316284))+u))+E(W*j));f=B[a+4288>>2];k=C;while(1){z=x[k+16>>2];A=z-1|0;x[k+16>>2]=A;if((z|0)<=0){x[k+16>>2]=A+x[k+12>>2]}z=x[k+20>>2];A=z-1|0;x[k+20>>2]=A;if((z|0)<=0){x[k+20>>2]=A+x[k+12>>2]}k=k+24|0;if((V|0)!=(k|0)){continue}break}f=E(E(f*E(i-e))+g);e:{f:{if(y[a+4264|0]&2){p=Y;k=X;break f}B[m>>2]=E(B[a+5036>>2]+j)*E(.5);B[n>>2]=E(B[a+5040>>2]+f)*E(.5);B[a+5040>>2]=f;B[a+5036>>2]=j;if((q|0)==1){break e}q=q-1|0;p=p+8|0;n=n+4|0;m=m+4|0;k=t+8|0}t=k;B[m>>2]=j;B[n>>2]=f;n=n+4|0;m=m+4|0;q=q-1|0;if(q){continue}break d}break}v[a+5044|0]=1}zi(a,b,c,ld(o,0),ld(o,1),d)}}function Oia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-272|0;hb=e;Lc(b);a:{if(!KA(b,e+200|0)){break a}if(!lQ(e+200|0)){break a}if(!Qb(b,jd(kQ(e+200|0),lb))){break a}b:{if(!c){break b}Nd(a,16);f=e+32|0;_n(f,2,e+200|4);j=e+48|0;Ic(j,f);Db(a+1304400|0,j);xb(j);w[a+480190>>1]=y[e+230|0];w[a+480188>>1]=y[e+233|0];d=Ub(j,4584);Db(a+1304436|0,d);xb(d);d=Ub(j,6110);Db(a+1304448|0,d);xb(d);j=Ub(e+184|0,10917);x[114414]=0;P(187,f|0,j|0);d=x[114414];x[114414]=0;c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){d=e+200|3;x[e+8>>2]=y[d|0]>>>4;d=y[d|0];x[114414]=0;x[e+176>>2]=d&15;X(501,e+48|0,e+32|0,e+8|0,e+176|0);d=x[114414];x[114414]=0;if((d|0)==1){break i}d=e+48|0;Db(a+1304460|0,d);xb(d);Gb(e+32|0);xb(j);x[a+1304496>>2]=4;if(z[a+480190>>1]){i=1;while(1){g=e+48|0;TB(b,g);f=hb-16|0;hb=f;j=i&65535;h=(D(j,104)+a|0)+484380|0;Ad(h,0);w[f+14>>1]=y[g+35|0]<<2;w[f+12>>1]=256;t=h,u=z[Cf(f+14|0,f+12|0)>>1],w[t+30>>1]=u;j:{if((y[g+22|0]|y[g+23|0]<<8|(y[g+24|0]<<16|y[g+25|0]<<24))>>>0<3){break j}x[h>>2]=y[g+22|0]|y[g+23|0]<<8|(y[g+24|0]<<16|y[g+25|0]<<24);x[h+4>>2]=y[g+26|0]|y[g+27|0]<<8|(y[g+28|0]<<16|y[g+29|0]<<24);x[f+8>>2]=y[g+30|0]|y[g+31|0]<<8|(y[g+32|0]<<16|y[g+33|0]<<24);x[f+4>>2]=1;t=h,u=x[_c(f+8|0,f+4|0)>>2]-1|0,x[t+8>>2]=u;xc(h+8|0,x[h>>2]);d=x[h+8>>2];k:{if(d>>>0<=x[h+4>>2]+4>>>0){x[h+4>>2]=0;x[h+8>>2]=0;break k}if(d>>>0<3){break k}w[h+34>>1]=z[h+34>>1]|2}v[h+37|0]=y[g+34|0];t=h,u=yt(0,v[g+34|0]<<4),x[t+24>>2]=u;if(!(v[g+36|0]&1)){break j}w[h+34>>1]=z[h+34>>1]|1;x[h>>2]=x[h>>2]>>>1;x[h+4>>2]=x[h+4>>2]>>>1;x[h+8>>2]=x[h+8>>2]>>>1}hb=f+16|0;f=e+8|0;lm(f,2,g);d=e+32|0;Ic(d,f);x[114414]=0;O(334,((j<<5)+a|0)+946304|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}xb(e+32|0);i=i+1|0;if(z[a+480190>>1]>=(i&65535)>>>0){continue}break}}if(z[a+480188>>1]){i=0;while(1){d=(i<<5)+a|0;Lg(d+480280|0);w[d+480284>>1]=(y[(e+i|0)+234|0]<<4|8)&248;i=i+1|0;if(i>>>0<z[a+480188>>1]){continue}break}}h=e+48|0;g=hb-16|0;hb=g;l:{if(Qb(b,128)){d=g+8|0;WR(d,h);Dd(b,d);break l}j=hb-16|0;hb=j;f=0;d=hb-16|0;hb=d;while(1){mf(f+h|0);f=f+1|0;if((f|0)!=128){continue}break}hb=d+16|0;hb=j+16|0}hb=g+16|0;$B(Vb(a+484360|0),h,y[e+227|0]+1|0);if(y[e+232|0]){break g}n=64;break f}i=N()|0;break h}i=N()|0;Gb(e+32|0)}xb(j);break c}n=y[e+232|0]}Bd(e+32|0,b,D(y[e+224|0]|y[e+225|0]<<8,192));m:{r=c&1;if(!r){break m}d=y[e+226|0];x[114414]=0;P(362,a+484344|0,d+1|0);d=x[114414];x[114414]=0;if((d|0)!=1){break m}break d}l=a+484344|0;d=0;n:{while(1){o:{p:{if(r){x[114414]=0;j=U(363,l|0,o&65535,n|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}i=0;if(j){break p}}x[114414]=0;O(304,b|0,64)|0;f=x[114414];x[114414]=0;if((f|0)!=1){break o}break d}while(1){x[114414]=0;g=R(321,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}q=i;q:{if(!g|g>>>0>(y[e+224|0]|y[e+225|0]<<8)>>>0){break q}j=q&65535;if(j>>>0>=z[a+480188>>1]){break q}x[114414]=0;O(224,e+32|0,D(g,192)-192|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}f=Zb(l,o);x[114414]=0;i=U(427,f|0,0,j|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break n}k=0;if(!n){break q}while(1){j=d;x[114414]=0;P(786,e+8|0,e+32|0);d=x[114414];x[114414]=0;r:{s:{t:{u:{v:{if((d|0)!=1){g=e+8|0;m=ed(g);f=rf(g);d=y[g|0];if(d>>>0>=4){v[i|0]=(d>>>2|0)+37;d=y[g|0]}v[i+1|0]=d<<4&48|y[m|0]>>>4;d=y[f|0];g=0;h=0;w:{x:{f=y[m|0]&15;switch(f-8|0){case 0:break u;case 2:break w;case 6:break x;default:break v}}f=14;m=(d&240)<<24>>24;if((m|0)<=-17|!(435>>>((m+16&255)>>>4)&1)){break t}break u}d=d&240?d&-16:d;f=10;break t}break d}g=f;h=d}d=h;f=g;if(!((d|f)&255)){break s}}v[i+5|0]=d;v[i+3|0]=f;x[114414]=0;W(541,i|0);d=x[114414];x[114414]=0;y:{if((d|0)!=1){d=1;switch(y[i+3|0]-16|0){case 0:break r;case 1:break y;default:break s}}break d}s=1}d=j}i=D(z[a+480188>>1],6)+i|0;k=k+1|0;if((n|0)!=(k|0)){continue}break}}i=q+1|0;if((q&65535)>>>0<31){continue}break}}f=y[e+226|0]>o>>>0;o=o+1|0;if(f){continue}break}z:{if(!(d&s)){break z}t=e,u=bc(l),x[t+8>>2]=u;t=e,u=dc(l),x[t+176>>2]=u;if(Hb(e+8|0,e+176|0)){while(1){k=0;A:{h=x[e+8>>2];if(!x[h+12>>2]){break A}while(1){B:{x[114414]=0;j=O(898,h|0,k|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break B}i=0;g=0;f=0;if(z[a+480188>>1]){while(1){d=1;C:{switch(y[(j+D(i,6)|0)+3|0]-16|0){case 1:g=1;default:d=f;break;case 0:break C}}f=d;i=i+1|0;if(i>>>0<z[a+480188>>1]){continue}break}if(d&g&1){break z}}k=k+1|0;if(k>>>0<A[h+12>>2]){continue}break A}break}break d}d=e+8|0;Zl(d);if(Hb(d,e+176|0)){continue}break}}t=e,u=bc(l),x[t+176>>2]=u;t=e,u=dc(l),x[t+24>>2]=u;if(!Hb(e+176|0,e+24|0)){break z}while(1){h=0;D:{j=x[e+176>>2];if(!x[j+12>>2]){break D}while(1){E:{x[114414]=0;f=O(453,j|0,h|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break E}i=0;F:{if(!z[a+480188>>1]){break F}while(1){d=y[(f+D(i,6)|0)+3|0];if((d&254)==16){x[114414]=0;d=(d|0)==16;f=U(454,e+8|0,(d?17:16)|0,(d?125:6)|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){d=Ie(f,h);x[114414]=0;O(455,j|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break F}}break d}i=i+1|0;if(i>>>0<z[a+480188>>1]){continue}break}}h=h+1|0;if(h>>>0<A[j+12>>2]){continue}break D}break}break d}d=e+176|0;Zl(d);if(Hb(d,e+24|0)){continue}break}}G:{if(!(y[e+228|0]|y[e+229|0]<<8)){break G}d=y[e+228|0]|y[e+229|0]<<8;x[114414]=0;aa(514,a+1304424|0,b|0,d|0,39,1)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break G}break d}H:{if(!(!(c&2)|!z[a+480190>>1])){d=1;while(1){f=D(d&65535,104)+a|0;c=ad(e+176|0,w[f+484414>>1]&1?16:8,1,0,1);x[114414]=0;U(361,c|0,f+484380|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break H}d=d+1|0;if(z[a+480190>>1]>=(d&65535)>>>0){continue}break}}x[a+480260>>2]=64;x[a+480264>>2]=32767;Ab(e+32|0);break b}break d}break d}i=N()|0;xb(e+32|0);break c}i=N()|0;Ab(e+32|0)}Q(i|0);p()}i=1}hb=e+272|0;return i|0}function ft(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=hb-16|0;hb=k;x[k+12>>2]=c;a:{if((c|0)<=0){break a}h=x[b+104>>2];b:{c:{d:{e:{f:{g:{h:{i:{j:{i=x[b+656>>2];k:{if(!(!i|x[a+480180>>2]!=16777216)){o=x[i+44>>2]!=0;break k}if(!i){break j}}j=i+236|0;l:{if((c|0)>128){j=c;break l}n=c-1|0;j=z[fd(j,n)>>1];m:{if((j-1&65535)>>>0<=3998){h=(D(j,104)+a|0)+484380|0;break m}if(!$b(a+1074312|0,43)){break m}if(!wj(b)){break a}}j=y[gc(i+108|0,n)|0];x[k+12>>2]=j}if(j>>>0<=120){break h}c=j;break i}l=0;if(c>>>0<121){break g}}n:{if(!(x[a+480180>>2]&16777248?(c|0)!=255:0)){vn(a,b);if(d){break n}if(!$b(a+1074312|0,100)|!(y[a+480208|0]&4)|!y[b+811|0]){break n}x[b+88>>2]=x[b+88>>2]&-6145;break n}if(!z[a+480192>>1]){break n}x[b+88>>2]=x[b+88>>2]|4096}o:{if((c|0)!=254){break o}p:{c=x[b+88>>2];if(!(c&512)){break p}c=x[b+88>>2];if(x[a+480180>>2]!=2){break p}x[b+88>>2]=c|2048;break o}x[b+88>>2]=c|2101248;q:{if(x[a+480180>>2]&16777248){if(!z[a+480192>>1]){break q}if($b(a+1074312|0,50)){break q}}x[b+688>>2]=0}if($b(a+1074312|0,50)){x[b+8>>2]=0;x[b+12>>2]=0}x[b+696>>2]=0}if(!$b(a+1074312|0,20)){break a}v[b+819|0]=0;v[b+824|0]=0;break a}l=0;if(!o){break g}if(d){l=y[b+819|0];if(l){break f}}x[b+708>>2]=0;l=1}j=l;if(d){break e}if(!(!(x[a+480180>>2]&1048588)|!h)){x[b+772>>2]=v[h+36|0];x[b+768>>2]=v[h+37|0];break d}if(h){break d}h=0;o=1;break c}n=x[i+44>>2];w[k+10>>1]=l;w[k+8>>1]=j;x[k+4>>2]=0;j=(x[k+4>>2]+D(w[n+36>>1]+1|0,w[k+8>>1]-w[k+10>>1]|0)|0)-x[b+876>>2]|0;x[b+708>>2]=j;x[b+876>>2]=0-j;j=1}o=!h;l=1;if(Sh(b)){break b}n=a+1074312|0;if($b(n,54)){x[b+700>>2]=0;break a}l=($b(n,39)^-1)&d;break b}o=0;if(!$b(a+1074312|0,24)){break c}x[b+704>>2]=x[h+24>>2]}l=0}r:{if(lq(a)){x[k+12>>2]=x[k+12>>2]+x[b+772>>2];_d(k+12|0,12,131);break r}vQ(k+12|0)}m=a+1074312|0;s:{if($b(m,34)){c=sO(c);break s}c=x[k+12>>2]}v[b+819|0]=c;v[b+872|0]=y[b+872|0]|16;if(!(x[a+480180>>2]&16777250?0:l)){v[b+825|0]=0}p=eg(a,x[k+12>>2],x[b+768>>2],x[b+704>>2]);v[b+851|0]=0;if($b(m,48)){YM(a,b,i,h)}t:{if(l|e^1){break t}x[b+788>>2]=0;x[b+792>>2]=0;if(!i){break t}if($b(m,29)){v[b+820|0]=y[i+16|0]}if(!(y[i+60|0]&8)){Hi(b+724|0)}if(!(y[i+80|0]&8)){Hi(b+736|0)}if(!(y[i+100|0]&8)){Hi(b+748|0)}if(y[i+20|0]){c=((D(bt(un(a)),y[i+20|0])<<16>>16)/64|0)+1<<16>>16;u:{if($b(m,28)){d=x[b+764>>2];break u}d=(x[b+688>>2]+1|0)/2|0}w[b+788>>1]=(D(d,c)|0)/199}v:{if(!y[i+19|0]){break v}q=b,r=(D(bt(un(a)),y[i+19|0])<<16>>16)/32|0,w[q+790>>1]=r;if($b(m,28)|z[b+796>>1]){break v}w[b+796>>1]=z[b+692>>1]+1}n=y[i+23|0];if(n){d=bt(un(a));c=y[b+857|0];v[b+818|0]=c+1;w[b+792>>1]=(D(c,(D(n,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}n=y[i+24|0];if(!n){break t}d=bt(un(a));c=y[b+858|0];v[b+817|0]=c+1;w[b+794>>1]=(D(c,(D(n,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(o){break a}w:{x:{if(!p){h=0;break x}if(!(l&x[b+700>>2]!=0)){x[b+700>>2]=p}y:{z:{if(!j){if(!l){if($b(m,69)){break z}if($b(m,46)|x[a+480180>>2]==1){break z}}x[b+708>>2]=p}if(!l){break z}if(x[b+76>>2]|x[a+480180>>2]&2){break y}}x[b+104>>2]=h;c=x[h>>2];x[b+84>>2]=c;x[b+76>>2]=c;x[b+80>>2]=0;x[b>>2]=0;x[b+4>>2]=0;A:{B:{C:{if(!(y[a+480210|0]&32)){if(!$b(m,96)|y[b+811|0]){break B}c=x[b+76>>2];break C}if(y[b+811|0]){break B}}x[k+4>>2]=c-1;q=b,r=x[Mb(b+660|0,k+4|0)>>2],x[q+4>>2]=r;break A}x[b+660>>2]=0}c=z[h+34>>1];j=c&1023;d=j|x[b+88>>2]&-525056;x[b+88>>2]=d;D:{E:{if(c&8){x[b+80>>2]=x[h+12>>2];c=x[h+16>>2];x[b+88>>2]=(j&16?d|4:d&-524295)|2;x[b+84>>2]=c;if(A[b+76>>2]>c>>>0){break E}break D}if(!(j&2)){break D}x[b+80>>2]=x[h+4>>2];c=x[h+8>>2];x[b+84>>2]=c;if(A[b+76>>2]<=c>>>0){break D}}x[b+76>>2]=c}F:{if(!(q=0,r=$b(m,83),s=x[b+80>>2],s?q:r)){c=x[b+76>>2];break F}c=x[h>>2];x[b+84>>2]=c;x[b+76>>2]=c}d=x[b+88>>2];if(!(!(d&128)|!c)){x[b+4>>2]=c-1;x[b+88>>2]=d|128}G:{if(y[b+842|0]>3){break G}c=b;H:{if(!($b(m,21)|!(x[a+480180>>2]&16777248))){d=16;if(!(y[a+480208|0]&4)){break H}}d=32;if(x[a+480180>>2]==16){break H}if(x[a+480180>>2]&67633152){break G}d=0}v[c+839|0]=d}if($b(m,21)|y[b+845|0]>3){break y}v[b+840|0]=0}d=x[b>>2];if(A[b+76>>2]<=A[b+4>>2]){c=x[b+80>>2];x[b>>2]=d;x[b+4>>2]=c}h=0;if(!l){break x}h=1;if(!(x[a+480180>>2]&17301536)|(x[b+696>>2]?0:y[b+89|0]&16)){break x}d=1;if(!(y[a+480208|0]&8)){break w}d=1;if(!y[b+811|0]){break w}}if(!(x[b+696>>2]|(!(x[a+480180>>2]&17301536)|!(y[b+89|0]&16)))){Rl(b);if(!$b(m,21)){v[b+838|0]=0;x[b+780>>2]=0}x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}if(!(!h|!(y[a+480208|0]&8))){d=1;if(!y[b+811|0]){break w}}if(!(y[b+811|0]?0:x[a+480180>>2]&1048580)){x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}d=h}I:{if(!(!d|!$b(m,40)|(y[b+811|0]?y[a+480208|0]&8:0))){c=x[b+88>>2]&-4194305;break I}c=x[b+88>>2]&-4196353}x[b+88>>2]=c;J:{if(d){break J}w[b+862>>1]=65535;x[b+88>>2]=c&-6324225|2097152;K:{if($b(m,23)){break K}if($b(m,22)){break K}if($b(m,52)){break K}if($b(m,71)){break K}v[b+859|0]=0;w[b+798>>1]=0}if(e){v[b+838|0]=0;x[b+780>>2]=0}x[b+20>>2]=0;x[b+24>>2]=0;c=x[a+480208>>2]&8192;h=!c;L:{if(i){M:{N:{if(!qC(i)){if(fv(i)){break N}if(!c){break M}break L}q=b,r=rC(i),v[q+858|0]=r;if(!fv(i)){break M}}q=b,r=sC(i),v[q+857|0]=r}h=1;c=y[i+25|0];if((c|0)==255){break L}v[b+865|0]=c;break L}x[b+788>>2]=0;x[b+792>>2]=0}O:{if(y[b+857|0]>=127){if($b(m,36)&h){break O}break J}if(!h){break J}}if((Hp(a,b,1,256)|0)<0|!(y[b+89|0]&2)){break J}c=a+1304392|0;if(!zd(c)|(g|0)==65535){break J}Pp(x[c>>2],g,y[b+857|0]>>>1|0,1)}c=x[b+88>>2];P:{Q:{R:{if(f){x[b+88>>2]=c&-1025;break R}if(!(c&1024)){break R}if(y[a+24618|0]&16){break Q}}a=x[b+104>>2];if(!a|!(y[a+35|0]&4)|f){a=x[b+656>>2];if(!a|!(y[a+15|0]&2)){break P}}if(f){break P}}x[b+700>>2]=0}if(d){break a}w[b+136>>1]=0;x[b+132>>2]=4194304;x[b+112>>2]=0;x[b+116>>2]=0}hb=k+16|0}function h1(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,E=0,G=0,H=0;n=hb-560|0;hb=n;x[n+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){u=1;C=1782;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){u=1;C=1785;break a}u=e&1;C=u?1788:1783;E=!u}b:{if((g&2146435072)==2146435072){g=u+3|0;hf(a,32,c,g,e&-65537);We(a,C,u);d=f&32;We(a,b!=b?d?5964:9609:d?7011:9918,3);hf(a,32,c,g,e^8192);p=(c|0)<(g|0)?g:c;break b}z=n+16|0;c:{d:{e:{b=JG(b,n+44|0);b=b+b;if(b!=0){g=x[n+44>>2];x[n+44>>2]=g-1;A=f|32;if((A|0)!=97){break e}break c}A=f|32;if((A|0)==97){break c}l=x[n+44>>2];m=(d|0)<0?6:d;break d}l=g-29|0;x[n+44>>2]=l;b=b*268435456;m=(d|0)<0?6:d}s=(n+48|0)+((l|0)>=0?288:0)|0;h=s;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}x[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;i=s;break f}i=s;d=l;while(1){q=(d|0)>=29?29:d;g=h-4|0;g:{if(i>>>0>g>>>0){break g}d=0;while(1){k=x[g>>2];B=d;d=q&31;if((q&63)>>>0>=32){p=k<<d;d=0}else{p=(1<<d)-1&k>>>32-d;d=k<<d}B=B+d|0;k=p+r|0;d=Bna(B,d>>>0>B>>>0?k+1|0:k,1e9,0);G=g,H=B-yna(d,lb,1e9,0)|0,x[G>>2]=H;g=g-4|0;if(i>>>0<=g>>>0){continue}break}if(!d){break g}i=i-4|0;x[i>>2]=d}while(1){g=h;if(i>>>0<g>>>0){h=g-4|0;if(!x[h>>2]){continue}}break}d=x[n+44>>2]-q|0;x[n+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){w=((m+25>>>0)/9|0)+1|0;r=(A|0)==102;while(1){d=0-d|0;p=(d|0)>=9?9:d;h:{if(g>>>0<=i>>>0){h=x[i>>2];break h}q=1e9>>>p|0;k=-1<<p^-1;d=0;h=i;while(1){B=d;d=x[h>>2];x[h>>2]=B+(d>>>p|0);d=D(q,d&k);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=x[i>>2];if(!d){break h}x[g>>2]=d;g=g+4|0}d=p+x[n+44>>2]|0;x[n+44>>2]=d;i=(!h<<2)+i|0;h=r?s:i;g=g-h>>2>(w|0)?h+(w<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=i>>>0){break i}d=D(s-i>>2,9);h=10;k=x[i>>2];if(k>>>0<10){break i}while(1){d=d+1|0;h=D(h,10);if(k>>>0>=h>>>0){continue}break}}h=(m-((A|0)!=102?d:0)|0)-((A|0)==103&(m|0)!=0)|0;if((h|0)<(D(g-s>>2,9)-9|0)){q=h+9216|0;k=(q|0)/9|0;l=((((l|0)<0?4:292)+n|0)+(k<<2)|0)-4048|0;h=10;p=q-D(k,9)|0;if((p|0)<=7){while(1){h=D(h,10);p=p+1|0;if((p|0)!=8){continue}break}}q=x[l>>2];w=(q>>>0)/(h>>>0)|0;r=q-D(h,w)|0;k=l+4|0;j:{if(!r&(k|0)==(g|0)){break j}k:{if(!(w&1)){b=9007199254740992;if(!(v[l-4|0]&1)|((h|0)!=1e9|i>>>0>=l>>>0)){break k}}b=9007199254740994}t=(g|0)==(k|0)?1:1.5;k=h>>>1|0;t=k>>>0>r>>>0?.5:(k|0)==(r|0)?t:1.5;if(!(y[C|0]!=45|E)){t=-t;b=-b}k=q-r|0;x[l>>2]=k;if(b+t==b){break j}d=h+k|0;x[l>>2]=d;if(d>>>0>=1e9){while(1){x[l>>2]=0;l=l-4|0;if(l>>>0<i>>>0){i=i-4|0;x[i>>2]=0}d=x[l>>2]+1|0;x[l>>2]=d;if(d>>>0>999999999){continue}break}}d=D(s-i>>2,9);h=10;k=x[i>>2];if(k>>>0<10){break j}while(1){d=d+1|0;h=D(h,10);if(k>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){k=g;q=g>>>0<=i>>>0;if(!q){g=k-4|0;if(!x[g>>2]){continue}}break}l:{if((A|0)!=103){l=e&8;break l}h=m?m:1;g=(h|0)>(d|0)&(d|0)>-5;m=(g?d^-1:-1)+h|0;f=(g?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(q){break m}l=x[k-4>>2];if(!l){break m}p=10;g=0;if((l>>>0)%10|0){break m}while(1){h=g;g=g+1|0;p=D(p,10);if(!((l>>>0)%(p>>>0)|0)){continue}break}g=h^-1}h=D(k-s>>2,9);if((f&-33)==70){l=0;g=(g+h|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}l=0;g=((d+h|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}p=-1;q=l|m;if(((q?2147483645:2147483646)|0)<(m|0)){break b}r=(((q|0)!=0)+m|0)+1|0;h=f&-33;n:{if((h|0)==70){if((r^2147483647)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=an((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;v[g|0]=48;if((z-g|0)<2){continue}break}}w=g-2|0;v[w|0]=f;v[g-1|0]=(d|0)<0?45:43;g=z-w|0;if((g|0)>(r^2147483647)){break b}}d=g+r|0;if((d|0)>(u^2147483647)){break b}r=d+u|0;hf(a,32,c,r,e);We(a,C,u);hf(a,48,c,r,e^65536);o:{p:{q:{if((h|0)==70){f=n+16|0;d=f|8;l=f|9;h=i>>>0>s>>>0?s:i;i=h;while(1){g=an(x[i>>2],0,l);r:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break r}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}v[n+24|0]=48;g=d}We(a,g,l-g|0);i=i+4|0;if(s>>>0>=i>>>0){continue}break}if(q){We(a,12715,1)}if((m|0)<=0|i>>>0>=k>>>0){break q}while(1){g=an(x[i>>2],0,l);if(g>>>0>n+16>>>0){while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}}We(a,g,(m|0)>=9?9:m);g=m-9|0;i=i+4|0;if(k>>>0<=i>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}s=i>>>0<k>>>0?k:i+4|0;f=n+16|0;d=f|8;k=f|9;h=i;while(1){g=an(x[h>>2],0,k);if((k|0)==(g|0)){v[n+24|0]=48;g=d}t:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break t}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break t}We(a,g,1);g=g+1|0;if(!(l|m)){break t}We(a,12715,1)}f=k-g|0;We(a,g,(f|0)>(m|0)?m:f);m=m-f|0;h=h+4|0;if(s>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}hf(a,48,m+18|0,18,0);We(a,w,z-w|0);break o}g=m}hf(a,48,g+9|0,9,0)}hf(a,32,c,r,e^8192);p=(c|0)<(r|0)?r:c;break b}l=(f<<26>>31&9)+C|0;u:{if(d>>>0>11){break u}g=12-d|0;t=16;while(1){t=t*16;g=g-1|0;if(g){continue}break}if(y[l|0]==45){b=-(t+(-b-t));break u}b=b+t-t}g=x[n+44>>2];h=g>>31;g=an((g^h)-h|0,0,z);if((z|0)==(g|0)){v[n+15|0]=48;g=n+15|0}s=u|2;i=f&32;h=x[n+44>>2];m=g-2|0;v[m|0]=f+15;v[g-1|0]=(h|0)<0?45:43;g=e&8;h=n+16|0;while(1){f=h;if(F(b)<2147483648){k=~~b}else{k=-2147483648}v[h|0]=i|y[k+59088|0];b=(b-+(k|0))*16;h=f+1|0;if(!(!(g|(d|0)>0)&b==0|(h-(n+16|0)|0)!=1)){v[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}p=-1;g=z-m|0;f=g+s|0;if((2147483645-f|0)<(d|0)){break b}v:{w:{if(!d){break w}i=h-(n+16|0)|0;if((i-2|0)>=(d|0)){break w}d=d+2|0;break v}i=h-(n+16|0)|0;d=i}f=d+f|0;hf(a,32,c,f,e);We(a,l,s);hf(a,48,c,f,e^65536);We(a,n+16|0,i);hf(a,48,d-i|0,0,0);We(a,m,g);hf(a,32,c,f,e^8192);p=(c|0)<(f|0)?f:c}hb=n+560|0;return p|0}function IL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,A=0,C=0,F=0,G=0,H=0,I=0,J=E(0),K=E(0),L=0,M=0,N=0,O=E(0),P=0;a:{if(z[a+480188>>1]<=b>>>0){break a}b:{c:{i=D(b,896)+a|0;c=y[i+1075797|0];switch(c-31|0){case 1:break b;case 0:break c;default:break a}}if(!(y[a+480209|0]&16)){break a}}e=a;k=b;p=(c|0)==32;i=v[i+1075799|0];if((i|0)>=0){l=((y[(D(b,896)+a|0)+1075848|0]<<5)+a|0)+901692|0}else{l=(((i&127)<<5)+a|0)+902204|0}g=i&255;c=0;a=0;j=hb-48|0;hb=j;h=z[e+480192>>1]?x[(D(k,896)+e|0)+1075640>>2]:h;o=e+1074312|0;b=D(k,896)+e|0;q=b+1075805|0;t=b+1075672|0;u=b+1075772|0;r=b+1075748|0;s=b+1075744|0;A=b+1075704|0;C=b+1075676|0;F=b+1075668|0;G=b+1075648|0;H=b+1075792|0;I=b+1075072|0;d=b+1075855|0;J=E(y[d|0]);K=E(g>>>0);n=255;i=1;while(1){b=y[a+l|0];if(b){f=b-48|0;d:{e:{if((f&255)>>>0<10){break e}if((b-65&255)>>>0<=5){f=b-55|0;break e}f:{g:{h:{switch(b-97|0){case 2:i:{b=Pl(e,k,3,0);if((b-1&255)>>>0>249){break i}b=x[(D(b,160)+e|0)+906140>>2];if(!b){break i}b=Tv(b,78872,78880);if(!b){break i}f=mb[x[x[b>>2]+184>>2]](b,k)|0;b=(f|0)!=255;f=b?f:0;if(b|!h){break e}break f}if(h){break f}f=0;break e;case 13:b=0;if(!Zd(y[q|0])){break g}b=y[q|0]-1|0;break g;case 21:b=j+8|0;Kb(b,o,28);j:{if(!Ib(b)){Kb(j,o,1);b=0;if(!Ib(j)){break j}}b=w[u>>1]}f=D(x[r>>2],x[s>>2]);b=D(x[e+1074444>>2],b+x[t>>2]|0);b=Xb((Cc(zna(yna(f,f>>31,b,b>>31),lb,1048576,0),lb)|0)/2|0,1,127);break g;case 23:x[j+8>>2]=x[C>>2]/2;x[j>>2]=127;b=x[be(j+8|0,j)>>2];break g;case 24:x[j+8>>2]=x[F>>2]/2;x[j>>2]=127;b=x[be(j+8|0,j)>>2];break g;case 0:b=0;if(!h){break g}f=z[h+28>>1];if(!f){break g}b=f-1>>>7&127;break g;case 1:b=0;if(!h){break g}f=z[h+28>>1];if(!f){break g}b=f-1&127;break g;case 14:b=x[G>>2]>>>8|0;break g;case 7:b=(z[e+480188>>1]<=k>>>0?y[H|0]-1|0:k)&127;break g;case 12:b=y[I|0]>>>7|0;break g;case 15:b=0;if(!h){break g}f=y[h+30|0];if(!f){break g}b=f-1&127;break g;case 25:k:{if(!p|v[d|0]<0){break k}l:{if(c>>>0<3){break l}b=(j+16|0)+c|0;if(y[b-3|0]!=240){break l}if(y[b-2|0]>239){break k}}m=yp(e,J,K);m:{if(m<E(4294967296)&m>=E(0)){b=~~m>>>0;break m}b=0}v[d|0]=b;n=128;break g}n=(n&255)==255?g:n;b=g;break g;case 18:b=c;n:{if(!b){b=0;break n}while(1){b=b-1|0;if(y[b+(j+16|0)|0]==240){break n}if(b){continue}break}}if(y[(j+16|0)+b|0]!=240|c-b>>>0<5){break d}f=0;b=b+5|0;if((c|0)!=(b|0)){while(1){f=y[(j+16|0)+b|0]+f|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}b=0-f&127;break g;case 20:break h;default:break d}}b=D(x[r>>2],x[s>>2]);f=b;L=b>>31;b=D(x[e+1074444>>2],x[A>>2]);b=Xb((Cc(zna(yna(f,L,b,b>>31),lb,67108864,0),lb)|0)/2|0,1,127)}f=i^-1;i=1;c=(f&1)+c|0;v[c+(j+16|0)|0]=b;c=c+1|0;break d}b=0;o:{if(k>>>0>=256){break o}if(y[h+31|0]==17){b=z[(D(k,896)+e|0)+1075792>>1];b=(b?b-1|0:k)&15;break o}if(!Ki(h)){break o}b=y[h+31|0]-1&15}f=b}b=(j+16|0)+c|0;p:{if(i&1){v[b|0]=f;break p}v[b|0]=y[b|0]<<4|f;c=c+1|0}i=i^1}a=a+1|0;if((a|0)!=31){continue}}break}b=((i^-1)&1)+c|0;if(n<<24>>24>=0){v[d|0]=n}q:{if(!b){break q}f=0;i=0;while(1){d=(j+16|0)+i|0;a=v[d|0];r:{s:{t:{if((a|0)==-16){if(b-i>>>0>=4){a=4;if((y[(j+i|0)+17|0]&254)==240){break s}}a=i;u:{while(1){a=a+1|0;if(b>>>0<=a>>>0){break u}if(y[(j+16|0)+a|0]!=247){continue}break}a=(a-i|0)+1|0;if(a){break s}}v[(j+16|0)+b|0]=247;b=b+1|0;a=b-i|0;break t}if((a|0)>=0){if(f&255){i=i-1|0;v[i+(j+16|0)|0]=f;break r}i=i+1|0;f=0;break r}M=j,N=OO(a&255),x[M+8>>2]=N;x[j>>2]=b-i;a=x[Mb(j+8|0,j)>>2]}if(!a){break q}c=y[d|0];f=c>>>0<240?c:f}g=0;l=hb-32|0;hb=l;x[l+28>>2]=a;v:{if(!a){break v}c=y[d|0];h=c-250|0;if(!(h>>>0>5|!(1<<h&37))){if(z[e+480188>>1]){c=0;while(1){h=(D(c,896)+e|0)+1075841|0;v[h|0]=127;v[h+1|0]=0;c=c+1|0;if(c>>>0<z[e+480188>>1]){continue}break}}c=y[d|0]}w:{if((c&255)!=240){break w}h=y[d+1|0];if((h&254)!=240){break w}if(a>>>0<4){break v}n=(D(k,896)+e|0)+1074984|0;o=y[d+2|0];c=v[d+3|0];g=(h|0)!=241&(c|0)>=0;if(!(o|!g)){d=D(k,896)+e|0;g=d+1075841|0;if(p){c=CM(yp(e,E(y[g|0]),E((c&255)>>>0)))}v[g|0]=c;v[d+1075802|0]=0;g=4;c=d+1075072|0;d=Hp(e,n,!(x[c>>2]&32768),256);if((d|0)<0|!(y[c+1|0]&2)){break v}c=e+1304392|0;if(!zd(c)){break v}Pp(x[c>>2],k,d>>>2&255,1);break v}d=o<<24>>24;if(g&(d|0)==1){g=D(k,896)+e|0;d=g+1075842|0;x:{if(!p){break x}m=yp(e,E(y[d|0]),E((c&255)>>>0));if(m<E(4294967296)&m>=E(0)){c=~~m>>>0;break x}c=0}v[d|0]=c;v[g+1075801|0]=0;Hp(e,n,!(x[g+1075072>>2]&32768),256);g=4;break v}if(!((h|0)==241|(d|0)!=2)){g=4;if(c>>>0>31){break v}d=D(k,896)+e|0;v[d+1075849|0]=(c&240)>>>4;Hp(e,n,!(x[d+1075072>>2]&32768),256);break v}if(!((h|0)==241|(d|0)!=3)){g=4;d=Pl(e,k,3,0);if((c|0)<0|(d-1&255)>>>0>249){break v}d=(D(d,160)+e|0)+906284|0;m=E(E(((c^127)&255)>>>0)*E(.007874015718698502));if(!p){B[d>>2]=m;break v}M=d,O=yp(e,B[d>>2],m),B[M>>2]=O;break v}g=0;if((h|0)!=241&(d|0)>=0){break v}g=4;d=Pl(e,k,3,0);if((d-1&255)>>>0>249){break v}d=x[(D(d,160)+e|0)+906140>>2];if(!d|(c|0)<0){break v}h=(h|0)!=241?o&127:o+128|0;m=E(E((c&255)>>>0)*E(.007874015718698502));c=x[d>>2];if(!p){mb[x[c+44>>2]](d,h,m);break v}N=d,P=h,O=yp(e,E(mb[x[c+48>>2]](d,h)),m),M=x[x[d>>2]+44>>2],mb[M](N|0,P|0,E(O));break v}y:{z:{A:{if(z[e+480188>>1]>k>>>0){c=k+1|0;break A}c=z[(D(k,896)+e|0)+1075792>>1];if(!c){break z}}if(y[(D(k,896)+e|0)+1075075|0]&4|z[e+480188>>1]<(c&65535)>>>0){break z}c=Pl(e,k,3,0);if((c-1&255)>>>0>249){break z}c=x[(D(c,160)+e|0)+906140>>2];if(!c){break z}g=y[d|0];if((g|0)!=240){break y}g=l+16|0;jc(g,Cb(d),a);mb[x[x[c>>2]+72>>2]](c,g)|0}g=a;break v}M=l,P=OO(g),x[M+12>>2]=P;g=l+12|0;h=x[Mb(g,l+28|0)>>2];x[l+12>>2]=0;sc(g,d,h);mb[x[x[c>>2]+68>>2]](c,x[l+12>>2])|0;g=x[l+28>>2]}hb=l+32|0;i=(g?g:a)+i|0}if(b>>>0>i>>>0){continue}break}}hb=j+48|0}}function xV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-160|0;hb=e;Lc(b);gr(a);a:{if(!ov(b,e+120|0)){break a}if(!lL(e+120|0)){break a}f=e+120|0;k=wf(8966);if(k){n=x[b+8>>2];if(Rc(b,y[f+16|0]|y[f+17|0]<<8|(y[f+18|0]<<16|y[f+19|0]<<24))){b:{if(!(y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24))){break b}while(1){if(!Qb(b,4)){break b}c:{if((y[f+4|0]|y[f+5|0]<<8)>>>0>=64){if((Qh(b)|0)<=0){break c}}h=0;d=1;while(1){g=pe(b);if(g){o=mn(g<<24>>24);l=h>>>0>=k>>>0;g=l&d;if(!(!(d&1)|l)){g=y[h+8966|0]==(o&255)}d=g;h=h+1|0;continue}break}cc(b,4);i=(h|0)==(k|0)?d?1:i:i}m=m+1|0;if(m>>>0<(y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24))>>>0){continue}break}}h=i&1}Rc(b,n)}if(!h){break a}if(!c){j=1;break a}c=hb-16|0;hb=c;g=oh(e+104|0);i=e+120|0;d=i+16|0;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[114414]=0;d=O(224,b|0,d|0)|0;f=x[114414];x[114414]=0;d:{e:{f:{g:{if((f|0)!=1){if(!d){break d}d=i+12|0;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[114414]=0;x[c>>2]=d;d=R(296,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break f}x[114414]=0;x[c+12>>2]=(d>>>0)/5;d=O(297,c|0,c+12|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break f}f=x[d>>2];x[114414]=0;P(1545,g|0,f|0);d=x[114414];x[114414]=0;if((d|0)==1){break g}if(!f){break d}i=i+4|0;d=0;h:{while(1){x[114414]=0;h=O(226,b|0,5)|0;k=x[114414];x[114414]=0;i:{if((k|0)!=1){if(h){break i}break d}a=N()|0;break e}h=y[i|0]|y[i+1|0]<<8;x[114414]=0;T(1546,c|0,b|0,h|0);h=x[114414];x[114414]=0;if((h|0)!=1){x[114414]=0;P(1547,g|0,c|0);h=x[114414];x[114414]=0;if((h|0)==1){break h}xb(c);d=d+1|0;if((f|0)!=(d|0)){continue}break d}break}a=N()|0;break e}a=N()|0;xb(c);break e}a=N()|0;break e}a=N()|0;break e}a=N()|0}qd(g);Q(a|0);p()}hb=c+16|0;c=y[e+152|0]|y[e+153|0]<<8|(y[e+154|0]<<16|y[e+155|0]<<24);x[114414]=0;c=O(224,b|0,c|0)|0;g=x[114414];x[114414]=0;j:{k:{l:{m:{n:{o:{p:{q:{if((g|0)!=1){if(!c){break j}g=hb-16|0;hb=g;c=e+88|0;x[c>>2]=0;x[c+4>>2]=0;x[114414]=0;x[g+12>>2]=0;U(309,c+8|0,g+12|0,g+8|0)|0;d=x[114414];x[114414]=0;r:{if((d|0)!=1){hb=g+16|0;break r}S(0)|0;zb();p()}g=y[e+148|0]|y[e+149|0]<<8|(y[e+150|0]<<16|y[e+151|0]<<24);x[114414]=0;x[e+24>>2]=g;g=R(296,b|0)|0;d=x[114414];x[114414]=0;s:{if((d|0)==1){break s}x[114414]=0;x[e+56>>2]=g>>>2;g=O(297,e+24|0,e+56|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break s}g=x[g>>2];x[114414]=0;P(298,c|0,g|0);d=x[114414];x[114414]=0;if((d|0)==1){break p}if(!g){break q}d=e+120|4;i=0;while(1){x[114414]=0;f=O(226,b|0,4)|0;h=x[114414];x[114414]=0;t:{if((h|0)!=1){if(f){break t}break q}b=N()|0;break n}f=y[d|0]|y[d+1|0]<<8;x[114414]=0;f=O(299,b|0,f|0)|0;h=x[114414];x[114414]=0;u:{if((h|0)!=1){x[e+24>>2]=f;if(zc(e+104|0)>>>0<=f>>>0){break u}x[114414]=0;P(300,c|0,e+24|0);f=x[114414];x[114414]=0;if((f|0)!=1){break u}}b=N()|0;break n}i=i+1|0;if((g|0)!=(i|0)){continue}break}break q}b=N()|0;break n}b=N()|0;break m}g=y[e+144|0]|y[e+145|0]<<8|(y[e+146|0]<<16|y[e+147|0]<<24);x[114414]=0;g=O(224,b|0,g|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break o}}b=N()|0;break n}if(!g){break k}if(!(y[e+140|0]|y[e+141|0]<<8|(y[e+142|0]<<16|y[e+143|0]<<24))){break l}h=e+36|0;g=e+120|4;i=0;v:{w:{x:{y:{z:{A:{while(1){x[114414]=0;d=O(226,b|0,4)|0;f=x[114414];x[114414]=0;B:{if((f|0)!=1){if(d){break B}break l}b=N()|0;break n}d=y[g|0]|y[g+1|0]<<8;x[114414]=0;ia(301,b|0,e+84|0,e+80|0,e+76|0,e+72|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break y}C:{D:{if(x[e+76>>2]<=0){break D}d=x[e+84>>2];if((d|0)>=0){break D}d=d^-1;x[e+84>>2]=d;if(Lb(c)>>>0<=d>>>0){break D}if(!Td(wd(e+104|0,x[Pb(c,x[e+84>>2])>>2]),8966)){break D}x[114414]=0;X(302,e+56|0,b|0,x[e+80>>2],x[e+76>>2]);d=x[114414];x[114414]=0;if((d|0)==1){break x}x[114414]=0;d=R(303,e+56|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break w}if(d){if((y[g|0]|y[g+1|0]<<8)>>>0<=39){x[114414]=0;O(304,e+56|0,8)|0;d=x[114414];x[114414]=0;if((d|0)==1){break w}}if((y[g|0]|y[g+1|0]<<8)>>>0<=59){x[114414]=0;O(304,e+56|0,16)|0;d=x[114414];x[114414]=0;if((d|0)==1){break w}}x[114414]=0;R(305,e+56|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break w}E:{F:{G:{if((y[g|0]|y[g+1|0]<<8)>>>0>=120){x[114414]=0;R(305,e+56|0)|0;d=x[114414];x[114414]=0;f=8;break G}H:{if((y[g|0]|y[g+1|0]<<8)>>>0>=100){x[114414]=0;O(304,e+56|0,4)|0;d=x[114414];x[114414]=0;if((d|0)==1){break w}break H}if((y[g|0]|y[g+1|0]<<8)>>>0<62){break F}}x[114414]=0;R(305,e+56|0)|0;d=x[114414];x[114414]=0;f=4}if((d|0)==1){break w}x[114414]=0;O(304,e+56|0,f|0)|0;break E}x[114414]=0;R(305,e+56|0)|0}d=x[114414];x[114414]=0;if((d|0)==1){break w}x[114414]=0;f=R(305,e+56|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break z}x[114414]=0;d=R(306,e+24|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break C}j=x[e+72>>2];I:{if((j|0)<0){break I}if(zc(e+104|0)>>>0<=j>>>0){break I}j=wd(e+104|0,x[e+72>>2]);x[114414]=0;T(13,e+8|0,2,j|0);j=x[114414];x[114414]=0;if((j|0)==1){break A}j=e+8|0;Db(d,j);xb(j)}x[114414]=0;T(307,e+8|0,e+56|0,f|0);f=x[114414];x[114414]=0;if((f|0)==1){break A}f=e+8|0;Ud(h,f);Ab(f);x[114414]=0;P(308,a|0,d|0);f=x[114414];x[114414]=0;if((f|0)==1){break A}dr(d)}Ab(e+56|0)}i=i+1|0;if(i>>>0<(y[e+140|0]|y[e+141|0]<<8|(y[e+142|0]<<16|y[e+143|0]<<24))>>>0){continue}break l}break}b=N()|0;break v}b=N()|0;dr(d);break v}b=N()|0;break v}b=N()|0;break n}b=N()|0;break n}b=N()|0}Ab(e+56|0)}IC(c)}qd(e+104|0);Q(b|0);p()}j=od(a)^1}IC(c)}qd(e+104|0)}hb=e+160|0;return j|0}function Fha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb-368|0;hb=d;Rc(b,60);g=15;a:{if(!yh(b,9903)){Rc(b,124);g=31;if(!yh(b,11212)){break a}}Nd(a,536870912);w[a+480190>>1]=g;Lc(b);b:{if(z[a+480190>>1]){while(1){f=VA(b);x[(d+240|0)+(e<<2)>>2]=f;if(f>>>0>131072){break b}e=e+1|0;if(e>>>0<z[a+480190>>1]){continue}break}}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480196>>2]=6;e=0;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;j=1;uj(a,1);cc(b,4);f=Du(b);if(f>>>0<178){break a}q=a,r=gg(177693e5/+(f>>>0)),x[q+480204>>2]=r;cc(b,14);c:{d:{e:{if(z[a+480190>>1]){o=1;while(1){g=d+72|0;OQ(b,g);e=x[((j<<2)+d|0)+236>>2];l=hb-16|0;hb=l;h=(D(j,104)+a|0)+484380|0;Ad(h,1);x[h>>2]=e;v[h+37|0]=y[g+24|0]<<4;v[l+15|0]=y[g+25|0];v[l+14|0]=64;q=h,r=y[rc(l+15|0,l+14|0)|0]<<2,w[q+30>>1]=r;e=g+26|0;e=y[e|0]|y[e+1|0]<<8;k=g+28|0;f=x[h>>2];f:{if(!f){break f}i=y[k|0]|y[k+1|0]<<8;k=(e<<8|(e&65280)>>>8)&65535;x[h+4>>2]=k;e=(((i<<8|i>>>8)&65535)<<1)+k|0;x[h+8>>2]=e;if(f>>>0<=k>>>0){k=f-1|0;x[h+4>>2]=k}if(e>>>0>f>>>0){x[h+8>>2]=f;e=f}if(!(!(e>>>0<4|e>>>0<k>>>0)&e-k>>>0>3)){x[h+4>>2]=0;x[h+8>>2]=0;break f}if(e>>>0<=k>>>0){break f}w[h+34>>1]=z[h+34>>1]|2}hb=l+16|0;e=0;while(1){if((y[g|0]-1&255)>>>0<=30){v[g|0]=32;n=n+1|0}e=e+1|0;g=e+(d+72|0)|0;if((e|0)!=22){continue}break}if(n>>>0>=128){break b}e=d+208|0;lm(e,3,d+72|0);f=d+224|0;Ic(f,e);x[114414]=0;O(334,((j<<5)+a|0)+946304|0,f|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break e}xb(d+224|0);o=o+1|0;j=o&65535;if(j>>>0<=z[a+480190>>1]){continue}break}}f=Ub(d+72|0,9788);x[114414]=0;e=a+946336|0;g=O(984,e|0,f|0)|0;j=x[114414];x[114414]=0;h=1;g:{h:{i:{j:{if((j|0)!=1){if(!g){x[114414]=0;g=O(118,d+224|0,9799)|0;h=x[114414];x[114414]=0;if((h|0)==1){break j}x[114414]=0;h=O(984,e|0,g|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break i}xb(g)}xb(f);e=0;if(!Oz(b,d+72|0)){break a}if(!qP(d+72|0)){break a}if(c){break g}break c}e=N()|0;break h}e=N()|0;break h}e=N()|0;xb(g)}xb(f);break d}w[d+70>>1]=0;if(y[d+72|0]){while(1){w[d+208>>1]=y[(d+e|0)+74|0]+1;q=d,r=z[aj(d+70|0,d+208|0)>>1],w[q+70>>1]=r;e=e+1|0;if(e>>>0<y[d+72|0]){continue}break}}e=d+72|1;f=y[e|0];g=y[d+72|0];j=a+484360|0;Se(Vb(j),f>>>0<g>>>0?y[e|0]:0);$n(Vb(j),d+72|2,y[d+72|0],65535,65535);if(z[a+480190>>1]==31){cc(b,4)}x[d+64>>2]=0;x[d+60>>2]=0;x[d+56>>2]=0;v[d+55|0]=0;l=c&1;if(l){cg(a+484344|0,z[d+70>>1])}if(z[d+70>>1]){k=a+484344|0;j=0;while(1){k:{l:{if(l){n=0;if(Tg(k,j&65535,64)){break l}}cc(b,1024);break k}while(1){o=Df(Zb(k,j),n,0);e=0;while(1){g=d+208|0;km(g,b);f=o+D(e,6)|0;m:{n:{if(y[gc(g,0)|0]!=255){break n}v[(d- -64|0)+e|0]=0;v[(d+56|0)+e|0]=0;o:{if(!h){break o}if(y[gc(d+208|0,1)|0]!=252){break o}q=gc(d+208|0,1),r=254,v[q|0]=r}p:{switch(y[gc(d+208|0,1)|0]-252|0){case 2:v[f+3|0]=13;break m;case 1:break m;case 0:break p;default:break n}}v[f+3|0]=14;v[d+55|0]=9;break m}g=x[d+208>>2];x[d+48>>2]=g;x[d+12>>2]=g;Rt(d+12|0,f);g=y[f|0];q:{if(!g){break q}v[(d+56|0)+e|0]=0;v[(d- -64|0)+e|0]=g;if(g>>>0>48){break q}v[d+32|0]=8;q=d,r=y[Xg(d+55|0,d+32|0)|0],v[q+55|0]=r}r:{s:{t:{u:{v:{w:{switch(y[f+3|0]){case 1:v[f+3|0]=1;break m;case 2:g=y[f+5|0];if(g>>>0>=16){v[f+3|0]=3;v[f+5|0]=g>>>4;break m}if(g){v[f+3|0]=2;v[f+5|0]=g;break m}v[f+5|0]=0;break s;case 3:if(y[(d+56|0)+e|0]){break t}v[f+3|0]=19;v[f+5|0]=0;break m;case 4:if(y[(d+56|0)+e|0]){break t}v[f+3|0]=19;v[f+5|0]=1;break m;case 5:if(!y[f+1|0]){break t}v[f+3|0]=13;v[d+32|0]=63;v[d+47|0]=y[f+5|0]+(z[(D(y[f+1|0],104)+a|0)+484410>>1]>>>2|0);q=f,r=y[rc(d+32|0,d+47|0)|0],v[q+5|0]=r;if(!y[(d+56|0)+e|0]){break v}v[f+2|0]=1;v[f+4|0]=y[f+5|0];v[f+5|0]=0;break s;case 6:g=y[f+1|0];if(!g){break t}v[f+3|0]=13;g=z[(D(g,104)+a|0)+484410>>1]>>>2|0;i=y[f+5|0];g=g>>>0>=i>>>0?g-i|0:0;v[f+5|0]=g;if(!y[(d+56|0)+e|0]){break v}v[f+4|0]=g;v[f+2|0]=1;v[f+5|0]=0;break s;case 8:i=y[(d- -64|0)+e|0];g=y[f+5|0];m=i+(g>>>4|0)|0;v[(d+60|0)+e|0]=m;v[f+3|0]=2;g=g&15;v[(d+56|0)+e|0]=g;q=f,r=pP(g,i,m&255),v[q+5|0]=r;break v;case 9:v[d+32|0]=8;q=d,r=y[Xg(d+55|0,d+32|0)|0],v[q+55|0]=r;break s;case 0:break u;case 7:break w;default:break s}}g=y[(d- -64|0)+e|0];i=y[f+5|0];m=g-(i>>>4|0)|0;v[(d+60|0)+e|0]=m;v[f+3|0]=3;i=i&15;v[(d+56|0)+e|0]=i;q=f,r=pP(i,m&255,g),v[q+5|0]=r}if(!y[f+3|0]){break r}break m}if(!y[f+5|0]){break r}break s}v[f+5|0]=0}v[f+3|0]=0}i=y[(d+56|0)+e|0];if(!i){break m}m=(d+60|0)+e|0;g=y[m|0];if(g){v[(d- -64|0)+e|0]=g;v[f|0]=g;v[f+5|0]=i;v[m|0]=0}v[f+3|0]=4}e=e+1|0;if((e|0)!=4){continue}break}n=n+1|0;if((n|0)!=64){continue}break}}j=j+1|0;if(j>>>0<z[d+70>>1]){continue}break}}g=z[a+480190>>1];x:{y:{z:{A:{B:{C:{D:{if(c&2){if(!(g&65535)){break D}e=1;while(1){c=(D(e&65535,104)+a|0)+484380|0;if(x[c>>2]){Eg(ad(d+208|0,8,1,0,0),c,b);g=z[a+480190>>1]}e=e+1|0;if((e&65535)>>>0<=(g&65535)>>>0){continue}break}}if((g&65535)==15){break C}}x[114414]=0;b=O(2,d+208|0,8137)|0;c=x[114414];x[114414]=0;if((c|0)==1){break z}Db(a+1304436|0,b);break B}b=Ub(d+16|0,11471);x[114414]=0;P(187,d+32|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break y}x[114414]=0;T(504,d+208|0,d+32|0,d+55|0);c=x[114414];x[114414]=0;if((c|0)==1){break A}c=d+208|0;Db(a+1304436|0,c);xb(c);Gb(d+32|0)}xb(b);Pc(a+1304448|0,z[a+480190>>1]==15?1768:10703);x[a+1304496>>2]=2;break c}e=N()|0;Gb(d+32|0);break x}e=N()|0;break d}e=N()|0}xb(b);break d}e=N()|0;xb(d+224|0)}Q(e|0);p()}e=1;break a}e=0}hb=d+368|0;return e|0}function ola(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;e=hb-192|0;hb=e;a:{if(yh(b,9635)){if(d){v[d|0]=1}j=a+1074312|0;ju(j);b:{if(!Qb(b,7)){break b}l=a+480216|0;m=a+480220|0;n=a+480224|0;o=a+1074372|0;q=a+480228|0;r=a+480232|0;s=a+480200|0;t=a+484360|0;k=a+480268|0;u=a+1304412|0;B=a+480248|0;while(1){d=Gf(b);f=pg(b);if((d|0)==(y[17374]|y[17375]<<8|(y[17376]<<16|y[17377]<<24))){ng(b,6);break b}if(!(d&1616928864)|d&-2139062144){break b}if(!Qb(b,f)){break b}Bd(e+176|0,b,f);c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((d|0)<=1347243309){if((d|0)<=1146367533){if((d|0)<=1130917458){if((d|0)==1127099950){break w}if((d|0)!=1129797166){break c}x[114414]=0;x[e+160>>2]=0;T(648,e+176|0,f|0,e+160|0);d=x[114414];x[114414]=0;if((d|0)==1){break u}x[a+1074304>>2]=x[e+160>>2];break c}if((d|0)==1130917459){break q}if((d|0)!=1145525806){break c}g=s;break e}if((d|0)<=1213486400){if((d|0)==1146367534){break y}if((d|0)!=1196316499|f>>>0<3){break c}x[114414]=0;P(649,e+160|0,e+176|0);d=x[114414];x[114414]=0;if((d|0)==1){break o}x[114414]=0;g=U(650,e|0,e+160|0,8)|0;d=x[114414];x[114414]=0;if((d|0)==1){break n}xb(e+160|0);x[114414]=0;d=R(223,e+176|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break m}x[114414]=0;T(651,g|0,B|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break m}Lf(g);break c}if((d|0)==1213486401){break r}if((d|0)==1280530262){break t}if((d|0)!=1297303086){break c}ju(j);g=0;break l}if((d|0)<=1380994349){if((d|0)<=1380340803){if((d|0)==1347243310){break v}if((d|0)!=1347244882){break c}x[114414]=0;T(652,e+176|0,f|0,k|0);d=x[114414];x[114414]=0;if((d|0)==1){break d}if(mo(y[k|0])){break c}v[k|0]=5;break c}if((d|0)==1380340804){break x}if((d|0)==1380986414){break s}g=l;if((d|0)==1380991534){break e}break c}if((d|0)<=1397768493){g=m;if((d|0)==1380994350){break e}if((d|0)!=1397052739|f>>>0<3){break c}x[114414]=0;g=R(321,e+176|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break f}if(!g|g>>>0>z[a+480190>>1]){break c}d=0;f=(D(g,104)+a|0)+484448|0;g=f;while(1){x[114414]=0;h=R(391,e+176|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break p}x[g>>2]=h;d=d+1|0;g=f+(d<<2)|0;if((d|0)!=9){continue}break}break c}g=q;if((d|0)==1397768494){break e}if((d|0)==1414344238){break k}g=r;if((d|0)==1448301654){break e}break c}x[114414]=0;T(648,e+176|0,f|0,e+160|0);d=x[114414];x[114414]=0;if((d|0)==1){break j}x[a+480204>>2]=D(x[e+160>>2],1e4)+(A[a+480204>>2]%1e4|0);break c}x[114414]=0;T(648,e+176|0,f|0,e+160|0);d=x[114414];x[114414]=0;if((d|0)!=1){d=x[a+480204>>2];x[a+480204>>2]=d-((d>>>0)%1e4|0)+A[e+160>>2]%1e4;break c}d=N()|0;break a}if(c){break c}x[114414]=0;w[e+160>>1]=0;T(653,e+176|0,f|0,e+160|0);d=x[114414];x[114414]=0;if((d|0)!=1){C=a,E=Md(z[e+160>>1],z[a+480188>>1],127),w[C+480188>>1]=E;break c}d=N()|0;break a}x[114414]=0;T(654,e+176|0,f|0,o|0);d=x[114414];x[114414]=0;if((d|0)!=1){break c}break d}d=N()|0;break a}x[114414]=0;x[e+160>>2]=0;T(648,e+176|0,f|0,e+160|0);d=x[114414];x[114414]=0;if((d|0)==1){break i}d=x[e+160>>2];if(!d){break c}x[a+1074308>>2]=d;break c}if(x[a+480180>>2]==4){break c}x[114414]=0;T(653,e+176|0,f|0,e+160|0);d=x[114414];x[114414]=0;if((d|0)!=1){Se(Vb(t),z[e+160>>1]);break c}d=N()|0;break a}g=Wb(e+160|0);x[114414]=0;d=R(223,e+176|0)|0;f=x[114414];x[114414]=0;z:{if((f|0)==1){break z}x[114414]=0;U(655,e+176|0,g|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break z}x[114414]=0;T(13,e+144|0,0,g|0);d=x[114414];x[114414]=0;if((d|0)==1){break z}d=e+144|0;Db(u,d);xb(d);xb(g);break c}d=N()|0;xb(g);break a}if(f&1|f>>>0>126){break c}w[e+160>>1]=(f>>>1|0)- -64;x[114414]=0;w[e+144>>1]=127;d=O(433,e+160|0,e+144|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break h}h=z[d>>1];if(h>>>0<65){break c}g=64;while(1){x[114414]=0;P(428,e+160|0,e+176|0);d=x[114414];x[114414]=0;if((d|0)==1){break g}d=ed(e+160|0);A:{if(y[e+160|0]==255){break A}f=y[d|0];d=(g<<5)+a|0;i=d+480284|0;w[i>>1]=128;w[d+480286>>1]=f;f=d+480280|0;x[f>>2]=0;x[f>>2]=(y[e+160|0]&128)<<3;d=y[e+160|0]&127;v[e+160|0]=d;if(d>>>0<65){w[i>>1]=d<<2;d=y[e+160|0]}if((d&255)!=100){break A}x[f>>2]=x[f>>2]|256}g=g+1|0;if((h|0)!=(g|0)){continue}break}break c}d=N()|0;break a}d=N()|0;break a}d=N()|0;xb(e+160|0);break a}d=N()|0;Lf(g);break a}B:{C:{D:while(1){x[114414]=0;d=O(226,e+176|0,1)|0;f=x[114414];x[114414]=0;if((f|0)==1){break C}if(!d|g>>>0>=110){break c}x[114414]=0;f=R(403,e+176|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break B}d=0;while(1){E:{if(!(!(f>>>d&1)|g>>>0>=110)){x[114414]=0;U(434,j|0,g|0,1)|0;h=x[114414];x[114414]=0;if((h|0)==1){break E}}g=g+1|0;d=d+1|0;if((d|0)!=8){continue}continue D}break}break}d=N()|0;break a}d=N()|0;break a}d=N()|0;break a}x[114414]=0;T(656,e+176|0,f|0,n|0);d=x[114414];x[114414]=0;if((d|0)==1){break d}break c}d=N()|0;break a}d=N()|0;break a}d=N()|0;break a}d=N()|0;break a}d=N()|0;break a}x[114414]=0;T(648,e+176|0,f|0,g|0);d=x[114414];x[114414]=0;if((d|0)!=1){break c}}d=N()|0;break a}Ab(e+176|0);if(Qb(b,7)){continue}break}}yo(a+480204|0,D(x[x[a+8>>2]+20>>2],1e4),D(x[x[a+8>>2]+24>>2],1e4));if(x[a+480224>>2]>=3){x[a+480224>>2]=0}if(x[a+1074372>>2]>=6){x[a+1074372>>2]=0}xc(a+480200|0,256);xc(a+480216|0,65536);xc(a+480220|0,65536)}hb=e+192|0;return}Ab(e+176|0);Q(d|0);p()}function Fp(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;h=z[a+480192>>1]>=c>>>0?x[((c<<2)+a|0)+900380>>2]:h;q=x[b+764>>2];j=y[b+824|0];a:{if(!j){if($b(a+1074312|0,11)){break a}}b:{c:{if(!h){break c}if(!Zd(j)){break c}d:{g=h+236|0;j=j-1|0;if(z[fd(g,j)>>1]){break d}if(!$b(a+1074312|0,43)){break d}if(Ki(h)){break d}x[b+656>>2]=h;return}if(y[gc(h+108|0,j)|0]>120){break a}j=z[fd(g,j)>>1];m=(j-1&65535)>>>0<3999?(D(j,104)+a|0)+484380|0:0;break b}if(!z[a+480192>>1]){m=(D(c,104)+a|0)+484380|0;break b}if(j>>>0>250){break a}if(!$b(a+1074312|0,43)){break b}if(h){if(Ki(h)){break b}}v[b+825|0]=0;x[b+656>>2]=0;return}j=x[b+656>>2];g=x[b+104>>2];n=(g|0)!=0&(g|0)!=(m|0);g=!n;o=!h|x[a+480180>>2]!=16777216?o:x[h+44>>2]!=0;if(!(!d|!o|x[b+656>>2]!=(h|0)|g)){break a}p=d^1;e:{if(g|p){break e}i=a+1074312|0;if(!(!$b(i,32)|!(y[a+480208|0]&8))){m=x[b+8>>2]|x[b+12>>2]?x[b+104>>2]:m}f:{if(!(x[a+480180>>2]&1048580?!h|(h|0)!=(j|0):1)|x[a+480180>>2]==268435456){break f}if(x[a+480180>>2]==1){if(Sh(b)){break f}}if(!$b(i,79)){break e}if(!Sh(b)){break e}}k=1}g:{if(!x[b+16>>2]|(g|(!z[a+480192>>1]|(h|0)!=(j|0)))){break g}if(!$b(a+1074312|0,87)){break g}k=Af(b+810|0)^1|k}j=(h|0)!=(j|0);h:{if(Sh(b)|!(x[a+480180>>2]&16777248)){break h}if(h){if(Ki(h)){break h}}j=1}i:{j:{if(!j|!d){break j}if(!$b(a+1074312|0,61)){break j}g=x[b+104>>2];i=x[b+656>>2];l=0;if(g|i){break i}}x[b+656>>2]=h;g=m;i=h;l=j}j=l;k:{l:{m:{if(!e){break m}n:{if(x[a+480180>>2]&3){if(g){if(Be(g)){break n}}if(!wj(b)){break m}}if(!g){break l}}if(w[g+34>>1]<0){break m}x[b+688>>2]=z[g+30>>1]}h=(g|0)!=0;if(!(k&n)|!g){break k}if($b(a+1074312|0,85)){x[b+768>>2]=v[g+37|0]}h=1;if(x[a+480180>>2]!=2){break k}if(!Be(g)){break k}x[b+704>>2]=x[g+24>>2];break k}if(!(!i|!y[i+34|0])){h=x[b+656>>2];o:{if(h){l=x[h+4>>2]<<2;break o}l=x[b+688>>2]}x[b+688>>2]=l;h=0;break k}h=0;x[b+688>>2]=0}if(k){break a}v[b+825|0]=0;p:{if(!i){break p}if(r=(u=$b(a+1074312|0,29),B=1,C=g,C?u:B),s=0,t=(j|y[i+34|0]!=0)!=1,t?r:s){break p}v[b+820|0]=y[i+16|0]}k=64;x[b+764>>2]=64;if(g){k=z[g+32>>1];x[b+764>>2]=k}if(i){x[b+764>>2]=D(x[i+4>>2],k)>>>6}q:{if(!(x[a+480180>>2]&1048580?e:1)){break q}if($b(a+1074312|0,48)){break q}YM(a,b,i,g)}r:{s:{t:{if(!f){break t}u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{f=a+1074312|0;if($b(f,19)){if(x[b+76>>2]){if(!(!c|p)){e=(y[a+480208|0]&8)>>>3|0;if(e){break C}break D}e=0;if(c){break D}break C}c=1;if(j|!x[b+696>>2]){break A}c=(y[b+89|0]&8)>>>3|0;break A}e=1;E:{if(!d|!(x[a+480180>>2]&17301536)|(!x[b+76>>2]|y[a+480208|0]&8)){break E}e=0;if(!(y[b+89|0]&16)){break E}e=!x[b+696>>2]}if(!(x[a+480180>>2]&17301536)|(j|!i)){break B}if(!e){break x}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(c&6144){break z}break v}if(d){break C}if(!(y[b+89|0]&24)){e=0;break C}e=(y[a+480208|0]&4)>>>2|0}if(j|!x[b+696>>2]){break B}if(!e){break y}c=(y[b+89|0]&8)>>>3|0;break A}c=1;if(!e){break y}}x[b+88>>2]=x[b+88>>2]|2097152;if(!i){break u}if(!c){break v}}Rl(b);break u}if(!i){break w}}if(v[i+60|0]&1){break t}if($b(f,32)){Hi(b+724|0);break t}Rl(b);break t}c=0;if(!g){break s}break r}if(!(y[i+60|0]&8)){Hi(b+724|0)}if(!(y[i+80|0]&8)){Hi(b+736|0)}if(y[i+100|0]&8){break u}Hi(b+748|0)}if($b(f,21)){break t}v[b+838|0]=0;x[b+780>>2]=0}c=0;if(g){break r}if(!i){break s}c=1;if(Ki(i)){break r}}x[b+764>>2]=0;x[b+104>>2]=0;return}F:{if(!(!d|(h^1|x[b+104>>2]!=(g|0)))){if(x[b+76>>2]?x[a+480180>>2]&16777250:0){break a}G:{H:{if(x[a+480180>>2]!=4){break H}if(!$b(a+1074312|0,40)|y[b+811|0]){break H}e=x[b+88>>2];break G}e=x[b+88>>2]&-6145}x[b+88>>2]=e&-640;break F}x[b+88>>2]=x[b+88>>2]&-6145;e=a+1074312|0;I:{J:{if(!$b(e,18)){h=-640;if(j|(x[a+480180>>2]&16777248|x[b+104>>2]!=(g|0))){break J}break I}h=-640;if((j|x[b+104>>2]!=(g|0))!=1){break I}}h=-768}x[b+88>>2]=x[b+88>>2]&h;if(!i){break F}v[b+724|0]=y[i+60|0];v[b+736|0]=y[i+80|0];v[b+748|0]=y[i+100|0];K:{if((y[i+100|0]&17)!=17){break K}if($b(e,36)|y[b+857|0]){break K}v[b+857|0]=127}if(fv(i)){r=b,s=sC(i),v[r+857|0]=s}if(!qC(i)){break F}r=b,s=rC(i),v[r+858|0]=s}if(c){x[b+76>>2]=0;x[b+104>>2]=0;return}L:{if(x[b+76>>2]|!d){break L}c=a+1074312|0;if(!$b(c,54)){if(!$b(c,39)){break L}}x[b+8>>2]=0;x[b+12>>2]=0}M:{if(y[b+810|0]!=255){break M}if(!$b(a+1074312|0,100)|!(y[a+480208|0]>>>2&n)){break M}c=x[b+104>>2];if(c){x[b+88>>2]=x[b+88>>2]|z[c+34>>1]&1023}x[b+764>>2]=q;x[b+688>>2]=z[g+30>>1];if(!(y[g+34|0]&32)){break a}Bt(b,z[g+28>>1],a);return}x[b+104>>2]=g;x[b+76>>2]=x[g>>2];x[b+80>>2]=x[g+4>>2];x[b+84>>2]=x[g+8>>2];c=a+1074312|0;if(!(!$b(c,83)|x[b+80>>2])){x[b+84>>2]=x[g>>2]}x[b+88>>2]=x[b+88>>2]|z[g+34>>1]&1023;if($b(c,21)){v[b+838|0]=0;x[b+780>>2]=0}N:{O:{if(o){x[b+704>>2]=x[g+24>>2];v[b+872|0]=y[b+872|0]|16;d=0;break O}if(!(x[a+480180>>2]&5?n|p:1)){break N}x[b+704>>2]=x[g+24>>2];d=v[g+37|0]}x[b+768>>2]=d}if(lq(a)){d=v[g+36|0]}else{d=0}x[b+772>>2]=d;if(!($b(c,69)|x[a+480180>>2]==1)){x[b+708>>2]=0}x[b+876>>2]=0;h=x[b+88>>2];if(h&8){x[b+80>>2]=x[g+12>>2];x[b+84>>2]=x[g+16>>2];h=h>>>2&4|h|2;x[b+88>>2]=h}c=x[b+76>>2];P:{if(!(h&2)){break P}d=x[b+84>>2];if(d>>>0>=c>>>0){break P}x[b+76>>2]=d;c=d}if(!(x[a+480180>>2]&16777248)|A[b+4>>2]<c>>>0){break a}x[b>>2]=0;x[b+4>>2]=0}}function HG(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0,E=0,F=0,G=0;j=hb-80|0;hb=j;x[j+76>>2]=b;E=j+55|0;s=j+56|0;a:{b:{c:{d:{e:while(1){k=b;if((p^2147483647)<(h|0)){break d}p=h+p|0;f:{g:{h:{h=k;i=y[h|0];if(i){while(1){i:{b=i&255;j:{if(!b){b=h;break j}if((b|0)!=37){break i}i=h;while(1){if(y[i+1|0]!=37){b=i;break j}h=h+1|0;m=y[i+2|0];b=i+2|0;i=b;if((m|0)==37){continue}break}}h=h-k|0;B=p^2147483647;if((h|0)>(B|0)){break d}if(a){We(a,k,h)}if(h){continue e}x[j+76>>2]=b;h=b+1|0;q=-1;if(!(!ih(v[b+1|0])|y[b+2|0]!=36)){q=v[b+1|0]-48|0;u=1;h=b+3|0}x[j+76>>2]=h;n=0;i=v[h|0];b=i-32|0;k:{if(b>>>0>31){o=h;break k}o=h;b=1<<b;if(!(b&75913)){break k}while(1){o=h+1|0;x[j+76>>2]=o;n=b|n;i=v[h+1|0];b=i-32|0;if(b>>>0>=32){break k}h=o;b=1<<b;if(b&75913){continue}break}}l:{if((i|0)==42){m:{if(!(!ih(v[o+1|0])|y[o+2|0]!=36)){x[((v[o+1|0]<<2)+e|0)-192>>2]=10;i=o+3|0;u=1;b=x[((v[o+1|0]<<3)+d|0)-384>>2];break m}if(u){break h}i=o+1|0;if(!a){x[j+76>>2]=i;u=0;r=0;break l}b=x[c>>2];x[c>>2]=b+4;u=0;b=x[b>>2]}x[j+76>>2]=i;r=b;if((b|0)>=0){break l}r=0-r|0;n=n|8192;break l}r=GG(j+76|0);if((r|0)<0){break d}i=x[j+76>>2]}h=0;l=-1;n:{if(y[i|0]!=46){b=i;A=0;break n}if(y[i+1|0]==42){o:{if(!(!ih(v[i+2|0])|y[i+3|0]!=36)){x[((v[i+2|0]<<2)+e|0)-192>>2]=10;b=i+4|0;l=x[((v[i+2|0]<<3)+d|0)-384>>2];break o}if(u){break h}b=i+2|0;l=0;if(!a){break o}i=x[c>>2];x[c>>2]=i+4;l=x[i>>2]}x[j+76>>2]=b;A=(l^-1)>>>31|0;break n}x[j+76>>2]=i+1;l=GG(j+76|0);b=x[j+76>>2];A=1}while(1){t=h;o=28;m=b;h=v[b|0];if(h-123>>>0<4294967238){break c}b=m+1|0;h=y[(h+D(t,58)|0)+58559|0];if(h-1>>>0<8){continue}break}x[j+76>>2]=b;p:{q:{if((h|0)!=27){if(!h){break c}if((q|0)>=0){x[(q<<2)+e>>2]=h;i=(q<<3)+d|0;h=x[i+4>>2];x[j+64>>2]=x[i>>2];x[j+68>>2]=h;break q}if(!a){break f}FG(j- -64|0,h,c,g);break p}if((q|0)>=0){break c}}h=0;if(!a){continue e}}i=n&-65537;n=n&8192?i:n;q=0;z=1772;o=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{h=v[m|0];h=t?(h&15)==3?h&-33:h:h;switch(h-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(h-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((h|0)==83){break w}break g}i=x[j+64>>2];m=x[j+68>>2];z=1772;break z}h=0;I:{switch(t&255){case 0:x[x[j+64>>2]>>2]=p;continue e;case 1:x[x[j+64>>2]>>2]=p;continue e;case 2:k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e;case 3:w[x[j+64>>2]>>1]=p;continue e;case 4:v[x[j+64>>2]]=p;continue e;case 6:x[x[j+64>>2]>>2]=p;continue e;case 7:break I;default:continue e}}k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e}l=l>>>0<=8?8:l;n=n|8;h=120}k=s;F=h&32;i=x[j+64>>2];m=x[j+68>>2];if(i|m){while(1){k=k-1|0;v[k|0]=F|y[(i&15)+59088|0];G=!m&i>>>0>15|(m|0)!=0;t=m;m=m>>>4|0;i=(t&15)<<28|i>>>4;if(G){continue}break}}if(!(n&8)|!(x[j+64>>2]|x[j+68>>2])){break y}z=(h>>>4|0)+1772|0;q=2;break y}h=s;k=x[j+68>>2];m=k;i=x[j+64>>2];if(k|i){while(1){h=h-1|0;v[h|0]=i&7|48;t=!m&i>>>0>7|(m|0)!=0;k=m;m=k>>>3|0;i=(k&7)<<29|i>>>3;if(t){continue}break}}k=h;if(!(n&8)){break y}h=s-k|0;l=(h|0)<(l|0)?l:h+1|0;break y}i=x[j+64>>2];h=x[j+68>>2];m=h;if((h|0)<0){k=0-(m+((i|0)!=0)|0)|0;m=k;i=0-i|0;x[j+64>>2]=i;x[j+68>>2]=k;q=1;z=1772;break z}if(n&2048){q=1;z=1773;break z}q=n&1;z=q?1774:1772}k=an(i,m,s)}if((l|0)<0?A:0){break d}n=A?n&-65537:n;h=x[j+64>>2];i=x[j+68>>2];if(!((h|i)!=0|l)){k=s;l=0;break g}h=!(h|i)+(s-k|0)|0;l=(h|0)<(l|0)?l:h;break g}h=x[j+64>>2];k=h?h:12950;m=l>>>0>=2147483647?2147483647:l;h=fs(k,0,m);h=h?h-k|0:m;o=h+k|0;if((l|0)>=0){n=i;l=h;break g}n=i;l=h;if(y[o|0]){break d}break g}if(l){i=x[j+64>>2];break u}h=0;hf(a,32,r,0,n);break t}x[j+12>>2]=0;x[j+8>>2]=x[j+64>>2];i=j+8|0;x[j+64>>2]=i;l=-1}h=0;J:{while(1){k=x[i>>2];if(!k){break J}m=EG(j+4|0,k);k=(m|0)<0;if(!(k|m>>>0>l-h>>>0)){i=i+4|0;h=h+m|0;if(l>>>0>h>>>0){continue}break J}break}if(k){break b}}o=61;if((h|0)<0){break c}hf(a,32,r,h,n);if(!h){h=0;break t}o=0;i=x[j+64>>2];while(1){k=x[i>>2];if(!k){break t}k=EG(j+4|0,k);o=k+o|0;if(o>>>0>h>>>0){break t}We(a,j+4|0,k);i=i+4|0;if(h>>>0>o>>>0){continue}break}}hf(a,32,r,h,n^8192);h=(h|0)<(r|0)?r:h;continue e}if((l|0)<0?A:0){break d}o=61;h=mb[f|0](a,C[j+64>>3],r,l,n,h)|0;if((h|0)>=0){continue e}break c}v[j+55|0]=x[j+64>>2];l=1;k=E;n=i;break g}i=y[h+1|0];h=h+1|0;continue}}if(a){break a}if(!u){break f}h=1;while(1){a=x[(h<<2)+e>>2];if(a){FG((h<<3)+d|0,a,c,g);p=1;h=h+1|0;if((h|0)!=10){continue}break a}break}p=1;if(h>>>0>=10){break a}while(1){if(x[(h<<2)+e>>2]){break h}h=h+1|0;if((h|0)!=10){continue}break}break a}o=28;break c}m=o-k|0;i=(l|0)>(m|0)?l:m;if((i|0)>(q^2147483647)){break d}o=61;l=i+q|0;h=(l|0)<(r|0)?r:l;if((B|0)<(h|0)){break c}hf(a,32,h,l,n);We(a,z,q);hf(a,48,h,l,n^65536);hf(a,48,i,m,0);We(a,k,m);hf(a,32,h,l,n^8192);continue}break}p=0;break a}o=61}x[114240]=o}p=-1}hb=j+80|0;return p}function lja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=hb-1824|0;hb=d;Lc(b);e=hb-16|0;hb=e;h=e+8|0;k=d+1224|0;BQ(h,k);i=Eb(h);h=nc(b,ac(e,h));if((i|0)==(h|0)){cc(b,Eb(e+8|0))}hb=e+16|0;e=(h|0)==(i|0);if(!e){CQ(k)}a:{if(!e){break a}if(!MQ(d+1224|0)){break a}if(!Nz(b,16,0)){break a}x[d+1216>>2]=x[d+1240>>2];e=x[d+1228>>2];x[d+1200>>2]=x[d+1224>>2];x[d+1204>>2]=e;e=d+1232|0;g=x[e+4>>2];x[d+1208>>2]=x[e>>2];x[d+1212>>2]=g;Nd(a,1);e=a+1074312|0;Ig(e,83);Nb(e,84,1);Nb(e,85,1);w[a+480188>>1]=4;x[d+1196>>2]=0;w[a+480190>>1]=15;Rc(b,20);l=a+480188|0;g=1;k=1;while(1){h=D(g,104)+a|0;i=h+484380|0;e=((g<<5)+a|0)+946304|0;Pz(b,d+16|0,i,e,1);n=x[i>>2];b:{if(!y[gc(e,0)|0]){break b}c:{if(cd(e,12717,3)){if(cd(e,12721,3)){break c}}if(y[gc(e,5)|0]==58){break b}}k=0}e=y[d+44|0]|y[d+45|0]<<8;if(((e<<8|e>>>8)&65535)>>>0>=2){e=y[d+42|0]|y[d+43|0]<<8;x[h+484384>>2]=(e<<8|e>>>8)&65535;e=y[d+42|0]|y[d+43|0]<<8;j=(e<<8|e>>>8)&65535;e=y[d+44|0]|y[d+45|0]<<8;x[h+484388>>2]=j+(((e<<8|e>>>8)&65535)<<1);Dn(i)}e=y[d+38|0]|y[d+39|0]<<8;d:{if(((e<<8|e>>>8)&65535)>>>0<=4999){e=y[d+42|0]|y[d+43|0]<<8;if(((e<<8|e>>>8)&65535)>>>0<1e4){break d}}x[d+1064>>2]=5;s=d,t=x[Bf(d+1196|0,d+1064|0)>>2],x[s+1196>>2]=t}f=f+n|0;g=g+1|0;if((g|0)!=16){continue}break}e=d+1064|0;Oz(b,e);o=a+484360|0;$n(Vb(o),e|2,128,65535,65535);n=SQ(b,Vb(o),y[e|0],f,l,0,1);e=e|1;if(!(y[e|0]|n>>>0>1)){g=0;if(!y[d+1064|0]){break a}}f=(n<<10)+f|0;x[d+1060>>2]=f;x[d+16>>2]=65536;g=0;if(!Qb(b,f-x[Mb(d+1060|0,d+16|0)>>2]|0)){break a}if(!c){g=1;break a}if(!y[e|0]){v[e|0]=120}if(!cd(d+1200|0,10446,6)){v[e|0]=120}x[a+480204>>2]=125e4;e:{if(y[e|0]==120){break e}s=a,t=gg(145364549.18032786/+(240-y[e|0]|0)),x[s+480204>>2]=t;if(x[d+1196>>2]>=2){x[d+16>>2]=k&1?4:5;s=d,t=x[Bf(d+1196|0,d+16|0)>>2],x[s+1196>>2]=t;break e}x[d+16>>2]=k&1?1:2;s=d,t=x[Bf(d+1196|0,d+16|0)>>2],x[s+1196>>2]=t}x[a+480228>>2]=64;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480208>>2]=x[a+480208>>2]|2097152;e=d+1048|0;_n(e,3,d+1200|0);f=d+16|0;Ic(f,e);Db(a+1304400|0,f);xb(f);uj(a,0);q=x[b+8>>2];w[d+1046>>1]=0;f:{g:{if(!n){break g}r=k&1;h=0;k=0;while(1){s=d,t=Lz(bc(Vb(o)),dc(Vb(o)),d+1046|0),x[s+16>>2]=t;s=d,t=dc(Vb(o)),x[s+1048>>2]=t;f=d+16|0;e=Hb(f,d+1048|0);LQ(b,f);if(e){h=Kz(d+16|0,0)+h|0;if(h>>>0>512){break f}}i=0;f=0;l=0;while(1){g=0;while(1){e=f;m=$e(KQ(d+16|0,i),g);p=y[gc(m,2)|0]&15;j=y[gc(m,3)|0];f=0;h:{if(!(e&255)|(y[m|0]|y[m+1|0]<<8|(y[m+2|0]<<16|y[m+3|0]<<24))){break h}f=e+1|0;if((f&255)>>>0<33){break h}x[d+1196>>2]=6}i:{j:{k:{switch(p-1|0){case 0:case 1:e=x[d+1196>>2];if((e|0)==1&j>>>0>=32){break j}m=(p|0)!=1;if(!(m|!j|j>>>0>2)){x[d+1048>>2]=2;s=d,t=x[Bf(d+1196|0,d+1048|0)>>2],x[s+1196>>2]=t;break i}if(m|(j|0)!=55&(j|0)!=71){break i}if((e|0)<=2){break j}break i;case 10:x[d+1196>>2]=6;break i;case 11:case 12:case 13:x[d+1048>>2]=2;s=d,t=x[Bf(d+1196|0,d+1048|0)>>2],x[s+1196>>2]=t;if((p|0)!=13){break i}l=((i|j)!=0)+l|0;f=1;break i;case 14:break k;default:break i}}x[d+1048>>2]=3;s=d,t=x[Bf(d+1196|0,d+1048|0)>>2],x[s+1196>>2]=t;break i}x[d+1196>>2]=r}g=g+1|0;if((g|0)!=4){continue}break}i=i+1|0;if((i|0)!=64){continue}break}if((l-1&255)>>>0<2){x[d+1196>>2]=6}k=(l&255)+k|0;f=z[d+1046>>1]+1|0;w[d+1046>>1]=f;if(n>>>0>(f&65535)>>>0){continue}break}if(x[d+1196>>2]!=6|n+32>>>0>=k>>>0){break g}x[d+1196>>2]=5}Rc(b,q);o=c&1;if(o){cg(a+484344|0,n)}if(n){m=a+484344|0;k=0;while(1){LQ(b,d+16|0);l:{if(!o){break l}if(!Tg(m,k&65535,64)){break l}x[d+1048>>2]=0;l=0;while(1){p=Df(Zb(m,k),l,0);h=0;while(1){f=$e(KQ(d+16|0,l),h);f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);x[d+4>>2]=f;x[d+8>>2]=f;e=p+D(h,6)|0;Rt(d+4|0,e);m:{n:{o:{f=y[e+5|0];if(f){i=e+3|0;j=(d+1048|0)+h|0;g=y[e+3|0];if((g|0)!=14){break o}v[j|0]=0;g=14;break n}v[(d+1048|0)+h|0]=0;g=y[e+3|0];if(!g){break m}i=e+3|0;break n}j=y[j|0];if(!j){break n}if(j>>>0>=16){v[e+2|0]=3;v[e+4|0]=j>>>4;break n}v[e+2|0]=4;v[e+4|0]=j}p:{q:{r:{s:{t:{switch(g-12|0){case 1:j=x[d+1196>>2];if((j|0)==6){break q}g=10;v[i|0]=10;break r;case 0:f=f&127;v[e+5|0]=f;g=12;break s;case 2:if(f>>>0<=1&x[d+1196>>2]>3){break p}g=10;v[i|0]=10;v[(d+1048|0)+h|0]=f;break s;case 3:break t;default:break s}}g=15;f=f&15;v[e+5|0]=f}j=x[d+1196>>2]}if((j|0)>1){break p}u:{v:{w:{switch(g|0){case 0:if(f>>>0>2){break v}break;case 2:break u;case 1:break v;default:break w}}v[i|0]=0;break m}v[i|0]=1;break m}g=f&15;if(g){v[i|0]=2;v[e+5|0]=g;break m}if(f>>>0<16){break m}v[i|0]=3;v[e+5|0]=f>>>4;break m}v[e+5|0]=0}Fj(e)}h=h+1|0;if((h|0)!=4){continue}break}l=l+1|0;if((l|0)!=64){continue}break}}k=k+1|0;if((n|0)!=(k|0)){continue}break}}f=x[d+1196>>2];if(f>>>0>=7){f=17386}else{f=x[(f<<2)+76312>>2]}e=d+16|0;g=Ub(e,4509);Db(a+1304436|0,g);xb(g);e=Ub(e,6729);Db(a+1304448|0,e);xb(e);Pc(a+1304460|0,f);x[a+1304496>>2]=2;g=1;if(!(c&2)){break a}h=1;while(1){c=D(h,104)+a|0;f=c+484384|0;cc(b,x[f>>2]);e=x[f>>2];x[f>>2]=0;f=c+484380|0;x[f>>2]=x[f>>2]-e;c=c+484388|0;x[c>>2]=x[c>>2]-e;c=d+16|0;ad(c,8,1,1,0);Eg(c,f,b);h=h+1|0;if((h|0)!=16){continue}break}break a}g=0}hb=d+1824|0;return g|0}function hja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=hb-256|0;hb=d;Lc(b);a:{b:{c:{d:{e:{f:{if(!pu(b,d+240|0)){break f}if(!IQ(d+240|0)){break f}h=ci(d+224|0);i=hd(d+208|0);Sb(d+144|0,0,64);x[114414]=0;f=O(862,b|0,d+136|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break c}g:{if(!f){break g}f=d+136|4;g=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);g=(g<<24|(g&65280)<<8|(g>>>8&65280|g>>>24))-4|0;g=g<<24|(g&65280)<<8|(g>>>8&65280|g>>>24);v[f|0]=g;v[f+1|0]=g>>>8;v[f+2|0]=g>>>16;v[f+3|0]=g>>>24;g=0;h:{i:{j:{while(1){e=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);e=(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))-8|0;e=e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24);v[f|0]=e;v[f+1|0]=e>>>8;v[f+2|0]=e>>>16;v[f+3|0]=e>>>24;k:{if(c){break k}e=d+136|0;if((y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))!=1413764176){break k}g=1;break g}e=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);x[114414]=0;T(307,d+16|0,b|0,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24));e=x[114414];x[114414]=0;l:{m:{n:{o:{p:{if((e|0)!=1){x[114414]=0;e=R(303,d+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break o}if(e){break p}Ab(d+16|0);break l}a=N()|0;break a}e=d+136|0;e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);e=e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24);if((e|0)<=1347699795){if((e|0)==1129139796){break n}if((e|0)!=1229866575){break m}x[114414]=0;k=O(863,d+16|0,d+144|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break o}break m}if((e|0)!=1347699796){if((e|0)!=1447383635){break m}x[114414]=0;O(304,d+16|0,4)|0;e=x[114414];x[114414]=0;if((e|0)==1){break o}x[114414]=0;e=O(864,d+16|0,9470)|0;j=x[114414];x[114414]=0;if((j|0)==1){break o}if(!e){break m}e=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);if((e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))>>>0<7){break m}e=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);x[114414]=0;Z(865,d+16|0,i|0,2,(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))-6|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break o}break m}x[114414]=0;g=U(866,a|0,d+16|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){break m}}a=N()|0;Ab(d+16|0);break a}HQ(h,d+16|0)}Ab(d+16|0);x[114414]=0;e=O(862,b|0,d+136|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break j}if(e){continue}}break}if(Wc(i)){x[114414]=0;b=O(2,d+120|0,10398)|0;c=x[114414];x[114414]=0;if((c|0)==1){break i}Db(i,b);xb(b)}if(!(g&k&1)){break h}b=d+186|0;b=y[b|0]|y[b+1|0]<<8;x[114414]=0;c=b&1;U(434,a+1074312|0,5,!c|0)|0;b=x[114414];x[114414]=0;q:{r:{s:{if((b|0)!=1){b=d+182|0;if(y[b|0]|y[b+1|0]<<8){w[d+16>>1]=64;b=y[b|0]|y[b+1|0]<<8;x[114414]=0;w[d+104>>1]=b<<8|b>>>8;b=O(433,d+16|0,d+104|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break s}x[a+480228>>2]=z[b>>1]}b=d+184|0;if(!(!c|!(y[b|0]|y[b+1|0]<<8))){b=y[b|0]|y[b+1|0]<<8;x[a+480204>>2]=D((b<<8|b>>>8)&65535,1e4)}if(y[d+144|0]){x[114414]=0;T(354,d+104|0,2,d+144|0);b=x[114414];x[114414]=0;if((b|0)==1){break r}x[114414]=0;P(355,d+16|0,d+104|0);b=x[114414];x[114414]=0;if((b|0)==1){break r}b=d+16|0;Db(a+1304400|0,b);xb(b)}b=z[d+190>>1];w[d+96>>1]=b;w[d+14>>1]=b;if(!_p(d+14|0,1,12)){break h}b=z[d+188>>1];w[d+88>>1]=b;w[d+12>>1]=b;if(!_p(d+12|0,1,31)){break h}b=z[d+194>>1];w[d+80>>1]=b;w[d+10>>1]=b;if(!_p(d+10|0,0,23)){break h}b=z[d+196>>1];w[d+72>>1]=b;w[d+8>>1]=b;if(!_p(d+8|0,0,59)){break h}b=z[d+198>>1];w[d+64>>1]=b;w[d+6>>1]=b;if(_p(d+6|0,0,59)){break q}break h}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}b=tq(d+16|0);c=d+192|0;c=y[c|0]|y[c+1|0]<<8;x[b+20>>2]=(c<<8|c>>>8)&65535;c=d+190|0;c=y[c|0]|y[c+1|0]<<8;x[b+16>>2]=((c<<8|c>>>8)&65535)-1;c=d+188|0;c=y[c|0]|y[c+1|0]<<8;x[b+12>>2]=(c<<8|c>>>8)&65535;c=d+194|0;c=y[c|0]|y[c+1|0]<<8;x[b+8>>2]=(c<<8|c>>>8)&65535;c=d+196|0;c=y[c|0]|y[c+1|0]<<8;x[b+4>>2]=(c<<8|c>>>8)&65535;c=d+198|0;c=y[c|0]|y[c+1|0]<<8;x[b>>2]=(c<<8|c>>>8)&65535;x[114414]=0;P(639,a+1304500|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break h}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}if(g&1){x[114414]=0;b=R(303,h|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break c}if(b){b=Wb(d+16|0);x[114414]=0;U(437,h|0,b|0,32)|0;c=x[114414];x[114414]=0;if((c|0)==1){break b}if(ku(b,9572)){x[114414]=0;T(13,d+104|0,2,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=d+104|0;Db(a+1304412|0,c);xb(c)}x[114414]=0;c=R(867,h|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}if(!c){x[114414]=0;c=R(296,h|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}x[114414]=0;aa(514,a+1304424|0,h|0,c|0,40,0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break b}}xb(b)}x[114414]=0;b=O(2,d+104|0,13305)|0;c=x[114414];x[114414]=0;if((c|0)==1){break e}x[114414]=0;T(695,d+16|0,b|0,i|0);c=x[114414];x[114414]=0;if((c|0)==1){break d}c=d+16|0;Db(a+1304460|0,c);xb(c);xb(b)}x[a+480208>>2]=x[a+480208>>2]|2097152;x[114414]=0;a=a+1074312|0;U(434,a|0,84,1)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}x[114414]=0;U(434,a|0,83,1)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}x[114414]=0;O(435,a|0,85)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}}xb(i);Ab(h)}hb=d+256|0;return g&1}a=N()|0;break a}a=N()|0;xb(b);break a}a=N()|0;break a}a=N()|0;xb(b)}xb(i);Ab(h);Q(a|0);p()}function GI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-448|0;hb=e;a:{if(vj(b)){break a}f=y[rk(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Fk(e+184|0,b,x[b+4>>2]-1|0);f=x[e+188>>2];x[b>>2]=x[e+184>>2];x[b+4>>2]=f}f=e+184|0;Hd(f);g=x[e+184>>2];Hd(e+416|0);h=qk(g,x[e+420>>2],b);Hd(f);f=x[b>>2];g=x[b+4>>2];b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)==x[e+188>>2]){x[e+440>>2]=f;x[e+444>>2]=g;a=tc(e+432|0,17386);f=x[e+444>>2];x[e+16>>2]=x[e+440>>2];x[e+20>>2]=f;f=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=f;if(Kc(e+16|0,e+8|0)){d=ec(8);x[114414]=0;a=O(2172,e+416|0,c|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;T(2152,e+184|0,13488,a|0);b=x[114414];x[114414]=0;if((b|0)==1){break i}b=oc(d,e+184|0);x[114414]=0;T(2042,b|0,82448,2050);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=N()|0;xb(e+184|0);xb(a);break c}b=N()|0;break d}if(!d){break k}f=ec(8);x[114414]=0;d=O(2172,e+384|0,b|0)|0;a=x[114414];x[114414]=0;l:{m:{n:{o:{p:{q:{r:{s:{if((a|0)!=1){x[114414]=0;T(2152,e+400|0,13524,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break s}x[114414]=0;T(2167,e+416|0,e+400|0,13498);b=x[114414];x[114414]=0;a=1;if((b|0)==1){break r}x[114414]=0;c=O(2172,e+368|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break q}x[114414]=0;T(137,e+184|0,e+416|0,c|0);b=x[114414];x[114414]=0;a=1;if((b|0)==1){break p}a=oc(f,e+184|0);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(e+184|0);a=0;break o}b=N()|0;break l}b=N()|0;xb(d);break l}b=N()|0;break m}b=N()|0;a=1;break n}b=N()|0}xb(c)}xb(e+416|0)}xb(e+400|0);xb(d);if(!a){break c}}hc(f);break c}x[e+360>>2]=f;x[e+364>>2]=g;d=tc(e+352|0,17386);f=x[e+364>>2];x[e+176>>2]=x[e+360>>2];x[e+180>>2]=f;f=x[d+4>>2];x[e+168>>2]=x[d>>2];x[e+172>>2]=f;if(Kc(e+176|0,e+168|0)){d=ec(8);x[114414]=0;a=O(2172,e+416|0,c|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;T(2152,e+184|0,13488,a|0);b=x[114414];x[114414]=0;if((b|0)==1){break h}b=oc(d,e+184|0);x[114414]=0;T(2042,b|0,82448,2050);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=N()|0;xb(e+184|0);xb(a);break c}b=N()|0;break e}d=x[b+4>>2];x[e+344>>2]=x[b>>2];x[e+348>>2]=d;d=tc(e+336|0,8168);f=x[e+348>>2];x[e+160>>2]=x[e+344>>2];x[e+164>>2]=f;f=x[d+4>>2];x[e+152>>2]=x[d>>2];x[e+156>>2]=f;if(Kc(e+160|0,e+152|0)){d=x[c+4>>2];b=x[c>>2];x[e+328>>2]=b;x[e+332>>2]=d;f=tc(e+320|0,2087);g=x[e+332>>2];x[e+64>>2]=x[e+328>>2];x[e+68>>2]=g;g=x[f+4>>2];x[e+56>>2]=x[f>>2];x[e+60>>2]=g;if(Kc(e- -64|0,e+56|0)){x[a+52>>2]=0;break k}x[e+312>>2]=b;x[e+316>>2]=d;f=tc(e+304|0,7165);g=x[e+316>>2];x[e+48>>2]=x[e+312>>2];x[e+52>>2]=g;g=x[f+4>>2];x[e+40>>2]=x[f>>2];x[e+44>>2]=g;if(Kc(e+48|0,e+40|0)){x[a+52>>2]=1;break k}x[e+296>>2]=b;x[e+300>>2]=d;b=tc(e+288|0,5177);d=x[e+300>>2];x[e+32>>2]=x[e+296>>2];x[e+36>>2]=d;d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Kc(e+32|0,e+24|0)){x[a+52>>2]=2;break k}d=ec(8);x[114414]=0;a=O(2172,e+416|0,c|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;T(2152,e+184|0,10158,a|0);b=x[114414];x[114414]=0;if((b|0)==1){break g}b=oc(d,e+184|0);x[114414]=0;T(2042,b|0,82448,2050);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=N()|0;xb(e+184|0);xb(a);break c}b=N()|0;break f}d=x[b+4>>2];x[e+280>>2]=x[b>>2];x[e+284>>2]=d;b=tc(e+272|0,7402);d=x[e+284>>2];x[e+144>>2]=x[e+280>>2];x[e+148>>2]=d;d=x[b+4>>2];x[e+136>>2]=x[b>>2];x[e+140>>2]=d;if(!Kc(e+144|0,e+136|0)){break k}d=x[c+4>>2];c=x[c>>2];x[e+264>>2]=c;x[e+268>>2]=d;b=tc(e+256|0,11636);f=x[e+268>>2];x[e+128>>2]=x[e+264>>2];x[e+132>>2]=f;f=x[b+4>>2];x[e+120>>2]=x[b>>2];x[e+124>>2]=f;b=0;t:{if(Kc(e+128|0,e+120|0)){break t}x[e+248>>2]=c;x[e+252>>2]=d;b=tc(e+240|0,11641);f=x[e+252>>2];x[e+112>>2]=x[e+248>>2];x[e+116>>2]=f;f=x[b+4>>2];x[e+104>>2]=x[b>>2];x[e+108>>2]=f;b=1;if(Kc(e+112|0,e+104|0)){break t}x[e+232>>2]=c;x[e+236>>2]=d;b=tc(e+224|0,8427);f=x[e+236>>2];x[e+96>>2]=x[e+232>>2];x[e+100>>2]=f;f=x[b+4>>2];x[e+88>>2]=x[b>>2];x[e+92>>2]=f;b=2;if(Kc(e+96|0,e+88|0)){break t}x[e+216>>2]=c;x[e+220>>2]=d;b=tc(e+208|0,5241);c=x[e+220>>2];x[e+80>>2]=x[e+216>>2];x[e+84>>2]=c;c=x[b+4>>2];x[e+72>>2]=x[b>>2];x[e+76>>2]=c;b=3;if(Kc(e+80|0,e+72|0)){break t}a=ec(8);x[114414]=0;c=O(118,e+184|0,7438)|0;b=x[114414];x[114414]=0;if((b|0)==1){break j}a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}x[a+56>>2]=b;b=a+24|0;if(!x[x[b>>2]+24668>>2]){break k}c=x[b>>2];d=c+24664|0;f=x[d+4>>2];x[e+200>>2]=x[d>>2];x[e+204>>2]=f;d=c+24656|0;f=x[d+4>>2];x[e+192>>2]=x[d>>2];x[e+196>>2]=f;d=x[c+24652>>2];x[e+184>>2]=x[c+24648>>2];x[e+188>>2]=d;i=e,j=nI(x[a+56>>2]),x[i+204>>2]=j;if(!tx(e+184|0,x[b>>2]+24648|0)){break k}my(x[b>>2],e+184|0)}hb=e+448|0;return}b=N()|0;hc(a);break c}b=N()|0;xb(a);break d}b=N()|0;xb(a);break e}b=N()|0;xb(a)}hc(d);break c}hc(d);break c}hc(d)}Q(b|0)}p()}
function zH(a,b,c,d,e,f){var g=0,h=E(0),i=0,j=E(0),k=0,l=E(0),m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=E(0),z=0,A=E(0),C=E(0),F=E(0),G=0,H=E(0),I=E(0),J=E(0),K=E(0),L=E(0),M=E(0),N=0,O=0,P=0,Q=0;if((d|0)>0){while(1){v=0;if((c|0)>0){x=D(t,2304)+b|0;m=hb-128|0;while(1){p=x+(v<<2)|0;o=0;k=m;i=k;while(1){j=B[D(31-o|0,72)+p>>2];u=D(o,72)+p|0;h=B[u>>2];n=E(j+h);l=B[u+1152>>2];y=B[D(15-o|0,72)+p>>2];A=E(l+y);B[i>>2]=n+A;u=D(o,12)+45952|0;j=E(B[u+4>>2]*E(h-j));h=E(B[u>>2]*E(y-l));B[i+64>>2]=j+h;l=B[u+8>>2];B[i+32>>2]=l*E(n-A);B[i+96>>2]=l*E(j-h);i=i+4|0;o=o+1|0;if((o|0)!=8){continue}break}o=0;while(1){n=B[k+28>>2];l=B[k>>2];j=E(n+l);y=B[k+16>>2];A=B[k+12>>2];h=E(y+A);C=E(j+h);F=B[k+24>>2];H=B[k+4>>2];I=E(F+H);J=B[k+20>>2];K=B[k+8>>2];L=E(J+K);M=E(I+L);B[k>>2]=C+M;B[k+16>>2]=E(C-M)*E(.7071067690849304);j=E(j-h);h=E(E(j+E(I-L))*E(.7071067690849304));B[k+24>>2]=E(j-h)*E(1.3065630197525024);B[k+8>>2]=E(h+j)*E(.5411961078643799);h=E(H-F);C=E(K-J);F=E(E(h+C)*E(.7071067690849304));j=E(l-n);n=E(F+j);h=E(j+h);l=E(E(E(A-y)+C)+E(h*E(-.1989123672246933)));h=E(E(l*E(.3826834261417389))+h);B[k+28>>2]=E(n-h)*E(2.562915563583374);B[k+4>>2]=E(h+n)*E(.509795606136322);h=E(l+E(h*E(-.1989123672246933)));j=E(j-F);B[k+20>>2]=E(h+j)*E(.8999761939048767);B[k+12>>2]=E(j-h)*E(.601344883441925);k=k+32|0;o=o+1|0;if((o|0)!=4){continue}break}o=0;j=B[m+32>>2];h=B[m+96>>2];l=B[m+64>>2];while(1){k=p;B[k>>2]=B[m+(o<<2)>>2];o=o+1|0;i=m+(o<<2)|0;n=B[i+96>>2];y=E(n+h);B[k+72>>2]=y+l;h=B[i+32>>2];B[k+144>>2]=h+j;l=B[i- -64>>2];B[k+216>>2]=y+l;p=k+288|0;j=h;h=n;if((o|0)!=7){continue}break}B[k+288>>2]=B[m+28>>2];j=B[m+124>>2];B[k+360>>2]=j+B[m+92>>2];h=B[m+60>>2];B[k+504>>2]=j;B[k+432>>2]=h;v=v+1|0;if((v|0)!=(c|0)){continue}break}}t=t+1|0;if((t|0)!=(d|0)){continue}break}}G=sc(f,a,3840);if((c|0)>0){O=d<<5;t=0;while(1){m=hb-32|0;hb=m;o=(t<<8)+G|0;v=(t<<2)+b|0;B[o+4080>>2]=B[v+1152>>2];f=d-1|0;u=v+D(f,2304)|0;B[o+4084>>2]=B[u+1152>>2];B[o+4088>>2]=B[v>>2];B[o+4092>>2]=B[u>>2];B[o+4336>>2]=B[v+1156>>2];B[o+4340>>2]=B[u+1156>>2];B[o+4344>>2]=B[v+4>>2];B[o+4348>>2]=B[u+4>>2];x=(D(t,O)<<1)+e|0;z=x+(f<<1)|0;ks(z,d,o+244|0);f=d<<6;ks(f+z|0,d,o+500|0);ks(x,d,o+240|0);ks(f+x|0,d,o+496|0);p=46048;N=o+3840|0;f=14;while(1){k=f;r=k<<4;i=r+N|0;g=D(31-k|0,72);B[i>>2]=B[g+v>>2];B[i+4>>2]=B[g+u>>2];g=g|4;B[i+8>>2]=B[g+v>>2];B[i+12>>2]=B[g+u>>2];g=D(k,72);q=g+76|0;B[i+256>>2]=B[q+v>>2];B[i+260>>2]=B[q+u>>2];g=g+72|0;B[i-248>>2]=B[g+v>>2];B[i-244>>2]=B[g+u>>2];q=k<<2;r=o+r|0;j=B[p+4>>2];h=B[p>>2];f=0;while(1){g=f<<2;n=B[g+i>>2];l=B[g+r>>2];B[g+(m+16|0)>>2]=E(n*h)-E(l*j);B[g+m>>2]=E(l*h)+E(n*j);f=f+1|0;if((f|0)!=4){continue}break}i=(q<<2)+N|0;r=i-3584|0;q=i-256|0;j=B[p+12>>2];h=B[p+8>>2];f=0;while(1){g=f<<2;s=g+m|0;n=B[g+r>>2];l=B[g+q>>2];B[s>>2]=E(E(n*h)+E(l*j))+B[s>>2];g=g+(m+16|0)|0;B[g>>2]=E(E(n*j)-E(l*h))+B[g>>2];f=f+1|0;if((f|0)!=4){continue}break}r=i-3328|0;q=i-512|0;j=B[p+20>>2];h=B[p+16>>2];f=0;while(1){g=f<<2;s=g+m|0;n=B[g+r>>2];l=B[g+q>>2];B[s>>2]=E(E(n*h)+E(l*j))+B[s>>2];g=g+(m+16|0)|0;B[g>>2]=E(E(l*h)-E(n*j))+B[g>>2];f=f+1|0;if((f|0)!=4){continue}break}r=i-3072|0;q=i-768|0;j=B[p+28>>2];h=B[p+24>>2];f=0;while(1){g=f<<2;s=g+m|0;n=B[g+r>>2];l=B[g+q>>2];B[s>>2]=E(E(n*h)+E(l*j))+B[s>>2];g=g+(m+16|0)|0;B[g>>2]=E(E(n*j)-E(l*h))+B[g>>2];f=f+1|0;if((f|0)!=4){continue}break}r=i-2816|0;q=i-1024|0;j=B[p+36>>2];h=B[p+32>>2];f=0;while(1){g=f<<2;s=g+m|0;n=B[g+r>>2];l=B[g+q>>2];B[s>>2]=E(E(n*h)+E(l*j))+B[s>>2];g=g+(m+16|0)|0;B[g>>2]=E(E(l*h)-E(n*j))+B[g>>2];f=f+1|0;if((f|0)!=4){continue}break}r=i-2560|0;q=i-1280|0;j=B[p+44>>2];h=B[p+40>>2];f=0;while(1){g=f<<2;s=g+m|0;n=B[g+r>>2];l=B[g+q>>2];B[s>>2]=E(E(n*h)+E(l*j))+B[s>>2];g=g+(m+16|0)|0;B[g>>2]=E(E(n*j)-E(l*h))+B[g>>2];f=f+1|0;if((f|0)!=4){continue}break}r=i-2304|0;q=i-1536|0;j=B[p+52>>2];h=B[p+48>>2];f=0;while(1){g=f<<2;s=g+m|0;n=B[g+r>>2];l=B[g+q>>2];B[s>>2]=E(E(n*h)+E(l*j))+B[s>>2];g=g+(m+16|0)|0;B[g>>2]=E(E(l*h)-E(n*j))+B[g>>2];f=f+1|0;if((f|0)!=4){continue}break}g=i-2048|0;r=i-1792|0;j=B[p+60>>2];h=B[p+56>>2];f=0;while(1){i=f<<2;q=i+m|0;n=B[g+i>>2];l=B[i+r>>2];B[q>>2]=E(E(n*h)+E(l*j))+B[q>>2];i=i+(m+16|0)|0;B[i>>2]=E(E(n*j)-E(l*h))+B[i>>2];f=f+1|0;if((f|0)!=4){continue}break}f=D(15-k|0,d)<<1;P=f+z|0,Q=si(B[m+20>>2]),w[P>>1]=Q;i=D(k+17|0,d)<<1;P=i+z|0,Q=si(B[m+4>>2]),w[P>>1]=Q;P=f+x|0,Q=si(B[m+16>>2]),w[P>>1]=Q;P=i+x|0,Q=si(B[m>>2]),w[P>>1]=Q;f=D(47-k|0,d)<<1;P=f+z|0,Q=si(B[m+28>>2]),w[P>>1]=Q;i=D(k+49|0,d)<<1;P=i+z|0,Q=si(B[m+12>>2]),w[P>>1]=Q;P=f+x|0,Q=si(B[m+24>>2]),w[P>>1]=Q;P=i+x|0,Q=si(B[m+8>>2]),w[P>>1]=Q;f=k-1|0;p=p- -64|0;if(k){continue}break}hb=m+32|0;t=t+2|0;if((t|0)<(c|0)){continue}break}}b=c<<6;a:{if((d|0)==1){t=0;while(1){B[(t<<2)+a>>2]=B[(b+t<<2)+G>>2];c=t>>>0<958;t=t+2|0;if(c){continue}break}break a}sc(a,(b<<2)+G|0,3840)}}function Oha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;d=hb-768|0;hb=d;Lc(b);f=hb-16|0;hb=f;e=f+8|0;h=d+160|0;uP(e,h);g=Eb(e);e=nc(b,ac(f,e));if((g|0)==(e|0)){cc(b,Eb(f+8|0))}hb=f+16|0;f=(e|0)==(g|0);if(!f){vP(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!f){break n}if(!xP(d+160|0)){break n}if(!Qb(b,jd(wP(d+160|0),lb))){break n}if(!c){o=1;break n}Nd(a,262144);h=d+104|0;ou(h,2,d+160|0);f=d+24|0;Ic(f,h);Db(a+1304400|0,f);xb(f);e=Ub(f,4522);Db(a+1304436|0,e);xb(e);f=Ub(f,6106);Db(a+1304448|0,f);xb(f);e=Ub(d+144|0,10899);x[114414]=0;P(187,h|0,e|0);f=x[114414];x[114414]=0;if((f|0)==1){break c}v[d+8|0]=y[d+190|0];f=y[d+189|0];x[114414]=0;v[d+127|0]=f;P(975,d+128|0,d+127|0);f=x[114414];x[114414]=0;if((f|0)==1){break e}f=0;x[114414]=0;X(401,d+24|0,d+104|0,d+8|0,d+128|0);h=x[114414];x[114414]=0;if((h|0)==1){break f}h=d+24|0;Db(a+1304460|0,h);xb(h);xb(d+128|0);g=d+104|0;Gb(g);xb(e);x[a+480208>>2]=12;x[a+1304496>>2]=4;w[a+480188>>1]=y[d+198|0]|y[d+199|0]<<8;w[d+24>>1]=y[d+194|0]|y[d+195|0]<<8;w[d+104>>1]=3999;B=a,C=z[Cf(h,g)>>1],w[B+480190>>1]=C;zA(Vb(a+484360|0),d+256|0,y[d+192|0]|y[d+193|0]<<8,255,254);if(z[a+480188>>1]){while(1){e=(f<<5)+a|0;Lg(e+480280|0);w[e+480284>>1]=(y[(d+f|0)+224|0]<<4|4)&244;f=f+1|0;if(f>>>0<z[a+480188>>1]){continue}break}}Bd(d+104|0,b,D(y[d+194|0]|y[d+195|0]<<8,80));if(z[a+480190>>1]){h=c&2;g=d+72|0;f=0;while(1){x[114414]=0;O(976,d+104|0,d+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break m}x[114414]=0;T(544,d+8|0,2,g|0);e=x[114414];x[114414]=0;o:{p:{q:{if((e|0)==1){break q}x[114414]=0;P(355,d+128|0,d+8|0);e=x[114414];x[114414]=0;if((e|0)==1){break q}x[114414]=0;f=f+1|0;O(334,((f<<5)+a|0)+946304|0,d+128|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break p}e=d+128|0;xb(e);x[114414]=0;i=e;e=(D(f,104)+a|0)+484380|0;T(977,i|0,d+24|0,e|0);i=x[114414];x[114414]=0;r:{if((i|0)==1){break r}if(!h|!x[e>>2]){break o}i=y[d+42|0]|y[d+43|0]<<8|(y[d+44|0]<<16|y[d+45|0]<<24);x[114414]=0;i=O(224,b|0,i|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break r}if(!i){break o}x[114414]=0;U(361,d+128|0,e|0,b|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){break o}}a=N()|0;break g}a=N()|0;break g}a=N()|0;xb(d+128|0);break g}if(z[a+480190>>1]>f>>>0){continue}break}}o=1;s:{if(!(c&1)){break s}c=y[d+196|0]|y[d+197|0]<<8;x[114414]=0;l=a+484344|0;P(362,l|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break l}if(!(y[d+196|0]|y[d+197|0]<<8)){break s}c=d+24|0;q=c|4;r=c|2;s=c|5;t=c|3;u=c|1;f=0;while(1){x[114414]=0;c=U(363,l|0,f&65535,64)|0;e=x[114414];x[114414]=0;if((e|0)==1){break k}t:{if(!c){break t}c=(f<<1)+d|0;e=c+512|0;if(!(y[e|0]|y[e+1|0]<<8)){break t}c=y[c+512|0]|y[c+513|0]<<8;x[114414]=0;c=O(224,b|0,c<<4)|0;e=x[114414];x[114414]=0;if((e|0)==1){break k}if(!c){break t}j=0;c=Zb(l,f);x[114414]=0;m=U(427,c|0,0,0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break h}while(1){x[114414]=0;c=O(226,b|0,1)|0;e=x[114414];x[114414]=0;u:{v:{w:{if((e|0)!=1){if(!c){break t}x[114414]=0;c=R(403,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break w}k=c<<24>>24;if(k){break v}j=j+1|0;m=D(z[a+480188>>1],6)+m|0;break u}a=N()|0;break g}a=N()|0;break g}w[d+28>>1]=0;x[d+24>>2]=0;c=k&31;e=D(c,6)+m|0;i=_h(d+24|0);h=c>>>0<z[a+480188>>1];n=h?e:i;x:{y:{z:{A:{B:{C:{g=k&255;D:{if(!(g&32)){break D}x[114414]=0;P(428,d+128|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break C}i=ed(d+128|0);c=y[d+128|0];v[n|0]=c;v[(h?e+1|0:u)|0]=y[i|0];E:{if(c){if((c|0)==254){break E}if(c>>>0<121){break D}}c=0}v[n|0]=c}if(!(g&64)){break x}x[114414]=0;P(428,d+128|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break j}A=ed(d+128|0);g=h?e+3|0:t;c=y[d+128|0];v[g|0]=c;i=h?e+5|0:s;v[i|0]=y[A|0];if(c>>>0>15){break B}x[114414]=0;W(541,n|0);c=x[114414];x[114414]=0;if((c|0)!=1){break A}a=N()|0;break g}a=N()|0;break g}if(c>>>0>23){break y}c=y[c+23975|0];v[g|0]=c;break z}c=y[g|0]}c=c&255;if((c|0)!=23){if((c|0)!=9){break x}v[g|0]=20;c=y[i|0];x[114414]=0;v[d+8|0]=c>>>3;v[d+127|0]=1;c=O(404,d+8|0,d+127|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){v[i|0]=y[c|0]-1&15|128;break x}a=N()|0;break g}x[114414]=0;v[d+8|0]=64;c=O(409,i|0,d+8|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){v[i|0]=y[c|0]<<1;break x}a=N()|0;break g}v[g|0]=0}if((k|0)>=0){break u}v[(h?e+2|0:r)|0]=1;x[114414]=0;c=R(403,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break i}v[(h?e+4|0:q)|0]=c}if(j>>>0<64){continue}break}}f=f+1|0;if(f>>>0<(y[d+196|0]|y[d+197|0]<<8)>>>0){continue}break}}Ab(d+104|0)}hb=d+768|0;return o|0}a=N()|0;break g}a=N()|0;break g}a=N()|0;break g}a=N()|0;break g}a=N()|0;break g}a=N()|0}Ab(d+104|0);break a}a=N()|0;xb(d+128|0);break d}a=N()|0}Gb(d+104|0);break b}a=N()|0}xb(e)}Q(a|0);p()}function AU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-128|0;hb=e;Lc(b);a:{if(!tB(b,7618)){break a}if(!Nu(b,e+112|0)){break a}if(!vB(e+112|0)){break a}if(!Qb(b,jd(uB(e+112|0),lb))){break a}if(!cc(b,y[e+121|0]|y[e+122|0]<<8)){break a}b:{if(!c){break b}Nd(a,4096);x[a+480208>>2]=12;d=e+112|0;w[a+480188>>1]=(y[d|2]&31)+1;h=d|3;w[a+480190>>1]=y[h|0];uj(a,1);d=e+56|0;i=Ub(d,4695);Db(a+1304436|0,i);xb(i);d=Ub(d,3356);Db(a+1304448|0,d);xb(d);d=Ub(e+80|0,10953);x[114414]=0;P(187,e+96|0,d|0);i=x[114414];x[114414]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((i|0)!=1){x[114414]=0;i=e+112|0;X(376,e+56|0,e+96|0,i|1,i|0);i=x[114414];x[114414]=0;if((i|0)==1){break o}i=e+56|0;Db(a+1304460|0,i);xb(i);i=e+96|0;Gb(i);xb(d);x[a+1304496>>2]=4;h=y[h|0];d=hb-16|0;hb=d;x[i>>2]=0;x[i+4>>2]=0;x[d+12>>2]=0;Id(i+8|0,d+12|0,d+8|0);if(h){Hq(i,h);pC(i,h,0)}hb=d+16|0;if(z[a+480190>>1]){d=1;h=1;while(1){x[114414]=0;O(377,b|0,e+56|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break k}x[114414]=0;P(378,e+56|0,(D(d,104)+a|0)+484380|0);g=x[114414];x[114414]=0;if((g|0)==1){break k}g=y[e+72|0];k=e+40|0;oe(k,i,d-1|0);he(k,(g&3)!=0);h=h+1|0;d=h&65535;if(d>>>0<=z[a+480190>>1]){continue}break}}x[114414]=0;U(379,b|0,a+1304400|0,-1)|0;h=x[114414];x[114414]=0;d=1;if((h|0)!=1){if(z[a+480190>>1]){while(1){x[114414]=0;U(380,b|0,(((d&65535)<<5)+a|0)+946304|0,-1)|0;h=x[114414];x[114414]=0;if((h|0)==1){break m}d=d+1|0;if(z[a+480190>>1]>=(d&65535)>>>0){continue}break}}if(z[a+480188>>1]){d=0;while(1){x[114414]=0;h=(d<<5)+a|0;W(381,h+480280|0);g=x[114414];x[114414]=0;if((g|0)==1){break e}x[114414]=0;U(382,b|0,h+480289|0,-1)|0;h=x[114414];x[114414]=0;if((h|0)==1){break e}d=d+1|0;if(d>>>0<z[a+480188>>1]){continue}break}}h=e+112|4;g=y[h|0]|y[h+1|0]<<8;d=0;x[114414]=0;k=a+484344|0;P(362,k|0,g|0);g=x[114414];x[114414]=0;if((g|0)!=1){break l}}b=N()|0;break d}b=N()|0;break n}b=N()|0;Gb(e+96|0)}xb(d);break c}b=N()|0;break d}if(y[h|0]|y[h+1|0]<<8){while(1){x[114414]=0;g=U(383,b|0,e+56|0,-1)|0;f=x[114414];x[114414]=0;p:{q:{if((f|0)==1){break q}x[114414]=0;f=U(363,k|0,d&65535,64)|0;j=x[114414];x[114414]=0;if((j|0)==1){break q}if((f&g)!=1){break p}g=Zb(k,d);x[114414]=0;O(384,g|0,e+56|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){break p}}b=N()|0;break d}d=d+1|0;if(d>>>0<(y[h|0]|y[h+1|0]<<8)>>>0){continue}break}}x[114414]=0;f=R(321,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break f}r:{if(!f){break r}x[114414]=0;d=O(226,b|0,f|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break f}if(!d){break r}g=Qq(e+56|0);x[114414]=0;U(385,b|0,g|0,f|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break h}d=Wb(e+40|0);x[114414]=0;P(108,d|0,f|0);f=x[114414];x[114414]=0;if((f|0)==1){break i}l=e,m=bc(g),x[l>>2]=m;l=e,m=dc(g),x[l+32>>2]=m;if(Hb(e,e+32|0)){while(1){s:{f=v[x[e>>2]];if((f|0)<0){l=e,m=jf(d),x[l+16>>2]=m;j=x[td(e+24|0,e+16|0)>>2];x[114414]=0;Z(386,d|0,j|0,f&127,32)|0;f=x[114414];x[114414]=0;if((f|0)!=1){break s}break i}x[114414]=0;P(107,d|0,f|0);f=x[114414];x[114414]=0;if((f|0)!=1){break s}break i}bg(e);if(Hb(e,e+32|0)){continue}break}}x[114414]=0;X(387,e|0,4,5,d|0);f=x[114414];x[114414]=0;if((f|0)==1){break i}Db(d,e);xb(e);f=Rb(d);x[114414]=0;f=R(388,f|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break i}j=Bb(d);x[114414]=0;aa(389,a+1304424|0,f|0,j|0,76,0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break i}xb(d);$d(g)}d=Vb(a+484360|0);g=e+112|6;g=y[g|0]|y[g+1|0]<<8;x[114414]=0;aa(390,d|0,b|0,g|0,65535,65535)|0;d=x[114414];x[114414]=0;if((d|0)==1){break f}t:{u:{v:{w:{if(!(y[h|0]|y[h+1|0]<<8)){break w}g=c&1;d=0;while(1){x[114414]=0;f=O(226,b|0,4)|0;j=x[114414];x[114414]=0;x:{if((j|0)!=1){if(f){break x}break w}b=N()|0;break d}x[114414]=0;f=R(391,b|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break u}x[114414]=0;T(307,e+56|0,b|0,f|0);f=x[114414];x[114414]=0;if((f|0)==1){break t}y:{if(!g){break y}x[114414]=0;f=O(392,k|0,d&65535)|0;j=x[114414];x[114414]=0;if((j|0)==1){break v}if(!f){break y}f=Zb(k,d);x[114414]=0;T(393,f|0,0,e+56|0);f=x[114414];x[114414]=0;if((f|0)==1){break v}}Ab(e+56|0);d=d+1|0;if(d>>>0<(y[h|0]|y[h+1|0]<<8)>>>0){continue}break}}if(!(!(c&2)|!z[a+480190>>1])){d=1;while(1){c=d&65535;h=D(c,104)+a|0;g=z[h+484414>>1];k=e+56|0;oe(k,i,c-1|0);c=ad(e+40|0,g&1?16:8,1,0,Ib(k)?6:0);x[114414]=0;U(361,c|0,h+484380|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break j}d=d+1|0;if(z[a+480190>>1]>=(d&65535)>>>0){continue}break}}ce(i);break b}b=N()|0;Ab(e+56|0);break d}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}b=N()|0;xb(d);break g}b=N()|0}$d(g);break d}b=N()|0;break d}b=N()|0}ce(i)}Q(b|0);p()}d=1}hb=e+128|0;return d|0}function cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;i=hb-208|0;hb=i;Lc(b);a:{b:{c:{d:{e:{if(!yA(b,i+160|0)){break e}if(!$O(i+160|0)){break e}if(!c){f=1;break e}if(!Qb(b,jd(_O(i+160|0),lb))){break e}Nd(a,128);f=i+144|0;Kg(f,2,i+175|0);d=i+72|0;Ic(d,f);Db(a+1304400|0,d);xb(d);g=Ub(d,4672);Db(a+1304436|0,g);xb(g);g=Ub(d,2476);Db(a+1304448|0,g);xb(g);g=Ub(f,13317);x[114414]=0;T(1014,d|0,g|0,x[(y[i+174|0]<<2)+76156>>2]);d=x[114414];x[114414]=0;if((d|0)==1){break b}d=i+72|0;Db(a+1304460|0,d);xb(d);xb(g);x[a+480208>>2]=12;x[a+1304496>>2]=4;oz(a+1304424|0,b,y[i+207|0]<<5,32,0);t=a,u=pe(b),w[t+480190>>1]=u;if(z[a+480190>>1]){f=1;g=1;while(1){f:{if(y[i+174|0]>=52){KA(b,i+72|0);break f}d=hb-16|0;hb=d;x[d+12>>2]=64;x[d>>2]=66;e=x[Mb(d+12|0,d)>>2];if(!Qb(b,e)){e=uf(b)}j=i+72|0;ru(d,j);lg(b,x[d>>2],e);ru(d,j);Sb(x[d>>2]+e|0,0,66-e|0);cc(b,x[d+12>>2]);hb=d+16|0;d=y[i+134|0]|y[i+135|0]<<8;v[i+136|0]=d;v[i+137|0]=d>>>8;v[i+134|0]=171;v[i+135|0]=32}e=hb-32|0;hb=e;d=(D(f,104)+a|0)+484380|0;Ad(d,0);l=i+72|0;j=l;Wk(e,2,j+32|0);h=e+16|0;Ic(h,e);x[114414]=0;O(335,d+43|0,h|0)|0;h=x[114414];x[114414]=0;g:{if((h|0)!=1){xb(e+16|0);h=j+56|0;k=j+52|0;h:{if((y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24))>>>0<=(y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))>>>0){break h}x[d>>2]=(y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24))-(y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24));h=j+44|0;x[d+12>>2]=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);h=j+48|0;x[e+16>>2]=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);t=d,u=x[Mb(e+16|0,d)>>2],x[t+16>>2]=u;w[d+30>>1]=y[j+60|0];h=j+62|0;x[d+24>>2]=y[h|0]|y[h+1|0]<<8;h=j- -64|0;if(y[h|0]|y[h+1|0]<<8){xt(d,+((y[h|0]|y[h+1|0]<<8)<<16>>16)*25431315104166665e-22)}j=j+61|0;if(y[j|0]&8){w[d+34>>1]=z[d+34>>1]|8}if(y[j|0]&16){w[d+34>>1]=z[d+34>>1]|16}if(!(y[j|0]&4)){break h}w[d+34>>1]=z[d+34>>1]|1;x[d+12>>2]=x[d+12>>2]>>>1;x[d+16>>2]=x[d+16>>2]>>>1}hb=e+32|0;break g}a=N()|0;xb(e+16|0);Q(a|0);p()}d=i+56|0;Kg(d,2,l);e=i+144|0;Ic(e,d);x[114414]=0;O(334,((f<<5)+a|0)+946304|0,e|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break c}xb(i+144|0);g=g+1|0;f=g&65535;if(f>>>0<=z[a+480190>>1]){continue}break}}oq(Vb(a+484360|0),b,256,255,254);f=0;d=pe(b);if(d>>>0>=127){break e}w[a+480188>>1]=d+1;d=pe(b);r=d+1|0;if(z[a+480188>>1]){while(1){g=(f<<5)+a|0;Lg(g+480280|0);l=g+480284|0;i:{if(y[i+174|0]>=51){j=(pe(b)<<4|8)&248;break i}j=f&1?192:64}w[l>>1]=j;f=f+1|0;if(f>>>0<z[a+480188>>1]){continue}break}}h=a+484344|0;cg(h,r);f=0;g=0;while(1){e=g&65535;if(!Tg(h,e,64)){break e}g=g+1|0;if(d>>>0>e>>>0){continue}break}if(z[a+480188>>1]){k=0;while(1){j=_h(i+72|0);l=0;while(1){if(Qb(b,5)){g=0;f=Df(Zb(h,l),0,k&65535);while(1){m=y[i+174|0];d=hb-16|0;hb=d;q=1;e=pe(b);if((e|0)==252){q=pe(b);e=pe(b)}v[j|0]=(e-1&255)>>>0<60?e+36|0:0;e=d+8|0;km(e,b);n=ed(e);o=rf(e);s=$h(e);v[j+1|0]=y[e|0];v[d+7|0]=y[n|0]&15;v[d+6|0]=y[n|0]>>>4;v[d+5|0]=y[o|0];v[d+4|0]=y[s|0];ZO(d+7|0,d+5|0,m);ZO(d+6|0,d+4|0,m);m=y[d+7|0];n=(m|0)!=10;e=y[d+6|0];j:{if(!(n|(e|0)!=10)){v[d+7|0]=0;t=d,u=gl((y[d+4|0]|y[d+5|0]<<8)>>>6|0),v[t+5|0]=u;break j}k:{l:{m:{if(!n){t=d,u=gl(y[d+5|0]<<2),v[t+5|0]=u;break m}if((e|0)==10){t=d,u=gl(y[d+4|0]<<2),v[t+4|0]=u;break j}if((e|0)!=(m|0)){break m}e=0;v[d+6|0]=0;break l}if((e|0)==13){break k}}if((m|0)==13|e){break j}}wh(d+7|0,d+6|0);wh(d+5|0,d+4|0)}e=d+6|0;m=d+4|0;n=d+7|0;o=d+5|0;Yx(e,m,n,o);Xx(d,n,o,e,m);v[j+2|0]=y[d+7|0];v[j+4|0]=y[d+5|0];v[j+3|0]=y[d+6|0];v[j+5|0]=y[d+4|0];hb=d+16|0;d=g+q|0;g=d>>>0>64?64-g|0:q;if(g){while(1){e=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);v[f|0]=e;v[f+1|0]=e>>>8;v[f+2|0]=e>>>16;v[f+3|0]=e>>>24;e=y[j+4|0]|y[j+5|0]<<8;v[f+4|0]=e;v[f+5|0]=e>>>8;f=D(z[a+480188>>1],6)+f|0;g=g-1|0;if(g){continue}break}g=d>>>0>=64?64:d;if(d>>>0<=63){continue}}break}l=l+1|0;if((r|0)!=(l|0)){continue}}break}k=k+1|0;if(z[a+480188>>1]>(k&65535)>>>0){continue}break}}f=z[a+480188>>1];d=Ot(i+8|0);v[d+16|0]=0;w[d+14>>1]=0;w[d+12>>1]=f;x[114414]=0;T(1016,d|0,f|0,0);f=x[114414];x[114414]=0;if((f|0)==1){a=N()|0;ce(d);Q(a|0);p()}x[114414]=0;T(1015,i+32|0,h|0,d|0);g=x[114414];x[114414]=0;f=1;if((g|0)==1){break d}ce(i+32|0);ce(d);if(!(c&2)|!z[a+480190>>1]){break e}g=1;while(1){c=D(g&65535,104)+a|0;Eg(ad(i+72|0,w[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);g=g+1|0;if(z[a+480190>>1]>=(g&65535)>>>0){continue}break}}hb=i+208|0;return f|0}f=N()|0;ce(d);break a}f=N()|0;xb(i+144|0);break a}f=N()|0;xb(g)}Q(f|0);p()}function Mia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=hb-112|0;hb=e;Lc(b);a:{b:{c:{d:{e:{if(!jQ(b,9899)){break e}g=nq(e+96|0);h=nq(e+80|0);l=Ot(e- -64|0);x[114414]=0;P(397,a|0,32768);d=x[114414];x[114414]=0;if((d|0)==1){break b}x[114414]=0;d=O(2,e+48|0,4374)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}Db(a+1304436|0,d);xb(d);x[114414]=0;d=O(2,e+32|0,2480)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}Db(a+1304448|0,d);xb(d);x[a+1304496>>2]=2;j=a+484360|0;i=e+24|4;while(1){x[114414]=0;d=O(226,b|0,8)|0;f=x[114414];x[114414]=0;f:{g:{h:{i:{if((f|0)!=1){j:{k:{l:{m:{n:{if(!d){break n}x[114414]=0;d=O(899,b|0,e+24|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break m}if(!d){break n}d=i;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[114414]=0;T(307,e+8|0,b|0,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24));d=x[114414];x[114414]=0;if((d|0)==1){break l}x[114414]=0;d=R(303,e+8|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break g}if(d){break k}Ab(e+8|0)}if(z[a+480188>>1]){break j}d=0;break h}a=N()|0;break a}a=N()|0;break a}o:{p:{q:{r:{s:{t:{d=e+24|0;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);if((d|0)<=1396788559){if((d|0)<=1346522947){if((d|0)==1129140036){break t}if((d|0)!=1346458708){break p}d=Vb(j);x[114414]=0;f=R(223,e+8|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break g}x[114414]=0;aa(548,d|0,e+8|0,f|0,255,254)|0;d=x[114414];x[114414]=0;if((d|0)==1){break g}break f}if((d|0)==1346522948){break r}if((d|0)!=1347175758){break p}x[114414]=0;d=R(223,e+8|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break g}if(d>>>0<2){break f}x[114414]=0;m=R(440,e+8|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break f}break g}if((d|0)<=1397507405){if((d|0)==1396788560){break s}if((d|0)!=1396854596){break p}if(rd(h)>>>0>3998){break f}x[114414]=0;f=R(223,e+8|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break g}d=h;if(!f){break f}break q}if((d|0)==1397507406){break f}if((d|0)!=1397769541){break p}x[114414]=0;d=R(223,e+8|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break g}if(d>>>0<2){break f}x[114414]=0;d=R(440,e+8|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break g}o=a,q=Md(d,1,255),x[o+480196>>2]=q;break f}if(z[a+480188>>1]){break f}x[114414]=0;d=R(223,e+8|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break g}f=0;if(d>>>0<8){break f}while(1){x[114414]=0;k=R(403,e+8|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break g}x[114414]=0;n=R(403,e+8|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break g}d=z[a+480188>>1];if(k|n){x[114414]=0;W(381,((d<<5)+a|0)+480280|0);d=x[114414];x[114414]=0;if((d|0)==1){break g}k=z[a+480188>>1];d=k+1|0;w[a+480188>>1]=d;w[((k<<5)+a|0)+480284>>1]=f-1>>>0<2?192:64}x[114414]=0;W(381,(((d&65535)<<5)+a|0)+480280|0);d=x[114414];x[114414]=0;if((d|0)==1){break g}d=z[a+480188>>1];w[a+480188>>1]=d+1;w[((d<<5)+a|0)+480284>>1]=f-1>>>0<2?192:64;f=f+1|0;if((f|0)!=4){continue}break}if(c){break f}d=1;break o}if(z[a+480190>>1]){break f}x[114414]=0;T(900,e+8|0,l|0,a|0);d=x[114414];x[114414]=0;if((d|0)!=1){break f}break g}d=g;if(rd(d)>>>0>=256){break f}}x[114414]=0;P(568,d|0,e+8|0);d=x[114414];x[114414]=0;if((d|0)!=1){break f}break g}d=e+24|0;if(!((y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))&-2139062144)){break f}d=0}Ab(e+8|0);break h}x[a+480200>>2]=256;x[a+480204>>2]=125e4;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480228>>2]=48;x[a+480232>>2]=48;b=Vb(j);x[114414]=0;P(901,b|0,m&65535);b=x[114414];x[114414]=0;if((b|0)==1){break b}u:{if(!(c&1)){break u}d=0;b=rd(g);x[114414]=0;P(362,a+484344|0,b&65535);b=x[114414];x[114414]=0;if((b|0)==1){break b}if(!rd(g)){break u}b=0;while(1){d=vc(g,d);x[114414]=0;T(902,d|0,b&65535,a|0);d=x[114414];x[114414]=0;if((d|0)==1){break i}b=b+1|0;d=b&65535;if(rd(g)>>>0>d>>>0){continue}break}}d=1;if(z[a+480190>>1]<2){break h}i=c&2;f=1;b=0;v:{while(1){if(!i|rd(h)>>>0<=b>>>0){break h}w:{c=(D(f,104)+a|0)+484380|0;if(x[c>>2]){d=vc(h,b);x[114414]=0;d=R(223,d|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break w}xc(c,d);d=e+8|0;oe(d,l,f-1|0);d=ad(e+24|0,8,1,1,Ib(d)?10:0);j=vc(h,b);x[114414]=0;U(361,d|0,c|0,j|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break v}b=b+1|0}d=1;f=f+1|0;if(f>>>0<z[a+480190>>1]){continue}break h}break}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}ce(l);id(h);id(g);break e}a=N()|0;Ab(e+8|0);break a}Ab(e+8|0);continue}}hb=e+112|0;return d|0}a=N()|0;break a}a=N()|0;break a}a=N()|0}ce(l);id(h);id(g);Q(a|0);p()}function Cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb-192|0;hb=d;Lc(b);a:{if(!yA(b,d+144|0)){break a}if(!mP(d+144|0)){break a}if(!Qb(b,jd(lP(d+144|0),lb))){break a}b:{if(!c){break b}Nd(a,256);h=d+16|0;_n(h,2,d+144|0);g=d+48|0;Ic(g,h);Db(a+1304400|0,g);xb(g);e=Ub(g,11180);Db(a+1304436|0,e);xb(e);e=Ub(g,6101);Db(a+1304448|0,e);xb(e);g=Ub(d+128|0,10977);x[114414]=0;P(187,h|0,g|0);e=x[114414];x[114414]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){x[114414]=0;P(400,d+112|0,d+175|0);e=x[114414];x[114414]=0;if((e|0)==1){break i}x[114414]=0;X(401,d+48|0,d+16|0,d+174|0,d+112|0);e=x[114414];x[114414]=0;if((e|0)==1){break h}e=d+48|0;Db(a+1304460|0,e);xb(e);xb(d+112|0);Gb(d+16|0);xb(g);x[a+1304496>>2]=4;Nb(a+1074312|0,107,1);x[a+480260>>2]=64;x[a+480264>>2]=32767;x[a+480188>>2]=2031620;f=y[d+176|0];if(y[d+175|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-D(e,10)}h=(f&255?f:96)&255;e=ZM(h);x[a+480196>>2]=h>>>4;x[a+480204>>2]=e;if(y[d+175|0]>10){break e}break d}f=N()|0;break f}f=N()|0;break g}f=N()|0;xb(d+112|0)}Gb(d+16|0)}xb(g);break c}v[d+48|0]=64;q=a,r=y[rc(d+178|0,d+48|0)|0]<<2,x[q+480200>>2]=r}f=0;while(1){e=(f<<5)+a|0;Lg(e+480280|0);w[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;j:{k:{while(1){Pt(b,d+16|0);if(y[d+28|0]!=46?y[d+28|0]:0){break k}j=hb-32|0;hb=j;i=(D(f,104)+a|0)+484380|0;Ad(i,0);k=d+16|0;Wk(j,2,k);e=j+16|0;Ic(e,j);x[114414]=0;O(335,i+43|0,e|0)|0;e=x[114414];x[114414]=0;l:{m:{if((e|0)!=1){h=j+16|0;xb(h);e=k+24|0;x[i+24>>2]=y[e|0]|y[e+1|0]<<8;v[j+16|0]=y[k+22|0];v[j|0]=64;q=i,r=y[rc(h,j)|0]<<2,w[q+30>>1]=r;e=k+16|0;x[i>>2]=y[e|0]|y[e+1|0]<<8;e=k+18|0;x[i+4>>2]=y[e|0]|y[e+1|0]<<8;e=k+20|0;g=y[e|0]|y[e+1|0]<<8;x[i+8>>2]=g;h=x[i>>2];if(h>>>0>1){break m}x[i>>2]=0;break l}a=N()|0;xb(j+16|0);Q(a|0);p()}e=x[i+4>>2];if((g|0)==65535|h>>>0<=e>>>0|e>>>0>=g>>>0){break l}w[i+34>>1]=2;q=i,r=x[Mb(i+8|0,i)>>2],x[q+8>>2]=r}hb=j+32|0;Wk(d,2,k);e=d+112|0;Ic(e,d);x[114414]=0;O(334,((f<<5)+a|0)+946304|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break j}xb(d+112|0);w[((f<<1)+d|0)+46>>1]=y[d+30|0]|y[d+31|0]<<8;f=f+1|0;if((f|0)!=32){continue}break}e=a+484360|0;oq(Vb(e),b,y[d+175|0]?128:64,65535,65535);e=Vb(e);q=d,r=bc(e),x[q+16>>2]=r;q=d,r=dc(e),x[q+112>>2]=r;if(Hb(d+16|0,d+112|0)){while(1){e=x[d+16>>2];h=z[e>>1];n:{if(!((h|0)!=255&(h|0)!=99)){w[e>>1]=65535;break n}if(h>>>0>63){break k}}e=d+16|0;ge(e);if(Hb(e,d+112|0)){continue}break}}k=c&1;if(k){cg(a+484344|0,y[d+177|0])}if(y[d+177|0]){o=a+484344|0;while(1){o:{p:{if(k){if(Tg(o,m&65535,64)){break p}}f=0;while(1){if((pe(b)+2&255)>>>0<=252){cc(b,3)}f=f+1|0;if((f|0)!=256){continue}break}break o}q=d,r=bc(Zb(o,m)),x[q+112>>2]=r;x[d>>2]=63;l=65535;n=0;while(1){f=0;while(1){h=f;g=0;f=0;i=0;j=0;q:{r:{s:{t:{u:{v:{e=pe(b);switch(e-251|0){case 1:break q;case 0:break t;case 2:break v;default:break u}}v[x[d+112>>2]]=254;break q}g=d+16|0;Fq(g,b);f=y[gc(g,0)|0];i=y[gc(g,1)|0];j=y[gc(g,2)|0];g=254;if((e|0)==254){break s}g=e;if(e>>>0>95){break r}}g=(D(g>>>4|0,12)+(g&15)|0)+37|0}e=g;v[x[d+112>>2]]=e}v[x[d+112>>2]+1|0]=(f&248)>>>3;if(y[x[d+112>>2]+1|0]>=32){v[x[d+112>>2]+1|0]=0}e=i>>>1&120|f&7;if(e>>>0<=64){v[x[d+112>>2]+2|0]=1;v[x[d+112>>2]+4|0]=e}v[x[d+112>>2]+3|0]=y[(i&15)+24e3|0];v[x[d+112>>2]+5|0]=j;w:{switch(y[x[d+112>>2]+3|0]-11|0){case 0:g=x[d+112>>2];e=y[g+5|0];if(y[x[d+112>>2]+5|0]&15){v[g+5|0]=e&15;break q}v[g+5|0]=e&240;break q;case 3:e=y[x[d+112>>2]+5|0];v[x[d+112>>2]+5|0]=D(e&240,10)|e&15;x:{if((l|0)!=65535){if(y[x[d+112>>2]+5|0]){break x}v[x[d+112>>2]+3|0]=12;v[x[d+112>>2]+5|0]=l}l=65535}xc(d,n);break q;case 1:l=y[x[d+112>>2]+5|0];x[d>>2]=63;v[x[d+112>>2]+3|0]=0;break q;case 5:if(y[d+175|0]<=20){e=y[x[d+112>>2]+5|0];v[x[d+112>>2]+5|0]=(e>>>0)%10|(e>>>0)/10<<4}if(y[x[d+112>>2]+5|0]){break q}v[x[d+112>>2]+3|0]=0;break q;case 7:break q;default:break w}}if(y[x[d+112>>2]+5|0]){break q}v[x[d+112>>2]+3|0]=0}Nj(d+112|0);f=h+1|0;if((h&65535)>>>0<3){continue}break}n=n+1|0;if((n|0)!=64){continue}break}if((l|0)==65535){break o}Ll(Zb(o,m),Zn(Ie(lo(d+16|0,12,l&255),x[d>>2])))}m=m+1|0;if(m>>>0<y[d+177|0]){continue}break}}f=1;if(!(c&2)){break a}h=ad(d+16|0,8,1,0,0);while(1){c=D(f,104)+a|0;e=c+484380|0;y:{if(!x[e>>2]|!z[c+484410>>1]){break y}c=z[((f<<1)+d|0)+46>>1];if(c>>>0<4){break y}if(!Rc(b,c<<4)){break y}Eg(h,e,b)}f=f+1|0;if((f|0)!=32){continue}break}break b}f=0;break a}f=N()|0;xb(d+112|0)}Q(f|0);p()}f=1}hb=d+192|0;return f|0}function bU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=hb-3040|0;hb=g;Lc(b);f=hb-16|0;hb=f;i=f+8|0;j=g+1080|0;ZA(i,j);h=Eb(i);i=nc(b,ac(f,i));if((h|0)==(i|0)){cc(b,Eb(f+8|0))}hb=f+16|0;f=(h|0)==(i|0);if(!f){_A(j)}a:{if(!f){break a}if(!cB(g+1080|0)){break a}if(!c){e=1;break a}if(!Qb(b,jd(1024,0))){break a}bB(b,g+560|0);bB(b,g+48|0);while(1){f=d<<2;i=f+(g+560|0)|0;if((y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24))>>>0>16777215){break a}f=f+(g+48|0)|0;l=y[f+1|0]<<8;m=y[f+2|0]<<16|y[f+3|0]<<24;if((y[f|0]|l|m)>>>0<3|(m|(l|y[f|0]))>>>0>4096){break a}if(!aB(b,((y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24))+(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24))|0)+2978|0)){break a}d=d+1|0;if((d|0)!=128){continue}break}Nd(a,2);Gi(a);d=g+16|0;e=Ub(d,9640);Db(a+1304436|0,e);xb(e);e=Ub(d,10297);Db(a+1304448|0,e);xb(e);d=Ub(d,11581);Db(a+1304460|0,d);xb(d);x[a+1304496>>2]=4;d=y[g+1080|0];x[a+480204>>2]=143e4;x[a+480196>>2]=d;j=a+484360|0;Se(Vb(j),y[g+1081|0]);x[a+480188>>2]=4194317;Nb(a+1074312|0,95,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=0;e=0;while(1){w[((e<<5)+a|0)+480284>>1]=e&1?192:64;e=e+1|0;if((e|0)!=4){continue}break}b:{c:{d:{e:{while(1){e=d+1|0;f=D(e,104)+a|0;i=f+484380|0;Ad(i,2);h=g+32|0;zh(h,1,(D(d,13)+g|0)+1082|0);k=g+16|0;Ic(k,h);x[114414]=0;O(334,((e<<5)+a|0)+946304|0,k|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break e}xb(g+16|0);h=i;d=(g+1080|0)+(d<<4)|0;i=d+422|0;x[h>>2]=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);if((y[d+430|0]|y[d+431|0]<<8|(y[d+432|0]<<16|y[d+433|0]<<24))>>>0<=(y[d+422|0]|y[d+423|0]<<8|(y[d+424|0]<<16|y[d+425|0]<<24))>>>0){x[f+484384>>2]=y[d+426|0]|y[d+427|0]<<8|(y[d+428|0]<<16|y[d+429|0]<<24);d=y[d+430|0]|y[d+431|0]<<8|(y[d+432|0]<<16|y[d+433|0]<<24);w[f+484414>>1]=2;x[f+484388>>2]=d}x[f+484404>>2]=8287;d=e;if((d|0)!=32){continue}break}d=0;while(1){e=d+33|0;i=(D(e,104)+a|0)+484380|0;Ad(i,2);f=g+32|0;zh(f,1,(D(d,13)+g|0)+2010|0);h=g+16|0;Ic(h,f);x[114414]=0;O(334,((e<<5)+a|0)+946304|0,h|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break d}e=g+16|0;xb(e);x[g+24>>2]=0;x[g+16>>2]=0;x[g+20>>2]=0;f=(g+1080|0)+D(d,11)|0;h=y[f+1347|0];n=gc(e,0),o=h,v[n|0]=o;h=y[f+1352|0];n=gc(e,1),o=h,v[n|0]=o;h=y[f+1348|0];n=gc(e,2),o=h,v[n|0]=o;h=y[f+1353|0];n=gc(e,3),o=h,v[n|0]=o;h=y[f+1349|0];n=gc(e,4),o=h,v[n|0]=o;h=y[f+1354|0];n=gc(e,5),o=h,v[n|0]=o;h=y[f+1350|0];n=gc(e,6),o=h,v[n|0]=o;h=y[f+1355|0];n=gc(e,7),o=h,v[n|0]=o;h=y[f+1351|0];n=gc(e,8),o=h,v[n|0]=o;h=y[f+1356|0];n=gc(e,9),o=h,v[n|0]=o;f=y[f+1346|0];n=gc(e,10),o=f,v[n|0]=o;x[g+8>>2]=x[g+24>>2];e=x[g+20>>2];x[g>>2]=x[g+16>>2];x[g+4>>2]=e;Tp(i,1,g);d=d+1|0;if((d|0)!=32){continue}break}Dq(Vb(j),g+2778|0,256,255,65535);h=a+484344|0;cg(h,128);m=c&1;f=0;f:{while(1){e=f<<2;d=e+(g+560|0)|0;Rc(b,(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))+2978|0);d=e+(g+48|0)|0;Bd(g+16|0,b,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));g:{if(!m){break g}x[114414]=0;d=U(363,h|0,f&65535,64)|0;e=x[114414];x[114414]=0;if((e|0)==1){break c}if(!d){break g}d=0;i=Zb(h,f);while(1){x[114414]=0;e=O(226,g+16|0,1)|0;j=x[114414];x[114414]=0;h:{i:{if((j|0)!=1){if(!e){break g}x[114414]=0;e=R(403,g+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break c}if(e>>>0>12){break i}x[114414]=0;j=U(427,i|0,d|0,e|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break c}x[114414]=0;P(428,g+32|0,g+16|0);k=x[114414];x[114414]=0;if((k|0)==1){break c}k=ed(g+32|0);l=y[g+32|0];e=e>>>0>3;v[j|0]=((l&15)+(e?13:37)|0)+D(l>>>4&7,12);v[j+1|0]=((y[k|0]>>>4|0)+(e?33:1)|0)+(y[g+32|0]>>>3&16);$A(j,y[k|0],e);break h}break c}j=e-32|0;if((j&255)>>>0<=12){x[114414]=0;j=U(427,i|0,d|0,j&65535)|0;k=x[114414];x[114414]=0;if((k|0)==1){break c}x[114414]=0;k=R(403,g+16|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break c}$A(j,k,e>>>0>35);break h}if((e|0)!=64){if((e|0)!=96){break f}if(!d){break g}x[114414]=0;d=U(427,i|0,d-1|0,0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break c}v[d+3|0]=14;break g}x[114414]=0;e=R(403,g+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break c}d=d+e|0}if(d>>>0<64){continue}break}}Ab(g+16|0);f=f+1|0;if((f|0)!=128){continue}break}e=1;if(!(c&2)){break a}d=1;while(1){Eg(ad(g+16|0,8,1,0,1),(D(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=33){continue}break}break a}Ab(g+16|0);e=0;break a}e=N()|0;xb(g+16|0);break b}e=N()|0;xb(g+16|0);break b}e=N()|0;Ab(g+16|0)}Q(e|0);p()}hb=g+3040|0;return e|0}function yd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;k=hb-96|0;hb=k;u=i&65535;o=(e^i)&-2147483648;q=e&65535;A=q;R=i>>>16&32767;S=e>>>16&32767;a:{b:{if(R-32767>>>0>4294934529&S-32767>>>0>=4294934530){break b}s=e&2147483647;r=s;j=d;if(!(!d&(r|0)==2147418112?!(b|c):r>>>0<2147418112)){m=d;o=e|32768;break a}s=i&2147483647;p=s;e=h;if(!(!e&(p|0)==2147418112?!(f|g):p>>>0<2147418112)){m=h;o=i|32768;b=f;c=g;break a}if(!(b|j|(r^2147418112|c))){if(!(e|f|(g|p))){o=2147450880;b=0;c=0;break a}o=o|2147418112;b=0;c=0;break a}if(!(e|f|(p^2147418112|g))){e=b|j;d=c|r;b=0;c=0;if(!(d|e)){o=2147450880;break a}o=o|2147418112;break a}if(!(b|j|(c|r))){b=0;c=0;break a}if(!(e|f|(g|p))){b=0;c=0;break a}if((r|0)==65535|r>>>0<65535){j=!(d|q);i=j?b:d;s=j<<6;e=G(i)+32|0;i=G(j?c:q);i=s+((i|0)==32?e:i)|0;gf(k+80|0,b,c,d,q,i-15|0);t=16-i|0;d=x[k+88>>2];A=x[k+92>>2];c=x[k+84>>2];b=x[k+80>>2]}if(p>>>0>65535){break b}i=!(h|u);e=i?f:h;q=i<<6;j=G(e)+32|0;e=G(i?g:u);e=q+((e|0)==32?j:e)|0;gf(k- -64|0,f,g,h,u,e-15|0);t=(t-e|0)+16|0;h=x[k+72>>2];u=x[k+76>>2];f=x[k+64>>2];g=x[k+68>>2]}e=f;f=g<<15|f>>>17;i=e<<15;e=0;v=i&-32768;L=c;s=yna(v,e,c,0);e=lb;z=e;M=f;r=b;b=yna(f,0,b,0);i=b+s|0;f=lb+e|0;c=b>>>0>i>>>0?f+1|0:f;j=0;b=yna(r,l,v,l);p=j+b|0;f=i;e=f+lb|0;e=b>>>0>p>>>0?e+1|0:e;q=e;N=(f|0)==(e|0)&j>>>0>p>>>0|e>>>0<f>>>0;O=d;w=yna(v,l,d,0);P=lb;b=yna(L,l,M,l);y=b+w|0;j=lb+P|0;j=b>>>0>y>>>0?j+1|0:j;b=u<<15|h>>>17;B=h<<15|g>>>17;d=yna(B,0,r,l);C=d+y|0;f=lb+j|0;f=d>>>0>C>>>0?f+1|0:f;D=f;d=(c|0)==(z|0)&i>>>0<s>>>0|c>>>0<z>>>0;E=c+C|0;f=d+f|0;f=c>>>0>E>>>0?f+1|0:f;u=f;g=E;c=f;F=A|65536;A=yna(v,l,F,n);Q=lb;d=yna(O,m,M,l);H=d+A|0;e=lb+Q|0;e=d>>>0>H>>>0?e+1|0:e;i=e;I=b|-2147483648;b=yna(I,0,r,l);J=b+H|0;f=lb+e|0;f=b>>>0>J>>>0?f+1|0:f;b=yna(B,m,L,l);z=b+J|0;K=f;f=f+lb|0;s=b>>>0>z>>>0?f+1|0:f;b=0;r=b+g|0;e=c+z|0;v=b>>>0>r>>>0?e+1|0:e;f=v;b=r+N|0;c=b>>>0<r>>>0?f+1|0:f;t=((S+R|0)+t|0)-16383|0;d=yna(I,m,L,l);h=lb;e=yna(F,m,M,l);g=e+d|0;f=lb+h|0;f=e>>>0>g>>>0?f+1|0:f;n=(h|0)==(f|0)&d>>>0>g>>>0|f>>>0<h>>>0;h=f;e=yna(B,m,O,m);d=e+g|0;f=lb+f|0;f=d>>>0<e>>>0?f+1|0:f;e=f;g=(f|0)==(h|0)&d>>>0<g>>>0|f>>>0<h>>>0;f=0;h=g;g=g+n|0;f=h>>>0>g>>>0?1:f;h=g;g=yna(I,m,F,m);h=h+g|0;f=lb+f|0;N=h;g=g>>>0>h>>>0?f+1|0:f;h=d;l=e;e=(j|0)==(P|0)&w>>>0>y>>>0|j>>>0<P>>>0;f=0;j=(j|0)==(D|0)&y>>>0>C>>>0|j>>>0>D>>>0;n=j;j=e+j|0;e=(n>>>0>j>>>0?1:f)+l|0;f=g;d=d+j|0;e=d>>>0<j>>>0?e+1|0:e;n=e;w=d;d=(e|0)==(l|0)&d>>>0<h>>>0|e>>>0<l>>>0;e=d;d=d+N|0;f=e>>>0>d>>>0?f+1|0:f;j=d;g=f;e=yna(B,m,F,m);l=lb;d=yna(I,m,O,m);h=d+e|0;f=lb+l|0;f=d>>>0>h>>>0?f+1|0:f;d=f;f=(l|0)==(f|0)&e>>>0>h>>>0|f>>>0<l>>>0;y=d+j|0;e=f+g|0;e=d>>>0>y>>>0?e+1|0:e;l=y;g=e;e=0;d=e+w|0;f=h+n|0;f=d>>>0<e>>>0?f+1|0:f;e=f;h=(n|0)==(f|0)&d>>>0<w>>>0|f>>>0<n>>>0;f=g;g=h+l|0;f=g>>>0<h>>>0?f+1|0:f;w=g;g=f;h=d;j=e;e=(s|0)==(K|0)&z>>>0<J>>>0|s>>>0<K>>>0;d=(i|0)==(Q|0)&A>>>0>H>>>0|i>>>0<Q>>>0;i=(i|0)==(K|0)&H>>>0>J>>>0|i>>>0>K>>>0;d=d+i|0;d=d+e|0;n=s;i=n+h|0;e=d+j|0;f=g;d=i;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(j|0)&h>>>0>d>>>0|e>>>0<j>>>0;g=h+w|0;f=h>>>0>g>>>0?f+1|0:f;j=g;g=f;h=d;f=0;i=e;n=(u|0)==(v|0)&r>>>0<E>>>0|u>>>0>v>>>0;l=n;n=n+((u|0)==(D|0)&C>>>0>E>>>0|u>>>0<D>>>0)|0;e=e+(l>>>0>n>>>0?1:f)|0;f=g;d=d+n|0;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(i|0)&d>>>0<h>>>0|e>>>0<i>>>0;g=h;h=h+j|0;f=g>>>0>h>>>0?f+1|0:f;i=f;c:{if(f&65536){t=t+1|0;break c}j=q>>>31|0;g=0;f=i<<1|h>>>31;h=h<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;f=q<<1|p>>>31;p=p<<1;q=f;f=c<<1|b>>>31;b=b<<1|j;c=f|g}if((t|0)>=32767){o=o|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){g=1-t|0;if(g>>>0<=127){f=t+127|0;gf(k+48|0,p,q,b,c,f);gf(k+32|0,d,e,h,i,f);Al(k+16|0,p,q,b,c,g);Al(k,d,e,h,i,g);p=x[k+32>>2]|x[k+16>>2]|(x[k+48>>2]|x[k+56>>2]|(x[k+52>>2]|x[k+60>>2]))!=0;q=x[k+36>>2]|x[k+20>>2];b=x[k+40>>2]|x[k+24>>2];c=x[k+44>>2]|x[k+28>>2];d=x[k>>2];e=x[k+4>>2];g=x[k+8>>2];f=x[k+12>>2];break d}b=0;c=0;break a}g=h;f=i&65535|t<<16}m=g|m;o=f|o;if(!(!b&(c|0)==-2147483648?!(p|q):(c|0)>0|(c|0)>=0)){b=d+1|0;c=b?e:e+1|0;d=(e|0)==(c|0)&b>>>0<d>>>0|c>>>0<e>>>0;e=o;m=d+m|0;o=m>>>0<d>>>0?e+1|0:e;break a}if(b|p|(c^-2147483648|q)){b=d;c=e;break a}j=o;f=e;b=d&1;c=b;b=b+d|0;f=c>>>0>b>>>0?f+1|0:f;c=f;d=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;m=d+m|0;o=d>>>0>m>>>0?j+1|0:j}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=m;x[a+12>>2]=o;hb=k+96|0}function Rga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb+-64|0;hb=f;a:{b:{if(Qb(c,8)){cc(c,4);while(1){if(iA(c)){break b}m=hb-288|0;hb=m;e=SN(m);g=hb-368|0;hb=g;h=sc(e,SN(g+80|0),282);e=0;if(yh(c,9488)){ng(c,4);i=df(g- -64|0,c);x[114414]=0;j=O(1195,i|0,h|0)|0;k=x[114414];x[114414]=0;c:{d:{e:{f:{if((k|0)==1){break f}if(!j){break c}j=y[h+26|0];x[114414]=0;j=O(226,i|0,j|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break f}if(!j){break c}if(!y[h+26|0]){j=0;break e}j=0;while(1){g:{x[114414]=0;k=R(340,i|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break g}v[(e+h|0)+27|0]=k;j=j+k|0;e=e+1|0;if(e>>>0<y[h+26|0]){continue}break e}break}e=N()|0;break d}e=N()|0;break d}e=0;x[114414]=0;k=j&65535;j=O(226,i|0,k|0)|0;l=x[114414];x[114414]=0;h:{if((l|0)==1){break h}if(!j){break c}x[114414]=0;O(304,i|0,k|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break h}ng(i,TN(h));x[114414]=0;j=R(1196,g+56|0)|0;e=x[114414];x[114414]=0;i:{if((e|0)!=1){e=g+80|0;RN(e);x[114414]=0;O(1197,i|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break i}x[114414]=0;w[g+102>>1]=0;w[g+104>>1]=0;U(1198,j|0,g+80|0,g+107|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break i}e=y[h+26|0];x[114414]=0;O(304,i|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break i}e=y[h+26|0];x[114414]=0;l=h+27|0;U(1198,j|0,l|0,e+l|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break i}x[114414]=0;T(307,g+40|0,i|0,k|0);e=x[114414];x[114414]=0;j:{k:{l:{if((e|0)!=1){x[114414]=0;P(838,g+16|0,g+40|0);e=x[114414];x[114414]=0;if((e|0)==1){break l}x[114414]=0;P(1200,g+8|0,g+16|0);e=x[114414];x[114414]=0;if((e|0)==1){break k}x[114414]=0;O(1201,j|0,g+8|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break k}Hc(g+16|0);Ab(g+40|0);e=0;x[114414]=0;j=R(1202,j|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break i}if((j|0)!=(y[h+22|0]|y[h+23|0]<<8|(y[h+24|0]<<16|y[h+25|0]<<24))){break c}e=TN(h);x[114414]=0;O(304,c|0,e|0)|0;h=x[114414];x[114414]=0;e=1;if((h|0)!=1){break c}break h}e=N()|0;break d}e=N()|0;break j}e=N()|0;Hc(g+16|0)}Ab(g+40|0);break d}e=N()|0;break d}e=N()|0;break d}e=N()|0}Ab(i);Q(e|0);p()}Ab(i)}hb=g+368|0;hb=m+288|0;if(e){continue}break}}Lc(c);Eg(b,a,c);a=1;break a}v[d|0]=1;Lc(c);d=Gf(c);e=f+48|0;Bd(e,c,uf(c));w[a+34>>1]=z[a+34>>1]&65534|y[b|0]>15;b=y[b+1|0]!=1;c=z[a+34>>1]&-65|b<<6;w[a+34>>1]=c;x[a>>2]=d>>>(c&1)>>>b;x[114414]=0;x[f+44>>2]=0;x[f+40>>2]=0;P(838,f+16|0,e|0);b=x[114414];x[114414]=0;m:{n:{o:{p:{if((b|0)!=1){x[114414]=0;b=R(421,f+16|0)|0;c=x[114414];x[114414]=0;q:{if((c|0)!=1){c=x[f+16>>2];x[114414]=0;d=R(835,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break q}x[114414]=0;e=R(836,c|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break q}x[114414]=0;d=aa(837,d|0,e|0,f+44|0,f+40|0,0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break q}x[114414]=0;O(304,f+48|0,x[f+44>>2])|0;e=x[114414];x[114414]=0;if((e|0)==1){break q}if(!d){break m}e=x[f+44>>2];x[114414]=0;R(416,a|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break q}g=c-e|0;e=b+e|0;c=x[f+40>>2];b=0;while(1){r:{if(c){if(!g|(c|0)!=1){break p}if(A[a>>2]>b>>>0){break r}break p}if(A[a>>2]<=b>>>0){break p}}if(!Be(a)){break p}x[114414]=0;x[f+12>>2]=0;x[f+8>>2]=0;c=R(835,e|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break o}x[114414]=0;h=R(836,g|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break o}x[114414]=0;c=ga(839,d|0,c|0,h|0,f+12|0,f+4|0,f+8|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break o}x[114414]=0;x[f+44>>2]=c;O(304,f+48|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break o}c=x[a>>2];x[114414]=0;h=x[f+44>>2];c=R(840,c-b|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break o}Ch(f+8|0,c);s:{if(x[f+8>>2]<=0){break s}if(x[f+12>>2]!=(Je(a)|0)){break s}c=0;if(x[f+12>>2]<=0){break s}while(1){i=x[a+20>>2];n=z[a+34>>1];j=D(Je(a),b);m=x[x[f+4>>2]+(c<<2)>>2];k=x[f+8>>2];l=x[f+12>>2];t:{if(n&1){x[114414]=0;ba(841,i+(j<<1)|0,m|0,l|0,k|0,c|0);i=x[114414];x[114414]=0;if((i|0)!=1){break t}break o}x[114414]=0;ba(842,i+j|0,m|0,l|0,k|0,c|0);i=x[114414];x[114414]=0;if((i|0)==1){break o}}c=c+1|0;if((c|0)<x[f+12>>2]){continue}break}}x[114414]=0;i=x[f+8>>2];c=R(843,d|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break o}g=g-h|0;e=e+h|0;x[f+40>>2]=c;b=b+i|0;continue}}break o}break o}c=N()|0;break n}x[114414]=0;W(844,d|0);a=x[114414];x[114414]=0;if((a|0)!=1){break m}}c=N()|0;Hc(f+16|0)}Ab(f+48|0);Q(c|0);p()}Hc(f+16|0);Ab(f+48|0);a=(d|0)!=0}hb=f- -64|0;return a|0}function Ada(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;g=hb-112|0;hb=g;Lc(c);a:{b:{if(!Qb(c,4)){break b}c:{while(1){d:{d=g+88|0;h=hb-16|0;hb=h;e:{if(Qb(c,3)){f=h+8|0;Tu(f,d);Dd(c,f);break e}i=hb-16|0;hb=i;f=0;j=hb-16|0;hb=j;while(1){mf(d+f|0);f=f+1|0;if((f|0)!=3){continue}break}hb=j+16|0;hb=i+16|0}hb=h+16|0;f:{if(!cd(d,10549,3)){d=g+40|0;h=hb-16|0;hb=h;g:{if(Qb(c,7)){f=h+8|0;Eu(f,d);Dd(c,f);break g}i=hb-16|0;hb=i;f=0;j=hb-16|0;hb=j;while(1){mf(d+f|0);f=f+1|0;if((f|0)!=7){continue}break}hb=j+16|0;hb=i+16|0}hb=h+16|0;h=3;d=0;while(1){f=v[(g+40|0)+h|0];if((f|0)<0){break c}d=f&255|d<<7;h=h+1|0;if((h|0)!=7){continue}break}cc(c,d);break f}h:{if(cd(g+88|0,9929,3)){break h}if(!RQ(c,9398)){break h}cc(c,Gf(c)+16|0);break f}if(!cd(g+88|0,25740,3)){break f}if(!cd(g+88|0,25744,3)){break f}if(y[g+88|0]){break d}ng(c,2)}if(Qb(c,4)){continue}break b}break}if(KO(g+88|0)){break b}}h=0;break a}Lc(c);d=g+88|0;qA(d,c);j=x[d>>2];x[114414]=0;c=R(421,d|0)|0;d=x[114414];x[114414]=0;i:{j:{k:{l:{if((d|0)!=1){x[114414]=0;c=R(835,c|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break l}}c=N()|0;break k}f=hb-16|0;hb=f;d=g+72|0;x[d>>2]=0;x[d+4>>2]=0;x[114414]=0;x[f+12>>2]=0;U(320,d+8|0,f+12|0,f+8|0)|0;h=x[114414];x[114414]=0;m:{if((h|0)!=1){hb=f+16|0;break m}S(0)|0;zb();p()}l=d;x[114414]=0;d=$(1233)|0;f=x[114414];x[114414]=0;n:{o:{p:{q:{r:{if((f|0)!=1){x[g+64>>2]=d;Sb(x[g- -64>>2],0,6668);d=x[g- -64>>2];x[114414]=0;W(1234,d|0);d=x[114414];x[114414]=0;if((d|0)!=1){x[g+56>>2]=0;x[g+60>>2]=0;x[g+48>>2]=0;x[g+52>>2]=0;x[114414]=0;x[g+40>>2]=0;x[g+44>>2]=0;n=O(1235,g+24|0,2304)|0;d=x[114414];x[114414]=0;if((d|0)!=1){f=0;d=0;while(1){s:{h=x[g- -64>>2];x[114414]=0;i=_f(410,j,m);k=x[114414];x[114414]=0;if((k|0)==1){break s}k=x[n>>2];x[114414]=0;o=aa(1236,h|0,c|0,i|0,k|0,g+40|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break s}if((o|0)<0){break q}h=x[g+40>>2];if((h|0)<0|!h){break q}i=x[g+52>>2];if((i|0)!=(f|0)?f:0){break q}h=x[g+48>>2];if((h|0)!=(d|0)?d:0){break q}if(h-3>>>0<4294967294|(i|0)<=0){break r}x[114414]=0;x[g>>2]=0;d=_f(410,j,m);f=x[114414];x[114414]=0;t:{u:{v:{if((f|0)==1){break v}x[114414]=0;x[g+20>>2]=d;d=U(1237,g+40|0,g|0,g+20|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break v}d=x[d>>2];x[114414]=0;x[g>>2]=0;f=_f(410,j,m);k=x[114414];x[114414]=0;if((k|0)==1){break u}x[114414]=0;x[g+20>>2]=f;f=U(1237,g+40|0,g|0,g+20|0)|0;k=x[114414];x[114414]=0;if((k|0)==1){break u}k=x[f>>2];q=k>>31;if(!o){break t}t=g,u=dc(l),x[t>>2]=u;f=td(g+16|0,g);r=x[n>>2];s=x[n>>2];f=x[f>>2];x[114414]=0;Z(1238,l|0,f|0,r|0,(D(h,o)<<1)+s|0)|0;f=x[114414];x[114414]=0;if((f|0)!=1){break t}c=S(75016)|0;if((ib|0)!=(ca(75016)|0)){break p}Y(c|0)|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;d=h;f=i;if((c|0)!=1){break q}c=N()|0;break p}c=N()|0;break p}c=N()|0;break p}if((qc(l)>>>0)/(h>>>0)>>>0>268435456){break r}c=c+d|0;f=i;d=h;m=m-(q+(j>>>0<k>>>0)|0)|0;j=j-k|0;if(!!j&(m|0)>=0|(m|0)>0){continue}break q}break}c=N()|0;break p}c=N()|0;break o}c=N()|0;break o}c=N()|0;break n}d=h;f=i}h=0;if(!f|!d){break i}if(od(l)){break i}if((qc(l)>>>0)/(d>>>0)>>>0>268435456){break i}x[114414]=0;O(1239,a|0,b|0)|0;c=x[114414];x[114414]=0;w:{x:{if((c|0)==1){break x}y:{z:{A:{if(!e){x[114414]=0;h=O(118,g|0,17386)|0;c=x[114414];x[114414]=0;if((c|0)==1){break A}x[114414]=0;O(334,((b<<5)+a|0)+946304|0,h|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break z}xb(h);x[114414]=0;c=D(b,104)+a|0;P(448,c+484380|0,0);h=x[114414];x[114414]=0;if((h|0)==1){break x}x[c+484404>>2]=f}f=D(b,104)+a|0;c=f+484380|0;t=c,u=(qc(l)>>>0)/(d>>>0)|0,x[t>>2]=u;h=f+484414|0;f=z[h>>1];w[h>>1]=(d|0)==2?f|65:f&65470|1;x[114414]=0;R(416,c|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break x}if(Be(c)){d=bc(l);f=dc(l);b=x[(D(b,104)+a|0)+484400>>2];x[114414]=0;U(1240,d|0,f|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break x}}if(!e){break y}break j}c=N()|0;break p}c=N()|0;xb(h);break p}b=x[a+480180>>2];x[114414]=0;T(1241,c|0,32,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break w}x[114414]=0;T(1242,c|0,a|0,0);a=x[114414];x[114414]=0;if((a|0)!=1){break j}}c=N()|0;break p}c=N()|0}Pq(n)}dg(g- -64|0)}Pq(l)}Hc(g+88|0);Q(c|0);p()}h=Be(c)}Pq(n);dg(g- -64|0);Pq(l);Hc(g+88|0)}hb=g+112|0;return h|0}function D9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0),i=0,j=0,k=0;d=hb-320|0;hb=d;e=-1;a:{b:{c:{if(!gu(x[x[b>>2]-12>>2]+b|0)){b=pl(d+216|0,b);x[114414]=0;e=O(658,d+200|0,9753)|0;g=x[114414];x[114414]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((g|0)!=1){x[114414]=0;x[d+184>>2]=83886084;x[d+188>>2]=0;T(659,b|0,e|0,d+184|0);g=x[114414];x[114414]=0;if((g|0)==1){break F}Gb(e);x[114414]=0;v[d+199|0]=0;e=O(658,d+184|0,10280)|0;g=x[114414];x[114414]=0;if((g|0)==1){break E}x[114414]=0;U(660,b|0,d+199|0,e|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break D}Gb(e);x[114414]=0;g=y[d+199|0];e=O(658,d+168|0,11801)|0;f=x[114414];x[114414]=0;if((f|0)==1){break C}x[114414]=0;g=g?0:c;X(1633,b|0,a+40|0,e|0,g|0);c=x[114414];x[114414]=0;if((c|0)==1){break B}Gb(e);x[114414]=0;w[d+166>>1]=65535;c=O(658,d+152|0,11563)|0;e=x[114414];x[114414]=0;if((e|0)==1){break A}x[114414]=0;U(1170,b|0,d+166|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break z}Gb(c);x[114414]=0;w[d+150>>1]=0;c=O(658,d+136|0,11195)|0;e=x[114414];x[114414]=0;if((e|0)==1){break y}x[114414]=0;U(1170,b|0,d+150|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break x}Gb(c);w[a>>1]=z[d+150>>1];x[114414]=0;c=O(658,d+120|0,10634)|0;e=x[114414];x[114414]=0;if((e|0)==1){break w}x[114414]=0;X(1634,b|0,a+52|0,c|0,g|0);e=x[114414];x[114414]=0;if((e|0)==1){break v}Gb(c);x[114414]=0;c=O(658,d+104|0,10520)|0;e=x[114414];x[114414]=0;if((e|0)==1){break u}x[114414]=0;U(1586,b|0,a+36|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break t}Gb(c);x[114414]=0;e=O(658,d+88|0,11565)|0;c=x[114414];x[114414]=0;if((c|0)==1){break s}x[114414]=0;c=a+4|0;Z(1635,b|0,c|0,e|0,1636)|0;g=x[114414];x[114414]=0;if((g|0)==1){break r}Gb(e);x[114414]=0;e=O(658,d+72|0,11197)|0;g=x[114414];x[114414]=0;if((g|0)==1){break q}x[114414]=0;g=a+28|0;U(1637,b|0,g|0,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break p}Gb(e);x[114414]=0;e=O(658,d+56|0,10735)|0;f=x[114414];x[114414]=0;if((f|0)==1){break o}x[114414]=0;U(1637,b|0,a+30|0,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break n}Gb(e);x[114414]=0;e=O(658,d+40|0,10544)|0;f=x[114414];x[114414]=0;if((f|0)==1){break m}x[114414]=0;U(1638,b|0,a+32|0,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break l}Gb(e);x[114414]=0;w[d+38>>1]=0;e=O(658,d+24|0,10481)|0;f=x[114414];x[114414]=0;if((f|0)==1){break c}x[114414]=0;U(1170,b|0,d+38|0,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break k}Gb(e);h=B[a+32>>2];x[114414]=0;h=E(db(1639,E(h)));e=x[114414];x[114414]=0;if((e|0)==1){break b}B[a+32>>2]=h;e=-1;j=d,k=bc(c),x[j+16>>2]=k;j=d,k=dc(c),x[j+8>>2]=k;if(Hb(d+16|0,d+8|0)){while(1){f=d+16|0;fe(f);if(Hb(f,d+8|0)){continue}break}}if(x[b>>2]&1073741824|(z[g>>1]+300&65535)>>>0>600){break d}f=z[a>>1];if(f>>>0>3|(f|0)==2|w[a+30>>1]<0){break d}f=x[a+36>>2];x[114414]=0;f=R(840,f|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break j}x[114414]=0;x[d+16>>2]=f;x[d+8>>2]=0;f=U(1237,d+16|0,d+8|0,35976)|0;i=x[114414];x[114414]=0;if((i|0)==1){break i}x[a+36>>2]=x[f>>2];if(Lb(c)>>>0>32767){break d}switch(z[a>>1]-1|0){case 0:break g;case 2:break h;default:break f}}a=N()|0;break a}a=N()|0;Gb(e);break a}a=N()|0;break a}a=N()|0;Gb(e);break a}a=N()|0;break a}a=N()|0;Gb(e);break a}a=N()|0;break a}a=N()|0;Gb(c);break a}a=N()|0;break a}a=N()|0;Gb(c);break a}a=N()|0;break a}a=N()|0;Gb(c);break a}a=N()|0;break a}a=N()|0;Gb(c);break a}a=N()|0;break a}a=N()|0;Gb(e);break a}a=N()|0;break a}a=N()|0;Gb(e);break a}a=N()|0;break a}a=N()|0;Gb(e);break a}a=N()|0;break a}a=N()|0;Gb(e);break a}a=N()|0;Gb(e);break a}a=N()|0;break a}a=N()|0;break a}if(w[d+38>>1]<=0){break d}w[d+6>>1]=z[a+30>>1];B[d+16>>2]=B[a+32>>2];c=z[a+28>>1];x[114414]=0;w[d+8>>1]=c;w[d+10>>1]=(c+z[d+38>>1]|0)-1;a=Z(1640,a|0,d+6|0,d+16|0,d+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){if(a){break e}break d}a=N()|0;break a}if(w[d+38>>1]<=0){break d}B[d+16>>2]=B[a+32>>2];f=z[a+28>>1];x[114414]=0;w[d+8>>1]=f;w[d+10>>1]=(f+z[d+38>>1]|0)-1;a=aa(1641,a|0,c|0,d+16|0,d+8|0,g|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){if(a){break e}break d}a=N()|0;break a}x[114414]=0;W(1642,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}}e=1}Hg(b)}hb=d+320|0;return e|0}a=N()|0;break a}a=N()|0}Hg(b);Q(a|0);p()}function w9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0);d=hb-128|0;hb=d;h=-1;a:{b:{c:{d:{if(!Jf(x[x[b>>2]-12>>2]+b|0)){break d}vf(d+112|0,b);e=x[d+120>>2];f=x[d+124>>2];i=d+104|0;um(i);mk(b,i,8);if((y[d+104|0]|y[d+105|0]<<8|(y[d+106|0]<<16|y[d+107|0]<<24))!=1414681667|(y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24))!=776101705){a=Ug(d+88|0,e,f);c=x[a+12>>2];x[d+16>>2]=x[a+8>>2];x[d+20>>2]=c;c=x[a+4>>2];x[d+8>>2]=x[a>>2];x[d+12>>2]=c;lj(b,d+8|0);break d}w[d+86>>1]=0;zf(b,d+86|0);if((z[d+86>>1]-4&65535)>>>0<65534){break d}e=d+78|0;um(e);mk(b,e,8);if((y[d+78|0]|y[d+79|0]<<8|(y[d+80|0]<<16|y[d+81|0]<<24))!=1933333571|(y[d+82|0]|y[d+83|0]<<8|(y[d+84|0]<<16|y[d+85|0]<<24))!=1111389030){break d}w[d+76>>1]=0;zf(b,d+76|0);e=z[d+76>>1];if((e-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{k:{if(e>>>0<=3){e=Wb(d+112|0);x[114414]=0;f=U(696,b|0,e|0,65535)|0;i=x[114414];x[114414]=0;if((i|0)==1){break b}if(!f){break j}x[114414]=0;T(13,d- -64|0,c|0,e|0);f=x[114414];x[114414]=0;if((f|0)!=1){break k}break b}e=Wb(d+112|0);x[114414]=0;f=U(698,b|0,e|0,255)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}if(!f){break i}x[114414]=0;T(13,d- -64|0,c|0,e|0);f=x[114414];x[114414]=0;if((f|0)==1){break c}}f=d- -64|0;Db(a+40|0,f);xb(f);xb(e);w[d+62>>1]=0;zf(b,d+62|0);w[d+60>>1]=0;zf(b,d+60|0);w[a>>1]=z[d+60>>1];w[d+58>>1]=0;l:{if(w[d+76>>1]<=3){x[d+112>>2]=0;Ri(b,d+112|0);e=x[d+112>>2];if(e>>>0>65535){break d}e=HA(e);w[d+58>>1]=e;break l}zf(b,d+58|0);e=z[d+58>>1]}m:{n:{o:{p:{if(e&65535){i=a+52|0;f=0;while(1){e=Wb(d+112|0);x[114414]=0;w[d+40>>1]=0;O(1645,b|0,d+40|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break g}q:{if(w[d+76>>1]<=3){x[114414]=0;g=U(696,b|0,e|0,65535)|0;j=x[114414];x[114414]=0;if((j|0)==1){break g}if(g){break q}break e}x[114414]=0;g=U(698,b|0,e|0,255)|0;j=x[114414];x[114414]=0;if((j|0)==1){break g}if(!g){break e}}x[114414]=0;T(13,d- -64|0,c|0,e|0);g=x[114414];x[114414]=0;if((g|0)==1){break p}x[114414]=0;g=O(1646,i|0,d+40|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break o}j=g;g=d- -64|0;Db(j,g);xb(g);xb(e);f=f+1|0;if(z[d+58>>1]>(f&65535)>>>0){continue}break}}c=d- -64|0;um(c);mk(b,c,8);if((y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24))!=1933333571|(y[d+68|0]|y[d+69|0]<<8|(y[d+70|0]<<16|y[d+71|0]<<24))!=1161720678){break d}c=z[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;if(w[d+86>>1]>2){break n}if(yK(b,c)){break m}break d}b=N()|0;break f}b=N()|0;xb(d- -64|0);break f}if(!xK(b,c)){break d}}c=a+4|0;k=d,l=bc(c),x[k+112>>2]=l;k=d,l=dc(c),x[k+40>>2]=l;if(Hb(d+112|0,d+40|0)){while(1){e=d+112|0;fe(e);if(Hb(e,d+40|0)){continue}break}}e=a+16|0;r:{if(w[d+86>>1]<=2){if(yK(b,e)){break r}break d}if(!xK(b,e)){break d}}e=a+16|0;k=d,l=bc(e),x[k+112>>2]=l;k=d,l=dc(e),x[k+40>>2]=l;if(Hb(d+112|0,d+40|0)){while(1){f=d+112|0;fe(f);if(Hb(f,d+40|0)){continue}break}}k=a,l=Lb(e),x[k+36>>2]=l;w[d+56>>1]=0;zf(b,d+56|0);e=z[d+56>>1];w[a+28>>1]=e;if((e-201&65535)>>>0<65135){break d}w[d+54>>1]=0;zf(b,d+54|0);e=w[d+54>>1];w[a+30>>1]=e;if((e|0)<0){break d}x[d+48>>2]=0;lp(b,d+48|0);k=a,m=zK(B[d+48>>2]),B[k+32>>2]=m;e=d+40|0;um(e);mk(b,e,8);if((y[d+40|0]|y[d+41|0]<<8|(y[d+42|0]<<16|y[d+43|0]<<24))!=1414681667|(y[d+44|0]|y[d+45|0]<<8|(y[d+46|0]<<16|y[d+47|0]<<24))!=776298313){break d}if(Lb(c)>>>0>32767){break d}b=z[a>>1];if(!(b?w[a+30>>1]>0&B[a+32>>2]>E(0):1)){break d}s:{switch(b-1|0){case 0:case 2:if(Lb(c)>>>0<w[a+30>>1]>>>0){break d}break;default:break s}}b=0;e=x[a+36>>2];if(e){b=e-1|0;x[a+36>>2]=b}k=d,l=Tt(b),x[k+112>>2]=l;x[d+32>>2]=0;k=a,l=x[dl(d+112|0,d+32|0,35976)>>2],x[k+36>>2]=l;mp(a);h=1;if(z[a>>1]!=3){break d}if((DK(Lb(c))|0)<(w[a+30>>1]-w[a+28>>1]|0)){break d}e=yk(d+112|0);h=0;if(w[a+30>>1]>0){while(1){b=Pb(c,h-w[a+28>>1]|0);x[114414]=0;P(1647,e|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break h}h=h+1|0;if((h|0)<w[a+30>>1]){continue}break}}b=z[a+28>>1];w[d+32>>1]=b;c=Lb(c);x[114414]=0;w[d+34>>1]=(b+c|0)-1;w[d+30>>1]=0;aa(1641,a|0,e|0,a+32|0,d+32|0,d+30|0)|0;a=x[114414];x[114414]=0;h=1;if((a|0)!=1){fg(e);break d}break h}xb(e);break d}xb(e);break d}b=N()|0;fg(e);break a}b=N()|0}xb(e);break a}xb(e)}hb=d+128|0;return h|0}b=N()|0;xb(e);break a}b=N()|0;xb(e)}Q(b|0);p()}function JI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-416|0;hb=e;v[e+415|0]=c;a:{if(vj(b)){break a}f=y[rk(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Fk(e+160|0,b,x[b+4>>2]-1|0);f=x[e+164>>2];x[b>>2]=x[e+160>>2];x[b+4>>2]=f}f=e+160|0;Hd(f);g=x[e+160>>2];Hd(e+376|0);h=qk(g,x[e+380>>2],b);Hd(f);f=x[b>>2];g=x[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==x[e+164>>2]){x[e+400>>2]=f;x[e+404>>2]=g;a=tc(e+392|0,17386);c=x[e+404>>2];x[e+8>>2]=x[e+400>>2];x[e+12>>2]=c;c=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=c;if(Kc(e+8|0,e)){a=ec(8);x[114414]=0;P(2171,e+376|0,e+415|0);b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;T(2152,e+160|0,13488,e+376|0);b=x[114414];x[114414]=0;if((b|0)==1){break g}a=oc(a,e+160|0);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(e+160|0);xb(e+376|0);break c}b=N()|0;break d}if(!d){break h}d=ec(8);x[114414]=0;a=O(2172,e+344|0,b|0)|0;b=x[114414];x[114414]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[114414]=0;T(2152,e+360|0,13524,a|0);b=x[114414];x[114414]=0;if((b|0)==1){break p}x[114414]=0;T(2167,e+376|0,e+360|0,13498);b=x[114414];x[114414]=0;c=1;if((b|0)==1){break o}x[114414]=0;P(2171,e+328|0,e+415|0);b=x[114414];x[114414]=0;if((b|0)==1){break n}x[114414]=0;T(137,e+160|0,e+376|0,e+328|0);b=x[114414];x[114414]=0;if((b|0)==1){break m}b=oc(d,e+160|0);x[114414]=0;T(2042,b|0,82448,2050);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=N()|0;xb(e+160|0);c=0;break l}b=N()|0;break i}b=N()|0;xb(a);break i}b=N()|0;break j}b=N()|0;break k}b=N()|0}xb(e+328|0)}xb(e+376|0)}xb(e+360|0);xb(a);if(!c){break c}}hc(d);break c}x[e+320>>2]=f;x[e+324>>2]=g;d=tc(e+312|0,17386);f=x[e+324>>2];x[e+152>>2]=x[e+320>>2];x[e+156>>2]=f;f=x[d+4>>2];x[e+144>>2]=x[d>>2];x[e+148>>2]=f;if(Kc(e+152|0,e+144|0)){a=ec(8);x[114414]=0;P(2171,e+376|0,e+415|0);b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;T(2152,e+160|0,13488,e+376|0);b=x[114414];x[114414]=0;if((b|0)==1){break f}a=oc(a,e+160|0);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(e+160|0);xb(e+376|0);break c}b=N()|0;break e}d=x[b+4>>2];x[e+304>>2]=x[b>>2];x[e+308>>2]=d;d=tc(e+296|0,3674);f=x[e+308>>2];x[e+136>>2]=x[e+304>>2];x[e+140>>2]=f;f=x[d+4>>2];x[e+128>>2]=x[d>>2];x[e+132>>2]=f;q:{if(!Kc(e+136|0,e+128|0)){d=x[b+4>>2];x[e+288>>2]=x[b>>2];x[e+292>>2]=d;d=tc(e+280|0,3656);f=x[e+292>>2];x[e+120>>2]=x[e+288>>2];x[e+124>>2]=f;f=x[d+4>>2];x[e+112>>2]=x[d>>2];x[e+116>>2]=f;if(!Kc(e+120|0,e+112|0)){break q}}v[a+60|0]=c;break h}d=x[b+4>>2];x[e+272>>2]=x[b>>2];x[e+276>>2]=d;d=tc(e+264|0,3240);f=x[e+276>>2];x[e+104>>2]=x[e+272>>2];x[e+108>>2]=f;f=x[d+4>>2];x[e+96>>2]=x[d>>2];x[e+100>>2]=f;r:{if(!Kc(e+104|0,e+96|0)){d=x[b+4>>2];x[e+256>>2]=x[b>>2];x[e+260>>2]=d;d=tc(e+248|0,3221);f=x[e+260>>2];x[e+88>>2]=x[e+256>>2];x[e+92>>2]=f;f=x[d+4>>2];x[e+80>>2]=x[d>>2];x[e+84>>2]=f;if(!Kc(e+88|0,e+80|0)){break r}}v[a+61|0]=c;break h}d=x[b+4>>2];x[e+240>>2]=x[b>>2];x[e+244>>2]=d;d=tc(e+232|0,3324);f=x[e+244>>2];x[e+72>>2]=x[e+240>>2];x[e+76>>2]=f;f=x[d+4>>2];x[e+64>>2]=x[d>>2];x[e+68>>2]=f;if(Kc(e+72|0,e- -64|0)){v[a+62|0]=c;break h}d=x[b+4>>2];x[e+224>>2]=x[b>>2];x[e+228>>2]=d;d=tc(e+216|0,2484);f=x[e+228>>2];x[e+56>>2]=x[e+224>>2];x[e+60>>2]=f;f=x[d+4>>2];x[e+48>>2]=x[d>>2];x[e+52>>2]=f;if(Kc(e+56|0,e+48|0)){v[a+63|0]=c;break h}d=x[b+4>>2];x[e+208>>2]=x[b>>2];x[e+212>>2]=d;d=tc(e+200|0,3723);f=x[e+212>>2];x[e+40>>2]=x[e+208>>2];x[e+44>>2]=f;f=x[d+4>>2];x[e+32>>2]=x[d>>2];x[e+36>>2]=f;if(Kc(e+40|0,e+32|0)){v[a+64|0]=c;break h}d=x[b+4>>2];x[e+192>>2]=x[b>>2];x[e+196>>2]=d;b=tc(e+184|0,9235);d=x[e+196>>2];x[e+24>>2]=x[e+192>>2];x[e+28>>2]=d;d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(!Kc(e+24|0,e+16|0)){break h}d=a+24|0;b=x[d>>2];f=b+24664|0;g=x[f+4>>2];x[e+176>>2]=x[f>>2];x[e+180>>2]=g;f=b+24656|0;g=x[f+4>>2];x[e+168>>2]=x[f>>2];x[e+172>>2]=g;f=x[b+24652>>2];x[e+160>>2]=x[b+24648>>2];x[e+164>>2]=f;if(c){a=nI(x[a+56>>2])}else{a=0}x[e+180>>2]=a;if(!tx(e+160|0,x[d>>2]+24648|0)){break h}my(x[d>>2],e+160|0)}hb=e+416|0;return}b=N()|0;xb(e+376|0);break d}b=N()|0;xb(e+376|0)}hc(a);break c}hc(a)}Q(b|0)}p()}function oma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb-336|0;hb=d;Lc(b);a:{if(!pu(b,d+320|0)){break a}if(!lT(d+320|0)){break a}if(x[d+320>>2]==1179472708){cc(b,4)}if(!If(b,d+312|0)|x[d+312>>2]!=1196314451){break a}if(!c){f=1;break a}j=d+312|4;nB(b,d+120|0,y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24));k=d+156|0;if((y[k|0]|y[k+1|0]<<8)>>>0>128){break a}h=d+162|0;if((y[h|0]|y[h+1|0]<<8)>>>0>16){break a}e=d+160|0;if((y[e|0]|y[e+1|0]<<8)>>>0>256){break a}l=d+154|0;if((y[l|0]|y[l+1|0]<<8)>>>0>128){break a}Nd(a,8192);i=d+40|0;e=Ub(i,2868);Db(a+1304436|0,e);xb(e);e=Ub(i,6122);Db(a+1304448|0,e);xb(e);x[a+1304496>>2]=4;e=d+104|0;ou(e,2,d+120|0);Ic(i,e);Db(a+1304400|0,i);xb(i);w[d+40>>1]=y[h|0]|y[h+1|0]<<8;w[d+104>>1]=1;q=a,r=z[aj(i,e)>>1],w[q+480188>>1]=r;x[a+480196>>2]=y[d+166|0];x[a+480204>>2]=D(y[d+167|0],1e4);v[d+40|0]=y[d+164|0];v[d+104|0]=64;e=y[rc(i,e)|0];x[a+480200>>2]=e<<2;if(!e){x[a+480200>>2]=256}e=d+165|0;b:{if(y[e|0]==128){x[d+40>>2]=256/z[a+480188>>1];x[d+104>>2]=128;g=x[Mb(d+40|0,d+104|0)>>2];break b}g=y[e|0]&127}x[a+480228>>2]=g;while(1){h=(f<<5)+a|0;Lg(h+480280|0);e=(d+f|0)+168|0;if(y[e|0]<=128){w[h+480284>>1]=y[e|0]<<1}f=f+1|0;if((f|0)!=16){continue}break}e=a+484360|0;$n(Vb(e),d+184|0,y[k|0]|y[k+1|0]<<8,255,254);if((y[l|0]|y[l+1|0]<<8)>>>0<(y[k|0]|y[k+1|0]<<8)>>>0){Se(Vb(e),y[l|0]|y[l+1|0]<<8)}f=1;if(!If(b,d+312|0)){break a}i=c&2;n=a+484344|0;k=c&1;l=d+76|0;while(1){Bd(d+104|0,b,y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24));c:{d:{e:{if(!(!k|x[d+312>>2]!=1414807888)){x[114414]=0;h=o&65535;e=U(363,n|0,h|0,64)|0;c=x[114414];x[114414]=0;if((c|0)==1){break e}if(!e){break c}x[114414]=0;O(304,d+104|0,2)|0;c=x[114414];x[114414]=0;if((c|0)==1){break e}Zh(d+40|0);m=0;f:{while(1){x[114414]=0;e=O(226,d+104|0,1)|0;c=x[114414];x[114414]=0;g:{h:{if((c|0)!=1){if(!(e&m>>>0<64)){break f}x[114414]=0;e=R(403,d+104|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break h}g=e<<24>>24;if(g){break g}m=m+1|0;continue}b=N()|0;break d}b=N()|0;break d}f=d+40|0;i:{j:{k:{e=g&15;l:{if(e>>>0<z[a+480188>>1]){c=Zb(n,h);x[114414]=0;f=U(427,c|0,m|0,e|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break l}}m:{if((g|0)>=0){break m}x[114414]=0;e=R(403,d+104|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break k}if(!e){break m}v[f|0]=e>>>0<109?e+12|0:e}g=g&255;if(!(g&64)){break i}x[114414]=0;e=R(403,d+104|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break j}}b=N()|0;break d}b=N()|0;break d}v[f+1|0]=e}n:{o:{p:{q:{r:{s:{t:{u:{if(g&32){v[f+2|0]=1;x[114414]=0;e=R(403,d+104|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break u}x[114414]=0;v[d+24|0]=e;v[d+8|0]=64;e=O(409,d+24|0,d+8|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break t}v[f+4|0]=y[e|0]}if(!(g&16)){continue}x[114414]=0;P(428,d+24|0,d+104|0);c=x[114414];x[114414]=0;if((c|0)==1){break s}c=d+24|0;g=c;e=ed(c);c=y[c|0];switch(c-17|0){case 2:break q;case 0:case 1:break r;default:break p}}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}c=c&15;break o}v[g|0]=33;v[e|0]=145;c=y[g|0];break n}if(c>>>0<17){break n}c=(c&240)==32?9:-1}v[g|0]=c}v[f+3|0]=c;v[f+5|0]=y[e|0];x[114414]=0;W(541,f|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}b=N()|0;break d}o=o+1|0;break c}if(x[d+312>>2]!=1414745673){break c}if(!Wn(a)){break c}e=z[a+480190>>1]+1|0;w[a+480190>>1]=e;x[114414]=0;O(542,d+104|0,d+40|0)|0;c=x[114414];x[114414]=0;v:{w:{x:{if((c|0)==1){break x}x[114414]=0;e=(D(e&65535,104)+a|0)+484380|0;P(543,d+40|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break x}x[114414]=0;T(544,d+8|0,2,l|0);c=x[114414];x[114414]=0;if((c|0)==1){break w}x[114414]=0;P(355,d+24|0,d+8|0);c=x[114414];x[114414]=0;if((c|0)==1){break w}c=z[a+480190>>1];x[114414]=0;O(334,((c<<5)+a|0)+946304|0,d+24|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break v}xb(d+24|0);if(!i){break c}x[114414]=0;P(545,d+24|0,d+40|0);c=x[114414];x[114414]=0;if((c|0)!=1){x[114414]=0;U(361,d+24|0,e|0,d+104|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break c}}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}b=N()|0;xb(d+24|0);break d}b=N()|0}Ab(d+104|0);Q(b|0);p()}Ab(d+104|0);f=1;if(If(b,d+312|0)){continue}break}}hb=d+336|0;return f|0}function ME(){var a=0,b=0,c=0,d=0,e=0,f=0;if(y[461040]){return x[115259]}b=Gd(462680);x[b>>2]=65176;x[114414]=0;c=O(2567,b+8|0,30)|0;a=x[114414];x[114414]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[114414]=0;d=O(118,b+152|0,9986)|0;a=x[114414];x[114414]=0;if((a|0)==1){break e}Lb(c);UE(c);og(c);e=Gd(462352),f=67764,x[e>>2]=f;x[114414]=0;P(2568,b|0,462352);a=x[114414];x[114414]=0;if((a|0)==1){break d}e=Gd(462360),f=67796,x[e>>2]=f;x[114414]=0;P(2569,b|0,462360);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;IE();a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(2571,b|0,462368);a=x[114414];x[114414]=0;if((a|0)==1){break d}e=Gd(462384),f=66712,x[e>>2]=f;x[114414]=0;P(2572,b|0,462384);a=x[114414];x[114414]=0;if((a|0)==1){break d}e=Gd(462392),f=66860,x[e>>2]=f;x[114414]=0;P(2573,b|0,462392);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;V(2574);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(2575,b|0,462400);a=x[114414];x[114414]=0;if((a|0)==1){break d}e=Gd(462416),f=67008,x[e>>2]=f;x[114414]=0;P(2576,b|0,462416);a=x[114414];x[114414]=0;if((a|0)==1){break d}e=Gd(462424),f=67240,x[e>>2]=f;x[114414]=0;P(2577,b|0,462424);a=x[114414];x[114414]=0;if((a|0)==1){break d}e=Gd(462432),f=67124,x[e>>2]=f;x[114414]=0;P(2578,b|0,462432);a=x[114414];x[114414]=0;if((a|0)==1){break d}e=Gd(462440),f=67356,x[e>>2]=f;x[114414]=0;P(2579,b|0,462440);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;V(2580);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(2581,b|0,462448);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;V(2582);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(2583,b|0,462472);a=x[114414];x[114414]=0;if((a|0)==1){break d}e=Gd(462504),f=67828,x[e>>2]=f;x[114414]=0;P(2584,b|0,462504);a=x[114414];x[114414]=0;if((a|0)==1){break d}e=Gd(462512),f=68072,x[e>>2]=f;x[114414]=0;P(2585,b|0,462512);a=x[114414];x[114414]=0;if((a|0)==1){break d}e=Gd(462520),f=68284,x[e>>2]=f;x[114414]=0;P(2586,b|0,462520);a=x[114414];x[114414]=0;if((a|0)==1){break d}e=Gd(462528),f=68516,x[e>>2]=f;x[114414]=0;P(2587,b|0,462528);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;TE();a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(2589,b|0,462536);a=x[114414];x[114414]=0;if((a|0)==1){break d}e=Gd(462544),f=69648,x[e>>2]=f;x[114414]=0;P(2590,b|0,462544);a=x[114414];x[114414]=0;if((a|0)==1){break d}e=Gd(462552),f=69764,x[e>>2]=f;x[114414]=0;P(2591,b|0,462552);a=x[114414];x[114414]=0;if((a|0)==1){break d}e=Gd(462560),f=69880,x[e>>2]=f;x[114414]=0;P(2592,b|0,462560);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;SE();a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(2594,b|0,462568);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;RE();a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(2596,b|0,462576);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;QE();a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(2598,b|0,462584);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;PE();a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(2600,b|0,462592);a=x[114414];x[114414]=0;if((a|0)==1){break d}a=Gd(462600);x[a+8>>2]=71744;x[a>>2]=68716;x[a+8>>2]=68764;x[114414]=0;P(2601,b|0,462600);a=x[114414];x[114414]=0;if((a|0)==1){break d}a=Gd(462616);x[a+8>>2]=71780;x[a>>2]=68980;x[a+8>>2]=69028;x[114414]=0;P(2602,b|0,462616);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;V(2603);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(2604,b|0,462632);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;V(2605);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(2606,b|0,462648);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;OE();a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(2608,b|0,462664);a=x[114414];x[114414]=0;if((a|0)==1){break d}e=Gd(462672),f=70772,x[e>>2]=f;x[114414]=0;P(2609,b|0,462672);b=x[114414];x[114414]=0;if((b|0)==1){break d}break a}b=N()|0;break b}b=N()|0;break c}b=N()|0;xb(d)}WE(c)}Q(b|0);p()}x[115258]=462680;v[461040]=1;x[115259]=461032;return 461032}function VM(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=hb-16|0;hb=h;a:{if(!Zd(d&255)){break a}j=(D(b,896)+a|0)+1074984|0;b:{if(!(!(x[a+480180>>2]&17825824)|!z[a+480192>>1]|e)){break b}if(wj(j)){break b}c=D(b,896)+a|0;d=c+1075060|0;if(!x[d>>2]){break a}c=x[c+1075072>>2];if(c&1024){break a}e=D(b,896)+a|0;g=e+1075004|0;e=e+1075008|0;if(!(x[g>>2]|x[e>>2])){break a}c:{if(!(c&512)){break c}c=a+1304392|0;if(!zd(c)){break c}Ji(x[c>>2],b,0);break a}c=Jy(a,b);if((c|0)==65535){break a}k=D(c,896);c=a+1074984|0;a=k+c|0;Bp(a,j);v[a+851|0]=0;v[a+827|0]=0;w[a+808>>1]=b+1;x[a+88>>2]=x[a+88>>2]&-918529;Nt(a+810|0);x[a+696>>2]=0;x[a+88>>2]=x[a+88>>2]|2101248;x[d>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=c+D(b,896)|0;x[a+92>>2]=0;x[a+96>>2]=0;x[g>>2]=0;x[e>>2]=0;break a}e=D(b,896)+a|0;l=x[e+1075088>>2];c=z[a+480192>>1]>=c>>>0?c:0;g=x[(c?((c<<2)+a|0)+900380|0:e+1075640|0)>>2];d:{if(!g){break d}i=d-1|0;c=z[fd(g+236|0,i)>>1];m=h+8|0;f=a+1074312|0;Kb(m,f,104);e:{if(Ib(m)){Kb(h,f,34);if(Ib(h)){break e}}d=y[gc(g+108|0,i)|0]}if((c-1&65535)>>>0<=3998){l=(D(c,104)+a|0)+484380|0;break d}c=h+8|0;Kb(c,f,43);if(!Ib(c)){break d}if(!Ki(g)){break a}}if(y[e+1075073|0]&4){break a}if(b>>>0<=255){i=a+1304392|0;m=a+1074312|0;p=b+1|0;c=b;while(1){f:{if((b|0)!=(c|0)&z[a+480188>>1]>c>>>0){break f}e=D(c,896)+a|0;if(z[e+1075792>>1]!=(p|0)&(b|0)!=(c|0)){break f}o=e+1075640|0;f=x[o>>2];if(!f){break f}n=e+1074984|0;g:{h:{i:{j:{k:{l:{m:{switch(y[f+17|0]-1|0){case 0:if(!d){break f}k=y[e+1075803|0]==(d|0)&(f|0)==(g|0);if(!g){break l}if(k){break i}break f;case 1:if(!l|x[e+1075088>>2]!=(l|0)){break f}if((f|0)==(g|0)){break g}f=h+8|0;Kb(f,m,104);if(!Ib(f)){break g}break f;case 3:break k;case 2:break m;default:break f}}if(g){break j}k=(f|0)==(g|0)}if(k){break g}break f}if(!g){break f}k=y[g+34|0];if(!k){break f}if((k|0)==y[f+34|0]){break h}break f}if((f|0)!=(g|0)){break f}}if(!y[g+34|0]){break g}}if(!y[e+1075803|0]|y[f+18|0]>2){break g}f=h+8|0;Kb(f,m,34);Ql(a,c&65535,BO(n,Ib(f))+255|0,0);v[e+1075806|0]=0}n:{o:{switch(y[x[o>>2]+18|0]){case 0:vn(a,n);x[e+1075672>>2]=0;if(!(y[e+1075073|0]&2)){break n}if(!zd(i)){break n}Ji(x[i>>2],c&65535,1);break n;case 1:vn(a,n);if(!(y[e+1075073|0]&2)){break n}if(!zd(i)){break n}Ik(x[i>>2],c&65535);break n;case 2:break o;default:break n}}n=e+1075072|0;f=x[n>>2];x[n>>2]=f|4096;if(!(f&512)){break n}if(!zd(i)){break n}f=h+8|0;Kb(f,m,105);if(Ib(f)){break n}Ik(x[i>>2],c&65535)}if(x[e+1075672>>2]){break f}x[e+1075680>>2]=0;e=e+1075072|0;x[e>>2]=x[e>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}d=0;c=0;p:{if(!wj(j)){break p}c=0;if(!Zd(y[(D(b,896)+a|0)+1075803|0])){break p}e=Pl(a,b,2,1);c=0;if((e-1&255)>>>0>249){break p}d=x[(D(e,160)+a|0)+906140>>2];if(!d){d=0;c=0;break p}c=h+8|0;Kb(c,a+1074312|0,34);c=(r=d,s=BO(j,Ib(c)),t=b,q=x[x[d>>2]+96>>2],mb[q](r|0,s|0,t|0)|0)}if(!(Sh(j)|c)){break a}g=Jy(a,b);if((g|0)==65535){break a}f=D(g,896)+a|0;e=f+1075072|0;i=f+1074984|0;q:{if(!(y[f+1075073|0]&2)){break q}l=a+1304392|0;if(!zd(l)){break q}Ji(x[l>>2],g,1)}Bp(i,j);x[e>>2]=x[e>>2]&-917505;v[f+1075835|0]=0;l=z[a+480188>>1];v[f+1075811|0]=0;w[f+1075792>>1]=b>>>0<l>>>0?b+1|0:0;r:{if(!(c&(d|0)!=0)){break r}c=y[(D(b,896)+a|0)+1075804|0];if(c>>>0>3|(c|0)==1){break r}Ql(a,b,255,0);v[(D(b,896)+a|0)+1075806|0]=0}s:{t:{switch(y[(D(b,896)+a|0)+1075804|0]){case 2:vn(a,i);if(!(y[e+1|0]&2)){break s}c=a+1304392|0;if(!zd(c)){break s}Ik(x[c>>2],b);d=h+8|0;Kb(d,a+1074312|0,105);if(!Ib(d)){break s}$y(x[c>>2],b,g);break s;case 0:x[(D(g,896)+a|0)+1075680>>2]=0;c=x[e>>2];x[e>>2]=c|4096;if(!(c&512)){break s}c=a+1304392|0;if(!zd(c)){break s}Ji(x[c>>2],b,1);break s;case 3:c=x[e>>2];x[e>>2]=c|4096;if(!(c&512)){break s}c=a+1304392|0;if(!zd(c)){break s}d=h+8|0;Kb(d,a+1074312|0,105);d=Ib(d);c=x[c>>2];if(d){$y(c,b,g);break s}Ik(c,b);break s;case 1:break t;default:break s}}if(!(y[e+1|0]&2)){break s}c=a+1304392|0;if(!zd(c)){break s}$y(x[c>>2],b,g)}if(!x[(D(g,896)+a|0)+1075672>>2]){x[(D(g,896)+a|0)+1075680>>2]=0;x[e>>2]=x[e>>2]|2101248}a=D(b,896)+a|0;x[a+1075060>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=a+1075076|0;x[a>>2]=0;x[a+4>>2]=0}hb=h+16|0}function WL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=hb-16|0;hb=h;a:{b:{c:{if(!Zd(c)|(!d|x[b+480180>>2]!=16777216)|z[b+480192>>1]<d>>>0){break c}d=x[((d<<2)+b|0)+900380>>2];if(!d){break c}d=x[d+44>>2];if(!d){break c}w[h+14>>1]=c-61;b=hb-80|0;hb=b;e=w[d+28>>1];f=h+14|0;c=w[f>>1];g=d+4|0;Lb(g);d:{e:{if((c|0)>=(e|0)){if((c|0)<=(z[d+28>>1]+Lb(g)|0)-1<<16>>16){break e}}hd(a);break d}f:{c=w[d+30>>1];if(!c){c=d+52|0;l=b,m=Nx(c,f),x[l+56>>2]=m;l=b,m=Ti(c),x[l+40>>2]=m;if(!Si(b+56|0,b+40|0)){break f}Uf(a,rh(b+56|0)+4|0);break d}e=w[f>>1];g:{if((e|0)>=0){c=(e|0)%(c|0)|0;break g}c=c+((e^-1)%(c|0)^-1)|0}w[b+78>>1]=c;c=hd(a);x[114414]=0;a=d+52|0;e=O(1627,a|0,b+78|0)|0;g=x[114414];x[114414]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((g|0)==1){break x}x[b+72>>2]=e;a=Ti(a);x[114414]=0;x[b+56>>2]=a;a=O(1628,b+72|0,b+56|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break i}if(a){x[114414]=0;a=R(1629,b+72|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break x}x[114414]=0;O(205,c|0,a+4|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break x}a=w[d+30>>1];d=w[f>>1];y:{if((d|0)>=0){a=(d|0)/(a|0)|0;break y}a=((d+1|0)/(a|0)|0)-1|0}x[114414]=0;x[b+40>>2]=a+5;P(202,b+56|0,b+40|0);a=x[114414];x[114414]=0;z:{if((a|0)!=1){x[114414]=0;O(160,c|0,b+56|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break z}xb(b+56|0);break d}a=N()|0;break h}a=N()|0;xb(b+56|0);break h}if(w[d+30>>1]>26){break u}x[114414]=0;e=U(779,b+40|0,1,y[b+78|0]+65<<24>>24)|0;a=x[114414];x[114414]=0;if((a|0)==1){break w}x[114414]=0;T(13,b+56|0,0,e|0);a=x[114414];x[114414]=0;if((a|0)==1){break v}a=b+56|0;Db(c,a);xb(a);xb(e);x[114414]=0;O(203,c|0,10181)|0;a=x[114414];x[114414]=0;if((a|0)!=1){break t}}a=N()|0;break h}a=N()|0;break h}a=N()|0;xb(e);break h}x[114414]=0;x[b+36>>2]=w[b+78>>1]%16;P(1630,b+40|0,b+36|0);a=x[114414];x[114414]=0;if((a|0)==1){break s}x[114414]=0;x[b+20>>2]=(w[b+78>>1]/16<<16>>16)%16;P(1630,b+24|0,b+20|0);a=x[114414];x[114414]=0;if((a|0)==1){break r}x[114414]=0;T(3,b+56|0,b+40|0,b+24|0);a=x[114414];x[114414]=0;if((a|0)==1){break q}a=b+56|0;Db(c,a);xb(a);xb(b+24|0);xb(b+40|0);if(w[b+78>>1]<256){break t}x[114414]=0;T(9,b+8|0,0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break o}x[114414]=0;P(1631,b+40|0,b+8|0);a=x[114414];x[114414]=0;if((a|0)==1){break n}x[114414]=0;T(13,b+56|0,0,b+40|0);a=x[114414];x[114414]=0;if((a|0)==1){break m}a=b+56|0;Db(c,a);xb(a);xb(b+40|0);xb(b+8|0)}a=w[d+30>>1];d=w[f>>1];if((d|0)<0){break k}a=(d|0)/(a|0)|0;break j}a=N()|0;break h}a=N()|0;break p}a=N()|0;xb(b+24|0)}xb(b+40|0);break h}a=N()|0;break h}a=N()|0;break l}a=N()|0;xb(b+40|0)}xb(b+8|0);break h}a=((d+1|0)/(a|0)|0)-1|0}x[114414]=0;x[b+24>>2]=a+5;P(202,b+56|0,b+24|0);a=x[114414];x[114414]=0;A:{if((a|0)!=1){x[114414]=0;O(160,c|0,b+56|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break A}xb(b+56|0);break d}a=N()|0;break h}a=N()|0;xb(b+56|0);break h}a=N()|0}xb(c);Q(a|0);p()}g=hb-16|0;hb=g;d=hb-16|0;hb=d;e=hb-144|0;hb=e;c=lh(e+8|0);i=x[x[c>>2]-12>>2];x[114414]=0;j=$(121)|0;k=x[114414];x[114414]=0;B:{C:{if((k|0)==1){break C}x[114414]=0;T(122,e|0,c+i|0,j|0);i=x[114414];x[114414]=0;if((i|0)==1){break C}Ob(e);x[114414]=0;P(130,c|0,f|0);f=x[114414];x[114414]=0;if((f|0)==1){break C}x[114414]=0;P(124,d|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break C}Xd(c);hb=e+144|0;break B}a=N()|0;Xd(c);Q(a|0);p()}x[114414]=0;T(13,a|0,0,d|0);a=x[114414];x[114414]=0;D:{if((a|0)!=1){xb(d);hb=d+16|0;break D}break a}hb=g+16|0}hb=b+80|0;break b}f=x[b>>2];b=hb-32|0;hb=b;E:{if(XL(c)){x[b+16>>2]=x[6452];d=x[6449];x[b>>2]=x[6448];x[b+4>>2]=d;d=x[6451];x[b+8>>2]=x[6450];x[b+12>>2]=d;Ub(a,(b+(c<<2)|0)-1004|0);break E}if(Zd(c)){d=hd(b);x[114414]=0;e=c-1|0;c=(e|0)/12|0;f=O(1446,d|0,f+(e-D(c,12)<<16>>16<<2)|0)|0;e=x[114414];x[114414]=0;F:{if((e|0)==1){break F}x[114414]=0;c=U(1447,f|0,1,c+48<<24>>24)|0;f=x[114414];x[114414]=0;if((f|0)==1){break F}x[114414]=0;O(4,a|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break F}xb(d);break E}break a}if(!c){Ub(a,12709);break E}Ub(a,10152)}hb=b+32|0}hb=h+16|0;return}a=N()|0;xb(d);Q(a|0);p()}function Kla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=hb-704|0;hb=l;a:{b:{c:{if(d>>>0<=511){d=0;j=hb-16|0;hb=j;a=hb-16|0;hb=a;i=j+8|0;g=l+24|0;jc(i,g,554);hb=a+16|0;k=Eb(i);a=nc(b,ac(j,i));if((k|0)==(a|0)){cc(b,Eb(j+8|0))}hb=j+16|0;b=(a|0)==(k|0);if(!b){a=hb-16|0;hb=a;Sb(g,0,554);hb=a+16|0}if(!b){break c}a=hb-32|0;hb=a;h=l+24|0;d:{if((y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24))!=1229999433){break d}gv(a,3,h+32|0);b=a+16|0;Ic(b,a);x[114414]=0;O(334,c+492|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}b=a+16|0;xb(b);zh(a,1,h+4|0);Ic(b,a);x[114414]=0;O(334,c+524|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}xb(a+16|0);b=y[h+24|0]|y[h+25|0]<<8;x[c+4>>2]=64;x[c+8>>2]=128;x[c>>2]=b<<6;v[c+16|0]=y[h+26|0];v[c+17|0]=y[h+27|0];k=c+108|0;d=c+236|0;while(1){b=h+(f<<1)|0;g=y[b- -64|0];b=y[b+65|0];m=fd(d,f),n=b,w[m>>1]=n;m=gc(k,f),n=(g>>>0<120?g:f)+1|0,v[m|0]=n;f=f+1|0;if((f|0)!=120){continue}break}v[c+60|0]=y[c+60|0]&254|v[h+17|0]&1;v[c+60|0]=y[c+60|0]&253|y[h+17|0]&2;v[c+60|0]=y[c+60|0]&251|y[h+17|0]&4;i=c+61|0;v[i|0]=y[h+18|0];g=c+62|0;v[g|0]=y[h+19|0];k=c+63|0;v[k|0]=y[h+20|0];d=c- -64|0;v[d|0]=y[h+21|0];e=c+48|0;Mg(e,25);f=0;while(1){e:{b=f<<1;j=y[(h+b|0)+504|0];m=Pb(e,f),n=j,w[m>>1]=n;if((j|0)==255){Mg(e,f);break e}b=y[(h+(b|1)|0)+504|0];m=Pb(e,f),n=b,v[m+2|0]=n;f=f+1|0;if((f|0)!=25){continue}}break}b=y[Xg(i,g)|0];if(Lb(e)>>>0<=b>>>0){v[c+60|0]=y[c+60|0]&253}b=y[Xg(k,d)|0];if(Lb(e)>>>0>b>>>0){break d}v[c+60|0]=y[c+60|0]&251}hb=a+32|0;d=554;break c}k=x[b+8>>2];g=hb-16|0;hb=g;x[g+12>>2]=674;x[g>>2]=674;d=x[Mb(g+12|0,g)>>2];if(!Qb(b,d)){d=uf(b)}e=l+24|0;iS(g,e);lg(b,x[g>>2],d);iS(g,e);Sb(x[g>>2]+d|0,0,674-d|0);cc(b,x[g+12>>2]);hb=g+16|0;g=x[a+480180>>2];a=hb-32|0;hb=a;f:{if((y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))==1229999433){gv(a,3,e+32|0);d=a+16|0;Ic(d,a);x[114414]=0;O(334,c+492|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}d=a+16|0;xb(d);zh(a,1,e+4|0);Ic(d,a);x[114414]=0;O(334,c+524|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}i=a+16|0;xb(i);x[c>>2]=(y[e+20|0]|y[e+21|0]<<8)<<5;x[c+4>>2]=y[e+24|0]>>>1;xc(c+4|0,64);d=y[e+25|0]&127;x[c+8>>2]=d>>>0>64?128:d<<2;v[c+15|0]=y[c+15|0]&254|((y[e+25|0]^-1)&128)>>>7;v[a+16|0]=y[e+26|0];v[a|0]=100;m=c,n=y[rc(i,a)|0],v[m+20|0]=n;v[a+16|0]=y[e+27|0];v[a|0]=64;m=c,n=y[rc(i,a)|0],v[m+19|0]=n;v[c+16|0]=y[e+17|0];v[c+17|0]=y[e+18|0];v[c+18|0]=y[e+19|0];v[c+26|0]=y[e+22|0];v[c+27|0]=y[e+23|0];ev(c,y[e+58|0]&127,y[e+58|0]>>>7|0);dv(c,y[e+59|0]&127,y[e+59|0]>>>7|0);g:{h:{i:{d=y[e+28|0]|y[e+29|0]<<8;if(!((d|0)==514|(d|0)==529|(y[e+28|0]|y[e+29|0]<<8)==544)){if((y[e+28|0]|y[e+29|0]<<8)!=532){break i}}if(y[e+61|0]==255){break i}if(y[e+61|0]<=128){v[c+30|0]=y[e+61|0]}f=y[e+62|0]|y[e+63|0]<<8;if(f>>>0<129){break h}break g}if(v[e+61|0]>=0){v[c+30|0]=y[e+61|0]+1}f=v[e+62|0]>=0?y[e+62|0]+1|0:f;if(v[e+63|0]<0){break h}f=(y[e+63|0]<<7)+f|0}w[c+28>>1]=f}d=v[e+60|0];v[c+31|0]=d;if((d|0)<0){v[c+31|0]=0;v[c+34|0]=d^128}f=0;d=g&16777216?240:25;iv(e+304|0,c+48|0,0,d);iv(e+386|0,c+68|0,32,d);iv(e+468|0,c+88|0,32,d);v[c+100|0]=y[c+100|0]&239|y[e+468|0]>>>3&16;i=c+108|0;g=c+236|0;while(1){d=e+(f<<1)|0;j=y[d- -64|0];d=y[d+65|0];m=fd(g,f),n=d,w[m>>1]=n;m=gc(i,f),n=(j>>>0<120?j:f)+1|0,v[m|0]=n;f=f+1|0;if((f|0)!=120){continue}break}f=554}hb=a+32|0;a=f;break f}if(a){d=y[e+550|0]|y[e+551|0]<<8|(y[e+552|0]<<16|y[e+553|0]<<24);if(!((d|0)!=1481920589&(d|0)!=1297110104)){g=c+236|0;a=0;while(1){f=y[(a+e|0)+554|0];d=fd(g,a);w[d>>1]=z[d>>1]|f<<8;a=a+1|0;if((a|0)!=120){continue}break}a=674}}else{a=0}d=a;Rc(b,k+d|0);if(!yh(b,9783)){break c}a=l+8|0;Bd(a,b,Gf(b));x[114414]=0;k=R(223,a|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break b}x[114414]=0;b=O(595,l+8|0,9587)|0;a=x[114414];x[114414]=0;if((a|0)==1){break b}if(b){x[114414]=0;b=R(403,l+8|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break b}v[c+34|0]=b>>>0<=250?b:0}d=(d+k|0)+8|0;Ab(l+8|0)}hb=l+704|0;return d|0}a=N()|0;Ab(l+8|0);Q(a|0);p()}b=N()|0;xb(a+16|0);Q(b|0);p()}function fH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;h=hb-560|0;hb=h;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;l=g+D(s,-24)|0;o=x[(e<<2)+48416>>2];j=d-1|0;if((o+j|0)>=0){g=d+o|0;c=s-j|0;while(1){C[(h+320|0)+(i<<3)>>3]=(c|0)<0?0:+x[(c<<2)+48432>>2];c=c+1|0;i=i+1|0;if((g|0)!=(i|0)){continue}break}}p=l-24|0;g=0;i=(o|0)>0?o:0;n=(d|0)<=0;while(1){a:{if(n){f=0;break a}k=g+j|0;c=0;f=0;while(1){f=C[(c<<3)+a>>3]*C[(h+320|0)+(k-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+h>>3]=f;c=(g|0)==(i|0);g=g+1|0;if(!c){continue}break}y=47-l|0;t=48-l|0;z=l-25|0;g=o;b:{while(1){f=C[(g<<3)+h>>3];c=0;i=g;k=(g|0)<=0;if(!k){while(1){n=(h+480|0)+(c<<2)|0;m=f*5.960464477539063e-8;c:{if(F(m)<2147483648){j=~~m;break c}j=-2147483648}m=+(j|0);f=m*-16777216+f;d:{if(F(f)<2147483648){j=~~f;break d}j=-2147483648}x[n>>2]=j;i=i-1|0;f=C[(i<<3)+h>>3]+m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=ok(f,p);f=f+J(f*.125)*-8;e:{if(F(f)<2147483648){n=~~f;break e}n=-2147483648}f=f-+(n|0);f:{g:{h:{u=(p|0)<=0;i:{if(!u){i=(g<<2)+h|0;j=x[i+476>>2];c=j>>t;r=i;i=j-(c<<t)|0;x[r+476>>2]=i;n=c+n|0;j=i>>y;break i}if(p){break h}j=x[((g<<2)+h|0)+476>>2]>>23}if((j|0)<=0){break f}break g}j=2;if(f>=.5){break g}j=0;break f}c=0;i=0;if(!k){while(1){r=(h+480|0)+(c<<2)|0;v=x[r>>2];k=16777215;j:{k:{if(i){break k}k=16777216;if(v){break k}i=0;break j}x[r>>2]=k-v;i=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(u){break l}c=8388607;m:{switch(z|0){case 1:c=4194303;break;case 0:break m;default:break l}}k=(g<<2)+h|0;x[k+476>>2]=x[k+476>>2]&c}n=n+1|0;if((j|0)!=2){break f}f=1-f;j=2;if(!i){break f}f=f-ok(1,p)}if(f==0){i=0;c=g;n:{if((g|0)<=(o|0)){break n}while(1){c=c-1|0;i=x[(h+480|0)+(c<<2)>>2]|i;if((c|0)>(o|0)){continue}break}if(!i){break n}l=p;while(1){l=l-24|0;g=g-1|0;if(!x[(h+480|0)+(g<<2)>>2]){continue}break}break b}c=1;while(1){i=c;c=c+1|0;if(!x[(h+480|0)+(o-i<<2)>>2]){continue}break}i=g+i|0;while(1){j=d+g|0;g=g+1|0;C[(h+320|0)+(j<<3)>>3]=x[(s+g<<2)+48432>>2];c=0;f=0;if((d|0)>0){while(1){f=C[(c<<3)+a>>3]*C[(h+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+h>>3]=f;if((g|0)<(i|0)){continue}break}g=i;continue}break}f=ok(f,24-l|0);o:{if(f>=16777216){d=(h+480|0)+(g<<2)|0;m=f*5.960464477539063e-8;p:{if(F(m)<2147483648){c=~~m;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(F(f)<2147483648){a=~~f;break q}a=-2147483648}x[d>>2]=a;g=g+1|0;break o}if(F(f)<2147483648){c=~~f}else{c=-2147483648}l=p}x[(h+480|0)+(g<<2)>>2]=c}f=ok(1,l);r:{if((g|0)<0){break r}d=g;while(1){a=d;C[(d<<3)+h>>3]=f*+x[(h+480|0)+(d<<2)>>2];d=d-1|0;f=f*5.960464477539063e-8;if(a){continue}break}k=0;if((g|0)<0){break r}a=(o|0)>0?o:0;i=g;while(1){d=a>>>0<k>>>0?a:k;l=g-i|0;c=0;f=0;while(1){f=C[(c<<3)+51200>>3]*C[(c+i<<3)+h>>3]+f;p=(c|0)!=(d|0);c=c+1|0;if(p){continue}break}C[(h+160|0)+(l<<3)>>3]=f;i=i-1|0;c=(g|0)!=(k|0);k=k+1|0;if(c){continue}break}}s:{t:{u:{switch(e|0){case 3:v:{if((g|0)<=0){break v}f=C[(h+160|0)+(g<<3)>>3];c=g;while(1){m=f;d=h+160|0;a=c-1|0;e=d+(a<<3)|0;w=C[e>>3];f=w+f;C[d+(c<<3)>>3]=m+(w-f);C[e>>3]=f;d=c>>>0>1;c=a;if(d){continue}break}if((g|0)<2){break v}f=C[(h+160|0)+(g<<3)>>3];c=g;while(1){m=f;d=h+160|0;a=c-1|0;e=d+(a<<3)|0;q=C[e>>3];f=q+f;C[d+(c<<3)>>3]=m+(q-f);C[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}q=0;if((g|0)<=1){break v}while(1){q=q+C[(h+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=C[h+160>>3];if(j){break t}C[b>>3]=f;f=C[h+168>>3];C[b+16>>3]=q;C[b+8>>3]=f;break s;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+C[(h+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;break s;case 1:case 2:break u;default:break s}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=d-1|0;f=f+C[(h+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;f=C[h+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+C[(h+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}C[b+8>>3]=j?-f:f;break s}C[b>>3]=-f;f=C[h+168>>3];C[b+16>>3]=-q;C[b+8>>3]=-f}hb=h+560|0;return n&7}function cJ(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;l=hb-48|0;hb=l;x[l+44>>2]=0;a:{if(d|g|h|i){k=g?l+44|0:0;b:{if(!k){break b}j=x[k>>2];if(!j){break b}_b(j);x[k>>2]=0}x[114414]=0;V(83);j=x[114414];x[114414]=0;c:{d:{if((j|0)==1){m=Za(75016,82332,82344,82448,75184,75288,75236,75128,75116,75432,75400,75368,75356,74968,0)|0;e:{f:{n=ib;if((n|0)==(ca(75016)|0)){j=Y(m|0)|0;x[114414]=0;P(2141,k|0,j|0);k=x[114414];x[114414]=0;j=277;if((k|0)==1){break f}break c}if((ca(82332)|0)==(n|0)){j=Y(m|0)|0;x[114414]=0;P(2141,k|0,j|0);k=x[114414];x[114414]=0;j=358;if((k|0)!=1){break c}j=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){break d}break e}if((ca(82344)|0)==(n|0)){j=Y(m|0)|0;x[114414]=0;P(2141,k|0,j|0);k=x[114414];x[114414]=0;j=359;if((k|0)!=1){break c}j=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){break d}break e}if((ca(82448)|0)==(n|0)){j=Y(m|0)|0;x[114414]=0;P(2141,k|0,j|0);k=x[114414];x[114414]=0;j=357;if((k|0)!=1){break c}j=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){break d}break e}if((ca(75184)|0)==(n|0)){j=Y(m|0)|0;x[114414]=0;P(2141,k|0,j|0);k=x[114414];x[114414]=0;j=300;if((k|0)!=1){break c}j=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){break d}break e}if((ca(75288)|0)==(n|0)){j=Y(m|0)|0;x[114414]=0;P(2141,k|0,j|0);k=x[114414];x[114414]=0;j=299;if((k|0)!=1){break c}j=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){break d}break e}if((ca(75236)|0)==(n|0)){j=Y(m|0)|0;x[114414]=0;P(2141,k|0,j|0);k=x[114414];x[114414]=0;j=298;if((k|0)!=1){break c}j=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){break d}break e}if((ca(75128)|0)==(n|0)){j=Y(m|0)|0;x[114414]=0;P(2141,k|0,j|0);k=x[114414];x[114414]=0;j=297;if((k|0)!=1){break c}j=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){break d}break e}if((ca(75116)|0)==(n|0)){j=Y(m|0)|0;x[114414]=0;P(2141,k|0,j|0);k=x[114414];x[114414]=0;j=296;if((k|0)!=1){break c}j=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){break d}break e}if((ca(75432)|0)==(n|0)){j=Y(m|0)|0;x[114414]=0;P(2141,k|0,j|0);k=x[114414];x[114414]=0;j=289;if((k|0)!=1){break c}j=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){break d}break e}if((ca(75400)|0)==(n|0)){j=Y(m|0)|0;x[114414]=0;P(2141,k|0,j|0);k=x[114414];x[114414]=0;j=288;if((k|0)!=1){break c}j=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){break d}break e}if((ca(75368)|0)==(n|0)){j=Y(m|0)|0;x[114414]=0;P(2141,k|0,j|0);k=x[114414];x[114414]=0;j=287;if((k|0)!=1){break c}j=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){break d}break e}if((ca(75356)|0)==(n|0)){j=Y(m|0)|0;x[114414]=0;P(2141,k|0,j|0);k=x[114414];x[114414]=0;j=286;if((k|0)!=1){break c}j=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){break d}break e}o=ca(74968)|0;j=257;m=Y(m|0)|0;if((n|0)!=(o|0)){break c}x[114414]=0;P(2141,k|0,m|0);k=x[114414];x[114414]=0;j=267;if((k|0)!=1){break c}j=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)==1){break e}break d}j=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){break d}}S(0)|0;zb()}p()}Q(j|0);p()}_();m=!g;if(d){k=mb[d|0](j,e)|0}else{k=3}if(!(m|!(k&2))){x[g+16>>2]=j;m=g;g=x[l+44>>2];q=m,r=Ld(g?g:17386),x[q+20>>2]=r}if(h){x[h>>2]=j}g=x[l+44>>2];if(i){q=i,r=Ld(g?g:17386),x[q>>2]=r;g=x[l+44>>2]}if(g){_b(g);x[l+44>>2]=0}if(!(k&1)){break a}}x[114414]=0;P(2024,l+32|0,a|0);g=x[114414];x[114414]=0;g:{h:{if((g|0)!=1){i:{if(f){x[114414]=0;P(2025,f|0,l+32|0);g=x[114414];x[114414]=0;if((g|0)!=1){break i}break h}g=Rb(l+32|0);if(b){x[114414]=0;P(b|0,g|0,c|0);g=x[114414];x[114414]=0;if((g|0)==1){break h}break i}Cs(g,l)}xb(l+32|0);break a}g=S(0)|0;break g}g=S(0)|0;xb(l+32|0)}Y(g|0)|0;x[l+28>>2]=f;x[l+24>>2]=e;x[l+20>>2]=d;x[l+16>>2]=c;x[l+12>>2]=b;x[l+4>>2]=252;x[l>>2]=5145;x[l+8>>2]=a?a:17386;a=x[14652];ZG(a,13702,l);dn(a);_()}hb=l+48|0}function p_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=hb+-64|0;hb=h;x[h+56>>2]=b;x[e>>2]=0;Dc(h,d);x[114414]=0;i=R(2510,h|0)|0;j=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Ob(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Ob(h);Q(a|0);p()}oF(a,f+24|0,h+56|0,c,e,i);break b}nF(a,f+16|0,h+56|0,c,e,i);break b}g=a;a=mb[x[x[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=jj(g,b,c,d,e,f,Rb(a),Rb(a)+(Bb(a)<<2)|0),x[k+56>>2]=l;break b}a=ii(h+56|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}g=x[16255];x[h+24>>2]=x[16254];x[h+28>>2]=g;g=x[16253];x[h+16>>2]=x[16252];x[h+20>>2]=g;g=x[16251];x[h+8>>2]=x[16250];x[h+12>>2]=g;g=x[16249];x[h>>2]=x[16248];x[h+4>>2]=g;k=h,l=jj(a,b,c,d,e,f,h,h+32|0),x[k+56>>2]=l;break b}g=x[16263];x[h+24>>2]=x[16262];x[h+28>>2]=g;g=x[16261];x[h+16>>2]=x[16260];x[h+20>>2]=g;g=x[16259];x[h+8>>2]=x[16258];x[h+12>>2]=g;g=x[16257];x[h>>2]=x[16256];x[h+4>>2]=g;k=h,l=jj(a,b,c,d,e,f,h,h+32|0),x[k+56>>2]=l;break b}a=ii(h+56|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=ii(h+56|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=ii(h+56|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=ii(h+56|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=ii(h+56|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+56|0;b=hb-16|0;hb=b;x[b+8>>2]=c;while(1){H:{if(hh(a,b+8|0)){break H}if(!lk(i,1,wl(a))){break H}Zm(a);continue}break}if(hh(a,b+8|0)){x[e>>2]=x[e>>2]|2}hb=b+16|0;break b}b=h+56|0;a=mb[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Bb(a)|0)==(0-Bb(a+12|0)|0)){x[e>>2]=x[e>>2]|4;break I}c=Fr(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=sc(h,65056,44);k=g,l=jj(a,b,c,d,e,f,g,g+44|0),x[k+56>>2]=l;break b}x[h+16>>2]=x[16280];g=x[16279];x[h+8>>2]=x[16278];x[h+12>>2]=g;g=x[16277];x[h>>2]=x[16276];x[h+4>>2]=g;k=h,l=jj(a,b,c,d,e,f,h,h+20|0),x[k+56>>2]=l;break b}a=ii(h+56|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}g=x[16291];x[h+24>>2]=x[16290];x[h+28>>2]=g;g=x[16289];x[h+16>>2]=x[16288];x[h+20>>2]=g;g=x[16287];x[h+8>>2]=x[16286];x[h+12>>2]=g;g=x[16285];x[h>>2]=x[16284];x[h+4>>2]=g;k=h,l=jj(a,b,c,d,e,f,h,h+32|0),x[k+56>>2]=l;break b}a=ii(h+56|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=mb[x[x[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=jj(g,b,c,d,e,f,Rb(a),Rb(a)+(Bb(a)<<2)|0),x[k+56>>2]=l;break b}mF(f+20|0,h+56|0,c,e,i);break b}a=ii(h+56|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=hb-16|0;hb=a;x[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(hh(c,a+8|0)){break M}b=4;if((Pm(i,wl(c))|0)!=37){break M}b=2;if(!hh(Zm(c),a+8|0)){break L}}x[e>>2]=x[e>>2]|b}hb=a+16|0}a=x[h+56>>2]}hb=h- -64|0;return a|0}function Mba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;x[a+24588>>2]=0;x[a+24592>>2]=0;x[a+4>>2]=0;x[a>>2]=25872;x[a+8>>2]=x[19567];b=a+24596|0;x[b>>2]=0;x[b+4>>2]=0;Vp(a+24604|0);pM(a+24648|0,0);b=a+393352|0;x[b>>2]=8;x[b+4>>2]=0;x[b+4104>>2]=0;x[b+4108>>2]=0;w[b+4128>>1]=0;d=b+4120|0;x[d>>2]=0;x[d+4>>2]=0;d=b+4112|0;x[d>>2]=0;x[d+4>>2]=0;Sb(b+4132|0,0,40);FO(b+8|0,1024);Sb(b+4172|0,0,49824);Sb(b+53996|0,0,32832);x[a+480224>>2]=0;w[a+480212>>1]=0;x[a+480204>>2]=0;x[a+480208>>2]=0;x[a+480180>>2]=0;x[a+480184>>2]=0;b=a+480186|0;w[b>>1]=0;w[b+2>>1]=0;w[b+4>>1]=0;w[b+6>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;k=Dk(a+480248|0);x[a+480272>>2]=0;b=a+484344|0;c=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{while(1){x[114414]=0;d=R(1395,c|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break m}c=d+32|0;if((b|0)!=(c|0)){continue}break}d=hb-16|0;hb=d;x[b>>2]=0;x[b+4>>2]=0;x[114414]=0;x[d+12>>2]=0;U(1408,b+8|0,d+12|0,d+8|0)|0;c=x[114414];x[114414]=0;n:{if((c|0)!=1){hb=d+16|0;break n}break a}x[b+12>>2]=a;d=b;x[114414]=0;l=O(1396,a+484360|0,a|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break l}g=a+900380|0;c=a+484380|0;while(1){x[114414]=0;b=O(996,c|0,0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break k}c=b+104|0;if((g|0)!=(c|0)){continue}break}x[114414]=0;R(1397,a+901404|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break j}h=a+946300|0;i=a+906300|0;c=i;while(1){x[114414]=0;b=R(1398,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break i}c=b+160|0;if((h|0)!=(c|0)){continue}break}x[a+946300>>2]=0;c=a+1074304|0;j=a+946304|0;b=j;while(1){x[114414]=0;b=R(1150,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break h}b=b+32|0;if((c|0)!=(b|0)){continue}break}x[a+1074304>>2]=0;x[a+1074308>>2]=0;Wq(a+1074312|0);x[114414]=0;b=$(1399)|0;c=x[114414];x[114414]=0;if((c|0)==1){break g}x[114414]=0;b=R(1400,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break g}x[a+1074328>>2]=b;x[114414]=0;R(1401,a+1074332|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break g}x[114414]=0;R(1402,a+1074376|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break g}x[114414]=0;m=U(1337,a+1304360|0,a|0,255)|0;b=x[114414];x[114414]=0;if((b|0)==1){break g}c=hb-16|0;hb=c;x[114414]=0;b=U(1405,a+1304392|0,c+8|0,c|0)|0;e=x[114414];x[114414]=0;o:{if((e|0)!=1){hb=c+16|0;break o}break a}c=b;e=hb-16|0;hb=e;x[114414]=0;b=U(1406,a+1304396|0,e+8|0,e|0)|0;f=x[114414];x[114414]=0;p:{if((f|0)!=1){hb=e+16|0;break p}break a}e=b;n=Wb(a+1304400|0);o=hd(a+1304412|0);q=Wb(a+1304424|0);r=nM(a+1304436|0);f=hb-16|0;hb=f;b=a+1304500|0;x[b>>2]=0;x[b+4>>2]=0;x[114414]=0;x[f+12>>2]=0;U(1407,b+8|0,f+12|0,f+8|0)|0;s=x[114414];x[114414]=0;q:{if((s|0)!=1){hb=f+16|0;break q}break a}f=b;v[a+1304512|0]=0;b=a+1304520|0;x[b>>2]=0;x[b+4>>2]=0;x[b+32>>2]=0;x[b+36>>2]=1072693248;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[a+1304560>>2]=0;wp(a+12|0);Xp(a+8204|0);Xp(a+12300|0);b=a+1074408|0;x[b>>2]=4;x[b+4>>2]=16;x[a+480216>>2]=4;x[a+480220>>2]=16;mM(g);x[114414]=0;W(1403,j|0);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=R(1404,12)|0;g=x[114414];x[114414]=0;if((g|0)==1){break f}x[b>>2]=0;x[b+4>>2]=0;x[b+8>>2]=0;d=hb-16|0;hb=d;x[b>>2]=0;x[b+4>>2]=0;x[114414]=0;x[d+12>>2]=0;U(1409,b+8|0,d+12|0,d+8|0)|0;c=x[114414];x[114414]=0;r:{if((c|0)!=1){hb=d+16|0;break r}break a}x[a+4>>2]=b;return a|0}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;break d}b=N()|0;if((c|0)==(i|0)){break d}while(1){c=vp(c-160|0);if((i|0)!=(c|0)){continue}break}break d}b=N()|0;break e}b=N()|0;break e}b=N()|0;lM(f);zy(r);xb(q);xb(o);xb(n);yy(e);xy(c);et(m)}while(1){h=vp(h-160|0);if((i|0)!=(h|0)){continue}break}}fz(l)}gM(d)}Ge(k);Q(b|0);p()}S(0)|0;zb();p()}function Mja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;f=hb-48|0;hb=f;a:{b:{c:{d:{if(!c){break d}u=f,w=pe(a),v[u+32|0]=w;g=f+32|0;e:{if(A[b+4>>2]<A[yb(b)>>2]){d=hb-16|0;hb=d;h=th(d,b,1);e=yb(b);j=x[h+4>>2];x[114414]=0;T(854,e|0,j|0,g|0);j=x[114414];x[114414]=0;if((j|0)!=1){x[h+4>>2]=x[h+4>>2]+1;Jb(h);hb=d+16|0;break e}a=N()|0;Jb(h);break a}d=hb-32|0;hb=d;e=yb(b);h=Yh(d+8|0,Wh(b,wc(b)+1|0),wc(b),e);j=x[h+8>>2];x[114414]=0;T(854,e|0,j|0,g|0);j=x[114414];x[114414]=0;f:{g:{if((j|0)==1){break g}x[h+8>>2]=x[h+8>>2]+1;x[114414]=0;P(328,b|0,h|0);j=x[114414];x[114414]=0;if((j|0)==1){break g}Ah(h);hb=d+32|0;break f}a=N()|0;Ah(h);break a}}j=c-1|0;if(j){while(1){h:{i:{c=i<<1;i=c&254;j:{if(!i){if(!Oe(a,f+32|0)){break d}c=y[f+32|0]<<1|1;i=c&255;if(c>>>0>255){break j}break i}if((c&65535)>>>0<256){break i}}d=1;while(1){k:{l:{m:{c=i<<1&254;if(c){e=i>>>0>127}else{if(!Oe(a,f+32|0)){break m}e=y[f+32|0]<<1|1;c=e&255;e=e>>>0>255}d=e|d<<1;i=c<<1&254;if(i){break l}if(!Oe(a,f+32|0)){break m}c=y[f+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break k}i=0;break k}if(c>>>0>127){continue}}break}n:{if((d|0)<=2){k=0;d=d-2|0;break n}if(!Oe(a,f+32|0)){break d}c=(y[f+32|0]|d<<8)-768|0;k=((c|0)>1279?2:1)+((c|0)>31999)|0;q=c^-1;d=0}c=i<<1&254;if(c){e=i>>>0>127}else{if(!Oe(a,f+32|0)){break d}e=y[f+32|0]<<1|1;c=e&255;e=e>>>0>255}i=c<<1&254;if(i){c=c>>>0>127}else{if(!Oe(a,f+32|0)){break d}c=y[f+32|0]<<1|1;i=c&255;c=c>>>0>255}c=c|(d<<2|(e?2:0));if(!c){d=1;while(1){o:{p:{q:{c=i<<1&254;if(c){e=i>>>0>127}else{if(!Oe(a,f+32|0)){break q}e=y[f+32|0]<<1|1;c=e&255;e=e>>>0>255}d=e|d<<1;i=c<<1&254;if(i){break p}if(!Oe(a,f+32|0)){break q}c=y[f+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break o}i=0;break o}if(c>>>0>127){continue}}break}c=d+2|0}e=c+k|0;d=0;if(e>>>0>j>>>0|(e|0)<=0|(q|0)>=0){break c}d=0;if((0-wc(b)|0)>(q|0)){break c}u=f,w=dc(b),x[u+32>>2]=w;c=td(f+40|0,f+32|0);v[f+24|0]=0;m=f+24|0;l=hb-48|0;hb=l;x[l+32>>2]=x[c>>2];c=x[b>>2];u=l,w=bc(b),x[u+8>>2]=w;k=qm(l+32|0,l+8|0)+c|0;r:{if(!e){break r}c=x[yb(b)>>2];g=x[b+4>>2];if(e>>>0<=c-g>>>0){c=e;d=g-k|0;if(c>>>0>d>>>0){qq(b,e-d|0,m);c=d;if(!c){break r}}r=hb-16|0;hb=r;d=g;t=x[b+4>>2];h=(t-(e+k|0)|0)+k|0;n=th(r,b,d-h|0);s:{t:{if(d>>>0>h>>>0){o=x[n+4>>2];g=h;while(1){s=yb(b);x[114414]=0;T(854,s|0,o|0,g|0);s=x[114414];x[114414]=0;if((s|0)==1){break t}o=o+1|0;x[n+4>>2]=o;g=g+1|0;if(d>>>0>g>>>0){continue}break}}Jb(n);bq(k,h,t);hb=r+16|0;break s}a=N()|0;Jb(n);break a}Th(k,c,(k>>>0<=m>>>0?A[b+4>>2]>m>>>0?e:0:0)+m|0);break r}c=yb(b);c=Yh(l+8|0,Wh(b,wc(b)+e|0),k-x[b>>2]|0,c);x[114414]=0;T(677,c|0,e|0,m|0);d=x[114414];x[114414]=0;if((d|0)==1){break b}x[114414]=0;k=U(851,b|0,c|0,k|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break b}Ah(c)}Fb(l+40|0,k);hb=l+48|0;u=f,w=dc(b),x[u+16>>2]=w;u=f,w=Tz(f+16|0,e),x[u+24>>2]=w;u=f,w=Fe(m,q),x[u+32>>2]=w;u=f,w=dc(b),x[u+16>>2]=w;u=f,w=Tz(f+16|0,e),x[u+24>>2]=w;c=e;while(1){u=f,w=Qw(f+32|0),x[u+16>>2]=w;d=y[x[f+16>>2]];u=f,w=Qw(f+24|0),x[u+8>>2]=w;v[x[f+8>>2]]=d;d=c>>>0>1;c=c-1|0;if(d){continue}break}j=j-e|0;break h}if(!Oe(a,f+32|0)){break d}h=f+32|0;u:{if(x[b+4>>2]!=x[yb(b)>>2]){d=hb-16|0;hb=d;g=th(d,b,1);e=yb(b);c=x[g+4>>2];x[114414]=0;T(532,e|0,c|0,h|0);c=x[114414];x[114414]=0;if((c|0)!=1){x[g+4>>2]=x[g+4>>2]+1;Jb(g);hb=d+16|0;break u}a=N()|0;Jb(g);break a}g=hb-32|0;hb=g;d=yb(b);c=Yh(g+8|0,Wh(b,wc(b)+1|0),wc(b),d);e=x[c+8>>2];x[114414]=0;T(532,d|0,e|0,h|0);e=x[114414];x[114414]=0;if((e|0)==1){break b}x[c+8>>2]=x[c+8>>2]+1;x[114414]=0;P(328,b|0,c|0);e=x[114414];x[114414]=0;if((e|0)==1){break b}Ah(c);hb=g+32|0}j=j-1|0}if(j){continue}break}}d=1;break c}d=0}hb=f+48|0;return d|0}a=N()|0;Ah(c)}Q(a|0);p()}function Rla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0;g=hb-992|0;hb=g;Lc(b);d=hb-16|0;hb=d;e=d+8|0;f=g+888|0;WS(e,f);h=Eb(e);e=nc(b,ac(d,e));if((h|0)==(e|0)){cc(b,Eb(d+8|0))}hb=d+16|0;d=(e|0)==(h|0);if(!d){XS(f)}a:{if(!d){break a}if(!_S(g+888|0)){break a}if(!Qb(b,jd(ZS(g+888|0),lb))){break a}if(!c){k=1;break a}Nd(a,512);x[a+480228>>2]=32;w[a+480188>>1]=16;x[a+480196>>2]=y[g+963|0];x[a+480200>>2]=256;x[a+480204>>2]=8e5;d=g+112|0;e=Ub(d,4429);Db(a+1304436|0,e);xb(e);e=Ub(d,5033);Db(a+1304448|0,e);xb(e);x[a+1304496>>2]=4;e=g+40|0;YS(e,2,g+888|4);Ic(d,e);Db(a+1304400|0,d);xb(d);d=0;while(1){e=(d<<5)+a|0;f=e+480280|0;Lg(f);h=f;f=(g+888|0)+d|0;x[h>>2]=!y[f+50|0]<<10;w[e+480284>>1]=(y[f+76|0]<<4|8)&248;d=d+1|0;if((d|0)!=16){continue}break}if(y[g+984|0]|y[g+985|0]<<8){oz(a+1304424|0,b,y[g+984|0]|y[g+985|0]<<8,132,0)}d=hb-16|0;hb=d;f=hb-16|0;hb=f;e=d+8|0;h=g+112|0;jc(e,h,771);hb=f+16|0;f=Eb(e);e=nc(b,ac(d,e));if((f|0)==(e|0)){cc(b,Eb(d+8|0))}hb=d+16|0;k=(e|0)==(f|0);if(!k){d=hb-16|0;hb=d;Sb(h,0,771);hb=d+16|0}if(!k){break a}d=a+484360|0;zA(Vb(d),g+112|0,y[g+369|0],255,254);Se(Vb(d),y[g+370|0]);Rc(b,y[g+935|0]|y[g+936|0]<<8);m=a+484344|0;q=c&1;e=0;b:{c:{while(1){d=(e<<1)+g|0;if(y[d+371|0]|y[d+372|0]<<8){Bd(g+40|0,b,y[d+371|0]|y[d+372|0]<<8);d=y[d+371|0]|y[d+372|0]<<8;h=(d-2|0)/64|0;d:{if(!q){break d}x[114414]=0;f=U(363,m|0,e&65535,h|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break c}if(!f){break d}x[114414]=0;j=R(403,g+40|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break c}x[114414]=0;O(304,g+40|0,1)|0;f=x[114414];x[114414]=0;if((f|0)==1){break c}if(d>>>0>=66){r=h>>>0<=1?1:h;i=0;while(1){d=Zb(m,e);x[114414]=0;s=O(453,d|0,i|0)|0;d=x[114414];x[114414]=0;l=0;if((d|0)==1){break c}while(1){x[114414]=0;P(562,g+24|0,g+40|0);d=x[114414];x[114414]=0;e:{f:{g:{if((d|0)!=1){d=D(l,6)+s|0;f=g+24|0;t=ed(f);o=rf(f);n=$h(f);f=y[f|0];if((f-1&255)>>>0>71){break g}v[d|0]=f+36;v[d+1|0]=y[t|0]+1;break f}break c}if(!(y[d|0]|y[o|0])){break e}}v[d+2|0]=1;u=d,B=(Md(y[o|0],1,16)<<2)-4|0,v[u+4|0]=B}f=y[n|0]&15;v[d+5|0]=f;h:{i:{switch((y[n|0]>>>4|0)-3|0){case 0:v[d+5|0]=f<<2;break h;case 1:v[d+5|0]=(6/(f+1>>>0)|0)+1;break h;case 3:case 4:v[d+5|0]=f<<3;break h;case 7:v[d+4|0]=(f<<2)+4;v[d+2|0]=1;break h;case 8:v[d+5|0]=f|128;break h;case 9:break i;default:break h}}v[d+5|0]=(6/(f+1>>>0)|0)+1|13}v[d+3|0]=y[(y[n|0]>>>4|0)+23488|0];l=l+1|0;if((l|0)!=16){continue}break}i=i+1|0;if((r|0)!=(i|0)){continue}break}}d=Zb(m,e);x[114414]=0;f=U(454,g+96|0,14,0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break c}f=ai(Ie(f,j?j>>>0>=h-2>>>0?-1:j+1|0:-1));x[114414]=0;O(455,d|0,f|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break c}}Ab(g+40|0)}e=e+1|0;if((e|0)!=256){continue}break}if(!(c&2)){break a}UT(b,g+88|0);d=0;while(1){j:{k:{if(!(y[g+88+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;break k}if(!yA(b,g+40|0)){break a}d=d+1|0;w[a+480190>>1]=d;c=g+8|0;Kg(c,1,g+40|0);e=g+24|0;Ic(e,c);c=z[a+480190>>1];x[114414]=0;O(334,((c<<5)+a|0)+946304|0,e|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break j}f=g+24|0;xb(f);c=(D(d,104)+a|0)+484380|0;Ad(c,0);e=g+40|0;x[c>>2]=y[e+32|0]|y[e+33|0]<<8|(y[e+34|0]<<16|y[e+35|0]<<24);x[c+4>>2]=y[e+38|0]|y[e+39|0]<<8|(y[e+40|0]<<16|y[e+41|0]<<24);h=y[e+42|0]|y[e+43|0]<<8|(y[e+44|0]<<16|y[e+45|0]<<24);x[c+24>>2]=16726;x[c+8>>2]=h;w[c+30>>1]=y[e+37|0]<<4;if(v[e+46|0]&1){x[c>>2]=x[c>>2]>>>1;x[c+4>>2]=x[c+4>>2]>>>1;x[c+8>>2]=x[c+8>>2]>>>1}if(!(!(y[e+47|0]&8)|A[c+8>>2]<=A[c+4>>2])){w[c+34>>1]=z[c+34>>1]|2}ad(f,v[e+46|0]&1?16:8,1,0,0);Eg(f,c,b)}if((d|0)!=64){continue}break a}break}d=N()|0;xb(g+24|0);break b}d=N()|0;Ab(g+40|0)}Q(d|0);p()}hb=g+992|0;return k|0}function w_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=hb-32|0;hb=h;x[h+24>>2]=b;x[e>>2]=0;i=h+8|0;Dc(i,d);x[114414]=0;i=R(21,i|0)|0;j=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Ob(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Ob(h+8|0);Q(a|0);p()}rF(a,f+24|0,h+24|0,c,e,i);break b}qF(a,f+16|0,h+24|0,c,e,i);break b}g=a;a=mb[x[x[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=kj(g,b,c,d,e,f,Rb(a),Rb(a)+Bb(a)|0),x[k+24>>2]=l;break b}a=ji(h+24|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}x[h+8>>2]=623865125;x[h+12>>2]=2032480100;k=h,l=kj(a,b,c,d,e,f,h+8|0,h+16|0),x[k+24>>2]=l;break b}x[h+8>>2]=623728933;x[h+12>>2]=1680158061;k=h,l=kj(a,b,c,d,e,f,h+8|0,h+16|0),x[k+24>>2]=l;break b}a=ji(h+24|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=ji(h+24|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=ji(h+24|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=ji(h+24|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=ji(h+24|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+24|0;b=hb-16|0;hb=b;x[b+8>>2]=c;while(1){H:{if(Ag(a,b+8|0)){break H}if(!zg(i,1,nk(a))){break H}yl(a);continue}break}if(Ag(a,b+8|0)){x[e>>2]=x[e>>2]|2}hb=b+16|0;break b}b=h+24|0;a=mb[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Bb(a)|0)==(0-Bb(a+12|0)|0)){x[e>>2]=x[e>>2]|4;break I}c=Hr(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=y[64968]|y[64969]<<8|(y[64970]<<16|y[64971]<<24);v[h+15|0]=g;v[h+16|0]=g>>>8;v[h+17|0]=g>>>16;v[h+18|0]=g>>>24;g=y[64965]|y[64966]<<8|(y[64967]<<16|y[64968]<<24);x[h+8>>2]=y[64961]|y[64962]<<8|(y[64963]<<16|y[64964]<<24);x[h+12>>2]=g;k=h,l=kj(a,b,c,d,e,f,h+8|0,h+19|0),x[k+24>>2]=l;break b}v[h+12|0]=y[64976];x[h+8>>2]=y[64972]|y[64973]<<8|(y[64974]<<16|y[64975]<<24);k=h,l=kj(a,b,c,d,e,f,h+8|0,h+13|0),x[k+24>>2]=l;break b}a=ji(h+24|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}x[h+8>>2]=624576549;x[h+12>>2]=1394948685;k=h,l=kj(a,b,c,d,e,f,h+8|0,h+16|0),x[k+24>>2]=l;break b}a=ji(h+24|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=mb[x[x[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=kj(g,b,c,d,e,f,Rb(a),Rb(a)+Bb(a)|0),x[k+24>>2]=l;break b}pF(f+20|0,h+24|0,c,e,i);break b}a=ji(h+24|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=hb-16|0;hb=a;x[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(Ag(c,a+8|0)){break M}b=4;if((Qm(i,nk(c))|0)!=37){break M}b=2;if(!Ag(yl(c),a+8|0)){break L}}x[e>>2]=x[e>>2]|b}hb=a+16|0}a=x[h+24>>2]}hb=h+32|0;return a|0}function OM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=hb-16|0;hb=h;e=c&15;f=D(b,896)+a|0;d=f+1074984|0;a:{b:{switch((c&240)-16>>>4|0){case 0:a=f+1075072|0;x[a>>2]=x[a>>2]&-1048577|((e|0)!=0)<<20;break a;case 1:if(!(y[a+480209|0]&16)){break a}if(x[a+480180>>2]==33554432){c=D(b,896)+a|0;d=c+1075684|0;if(!x[d>>2]){break a}c=x[c+1075088>>2];if(!c){break a}f=D(b,896)+a|0;g=f+1075688|0;e=z[D(e,24)+26112>>1];b=x[c+24>>2];i=yna(b,b>>31,1712,0);c=(e>>>1|0)+i|0;b=lb;b=Cc(zna(c,c>>>0<i>>>0?b+1|0:b,e,0),lb);x[g>>2]=b;k=d,l=eg(a,y[f+1075803|0],0,b),x[k>>2]=l;break a}if(x[a+480180>>2]!=64){b=D(b,896)+a|0;c=e<<28>>24;x[b+1075752>>2]=c;e=z[(e<<1)+26544>>1];x[b+1075688>>2]=e;d=b+1075684|0;if(!x[d>>2]){break a}k=d,l=eg(a,y[b+1075803|0],c,e),x[k>>2]=l;break a}a=D(b,896)+a|0;b=x[a+1075088>>2];if(!b){break a}x[a+1075688>>2]=x[b+24>>2]+D(e,80);break a;case 2:if(x[a+480180>>2]==2){v[(D(b,896)+a|0)+1075826|0]=c&3;break a}d=h+8|0;Kb(d,a+1074312|0,21);if(Ib(d)){v[(D(b,896)+a|0)+1075826|0]=e>>>0<4?e:0;break a}v[(D(b,896)+a|0)+1075826|0]=c&7;break a;case 3:if(x[a+480180>>2]==2){v[(D(b,896)+a|0)+1075829|0]=c&3;break a}d=h+8|0;Kb(d,a+1074312|0,21);if(Ib(d)){v[(D(b,896)+a|0)+1075829|0]=e>>>0<4?e:0;break a}v[(D(b,896)+a|0)+1075829|0]=c&7;break a;case 4:d=h+8|0;Kb(d,a+1074312|0,21);if(Ib(d)){a=D(b,896)+a|0;v[a+1075825|0]=0;v[a+1075832|0]=e>>>0<4?e:0;break a}v[(D(b,896)+a|0)+1075832|0]=c&7;break a;case 5:if(x[a+1074392>>2]|!(y[a+480209|0]&16)){break a}a=a+1074400|0;x[a>>2]=x[a>>2]+e;break a;case 6:if(!(y[a+480209|0]&16)){break a}if(e>>>0<=2){c=z[a+480188>>1];if(c>>>0>255){break a}d=a+1304392|0;i=b+1|0;j=e-1|0;while(1){e=D(c,896)+a|0;c:{if(z[e+1075792>>1]!=(i|0)){break c}d:{e:{switch(j|0){case 0:vn(a,e+1074984|0);if(!(y[e+1075073|0]&2)){break d}if(!zd(d)){break d}Ik(x[d>>2],c&65535);break d;case 1:g=e+1075072|0;f=x[g>>2];x[g>>2]=f|4096;if(!(f&512)){break d}if(!zd(d)){break d}Ik(x[d>>2],c&65535);break d;default:break e}}x[e+1075680>>2]=0;g=e+1075072|0;f=x[g>>2];x[g>>2]=f|4096;if(!(f&512)){break d}if(!zd(d)){break d}Ji(x[d>>2],c&65535,1)}f=x[e+1075640>>2];if(!f){break c}g=y[f+34|0];if(!g){break c}g=x[(D(g,160)+a|0)+906140>>2];if(!g){break c}mb[x[x[g>>2]+88>>2]](g,f,y[e+1075803|0]+255|0,0,b)}c=c+1|0;if((c&65535)!=256){continue}break}break a}yO(d,e,a);break a;case 7:if(!(y[a+480209|0]&16)){break a}Sl(a,d,e,4);break a;case 8:b=x[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(e|0){case 0:x[d+88>>2]=x[d+88>>2]&-257;break f;case 1:x[d+692>>2]=128;x[d+88>>2]=x[d+88>>2]|256;break f;case 8:x[d+88>>2]=x[d+88>>2]&-25165825|16777216;break f;case 9:x[d+88>>2]=x[d+88>>2]&-25165825|8388608;break f;case 10:x[a+480208>>2]=b&-16385;break f;case 11:x[a+480208>>2]=b|16384;break f;case 12:x[a+480208>>2]=b&-8193;break f;case 13:x[a+480208>>2]=b|8192;break f;case 14:x[d+88>>2]=x[d+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(!x[d+76>>2]|(x[d>>2]|x[d+4>>2])){break h}if(!(k=Af(d+810|0),l=1,m=y[d+88|0]&2,m?k:l)){break h}a=x[d+76>>2]-1|0;x[d>>2]=-1;x[d+4>>2]=a}x[d+88>>2]=x[d+88>>2]|128}break a;case 9:if(!(y[a+480209|0]&16)){break a}c=D(b,896)+a|0;v[c+1075840|0]=e;f=h+8|0;Kb(f,a+1074312|0,35);if(Ib(f)){break a}if(!Af(c+1075794|0)){break a}b=x[(D(b,896)+a|0)+1075060>>2];a=e<<16;if(b>>>0<=a>>>0){break a}x[d+4>>2]=a;break a;case 11:i:{if(e){break i}e=1;if(x[a+480180>>2]&16777248){break i}e=0;if(x[a+480180>>2]==2){break a}}c=h+8|0;Kb(c,a+1074312|0,30);if(Ib(c)){c=1}else{c=x[a+480180>>2]==2}Hy(a,b,e,c);break a;case 14:break b;default:break a}}if(x[a+480180>>2]==2){break a}v[(D(b,896)+a|0)+1075848|0]=e}hb=h+16|0}function HI(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=hb-256|0;hb=e;C[e+248>>3]=c;a:{if(vj(b)){break a}f=y[rk(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Fk(e+216|0,b,x[b+4>>2]-1|0);f=x[e+220>>2];x[b>>2]=x[e+216>>2];x[b+4>>2]=f}f=e+216|0;Hd(f);g=x[e+216>>2];Hd(e+200|0);h=qk(g,x[e+204>>2],b);Hd(f);f=x[b>>2];g=x[b+4>>2];b:{c:{d:{e:{f:{g:{h:{i:{if((h|0)==x[e+220>>2]){x[e+240>>2]=f;x[e+244>>2]=g;a=tc(e+232|0,17386);f=x[e+244>>2];x[e+16>>2]=x[e+240>>2];x[e+20>>2]=f;f=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=f;if(Kc(e+16|0,e+8|0)){a=ec(8);x[114414]=0;P(2174,e+200|0,e+248|0);b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;T(2152,e+216|0,13488,e+200|0);b=x[114414];x[114414]=0;if((b|0)==1){break g}a=oc(a,e+216|0);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(e+216|0);xb(e+200|0);break c}b=N()|0;break d}if(!d){break i}f=ec(8);x[114414]=0;d=O(2172,e+168|0,b|0)|0;a=x[114414];x[114414]=0;j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[114414]=0;T(2152,e+184|0,13524,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break q}x[114414]=0;T(2167,e+200|0,e+184|0,13498);b=x[114414];x[114414]=0;a=1;if((b|0)==1){break p}x[114414]=0;P(2174,e+152|0,e+248|0);a=x[114414];x[114414]=0;if((a|0)==1){break o}x[114414]=0;T(137,e+216|0,e+200|0,e+152|0);b=x[114414];x[114414]=0;a=1;if((b|0)==1){break n}a=oc(f,e+216|0);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(e+216|0);a=0;break m}b=N()|0;break j}b=N()|0;xb(d);break j}b=N()|0;break k}b=N()|0;a=1;break l}b=N()|0}xb(e+152|0)}xb(e+200|0)}xb(e+184|0);xb(d);if(!a){break c}}hc(f);break c}x[e+144>>2]=f;x[e+148>>2]=g;d=tc(e+136|0,17386);f=x[e+148>>2];x[e+80>>2]=x[e+144>>2];x[e+84>>2]=f;f=x[d+4>>2];x[e+72>>2]=x[d>>2];x[e+76>>2]=f;if(Kc(e+80|0,e+72|0)){a=ec(8);x[114414]=0;P(2174,e+200|0,e+248|0);b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;T(2152,e+216|0,13488,e+200|0);b=x[114414];x[114414]=0;if((b|0)==1){break f}a=oc(a,e+216|0);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(e+216|0);xb(e+200|0);break c}b=N()|0;break e}d=x[b+4>>2];x[e+128>>2]=x[b>>2];x[e+132>>2]=d;d=tc(e+120|0,3991);f=x[e+132>>2];x[e+64>>2]=x[e+128>>2];x[e+68>>2]=f;f=x[d+4>>2];x[e+56>>2]=x[d>>2];x[e+60>>2]=f;if(Kc(e- -64|0,e+56|0)){if(!y[a+28|0]){break i}if(!(!(c<=0)&c<=4)){a=ec(8);x[114414]=0;d=O(118,e+216|0,4086)|0;b=x[114414];x[114414]=0;if((b|0)==1){break h}a=oc(a,d);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(d);break c}b=gg(65536/c);a=a+24|0;x[x[a>>2]+480244>>2]=b;sp(x[a>>2]);break i}d=x[b+4>>2];x[e+112>>2]=x[b>>2];x[e+116>>2]=d;d=tc(e+104|0,4043);f=x[e+116>>2];x[e+48>>2]=x[e+112>>2];x[e+52>>2]=f;f=x[d+4>>2];x[e+40>>2]=x[d>>2];x[e+44>>2]=f;if(Kc(e+48|0,e+40|0)){if(!y[a+28|0]){break i}if(!(!(c<=0)&c<=4)){a=ec(8);x[114414]=0;d=O(118,e+216|0,4107)|0;b=x[114414];x[114414]=0;if((b|0)!=1){a=oc(a,d);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(d);break c}b=N()|0;hc(a);break c}b=gg(c*65536);a=a+24|0;x[x[a>>2]+480240>>2]=b;sp(x[a>>2]);break i}d=x[b+4>>2];x[e+96>>2]=x[b>>2];x[e+100>>2]=d;b=tc(e+88|0,4061);d=x[e+100>>2];x[e+32>>2]=x[e+96>>2];x[e+36>>2]=d;d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(!Kc(e+32|0,e+24|0)){break i}b=Cn(c*65536);x[x[a+24>>2]+480236>>2]=b}hb=e+256|0;return}b=N()|0;hc(a);break c}b=N()|0;xb(e+200|0);break d}b=N()|0;xb(e+200|0)}hc(a);break c}hc(a)}Q(b|0)}p()}function K2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-352|0;hb=d;a:{if(vj(b)){break a}e=y[rk(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Fk(d+320|0,b,x[b+4>>2]-1|0);e=x[d+324>>2];x[b>>2]=x[d+320>>2];x[b+4>>2]=e}f=d+320|0;Hd(f);e=x[d+320>>2];Hd(d+304|0);e=qk(e,x[d+308>>2],b);Hd(f);b:{c:{d:{e:{f:{g:{if((e|0)==x[d+324>>2]){a=x[b+4>>2];x[d+344>>2]=x[b>>2];x[d+348>>2]=a;a=tc(d+336|0,17386);e=x[d+348>>2];x[d+8>>2]=x[d+344>>2];x[d+12>>2]=e;e=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=e;if(Kc(d+8|0,d)){a=ec(8);x[114414]=0;c=O(118,d+320|0,6463)|0;b=x[114414];x[114414]=0;if((b|0)==1){break f}a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}e=0;if(!c){break g}c=ec(8);x[114414]=0;a=O(2172,d+304|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;T(2152,d+320|0,13524,a|0);b=x[114414];x[114414]=0;if((b|0)==1){break e}b=oc(c,d+320|0);x[114414]=0;T(2042,b|0,82448,2050);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=N()|0;xb(d+320|0);xb(a);break c}b=N()|0;break d}if(x[e+4>>2]){a=ec(8);x[114414]=0;c=O(118,d+320|0,7464)|0;b=x[114414];x[114414]=0;if((b|0)!=1){a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}b=N()|0;hc(a);break c}c=x[b+4>>2];x[d+296>>2]=x[b>>2];x[d+300>>2]=c;c=tc(d+288|0,17386);e=x[d+300>>2];x[d+152>>2]=x[d+296>>2];x[d+156>>2]=e;e=x[c+4>>2];x[d+144>>2]=x[c>>2];x[d+148>>2]=e;if(Kc(d+152|0,d+144|0)){a=ec(8);x[114414]=0;c=O(118,d+320|0,6463)|0;b=x[114414];x[114414]=0;if((b|0)!=1){a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}b=N()|0;hc(a);break c}c=x[b+4>>2];x[d+280>>2]=x[b>>2];x[d+284>>2]=c;c=tc(d+272|0,3674);e=x[d+284>>2];x[d+136>>2]=x[d+280>>2];x[d+140>>2]=e;e=x[c+4>>2];x[d+128>>2]=x[c>>2];x[d+132>>2]=e;h:{if(!Kc(d+136|0,d+128|0)){c=x[b+4>>2];x[d+264>>2]=x[b>>2];x[d+268>>2]=c;c=tc(d+256|0,3656);e=x[d+268>>2];x[d+120>>2]=x[d+264>>2];x[d+124>>2]=e;e=x[c+4>>2];x[d+112>>2]=x[c>>2];x[d+116>>2]=e;if(!Kc(d+120|0,d+112|0)){break h}}e=y[a+60|0]!=0;break g}c=x[b+4>>2];x[d+248>>2]=x[b>>2];x[d+252>>2]=c;c=tc(d+240|0,3240);e=x[d+252>>2];x[d+104>>2]=x[d+248>>2];x[d+108>>2]=e;e=x[c+4>>2];x[d+96>>2]=x[c>>2];x[d+100>>2]=e;i:{if(!Kc(d+104|0,d+96|0)){c=x[b+4>>2];x[d+232>>2]=x[b>>2];x[d+236>>2]=c;c=tc(d+224|0,3221);e=x[d+236>>2];x[d+88>>2]=x[d+232>>2];x[d+92>>2]=e;e=x[c+4>>2];x[d+80>>2]=x[c>>2];x[d+84>>2]=e;if(!Kc(d+88|0,d+80|0)){break i}}e=y[a+61|0]!=0;break g}c=x[b+4>>2];x[d+216>>2]=x[b>>2];x[d+220>>2]=c;c=tc(d+208|0,3324);e=x[d+220>>2];x[d+72>>2]=x[d+216>>2];x[d+76>>2]=e;e=x[c+4>>2];x[d+64>>2]=x[c>>2];x[d+68>>2]=e;if(Kc(d+72|0,d- -64|0)){e=y[a+62|0]!=0;break g}c=x[b+4>>2];x[d+200>>2]=x[b>>2];x[d+204>>2]=c;c=tc(d+192|0,2484);e=x[d+204>>2];x[d+56>>2]=x[d+200>>2];x[d+60>>2]=e;e=x[c+4>>2];x[d+48>>2]=x[c>>2];x[d+52>>2]=e;if(Kc(d+56|0,d+48|0)){e=y[a+63|0]!=0;break g}c=x[b+4>>2];x[d+184>>2]=x[b>>2];x[d+188>>2]=c;c=tc(d+176|0,3723);e=x[d+188>>2];x[d+40>>2]=x[d+184>>2];x[d+44>>2]=e;e=x[c+4>>2];x[d+32>>2]=x[c>>2];x[d+36>>2]=e;if(Kc(d+40|0,d+32|0)){e=y[a+64|0]!=0;break g}c=x[b+4>>2];x[d+168>>2]=x[b>>2];x[d+172>>2]=c;b=tc(d+160|0,9235);c=x[d+172>>2];x[d+24>>2]=x[d+168>>2];x[d+28>>2]=c;c=x[b+4>>2];x[d+16>>2]=x[b>>2];x[d+20>>2]=c;e=0;if(!Kc(d+24|0,d+16|0)){break g}e=x[x[a+24>>2]+24668>>2]!=0}hb=d+352|0;return e|0}b=N()|0;hc(a);break c}b=N()|0;xb(a)}hc(c)}Q(b|0)}p()}function ZU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=hb-576|0;hb=g;Lc(b);d=hb-16|0;hb=d;e=d+8|0;j=g+72|0;YB(e,j);h=Eb(e);e=nc(b,ac(d,e));if((h|0)==(e|0)){cc(b,Eb(d+8|0))}hb=d+16|0;d=(e|0)==(h|0);if(!d){ZB(j)}a:{if(!d){break a}if(!cC(g+72|0)){break a}b:{if(!c){break b}if(!Qb(b,jd(bC(g+72|0),lb))){break a}Nd(a,64);x[a+480204>>2]=78e4;x[a+480260>>2]=112;x[a+480264>>2]=13696;x[a+480196>>2]=4;w[a+480188>>1]=8;d=g+40|0;f=Ub(d,10194);Db(a+1304436|0,f);xb(f);d=Ub(d,10227);Db(a+1304448|0,d);xb(d);Pc(a+1304460|0,z[g+72>>1]==26217?10194:10222);x[a+1304496>>2]=4;d=y[g+182|0];w[a+480190>>1]=d;c:{d:{e:{f:{if(d){f=1;j=1;while(1){e=hb-16|0;hb=e;i=hb-16|0;hb=i;h=e+8|0;d=g+40|0;jc(h,d,25);hb=i+16|0;i=Eb(h);h=nc(b,ac(e,h));if((i|0)==(h|0)){cc(b,Eb(e+8|0))}hb=e+16|0;if((h|0)!=(i|0)){e=hb-16|0;hb=e;v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;v[d+24|0]=0;v[d+16|0]=0;v[d+17|0]=0;v[d+18|0]=0;v[d+19|0]=0;v[d+20|0]=0;v[d+21|0]=0;v[d+22|0]=0;v[d+23|0]=0;v[d+8|0]=0;v[d+9|0]=0;v[d+10|0]=0;v[d+11|0]=0;v[d+12|0]=0;v[d+13|0]=0;v[d+14|0]=0;v[d+15|0]=0;hb=e+16|0}if((y[g+53|0]|y[g+54|0]<<8|(y[g+55|0]<<16|y[g+56|0]<<24))>>>0>67108863){break d}e=(D(f,104)+a|0)+484380|0;Ad(e,0);x[e+24>>2]=8363;h=g+40|0;d=h;x[e>>2]=y[d+13|0]|y[d+14|0]<<8|(y[d+15|0]<<16|y[d+16|0]<<24);x[e+4>>2]=y[d+17|0]|y[d+18|0]<<8|(y[d+19|0]<<16|y[d+20|0]<<24);d=y[d+21|0]|y[d+22|0]<<8|(y[d+23|0]<<16|y[d+24|0]<<24);d=d>>>0>A[e>>2]?x[e+4>>2]?d:0:d;x[e+8>>2]=d;if(d){w[e+34>>1]=2;Dn(e)}d=g+8|0;zh(d,2,h);e=g+24|0;Ic(e,d);x[114414]=0;O(334,((f<<5)+a|0)+946304|0,e|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break f}xb(g+24|0);j=j+1|0;f=j&65535;if(f>>>0<=z[a+480190>>1]){continue}break}}f=g+24|0;e=g+72|2;aC(f,3,e,36);d=g+40|0;Ic(d,f);Db(a+1304400|0,d);xb(d);f=0;IO(a+1304424|0,Cb(e),108,36,0);d=a+484360|0;$B(Vb(d),g+185|0,128);if(z[uc(Vb(d),y[g+184|0])>>1]<y[g+183|0]){break e}break c}a=N()|0;xb(g+24|0);Q(a|0);p()}Se(Vb(d),y[g+184|0]);break c}f=0;break a}while(1){d=(f<<5)+a|0;Lg(d+480280|0);w[d+480284>>1]=f&1?208:48;f=f+1|0;if((f|0)!=8){continue}break}h=a+484344|0;cg(h,y[g+183|0]);if(y[g+183|0]){m=c&1;e=0;while(1){g:{h:{if(m){if(Tg(h,e&65535,64)){break h}}cc(b,1536);break g}x[g+24>>2]=-1;x[g+28>>2]=-1;l=0;while(1){f=mm(Zb(h,e),l);j=0;while(1){i=g+40|0;Fq(i,b);d=ed(i);n=rf(i);k=y[d|0];d=y[i|0];if(d>>>0<=253){v[f|0]=(d>>>2|0)+37;v[f+1|0]=(d<<4&48|k>>>4)+1;v[(g+24|0)+j|0]=255;d=y[i|0]}if((d|0)!=255){v[f+2|0]=1;v[f+4|0]=(((k&15)<<6|8)>>>0)/15}i=(g+24|0)+j|0;i:{j:{d=y[n|0];k:{if((d|0)!=255){v[i|0]=d;if(d&15|(d|0)==48){break k}break j}d=y[i|0];if((d|0)==255){break i}}k=d&15;v[f+5|0]=k;l:{if(d<<24>>24<0){break l}d=d>>>4|0;v[f+3|0]=y[d+23288|0];m:{switch(d-3|0){case 0:v[f+5|0]=k|32;break j;case 1:v[f+5|0]=D(k,17);break i;case 2:break j;case 3:break m;default:break i}}n:{switch(k|0){case 0:v[f+5|0]=79;break i;case 1:break n;default:break l}}v[f+5|0]=244;break i}v[f+3|0]=0;break i}v[i|0]=255}f=f+6|0;j=j+1|0;if((j|0)!=8){continue}break}l=l+1|0;if((l|0)!=64){continue}break}d=(g+72|0)+e|0;if(y[d+369|0]<63){Ll(Zb(h,e),ai(Ie(lo(g+40|0,14,0),y[d+369|0])))}Ll(Zb(h,e),ai(lo(g+40|0,16,y[d+241|0])))}e=e+1|0;if(e>>>0<y[g+183|0]){continue}break}}f=1;if(!(c&2)){break a}c=ad(g+40|0,8,1,0,1);if(!z[a+480190>>1]){break b}while(1){Eg(c,(D(f&65535,104)+a|0)+484380|0,b);f=f+1|0;if(z[a+480190>>1]>=(f&65535)>>>0){continue}break}}f=1}hb=g+576|0;return f|0}function ila(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=hb-384|0;hb=f;d=f+136|0;g=hb-48|0;hb=g;e=g+24|0;qA(e,b);x[114414]=0;P(678,g+8|0,e|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)==1){break b}x[114414]=0;P(679,g+16|0,g+8|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=g+16|0;e=x[b>>2];b=x[b+4>>2];x[114414]=0;U(680,d|0,e|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}Hc(g+24|0);hb=g+48|0;break a}a=N()|0;Hc(g+24|0);Q(a|0);p()}x[114414]=0;g=U(650,f+240|0,d|0,8)|0;b=x[114414];x[114414]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((b|0)!=1){xb(f+136|0);if(c>>>0<2189){break i}x[114414]=0;b=O(657,f+136|0,g|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break e}x[114414]=0;c=O(658,f+120|0,6105)|0;d=x[114414];x[114414]=0;if((d|0)==1){break B}x[114414]=0;x[f+104>>2]=19469590;x[f+108>>2]=0;T(659,b|0,c|0,f+104|0);d=x[114414];x[114414]=0;if((d|0)==1){break A}Gb(c);x[114414]=0;v[f+119|0]=0;c=O(658,f+104|0,6987)|0;d=x[114414];x[114414]=0;if((d|0)==1){break k}d=0;x[114414]=0;U(660,b|0,f+119|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break z}Gb(c);if(!y[f+119|0]){x[114414]=0;d=R(661,a|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break y}}e=x[a+4>>2];x[114414]=0;c=O(658,f+88|0,11801)|0;h=x[114414];x[114414]=0;if((h|0)==1){break x}x[114414]=0;X(662,b|0,e|0,c|0,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break w}Gb(c);x[114414]=0;c=O(658,f+72|0,11563)|0;e=x[114414];x[114414]=0;if((e|0)==1){break v}x[114414]=0;X(663,b|0,a|0,c|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break u}Gb(c);x[114414]=0;c=O(658,f+56|0,11195)|0;d=x[114414];x[114414]=0;if((d|0)==1){break t}x[114414]=0;d=a+484360|0;Z(664,b|0,d|0,c|0,665)|0;e=x[114414];x[114414]=0;if((e|0)==1){break s}Gb(c);x[114414]=0;c=O(658,f+40|0,23702)|0;e=x[114414];x[114414]=0;if((e|0)==1){break r}x[114414]=0;Z(666,b|0,a+484344|0,c|0,667)|0;e=x[114414];x[114414]=0;if((e|0)==1){break q}Gb(c);x[114414]=0;e=R(661,a|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break p}x[114414]=0;c=O(658,f+24|0,23708)|0;h=x[114414];x[114414]=0;if((h|0)==1){break o}x[114414]=0;X(668,b|0,d|0,c|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break n}Gb(c);if(x[b>>2]&1073741824){x[114414]=0;c=O(2,f+8|0,12164)|0;d=x[114414];x[114414]=0;if((d|0)==1){break m}x[114414]=0;T(623,a|0,1,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break l}xb(c)}Hg(b);break h}a=N()|0;xb(f+136|0);break c}a=N()|0;break j}a=N()|0;Gb(c);break j}a=N()|0;Gb(c);break j}a=N()|0;break j}a=N()|0;break j}a=N()|0;Gb(c);break j}a=N()|0;break j}a=N()|0;Gb(c);break j}a=N()|0;break j}a=N()|0;Gb(c);break j}a=N()|0;break j}a=N()|0;Gb(c);break j}a=N()|0;break j}a=N()|0;break j}a=N()|0;Gb(c);break j}a=N()|0;break j}a=N()|0;xb(c);break j}a=N()|0}Hg(b);break d}b=hd(f+136|0);d=x[a+4>>2];x[114414]=0;e=R(661,a|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break g}x[114414]=0;d=Z(669,d|0,g|0,b|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break g}C:{if((d|0)!=1){x[114414]=0;c=O(2,f+120|0,12470)|0;d=x[114414];x[114414]=0;D:{if((d|0)!=1){x[114414]=0;T(623,a|0,1,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break D}xb(c);break C}a=N()|0;break f}a=N()|0;xb(c);break f}x[114414]=0;d=R(661,a|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break g}x[114414]=0;X(670,g|0,a|0,d|0,c>>>0<2188|0);a=x[114414];x[114414]=0;if((a|0)==1){break g}}xb(b)}Lf(g);hb=f+384|0;return}a=N()|0}xb(b);break d}a=N()|0}Lf(g)}Q(a|0);p()}function wS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-192|0;hb=e;h=hb-16|0;hb=h;f=h+8|0;i=hb-16|0;hb=i;x[114414]=0;j=e+176|0;R(700,j+4|0)|0;g=x[114414];x[114414]=0;a:{b:{if((g|0)==1){break b}x[114414]=0;x[i+12>>2]=0;U(701,j+8|0,i+12|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}m=j,n=mc(j),x[m>>2]=n;hb=i+16|0;break a}S(0)|0;zb();p()}hb=h+16|0;c:{d:{e:{if(d){x[114414]=0;T(685,a|0,j|0,c|0);c=x[114414];x[114414]=0;if((c|0)!=1){break e}break d}x[114414]=0;T(686,a|0,j|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break d}}i=qw(e+160|0);if(z[b+480192>>1]){d=1;k=1;while(1){x[114414]=0;w[e+158>>1]=0;O(687,a|0,e+158|0)|0;c=x[114414];x[114414]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((c|0)!=1){x[114414]=0;c=O(688,j|0,e+158|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break i}x[e+152>>2]=c;h=((d<<2)+b|0)+900380|0;if(!x[h>>2]){break f}c=Ti(j);x[114414]=0;x[e+64>>2]=c;c=O(689,e+152|0,e- -64|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break D}if(!c){break j}x[114414]=0;c=R(690,e+152|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break C}x[114414]=0;c=O(4,e+136|0,c+4|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break C}x[114414]=0;d=O(2,e+120|0,12725)|0;f=x[114414];x[114414]=0;if((f|0)==1){break l}f=jq(c,d);xb(d);if(f){break u}d=x[b+4>>2];x[114414]=0;d=O(691,d|0,c|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break A}x[x[h>>2]+44>>2]=d;if(!x[x[h>>2]+44>>2]){break B}break g}b=N()|0;break h}b=N()|0;break h}b=N()|0;break h}x[114414]=0;d=O(2,e+104|0,9266)|0;f=x[114414];x[114414]=0;if((f|0)==1){break z}E:{F:{if(jq(c,d)){xb(d);break F}x[114414]=0;f=O(2,e+88|0,9477)|0;g=x[114414];x[114414]=0;if((g|0)==1){break y}g=jq(c,f);xb(f);xb(d);if(!g){break E}}x[114414]=0;d=R(692,c|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break x}x[e+64>>2]=d;d=x[b+4>>2];f=x[iq(e+80|0,e- -64|0)>>2];x[114414]=0;d=O(693,d|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break w}Tf(e- -64|0);if(d){break g}}f=bc(i);g=dc(i);d=hb-16|0;hb=d;x[d>>2]=g;x[d+8>>2]=f;G:{if(!Hb(d+8|0,d)){break G}while(1){if(jq(x[d+8>>2],c)){break G}f=d+8|0;_j(f);if(Hb(f,d)){continue}break}}hb=d+16|0;x[e+64>>2]=x[d+8>>2];m=e,n=dc(i),x[m+48>>2]=n;if(!Os(e- -64|0,e+48|0)){break u}x[114414]=0;P(694,i|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){break v}}b=N()|0;break k}b=N()|0;break k}b=N()|0;xb(d);break k}b=N()|0;break k}b=N()|0;Tf(e- -64|0);break k}x[114414]=0;d=O(2,e+16|0,13229)|0;f=x[114414];x[114414]=0;if((f|0)==1){break t}x[114414]=0;T(695,e+32|0,d|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break s}x[114414]=0;f=O(2,e|0,12213)|0;g=x[114414];x[114414]=0;if((g|0)==1){break r}x[114414]=0;T(3,e+48|0,e+32|0,f|0);g=x[114414];x[114414]=0;if((g|0)==1){break q}g=st(e- -64|0,e+48|0);x[114414]=0;P(601,b|0,g|0);l=x[114414];x[114414]=0;if((l|0)==1){break p}xb(g);xb(e+48|0);xb(f);xb(e+32|0);xb(d)}x[x[h>>2]+44>>2]=0;break g}b=N()|0;break k}b=N()|0;break m}b=N()|0;break n}b=N()|0;break o}b=N()|0;xb(g);xb(e+48|0)}xb(f)}xb(e+32|0)}xb(d);break k}b=N()|0}xb(c);break h}if(!x[h>>2]){break f}x[x[h>>2]+44>>2]=0;break f}b=N()|0}vl(i);break c}xb(c)}k=k+1|0;d=k&65535;if(d>>>0<=z[b+480192>>1]){continue}break}}vl(i);rS(j);hb=e+192|0;return}b=N()|0}rS(j);Q(b|0);p()}function pI(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=hb-48|0;hb=g;a:{b:{if(ws(c)){h=b+24|0;if(kg(x[h>>2]+484344|0,c&65535)){break b}}c=a;a=Wb(g+32|0);b=Wb(g+16|0);Oh(c,a,b);xb(b);xb(a);break a}b=Zb(x[h>>2]+484344|0,c);if(!(x[b+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Wb(g+32|0);b=Wb(g+16|0);Oh(c,a,b);xb(b);xb(a);break a}if(!(z[x[h>>2]+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Wb(g+32|0);b=Wb(g+16|0);Oh(c,a,b);xb(b);xb(a);break a}if(f>>>0>=6){c=a;a=Wb(g+32|0);b=Wb(g+16|0);Oh(c,a,b);xb(b);xb(a);break a}b=Df(b,d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{if(!Af(b)){if(!Ss(b)){break k}}c=g+16|0;WL(c,x[h>>2],y[b|0],y[b+1|0]);x[114414]=0;T(9,g+32|0,0,c|0);c=x[114414];x[114414]=0;d=1;if((c|0)!=1){break j}c=N()|0;break g}d=0;x[114414]=0;O(118,g+32|0,12709)|0;c=x[114414];x[114414]=0;if((c|0)==1){break i}}x[114414]=0;c=R(520,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break h}if(c){b=5954}else{b=Ss(b)?6259:12709}x[114414]=0;b=O(118,g|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break h}c=a;a=g+32|0;Oh(c,a,b);xb(b);xb(a);if(!d){break a}xb(g+16|0);break a}c=N()|0;break d}c=N()|0;xb(g+32|0);if(!d){break d}}xb(g+16|0);break d;case 1:c=b+1|0;l:{if(y[b+1|0]){Ut(g+32|0,c);break l}Ub(g+32|0,12714)}b=y[c|0];x[114414]=0;b=O(118,g+16|0,(b?6741:12714)|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break e}c=a;a=g+32|0;Oh(c,a,b);xb(b);xb(a);break a;case 2:m:{if(xn(b)){Ub(g+32|0,13671);break m}if(y[b+2|0]){Lj(g+32|0,1,ZK(x[x[h>>2]+8>>2],y[b+2|0]));break m}Ub(g+32|0,13671)}x[114414]=0;c=R(1345,b|0)|0;d=x[114414];x[114414]=0;n:{if((d|0)==1){break n}b=c?13671:y[b+2|0]?1991:13671;x[114414]=0;b=O(118,g+16|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break n}c=a;a=g+32|0;Oh(c,a,b);xb(b);xb(a);break a}c=N()|0;xb(g+32|0);break d;case 4:o:{if(xn(b)){i=g,j=Ny(b)&255,x[i>>2]=j;Vz(g+32|0,g);break o}if(y[b+2|0]){Ut(g+32|0,b+4|0);break o}Ub(g+32|0,12714)}x[114414]=0;c=R(1345,b|0)|0;d=x[114414];x[114414]=0;p:{if((d|0)==1){break p}b=c?1975:y[b+2|0]?1975:12714;x[114414]=0;b=O(118,g+16|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break p}c=a;a=g+32|0;Oh(c,a,b);xb(b);xb(a);break a}c=N()|0;xb(g+32|0);break d;case 3:q:{if(xn(b)){i=g,j=(gt(b)&3840)!=0,v[i|0]=j;c=hb-32|0;hb=c;v[c+16|0]=44;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=1058;x[c+4>>2]=1;d=hb-16|0;hb=d;x[d+12>>2]=y[g|0];nx(g+32|0,d+12|0,c);hb=d+16|0;hb=c+32|0;break q}if(y[b+3|0]){Lj(g+32|0,1,YK(x[x[h>>2]+8>>2],y[b+3|0]));break q}Ub(g+32|0,12715)}x[114414]=0;c=R(1345,b|0)|0;d=x[114414];x[114414]=0;r:{if((d|0)==1){break r}b=c?8131:y[b+3|0]?8131:12715;x[114414]=0;b=O(118,g+16|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break r}c=a;a=g+32|0;Oh(c,a,b);xb(b);xb(a);break a}c=N()|0;xb(g+32|0);break d;case 5:break f;default:break c}}s:{if(xn(b)){i=g,j=gt(b)&255,x[i>>2]=j;Vz(g+32|0,g);break s}if(y[b+3|0]){Ut(g+32|0,b+5|0);break s}Ub(g+32|0,12714)}x[114414]=0;c=R(1345,b|0)|0;d=x[114414];x[114414]=0;t:{if((d|0)==1){break t}b=c?7028:y[b+3|0]?7028:12714;x[114414]=0;b=O(118,g+16|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break t}c=a;a=g+32|0;Oh(c,a,b);xb(b);xb(a);break a}c=N()|0;xb(g+32|0);break d}c=N()|0;xb(g+32|0)}Q(c|0);p()}c=a;a=Wb(g+32|0);b=Wb(g+16|0);Oh(c,a,b);xb(b);xb(a)}hb=g+48|0}function Sma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=hb-720|0;hb=e;Lc(b);f=hb-16|0;hb=f;g=f+8|0;i=e+104|0;IT(g,i);h=Eb(g);g=nc(b,ac(f,g));if((h|0)==(g|0)){cc(b,Eb(f+8|0))}hb=f+16|0;f=(g|0)==(h|0);if(!f){JT(i)}a:{if(!f){break a}if(!LT(e+104|0)){break a}b:{if(!c){break b}Nd(a,67108864);Gi(a);d=y[e+129|0];w[a+480190>>1]=31;w[a+480188>>1]=d;x[a+480228>>2]=256/(d>>>0);d=Ub(e,4384);Db(a+1304436|0,d);xb(d);d=Ub(e,6744);Db(a+1304448|0,d);xb(d);f=Ub(e+88|0,10880);x[114414]=0;P(187,e- -64|0,f|0);d=x[114414];x[114414]=0;c:{d:{if((d|0)!=1){x[e+84>>2]=y[e+128|0]>>>4;d=y[e+128|0];x[114414]=0;x[e+80>>2]=d&15;X(501,e|0,e- -64|0,e+84|0,e+80|0);d=x[114414];x[114414]=0;if((d|0)!=1){Db(a+1304460|0,e);xb(e);Gb(e- -64|0);xb(f);x[a+1304496>>2]=2;$n(Vb(a+484360|0),e+152|0,y[e+151|0]+1|0,65535,65535);f=0;while(1){d=f+1|0;i=D(d,104)+a|0;j=i+484380|0;Ad(j,1);g=(e+104|0)+(f<<2)|0;h=y[g+176|0]|y[g+177|0]<<8|(y[g+178|0]<<16|y[g+179|0]<<24);x[j>>2]=h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24);h=y[g+300|0]|y[g+301|0]<<8|(y[g+302|0]<<16|y[g+303|0]<<24);k=h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24);x[i+484384>>2]=k;h=y[g+424|0]|y[g+425|0]<<8|(y[g+426|0]<<16|y[g+427|0]<<24);x[i+484388>>2]=k+(h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24));if(y[g+424|0]|y[g+425|0]<<8|(y[g+426|0]<<16|y[g+427|0]<<24)){g=i+484414|0;w[g>>1]=z[g>>1]|2}Dn(j);f=(e+104|0)+f|0;v[e|0]=y[f+548|0];v[e+64|0]=64;o=i+484410|0,q=y[rc(e,e- -64|0)|0]<<2,w[o>>1]=q;v[i+484417|0]=y[f+579|0]<<4;f=d;if((d|0)!=31){continue}break}WA(b,a+1304400|0,32);d=1;while(1){KT(b,((d<<5)+a|0)+946304|0,30);d=d+1|0;if((d|0)!=32){continue}break}k=c&1;if(k){cg(a+484344|0,y[e+150|0]+1|0)}j=a+484344|0;d=0;e:{while(1){i=ci(e- -64|0);f:{if(y[e+130|0]){x[114414]=0;f=R(440,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break e}x[114414]=0;T(307,e|0,b|0,f|0);break f}f=z[a+480188>>1];x[114414]=0;T(307,e|0,b|0,f<<8)}f=x[114414];x[114414]=0;if((f|0)==1){break e}g=d;Ud(i,e);Ab(e);g:{if(!k){break g}x[114414]=0;d=U(363,j|0,g&65535,64)|0;f=x[114414];x[114414]=0;if((f|0)==1){break e}if(!d){break g}if(!y[e+130|0]){d=0;if(!z[a+480188>>1]){break g}while(1){f=0;while(1){h=Zb(j,g);x[114414]=0;h=U(427,h|0,f|0,d&65535)|0;l=x[114414];x[114414]=0;if((l|0)==1){break e}x[114414]=0;P(502,i|0,h|0);h=x[114414];x[114414]=0;if((h|0)==1){break e}f=f+1|0;if((f|0)!=64){continue}break}d=d+1|0;if(z[a+480188>>1]>(d&65535)>>>0){continue}break}break g}h=0;x[114414]=0;O(503,i|0,e|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}while(1){d=Zb(j,g);x[114414]=0;l=O(453,d|0,h|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(z[a+480188>>1]){m=e+h|0;d=128;f=0;while(1){h:{if(!(y[m|0]&d)){break h}x[114414]=0;P(502,i|0,l+D(f,6)|0);n=x[114414];x[114414]=0;if((n|0)!=1){break h}break e}d=d>>>1|0;f=f+1|0;if(f>>>0<z[a+480188>>1]){continue}break}}h=h+1|0;if((h|0)!=64){continue}break}}Ab(i);d=g+1|0;if(g>>>0<y[e+150|0]){continue}break}d=1;if(!(c&2)){break a}c=ad(e,8,1,1,0);while(1){Eg(c,(D(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break b}d=N()|0;Ab(i);break c}d=N()|0;Gb(e- -64|0);break d}d=N()|0}xb(f)}Q(d|0);p()}d=1}hb=e+720|0;return d|0}function Sba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=hb-48|0;hb=f;a:{b:{c:{l=a+24|0;d:{if(zd(l)){break d}k=a+4|0;m=Bb(k);c=hb-48|0;hb=c;j=c+40|0;a=j;x[a>>2]=-1;x[a+4>>2]=-1;if(!(v[84124]&1)){while(1){d=h&255;b=0;e=0;while(1){b=d&1|b<<1;d=(d&254)>>>1|0;e=e+1|0;if((e|0)!=8){continue}break}b=(b&255)<<24;e=0;d=0;while(1){a=b<<1|e>>>31;e=e<<1;b=(b|0)<0;e=b?e^-1798752855:e;b=b?a^-1382821323:a;d=d+1|0;if((d|0)!=8){continue}break}g=0;i=0;d=0;while(1){i=i<<1|g>>>31;g=e&1|g<<1;a=b;b=b>>>1|0;e=(a&1)<<31|e>>>1;d=d+1|0;if((d|0)!=64){continue}break}a=(h<<3)+84128|0;x[a>>2]=g;x[a+4>>2]=i;h=h+1|0;if((h|0)!=256){continue}break}v[84124]=1}x[114414]=0;a=UD(2343);b=x[114414];x[114414]=0;d=lb;if((b|0)==1){S(0)|0;zb();p()}x[c+8>>2]=a;x[c+12>>2]=d;a=x[c+12>>2];x[c+16>>2]=x[c+8>>2];x[c+20>>2]=a;b=hb-16|0;hb=b;a=hb-16|0;hb=a;e=c+16|0;d=e;n=a,o=yna(x[d>>2],x[d+4>>2],1e3,0),x[n>>2]=o;x[a+4>>2]=lb;d=Ei(a+8|0,a);g=x[d>>2];d=x[d+4>>2];hb=a+16|0;hb=b+16|0;x[c+24>>2]=g;x[c+28>>2]=d;a=c+24|0;b=x[a>>2];d=b&16711680;g=d>>>8|0;h=b&-16777216;i=h>>>24|0;h=h<<8|d<<24;d=x[a+4>>2];d=h|(((d&255)<<24|b>>>8)&-16777216|((d&16777215)<<8|b>>>24)&16711680|(d>>>8&65280|d>>>24));v[c+32|0]=d;v[c+33|0]=d>>>8;v[c+34|0]=d>>>16;v[c+35|0]=d>>>24;b=b<<24|(b&65280)<<8|(g|i);v[c+36|0]=b;v[c+37|0]=b>>>8;v[c+38|0]=b>>>16;v[c+39|0]=b>>>24;b=x[c+36>>2];x[c+24>>2]=x[c+32>>2];x[c+28>>2]=b;VL(j,a,yb(a));x[114414]=0;b=UD(2344);d=x[114414];x[114414]=0;g=lb;if((d|0)==1){S(0)|0;zb();p()}x[c+8>>2]=b;x[c+12>>2]=g;b=x[c+12>>2];x[c+16>>2]=x[c+8>>2];x[c+20>>2]=b;d=hb-16|0;hb=d;b=hb-16|0;hb=b;g=x[e+4>>2];x[b>>2]=x[e>>2];x[b+4>>2]=g;e=Ei(b+8|0,b);g=x[e>>2];e=x[e+4>>2];hb=b+16|0;hb=d+16|0;x[c+24>>2]=g;x[c+28>>2]=e;b=x[a>>2];e=b<<24|(b&65280)<<8;d=b&16711680;g=d>>>8|0;h=b&-16777216;i=h>>>24|0;h=h<<8|d<<24;d=x[a+4>>2];b=h|(((d&255)<<24|b>>>8)&-16777216|((d&16777215)<<8|b>>>24)&16711680|(d>>>8&65280|d>>>24));v[c+32|0]=b;v[c+33|0]=b>>>8;v[c+34|0]=b>>>16;v[c+35|0]=b>>>24;b=e|(g|i);v[c+36|0]=b;v[c+37|0]=b>>>8;v[c+38|0]=b>>>16;v[c+39|0]=b>>>24;b=x[c+36>>2];x[c+24>>2]=x[c+32>>2];x[c+28>>2]=b;VL(j,a,yb(a));a=x[j>>2];d=x[j+4>>2];hb=c+48|0;if(m){b=Dk(f+32|0);x[114414]=0;x[f+16>>2]=d;P(88,b|0,f+16|0);c=x[114414];x[114414]=0;e:{f:{g:{if((c|0)!=1){x[114414]=0;x[f+16>>2]=a;P(88,b|0,f+16|0);a=x[114414];x[114414]=0;if((a|0)==1){break g}if(Bb(k)){a=0;while(1){c=y[pc(k,a)|0];x[114414]=0;x[f+16>>2]=c;P(88,b|0,f+16|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}a=a+1|0;if(Bb(k)>>>0>a>>>0){continue}break}}a=bc(b);c=dc(b);x[114414]=0;c=U(89,f+16|0,a|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}x[114414]=0;a=R(90,c|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}x[f+8>>2]=a;a=f+8|0;Vs(l,a);dg(a);Ge(c);Ge(b);break d}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;Ge(c);break a}lb=a;x[f+16>>2]=d;x[f+20>>2]=lb;b=Dk(f+32|0);x[114414]=0;T(96,b|0,f+16|0,f+24|0);a=x[114414];x[114414]=0;if((a|0)==1){a=N()|0;Ge(b);Q(a|0);p()}x[114414]=0;a=R(90,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break c}x[f+8>>2]=a;a=f+8|0;Vs(l,a);dg(a);Ge(b)}hb=f+48|0;return}a=N()|0;break a}a=N()|0}Ge(b);Q(a|0);p()}function rJ(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=E(0),p=0,q=E(0),r=E(0),s=0,t=0,u=E(0);j=hb-16|0;hb=j;s=a,t=Li(E(B[a+4256>>2]*E(3))),x[s+4264>>2]=t;s=a,u=E(Ze(x[a+16>>2])>>>((x[a+4264>>2]^-1)>>>1&1)>>>0),B[s+4268>>2]=u;B[a+4272>>2]=E(B[a+4244>>2]*E(100))*E(.0061803399585187435);s=j,u=le(E(10),E(E(qJ(a)+E(E(B[a+4228>>2]*E(11e3))+E(-1e4)))*E(.0005000000237487257))),B[s+12>>2]=u;x[j+8>>2]=1065353216;s=a,u=E(B[Hl(j+12|0,j+8|0)>>2]*E(.7609999775886536)),B[s+4280>>2]=u;d=le(E(10),E(E(E(B[a+4212>>2]*E(1e4))+E(-1e4))*E(.0010000000474974513)));if(d!=E(1)){c=_o(E(E(pJ(a)*E(6.2831854820251465))/B[a+4268>>2]));h=E(d+d);e=E(d*d);d=E(d*E(8));c=Qy(E(E(E(E(c*h)+E(-2))+E(M(E(E(E(e*E(-4))+d)+E(E(E(E(e*E(4))*c)-d)*c)))))/E(h+E(-2))),E(0),E(1))}else{c=E(0)}B[a+4276>>2]=c;i=hb-16|0;hb=i;d=B[a+4268>>2];c=E(B[a+4232>>2]*E(.30000001192092896));B[i+12>>2]=B[a+4240>>2]*E(.10000000149011612);x[i+8>>2]=1000593162;h=B[Ex(i+12|0,i+8|0)>>2];e=E(d*E(E(c+E(.007000000216066837))+h));a:{if(E(F(e))<E(2147483648)){b=~~e;break a}b=-2147483648}x[a+4352>>2]=b;b=1;while(1){k=((D(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=E(E(E(B[(b<<2)+36352>>2]*h)+c)*d);b:{if(E(F(e))<E(2147483648)){g=~~e;break b}g=-2147483648}x[k>>2]=g;b=b+1|0;if((b|0)!=12){continue}break}B[i+12>>2]=E(E(B[a+4248>>2]*E(100))*E(.009091000072658062))+E(.09091000258922577);x[i+8>>2]=1065353216;c=E(B[Hl(i+12|0,i+8|0)>>2]*d);h=E(c*E(.07500000298023224));c=E(c*E(.06700000166893005));b=0;while(1){g=(b<<2)+a|0;p=g+4316|0;n=b+n|0;e=le(E(.9300000071525574),E(n|0));f=E(h*e);c:{if(E(F(f))<E(2147483648)){k=~~f;break c}k=-2147483648}x[p>>2]=k;k=g+4292|0;e=E(c*e);d:{if(E(F(e))<E(2147483648)){g=~~e;break d}g=-2147483648}x[k>>2]=g;b=b+1|0;if((b|0)!=6){continue}break}g=a+4348|0;c=E(d*E(.0035299998708069324));e:{if(E(F(c))<E(2147483648)){b=~~c;break e}b=-2147483648}x[g>>2]=b;g=a+4344|0;c=E(d*E(.0032500000670552254));f:{if(E(F(c))<E(2147483648)){b=~~c;break f}b=-2147483648}x[g>>2]=b;g=a+4340|0;d=E(d*E(.009999999776482582));g:{if(E(F(d))<E(2147483648)){b=~~d;break g}b=-2147483648}x[g>>2]=b;b=0;while(1){sJ((D(b,24)+a|0)+4504|0,x[((b<<2)+a|0)+4292>>2]);b=b+1|0;if(b>>>0<15){continue}break}hb=i+16|0;b=hb-16|0;hb=b;c=Sg(a,5);e=Sg(a,11);d=E(c*Sg(a,4));h=E(E(d*E(.03999999910593033))+E(c*E(.02250000089406967)));c=E(e*Sg(a,10));e=E(E(c*E(.03999999910593033))+E(e*E(.02250000089406967)));if(v[a+4264|0]&1){f=Sg(a,3);l=Sg(a,9);f=E(f*d);d=E(Sg(a,2)*f);h=E(E(E(f*E(.12250000238418579))+h)+E(d*E(.1444000005722046)));f=E(l*c);c=E(Sg(a,8)*f);e=E(E(E(f*E(.12250000238418579))+e)+E(c*E(.1444000005722046)))}Sg(a,12);f=B[a+4496>>2];l=Sg(a,1);m=Sg(a,7);q=Sg(a,0);r=Sg(a,6);s=b,u=le(E(10),E(E(qJ(a)+E(E(B[a+4236>>2]*E(12e3))+E(-1e4)))*E(.0005000000237487257))),B[s+12>>2]=u;x[b+8>>2]=1065353216;o=B[Hl(b+12|0,b+8|0)>>2];f=E(f*f);c=E(m*E(f*c));m=E(r*c);d=E(l*E(f*d));f=E(q*d);l=E(E(E(m+f)*E(-.5))+E(1));B[a+4284>>2]=o*E(M(E(l/E(E(E(f+c)*E(.1444000005722046))+h))));B[a+4288>>2]=o*E(M(E(l/E(E(E(m+d)*E(.1444000005722046))+e))));hb=b+16|0;v[a+5046|0]=0;hb=j+16|0}function Fy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;h=hb-16|0;hb=h;j=D(b,896)+a|0;m=j+1075782|0;i=z[m>>1];e=h+8|0;k=a+1074312|0;Kb(e,k,23);g=c&15;a:{b:{c:{d:{e:{f:{if(Ib(e)){if(!(x[a+1074392>>2]|!y[(D(b,896)+a|0)+1075794|0])){w[m>>1]=g;break f}e=z[m>>1];if(e){f=e-1|0;w[m>>1]=f;e=0;if(f&65535){break c}}w[m>>1]=g;e=1;break c}e=h+8|0;Kb(e,k,52);f=c&256;if(!(!f|!Ib(e))){g:{if(!(y[a+480209|0]&16)){break g}e=D(b,896)+a|0;if(y[e+1075795|0]){i=NS(e+1075794|0)?1:i}if(y[e+1075796|0]!=1){break g}if(y[(D(b,896)+a|0)+1075798|0]){break b}}e=0;if(i<<16>>16<(g|0)){break c}if(y[a+480209|0]&16){if(Af((D(b,896)+a|0)+1075794|0)){break c}}i=0;e=1;break c}if(x[a+480180>>2]&16777250){e=!(i&65535?(i<<16>>16)%((g?g:1)|0)|0:1);i=i+1|0;break c}if(x[a+480180>>2]!=1){break d}e=A[a+1074392>>2]%A[a+1074416>>2]|0;if(!e){if(Af((D(b,896)+a|0)+1075794|0)){break a}}if(g){break e}}e=0;break c}e=!((e>>>0)%(g>>>0)|0);break c}if(x[a+480180>>2]==16){e=x[a+1074392>>2]==(g|0)&(g|0)!=0;break c}h:{i:{j:{k:{l:{if(f){e=D(b,896)+a|0;if(y[e+1075796|0]==1){g=(y[e+1075799|0]>15)+g|0}g=g?g:1;break l}if(y[a+480209|0]&16){break i}g=g?g:1;if(x[a+1074416>>2]){break k}}e=0;break j}e=!(A[a+1074392>>2]%(g>>>0)|0)}i=i+1|0;break h}e=0;i=x[a+480180>>2]&1048580?0:i}if(!(!(y[(D(b,896)+a|0)+1075794|0]|!f?x[a+1074392>>2]:1)|i<<16>>16<(g|0))){e=1}g=h+8|0;Kb(g,k,52);if(!Ib(g)|c){break c}e=!x[a+1074392>>2]}g=j+1074984|0;j=(D(b,896)+a|0)+1075060|0;m:{if(x[j>>2]){break m}f=h+8|0;Kb(f,k,38);if(!Ib(f)){break m}if(!wj(g)){break a}}f=h+8|0;Kb(f,k,106);if(u=0,B=Ib(f),C=x[(D(b,896)+a|0)+1075680>>2],C?u:B){break a}if(e){e=D(b,896)+a|0;p=e+1075672|0;x[h+4>>2]=x[p>>2];f=c>>>4&15;if(f){l=h+8|0;Kb(l,k,52);n:{if(u=Ib(l),B=0,C=y[(D(b,896)+a|0)+1075796|0]==1,C?u:B){break n}l=v[f+26960|0];if(l){x[h+4>>2]=(D(l,x[h+4>>2])|0)/16;break n}x[h+4>>2]=x[h+4>>2]+(v[f+26976|0]<<2)}_d(h+4|0,0,256);f=(D(b,896)+a|0)+1075072|0;x[f>>2]=x[f>>2]|2097152}q=e+1075684|0;l=x[q>>2];f=y[e+1075808|0];o:{if(!x[j>>2]|(f-1&255)>>>0>119){break o}if(!(!(y[(D(b,896)+a|0)+1075073|0]&2)|x[a+480180>>2]!=2)){e=h+8|0;Kb(e,k,108);if(!Ib(e)){break o}}VM(a,b,0,f,1)}e=0;p:{if(!(x[a+480180>>2]&1048580)){break p}e=(c|0)<256;if((c|0)>255){break p}j=y[(D(b,896)+a|0)+1075795|0];if(!j){break p}e=1;Fp(a,g,j,0,0,1)}j=D(b,896)+a|0;n=j+1075644|0;s=x[n>>2];x[n>>2]=0;o=j+1075072|0;t=x[o>>2];r=h+8|0;Kb(r,k,23);ft(a,g,f,Ib(r),e,0,b);if(!y[j+1075795|0]){x[n>>2]=s}if(!(!(t&4096)|x[a+480180>>2]!=4)){x[o>>2]=x[o>>2]|4096}e=j+1075794|0;x[p>>2]=x[h+4>>2];if(z[a+480192>>1]){v[e|0]=f;yL(a,b)}if(!(!(x[a+480180>>2]&16777248)|(y[e|0]|!l))){x[q>>2]=l}e=x[a+480180>>2];f=h+8|0;Kb(f,k,23);if(Ib(f)){x[g>>2]=0;x[g+4>>2]=0}e=e&16777250;q:{if(d-1>>>0>9){break q}f=x[(D(b,896)+a|0)+1075088>>2];if(!f){break q}r:{if((d|0)==1){b=x[(D(b,896)+a|0)+1075648>>2];break r}j=(D(b,896)+a|0)+1075648|0;b=x[(f+(d<<2)|0)+60>>2];x[j>>2]=b}Ep(a,g,b)}i=e?i:0}a=h+8|0;Kb(a,k,52);b=Ib(a);Kb(a,k,23);if(Ib(a)){break a}i=(b&c>>>8)+i|0}w[m>>1]=i}hb=h+16|0}function q9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-240|0;hb=f;vf(f+224|0,b);e=hb-48|0;hb=e;x[e+44>>2]=0;Ri(b,e+44|0);a:{b:{c:{if(x[e+44>>2]!=(Qj(9875)|0)){break c}x[e+40>>2]=0;Ri(b,e+40|0);h=-1;g=x[e+40>>2];if(g-3>>>0<4294967294){break c}d:{e:{f:{if(g>>>0<=1){g=Wb(e+24|0);x[114414]=0;i=U(696,b|0,g|0,256)|0;j=x[114414];x[114414]=0;if((j|0)==1){break b}if(!i){break e}x[114414]=0;T(13,e+8|0,d|0,g|0);i=x[114414];x[114414]=0;if((i|0)!=1){break f}break b}g=Wb(e+24|0);x[114414]=0;i=U(698,b|0,g|0,255)|0;j=x[114414];x[114414]=0;if((j|0)==1){break b}if(!i){break d}x[114414]=0;T(13,e+8|0,d|0,g|0);i=x[114414];x[114414]=0;if((i|0)==1){break b}}i=e+8|0;Db(c,i);xb(i);xb(g);g=0;w[e+8>>1]=0;zf(b,i);x[e+24>>2]=0;Ri(b,e+24|0);i=x[e+24>>2];if(i>>>0>50){break c}if(i){while(1){if(!rK(a,b,d)){break c}g=g+1|0;if(g>>>0<A[e+24>>2]){continue}break}}x[e+24>>2]=0;Ri(b,e+24|0);h=x[e+24>>2]==(Qj(9913)|0)?1:-1;break c}xb(g);break c}xb(g)}hb=e+48|0;break a}a=N()|0;xb(g);Q(a|0);p()}g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(!h){Sn(x[x[b>>2]-12>>2]+b|0,0);h=x[f+236>>2];x[f+16>>2]=x[f+232>>2];x[f+20>>2]=h;h=x[f+228>>2];x[f+8>>2]=x[f+224>>2];x[f+12>>2]=h;lj(b,f+8|0);b=pl(f+120|0,b);x[114414]=0;h=O(658,f+104|0,9982)|0;e=x[114414];x[114414]=0;if((e|0)==1){break h}x[114414]=0;x[f+88>>2]=3;x[f+92>>2]=0;T(659,b|0,h|0,f+88|0);e=x[114414];x[114414]=0;if((e|0)==1){break i}Gb(h);x[114414]=0;v[f+103|0]=0;h=O(658,f+88|0,10280)|0;e=x[114414];x[114414]=0;if((e|0)==1){break j}x[114414]=0;U(660,b|0,f+103|0,h|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break k}Gb(h);x[114414]=0;h=y[f+103|0];e=R(1654,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break l}x[114414]=0;g=R(1655,b|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break m}x[f+80>>2]=g;x[f+72>>2]=e;if(Hb(f+72|0,f+80|0)){h=h?0:d;while(1){x[114414]=0;w[f+70>>1]=65535;d=O(658,f+56|0,11801)|0;e=x[114414];x[114414]=0;if((e|0)==1){break p}x[114414]=0;e=U(1656,b|0,f+72|0,d|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break o}Gb(d);s:{if(!e){x[114414]=0;X(1657,b|0,f+72|0,c|0,h|0);d=x[114414];x[114414]=0;if((d|0)==1){break n}break s}x[114414]=0;d=O(658,f+40|0,11563)|0;e=x[114414];x[114414]=0;t:{u:{if((e|0)!=1){x[114414]=0;e=U(1656,b|0,f+72|0,d|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break u}Gb(d);if(e){break t}x[114414]=0;U(1658,b|0,f+72|0,f+70|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break s}break n}a=N()|0;break g}a=N()|0;Gb(d);break g}x[114414]=0;d=O(658,f+24|0,11195)|0;e=x[114414];x[114414]=0;if((e|0)==1){break r}x[114414]=0;e=U(1656,b|0,f+72|0,d|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break q}Gb(d);if(e){break s}x[114414]=0;X(1659,b|0,f+72|0,a|0,h|0);d=x[114414];x[114414]=0;if((d|0)==1){break n}}d=f+72|0;of(d);if(Hb(d,f+80|0)){continue}break}}a=x[b>>2];Hg(b);h=a&1073741824?-1:1}hb=f+240|0;return h|0}a=N()|0;break g}a=N()|0;Gb(d);break g}a=N()|0;break g}a=N()|0;Gb(d);break g}a=N()|0;break g}a=N()|0;break g}a=N()|0;break g}a=N()|0;Gb(h);break g}a=N()|0;break g}a=N()|0;Gb(h);break g}a=N()|0}Hg(b);Q(a|0);p()}function $f(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=hb-112|0;hb=j;k=i&2147483647;a:{b:{l=e&2147483647;m=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:m)){o=k-2147418112|0;if(!h&(o|0)==-2147418112?f|g:(o|0)==-2147418112&(h|0)!=0|o>>>0>2147549184){break b}}if(!(!d&(l|0)==2147418112?m:l>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(l^2147418112|c))){n=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:n;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|l))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}n=(k|0)==(l|0);r=n&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:n&d>>>0<h>>>0|k>>>0>l>>>0;m=r;l=m?f:b;o=m?g:c;n=m?i:e;s=n;m=m?h:d;q=n&65535;d=r?d:h;e=r?e:i;t=e;n=e>>>16&32767;p=s>>>16&32767;if(!p){e=!(m|q);i=e;k=e?l:m;e=e<<6;h=e;i=G(i?o:q);e=e+((i|0)==32?G(k)+32|0:i)|0;gf(j+96|0,l,o,m,q,e-15|0);m=x[j+104>>2];q=x[j+108>>2];o=x[j+100>>2];p=16-e|0;l=x[j+96>>2]}f=r?b:f;g=r?c:g;h=d;i=t&65535;if(!n){b=!(h|i);e=b;k=b?f:h;b=b<<6;c=b;e=G(e?g:i);b=b+((e|0)==32?G(k)+32|0:e)|0;gf(j+80|0,f,g,h,i,b-15|0);n=16-b|0;h=x[j+88>>2];i=x[j+92>>2];g=x[j+84>>2];f=x[j+80>>2]}c=i<<3|h>>>29;b=h<<3|g>>>29;c=c|524288;h=m<<3|o>>>29;i=q<<3|m>>>29;r=s^t;e=g<<3|f>>>29;d=f<<3;c:{if((n|0)==(p|0)){break c}f=p-n|0;if(f>>>0>127){b=0;c=0;e=0;d=1;break c}gf(j- -64|0,d,e,b,c,128-f|0);Al(j+48|0,d,e,b,c,f);b=x[j+56>>2];c=x[j+60>>2];e=x[j+52>>2];d=x[j+48>>2]|(x[j+64>>2]|x[j+72>>2]|(x[j+68>>2]|x[j+76>>2]))!=0}m=d;k=e;n=h;q=i|524288;e=o<<3|l>>>29;o=l<<3;l=e;d:{if((r|0)<0){f=0;g=0;h=0;i=0;if(!(m^o|b^n|(k^l|c^q))){break a}d=o-m|0;e=l-((m>>>0>o>>>0)+k|0)|0;f=n-b|0;g=(k|0)==(l|0)&m>>>0>o>>>0|k>>>0>l>>>0;h=f-g|0;b=(q-((b>>>0>n>>>0)+c|0)|0)-(f>>>0<g>>>0)|0;i=b;if(b>>>0>524287){break d}b=!(h|i);f=b;g=b?d:h;b=b<<6;c=b;f=G(f?e:i);b=b+((f|0)==32?G(g)+32|0:f)|0;b=b-12|0;gf(j+32|0,d,e,h,i,b);p=p-b|0;h=x[j+40>>2];i=x[j+44>>2];d=x[j+32>>2];e=x[j+36>>2];break d}e=k+l|0;d=m+o|0;e=d>>>0<o>>>0?e+1|0:e;f=(k|0)==(e|0)&d>>>0<m>>>0|e>>>0<k>>>0;k=c+q|0;b=b+n|0;k=b>>>0<n>>>0?k+1|0:k;h=b+f|0;i=h>>>0<b>>>0?k+1|0:k;if(!(i&1048576)){break d}d=m&1|((e&1)<<31|d>>>1);e=h<<31|e>>>1;p=p+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}c=0;l=s&-2147483648;if((p|0)>=32767){h=c;i=l|2147418112;f=0;g=0;break a}n=0;e:{if((p|0)>0){n=p;break e}gf(j+16|0,d,e,h,i,p+127|0);Al(j,d,e,h,i,1-p|0);d=x[j>>2]|(x[j+16>>2]|x[j+24>>2]|(x[j+20>>2]|x[j+28>>2]))!=0;e=x[j+4>>2];h=x[j+8>>2];i=x[j+12>>2]}o=d&7;d=(e&7)<<29|d>>>3;f=(o>>>0>4)+d|0;b=h<<29|e>>>3;g=d>>>0>f>>>0?b+1|0:b;d=(b|0)==(g|0)&d>>>0>f>>>0|b>>>0>g>>>0;b=c|((i&7)<<29|h>>>3);h=d+b|0;i=l|(i>>>3&65535|n<<16);i=b>>>0>h>>>0?i+1|0:i;f:{if((o|0)==4){b=0;k=g+b|0;d=f;c=f&1;f=f+c|0;g=d>>>0>f>>>0?k+1|0:k;b=(b|0)==(g|0)&c>>>0>f>>>0|b>>>0>g>>>0;h=b+h|0;i=b>>>0>h>>>0?i+1|0:i;break f}if(!o){break a}}}x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;hb=j+112|0}function _b(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=x[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=x[d>>2];d=d-b|0;if(d>>>0<A[114294]){break a}a=a+b|0;if(x[114295]!=(d|0)){if(b>>>0<=255){e=x[d+8>>2];b=b>>>3|0;c=x[d+12>>2];if((c|0)==(e|0)){i=457160,j=x[114290]&Cna(-2,b),x[i>>2]=j;break b}x[e+12>>2]=c;x[c+8>>2]=e;break b}h=x[d+24>>2];b=x[d+12>>2];c:{if((d|0)!=(b|0)){c=x[d+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break c}d:{e=d+20|0;c=x[e>>2];if(c){break d}e=d+16|0;c=x[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[g>>2]=0}if(!h){break b}e=x[d+28>>2];c=(e<<2)+457464|0;e:{if(x[c>>2]==(d|0)){x[c>>2]=b;if(b){break e}i=457164,j=x[114291]&Cna(-2,e),x[i>>2]=j;break b}x[h+(x[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}x[b+24>>2]=h;c=x[d+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[d+20>>2];if(!c){break b}x[b+20>>2]=c;x[c+24>>2]=b;break b}b=x[f+4>>2];if((b&3)!=3){break b}x[114292]=a;x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=x[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(x[114296]==(f|0)){x[114296]=d;a=x[114293]+a|0;x[114293]=a;x[d+4>>2]=a|1;if(x[114295]!=(d|0)){break a}x[114292]=0;x[114295]=0;return}if(x[114295]==(f|0)){x[114295]=d;a=x[114292]+a|0;x[114292]=a;x[d+4>>2]=a|1;x[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=x[f+8>>2];b=b>>>3|0;c=x[f+12>>2];if((c|0)==(e|0)){i=457160,j=x[114290]&Cna(-2,b),x[i>>2]=j;break g}x[e+12>>2]=c;x[c+8>>2]=e;break g}h=x[f+24>>2];b=x[f+12>>2];h:{if((f|0)!=(b|0)){c=x[f+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break h}i:{e=f+20|0;c=x[e>>2];if(c){break i}e=f+16|0;c=x[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[g>>2]=0}if(!h){break g}e=x[f+28>>2];c=(e<<2)+457464|0;j:{if(x[c>>2]==(f|0)){x[c>>2]=b;if(b){break j}i=457164,j=x[114291]&Cna(-2,e),x[i>>2]=j;break g}x[h+(x[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}x[b+24>>2]=h;c=x[f+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[f+20>>2];if(!c){break g}x[b+20>>2]=c;x[c+24>>2]=b}x[d+4>>2]=a|1;x[a+d>>2]=a;if(x[114295]!=(d|0)){break f}x[114292]=a;return}x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a}if(a>>>0<=255){b=(a&-8)+457200|0;c=x[114290];a=1<<(a>>>3);k:{if(!(c&a)){x[114290]=a|c;a=b;break k}a=x[b+8>>2]}x[b+8>>2]=d;x[a+12>>2]=d;x[d+12>>2]=b;x[d+8>>2]=a;return}e=31;if(a>>>0<=16777215){b=G(a>>>8|0);e=((a>>>38-b&1)-(b<<1)|0)+62|0}x[d+28>>2]=e;x[d+16>>2]=0;x[d+20>>2]=0;g=(e<<2)+457464|0;l:{m:{c=x[114291];b=1<<e;n:{if(!(c&b)){x[114291]=b|c;x[g>>2]=d;x[d+24>>2]=g;break n}e=a<<((e|0)!=31?25-(e>>>1|0)|0:0);b=x[g>>2];while(1){c=b;if((x[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=x[g+16>>2];if(b){continue}break}x[g+16>>2]=d;x[d+24>>2]=c}x[d+12>>2]=d;x[d+8>>2]=d;break l}a=x[c+8>>2];x[a+12>>2]=d;x[c+8>>2]=d;x[d+24>>2]=0;x[d+12>>2]=c;x[d+8>>2]=a}a=x[114298]-1|0;x[114298]=a?a:-1}}function qV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=hb-32|0;hb=e;x[e+28>>2]=b;if((d|0)<=0){a=0}else{x[e+8>>2]=d;x[e+16>>2]=214748364;s=e,t=D(x[Mb(e+28|0,e+16|0)>>2],20),x[s+20>>2]=t;Uv(c,x[Mb(e+8|0,e+20|0)>>2]);x[e+8>>2]=a;x[e+12>>2]=x[e+28>>2];a=0;while(1){a:{b=e+8|0;f=Ng(b,a);j=Ng(b,a+4|0);n=Ng(b,a+5|0);s=e,t=Ng(b,a+6|0)<<8|Ng(b,a+7|0),x[s+24>>2]=t;b=n|j<<8;q=a+8|0;b:{c:{d:{e:{switch(f|0){case 0:f:{if(b>>>0<=d>>>0){j=0;n=0;if(b){break f}break b}b=ec(8);x[114414]=0;a=R(317,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break d}break c}while(1){s=e,t=Ng(e+8|0,j+q|0),v[s+20|0]=t;Mo(c,e+20|0);j=j+1|0;if((b|0)!=(j|0)){continue}break};j=b;n=b;break b;case 1:break e;default:break a}}Ch(e+24|0,d);j=x[e+24>>2];g=Ng(e+8|0,a+10|0);v[e+20|0]=g;Mo(c,e+20|0);f=x[e+24>>2];x[e+24>>2]=f-1;n=b+3&65532;if((f|0)<2){break b}h=a+11|0;l=0;m=0;k=0;b=0;while(1){a=Wf(h,b,1,e+8|0);g:{h:{i:{j:{k:{if((k|0)<=7){if(a){f=b;break h}b=b+1|0;l=8;break k}f=b+1|0;l:{if(!a){if(!Wf(h,f,1,e+8|0)){break h}f=2;m:{n:{a=b+2|0;if(!Wf(h,a,1,e+8|0)){break n}f=3;a=b+3|0;if(!Wf(h,a,1,e+8|0)){break n}f=Wf(h,a,3,e+8|0);b=b+6|0;break m}b=a+1|0}a=4;o:{p:{q:{f=((l<<3)+f|0)-17|0;r:{if((f|0)<0){a=ec(8);x[114414]=0;b=R(317,a|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break q}break r}if(f>>>0<56){break o}a=ec(8);x[114414]=0;b=R(317,a|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break p}}b=N()|0;hc(a);Q(b|0);p()}da(b|0,76228,231);p()}da(b|0,76228,231);p()}l=y[f+23232|0];if((l|0)!=8){break j}break l}a=4;b=f;if((l|0)!=8){break j}}l=8;a=1;if((m|0)>19){break j}}a=0;break i}m=m+8|0}i=x[e+24>>2];s:{if((i|0)<=0){break s}while(1){f=e+8|0;o=(b|0)/8|0;i=o+h|0;r=Ng(f,i);i=(Ng(f,i+1|0)<<8|r<<16|Ng(f,i+2|0))<<(b-(o<<3)|0)+8^-2147483648;f=32-l|0;g=g-((i>>>f)-(-2147483648>>>f)|0)|0;v[e+20|0]=g;Mo(c,e+20|0);f=x[e+24>>2];i=f-1|0;x[e+24>>2]=i;b=b+l|0;if(!a){break s}a=a-1|0;if((f|0)>1){continue}break}}k=(k|0)==31?31:k+1|0;break g}t:{u:{v:{a=f+1|0;if(!Wf(h,a,1,e+8|0)){g=2;break v}a=f+2|0;if(!Wf(h,a,1,e+8|0)){g=4;break v}a=f+3|0;if(!Wf(h,a,1,e+8|0)){g=6;break v}a=f+5|0;if(!Wf(h,f+4|0,1,e+8|0)){b=f+8|0;a=Wf(h,a,3,e+8|0)+8|0;break t}b=f+10|0;g=16;a=Wf(h,a,5,e+8|0);break u}b=a+2|0;a=Wf(h,a+1|0,1,e+8|0)}a=a+g|0}w:{if(Wf(h,b,1,e+8|0)){f=-256;g=12;break w}b=b+1|0;g=Wf(h,b,1,e+8|0);f=g?-4352:0;g=g?14:8}b=b+1|0;i=Wf(h,b,g,e+8|0);if(a>>>0>=3){k=k-((a|0)!=3)|0;k=((k|0)<=1?1:k)-1|0}f=wc(c)+((i^-1)+f|0)|0;if(f>>>0<wc(c)>>>0){if(x[e+24>>2]<=0){break b}b=b+g|0;while(1){g=y[Bc(c,f)|0];v[e+20|0]=g;Mo(c,e+20|0);o=x[e+24>>2];i=o-1|0;x[e+24>>2]=i;if(a>>>0<2){break g}f=f+1|0;a=a-1|0;if((o|0)>1){continue}break}break g}b=ec(8);x[114414]=0;a=R(317,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break c}da(a|0,76228,231);p()}m=m-(m>>3)|0;if((i|0)>0){continue}break}break b}da(a|0,76228,231);p()}a=N()|0;hc(b);Q(a|0);p()}a=n+q|0;d=d-j|0;if((d|0)>0){continue}}break}a=od(c)^1}hb=e+32|0;return a|0}function sL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;a:{b:{if(b){f=a+327720|0;b=hb-400|0;hb=b;MN(b+384|0,8);x[114414]=0;ma(1203,b+368|0,9);h=x[114414];x[114414]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((h|0)!=1){x[114414]=0;h=O(1204,b+352|0,14)|0;d=x[114414];x[114414]=0;if((d|0)==1){break n}x[114414]=0;P(1205,b+384|0,h|0);d=x[114414];x[114414]=0;if((d|0)==1){break m}x[114414]=0;P(1205,b+368|0,h|0);d=x[114414];x[114414]=0;if((d|0)==1){break m}LN(b+280|0,4900);LN(b+208|0,32e3);HN(b+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);x[114414]=0;d=O(1206,b+104|0,b+384|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break l}rt(b+120|0,b+280|0,d);Pf(d);x[114414]=0;d=O(1206,b+72|0,b+368|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break k}rt(b+88|0,b+208|0,d);Pf(d);x[114414]=0;d=O(1206,b+40|0,b+120|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break j}rt(b+56|0,b+136|0,d);Pf(d);x[114414]=0;g=O(1206,b+8|0,b+88|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break i}d=b+24|0;rt(d,b+136|0,g);Pf(g);g=b+120|0;Op(g);i=b+56|0;Op(i);j=b+88|0;Op(j);Op(d);k=b+368|0;Op(k);Np(g,zn(f,0));Np(i,zn(f,1));Np(j,zn(f,2));Np(d,zn(f,3));Np(k,zn(f,4));Pf(d);Pf(i);Pf(j);Pf(g);Mp(h);Pf(k);Pf(b+384|0);hb=b+400|0;break c}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;break f}a=N()|0;break g}a=N()|0;break h}a=N()|0;Pf(b+56|0)}Pf(b+88|0)}Pf(b+120|0)}Mp(h)}Pf(b+368|0)}Pf(b+384|0);Q(a|0);p()}ey(a+131112|0,9.6377,.97);ey(a+196648|0,8.5,.5);ey(a+262184|0,2.7625,.425);b=a+368680|0;dy(b,a);break b}b=a+368680|0;if(dy(b,a)){break a}}g=a+24|0;n=C[a+8>>3];i=y[a+16|0];h=hb+-64|0;hb=h;while(1){q=+(l-4096|0)*.0001220703125;m=0;f=0;while(1){e=1;d=h+(f<<3)|0;c=+(f|0)-q;o=c+-3.5;if(F(o)<1e-8){c=n}else{o:{p:{switch(i|0){case 0:e=.5-xe(c*.8975979010256552)*.5;break o;case 1:e=xe(c*.8975979010256552)*-.46+.54;break o;case 2:c=c*.8975979010256552;e=xe(c+c);e=xe(c)*-.5+.42+e*.08;break o;case 3:c=c*.8975979010256552;e=xe(c+c);e=xe(c)*-.49364+.44959+e*.05677;break o;case 4:c=c*.8975979010256552;e=xe(c+c);e=xe(c)*-.49755+.42323+e*.07922;break o;case 5:c=c*.8975979010256552;e=xe(c+c);e=xe(c)*-.48829+.35875+e*.14128+xe(c*3)*-.01168;break o;case 6:c=c*.8975979010256552;e=xe(c+c);e=xe(c)*-.49703+.40217+e*.09392+xe(c*3)*-.00183;break o;case 7:break p;default:break o}}c=c*.8975979010256552;e=xe(c+c);e=xe(c)*-.49804+.40243+e*.09831+xe(c*3)*-.00122}c=o*3.141592653589793;c=oi(c*n)/c}c=c*e;C[d>>3]=c;m=c+m;f=f+1|0;if((f|0)!=8){continue}break}c=1/m;j=l<<3;f=0;while(1){k=g+(f+j<<1)|0;e=I(H(J(C[h+(f<<3)>>3]*32768*c+.5),32768),-32768);q:{if(F(e)<2147483648){d=~~e;break q}d=-2147483648}w[k>>1]=d;f=f+1|0;if((f|0)!=8){continue}break}l=l+1|0;if((l|0)!=8193){continue}break}hb=h- -64|0;f=x[a+20>>2];x[b+16>>2]=x[a+16>>2];x[b+20>>2]=f;f=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=f;f=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=f}}function Oea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-80|0;hb=e;r=x[a+16>>2];x[e+56>>2]=a+112;x[e+48>>2]=0;x[e+52>>2]=0;t=e,u=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[t+60>>2]=u;b=x[a+128>>2];x[e+68>>2]=0;x[e+64>>2]=b;a:{if(!b){break a}f=a+8|0;t=e,u=Sf(f,b),x[t+48>>2]=u;x[e+52>>2]=lb;t=e,u=Te(f,d),x[t+24>>2]=u;x[e+28>>2]=lb;tf(a,e+24|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+68>>2]=d}i=x[a+44>>2];x[e+28>>2]=i;h=x[a+48>>2];x[e+32>>2]=h;j=x[a+52>>2];x[e+36>>2]=j;k=x[a+56>>2];x[e+40>>2]=k;l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];n=b;f=x[a>>2];x[e+16>>2]=f;x[e+20>>2]=b;b=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=b;b:{c:{if(!d){b=l>>12;g=m>>12;break c}while(1){f=x[e+68>>2]-1|0;x[e+68>>2]=f;b=x[e+16>>2];g=(((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1;if(!f){x[e+48>>2]=0;x[e+52>>2]=0}f=g+r|0;x[e+72>>2]=b;x[e+76>>2]=0;d:{b=x[e+64>>2];if((b|0)<=0){break d}while(1){e:{i=x[e+72>>2];g=(x[e+76>>2]&2147483647)<<1|i>>>31;i=w[(g<<1|2)+f>>1];g=w[f+((g&2147483646)<<1)>>1];x[114414]=0;P(1048,x[e+56>>2],(g+i|0)/8<<16>>16);g=x[114414];x[114414]=0;if((g|0)==1){break e}x[114414]=0;P(1049,x[e+56>>2],4);g=x[114414];x[114414]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+72|0,e+48|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+56>>2];Tb(b,b+8|0);b=x[e+56>>2];g=x[b+4>>2];if(g){h=x[e+72>>2];i=(x[e+76>>2]&2147483647)<<1|h>>>31;h=w[(i<<1|2)+f>>1];f=w[f+((i&2147483646)<<1)>>1];x[114414]=0;P(1048,b|0,(f+h|0)/8<<16>>16);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(1049,x[e+56>>2],g|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[e+56>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114414]=0;b=O(1050,b|0,x[e+60>>2])|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}d=d-1|0;x[e+4>>2]=b;x[e>>2]=b;b=0;g=1;while(1){f=(b<<2)+e|0;o=x[f>>2];h=x[a+60>>2];i=(e+24|0)+(b<<3)|0;q=x[i+4>>2];j=Xb(q,-16777216,16776704);k=x[a+64>>2];n=Xb(x[i+8>>2],-16777216,16776704);b=x[a+68>>2];x[i+8>>2]=q;q=x[a+72>>2];o=o<<8;h=yna(h,h>>31,o,o>>31);s=lb;k=yna(k,k>>31,j,j>>31);j=k+h|0;h=lb+s|0;h=j>>>0<k>>>0?h+1|0:h;k=yna(b,b>>31,n,n>>31);j=k+j|0;b=lb+h|0;b=j>>>0<k>>>0?b+1|0:b;h=j+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;x[f>>2]=(b|0)/256;x[i+4>>2]=b-(o&q);f=g&1;g=0;b=1;if(f){continue}break}b=x[a+32>>2];m=x[a+28>>2]+m|0;g=m>>12;x[c>>2]=x[c>>2]+D(g,x[e>>2]);l=b+l|0;b=l>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[e+4>>2]);c=c+8|0;Tb(e+16|0,e+8|0);if(d){continue}break}k=x[e+40>>2];j=x[e+36>>2];h=x[e+32>>2];i=x[e+28>>2];f=x[e+16>>2];n=x[e+20>>2]}x[a>>2]=f;x[a+4>>2]=n;x[a+40>>2]=l;x[a+20>>2]=g;x[a+36>>2]=m;x[a+56>>2]=k;x[a+52>>2]=j;x[a+48>>2]=h;x[a+44>>2]=i;x[a+24>>2]=b;hb=e+80|0;return}b=N()|0;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;x[a+44>>2]=x[e+28>>2];x[a+48>>2]=x[e+32>>2];x[a+52>>2]=x[e+36>>2];x[a+56>>2]=x[e+40>>2];Q(b|0);p()}function _3(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=hb-144|0;hb=d;x[d+136>>2]=c;a:{b:{c:{d:{if(!(b<.8)){x[114414]=0;c=$(2189)|0;e=x[114414];x[114414]=0;e:{f:{g:{if((e|0)!=1){x[d+64>>2]=c;c=x[d+136>>2];x[114414]=0;c=R(2190,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break f}x[d+48>>2]=c;jn(x[d- -64>>2],x[d+48>>2]);c=x[d- -64>>2];a=df(d+120|0,a);x[114414]=0;e=x[a+12>>2];x[d+40>>2]=x[a+8>>2];x[d+44>>2]=e;e=x[a+4>>2];x[d+32>>2]=x[a>>2];x[d+36>>2]=e;a=U(2175,c|0,d+32|0,15)|0;c=x[114414];x[114414]=0;if((c|0)==1){break g}if(a){a=x[d- -64>>2];x[114414]=0;R(1410,a|0)|0;a=x[114414];x[114414]=0;f=1;if((a|0)==1){break g}}pd(d+48|0);ui(d- -64|0);break c}c=S(0)|0;break d}c=S(0)|0;pd(d+48|0);break e}c=S(0)|0}ui(d- -64|0);break d}if(!(b<.6)){x[114414]=0;c=$(2189)|0;e=x[114414];x[114414]=0;h:{i:{j:{if((e|0)!=1){x[d+64>>2]=c;c=x[d+136>>2];x[114414]=0;c=R(2190,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break i}x[d+48>>2]=c;jn(x[d- -64>>2],x[d+48>>2]);c=x[d- -64>>2];a=df(d+104|0,a);x[114414]=0;e=x[a+12>>2];x[d+24>>2]=x[a+8>>2];x[d+28>>2]=e;e=x[a+4>>2];x[d+16>>2]=x[a>>2];x[d+20>>2]=e;a=U(2175,c|0,d+16|0,2)|0;c=x[114414];x[114414]=0;if((c|0)==1){break j}if(a){a=x[d- -64>>2];x[114414]=0;R(1410,a|0)|0;a=x[114414];x[114414]=0;f=.8;if((a|0)==1){break j}}pd(d+48|0);ui(d- -64|0);break c}c=S(0)|0;break d}c=S(0)|0;pd(d+48|0);break h}c=S(0)|0}ui(d- -64|0);break d}f=.2;if(!(b<.2)){x[114414]=0;c=$(2189)|0;e=x[114414];x[114414]=0;k:{l:{m:{if((e|0)!=1){x[d+64>>2]=c;c=x[d+136>>2];x[114414]=0;c=R(2190,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break l}x[d+48>>2]=c;jn(x[d- -64>>2],x[d+48>>2]);c=x[d- -64>>2];a=df(d+88|0,a);x[114414]=0;e=x[a+12>>2];x[d+8>>2]=x[a+8>>2];x[d+12>>2]=e;e=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=e;a=U(2175,c|0,d|0,0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break m}f=0;if(a){a=x[d- -64>>2];x[114414]=0;R(1410,a|0)|0;a=x[114414];x[114414]=0;f=.6;if((a|0)==1){break m}}pd(d+48|0);ui(d- -64|0);break c}c=S(0)|0;break d}c=S(0)|0;pd(d+48|0);break k}c=S(0)|0}ui(d- -64|0);break d}if(b<.1){break c}x[114414]=0;T(834,d- -64|0,a|0,2048);c=x[114414];x[114414]=0;n:{o:{p:{if((c|0)!=1){x[114414]=0;c=R(421,d- -64|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break o}e=x[d- -64>>2];x[114414]=0;a=R(223,a|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break o}x[114414]=0;a=WD(2191,3,0,c,e,a,0);c=x[114414];x[114414]=0;if((c|0)==1){break o}a=a+1|0;if(a>>>0>=3){break p}f=C[(a<<3)+37640>>3];Hc(d- -64|0);break c}c=S(0)|0;break d}a=ec(8);x[114414]=0;e=O(118,d+48|0,17386)|0;c=x[114414];x[114414]=0;if((c|0)!=1){a=oc(a,e);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}c=S(0)|0;xb(e);break n}c=S(0)|0;hc(a);break n}c=S(0)|0}Hc(d- -64|0)}Y(c|0)|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;f=0;if((a|0)==1){break a}}pd(d+136|0);hb=d+144|0;return+f}p()}a=N()|0;pd(d+136|0);Q(a|0);p()}function faa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=hb-48|0;hb=c;if(xh(b)){h=zk(b);l=x[b+12>>2];e=hb-16|0;hb=e;f=c+32|0;x[f>>2]=0;x[f+4>>2]=0;x[e+12>>2]=0;Xc(f+8|0);if(h){sq(f,h);i=hb-16|0;hb=i;a:{b:{d=rq(i,f,h);g=x[d+4>>2];m=x[d+8>>2];if((g|0)!=(m|0)){while(1){j=yb(f);x[114414]=0;P(1593,j|0,g|0);j=x[114414];x[114414]=0;if((j|0)==1){break b}g=g+6|0;x[d+4>>2]=g;if((g|0)!=(m|0)){continue}break}}Jb(d);hb=i+16|0;break a}a=N()|0;Jb(d);Q(a|0);p()}}hb=e+16|0;c:{if(!l){break c}while(1){d=x[x[a>>2]-12>>2];x[114414]=0;d=R(1589,a+d|0)|0;g=x[114414];x[114414]=0;d:{if((g|0)!=1){e:{if(!d){break c}x[114414]=0;v[c+31|0]=0;O(1590,a|0,c+31|0)|0;d=x[114414];x[114414]=0;f:{if((d|0)!=1){d=v[c+31|0];if(d){break f}k=k+1|0;break d}break e}v[c+30|0]=0;g:{if((d|0)>=0){break g}x[114414]=0;O(1590,a|0,c+30|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){break g}break e}v[c+29|0]=0;Zh(c+16|0);h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{d=d&127;d=(d?d-1|0:0)&65535;i=d>>>0>=h>>>0;C:{D:{if(!i){x[114414]=0;g=U(427,b|0,k|0,d|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break e}if(v[c+30|0]&1){break D}break A}g=c+16|0;e=y[c+30|0];if(!(e&1)){break C}}x[114414]=0;O(1590,a|0,c+29|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break e}if(d>>>0<h>>>0){break B}e=y[c+30|0]}if(e&2){break z}break y}e=y[c+29|0];n=Qc(f,d),o=e,v[n|0]=o}n=g,o=y[Qc(f,d)|0],v[n|0]=o;if(!(y[c+30|0]&2)){break w}}x[114414]=0;O(1590,a|0,c+29|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break e}if(d>>>0<h>>>0){break x}e=y[c+30|0]}if(e&4){break v}break u}e=y[c+29|0];n=Qc(f,d),o=e,v[n+1|0]=o}n=g,o=y[Qc(f,d)+1|0],v[n+1|0]=o;if(!(y[c+30|0]&4)){break s}}x[114414]=0;O(1590,a|0,c+29|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break e}if(d>>>0<h>>>0){break t}e=y[c+30|0]}if(e&8){break r}break q}e=y[c+29|0];n=Qc(f,d),o=e,v[n+2|0]=o}n=g,o=y[Qc(f,d)+2|0],v[n+2|0]=o;if(!(y[c+30|0]&8)){break o}}x[114414]=0;O(1590,a|0,c+29|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break e}if(d>>>0<h>>>0){break p}e=y[c+30|0]}if(e&16){break n}break m}e=y[c+29|0];n=Qc(f,d),o=e,v[n+4|0]=o}n=g,o=y[Qc(f,d)+4|0],v[n+4|0]=o;if(!(y[c+30|0]&16)){break k}}x[114414]=0;O(1590,a|0,c+29|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break e}if(d>>>0<h>>>0){break l}e=y[c+30|0]}if(e&32){break j}break h}e=y[c+29|0];n=Qc(f,d),o=e,v[n+3|0]=o}n=g,o=y[Qc(f,d)+3|0],v[n+3|0]=o;if(!(y[c+30|0]&32)){break i}}x[114414]=0;O(1590,a|0,c+29|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break e}if(i){break h}e=y[c+29|0];n=Qc(f,d),o=e,v[n+5|0]=o}n=g,o=y[Qc(f,d)+5|0],v[n+5|0]=o}if(!(y[c+30|0]&64)){break d}x[114414]=0;O(1590,a|0,c+15|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){d=y[c+15|0];x[114414]=0;U(1591,a|0,d|0,-1)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break d}}}}a=N()|0;bm(f);Q(a|0);p()}if(k>>>0<l>>>0){continue}break}}bm(f)}hb=c+48|0}function _r(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=x[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=x[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=x[114295]){if(c>>>0<=255){e=x[a+8>>2];c=c>>>3|0;d=x[a+12>>2];if((d|0)!=(e|0)){break c}i=457160,j=x[114290]&Cna(-2,c),x[i>>2]=j;break b}h=x[a+24>>2];c=x[a+12>>2];d:{if((c|0)!=(a|0)){d=x[a+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break d}e:{e=a+20|0;d=x[e>>2];if(d){break e}e=a+16|0;d=x[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[g>>2]=0}if(!h){break b}e=x[a+28>>2];d=(e<<2)+457464|0;f:{if(x[d>>2]==(a|0)){x[d>>2]=c;if(c){break f}i=457164,j=x[114291]&Cna(-2,e),x[i>>2]=j;break b}x[h+(x[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}x[c+24>>2]=h;d=x[a+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[a+20>>2];if(!d){break b}x[c+20>>2]=d;x[d+24>>2]=c;break b}c=x[f+4>>2];if((c&3)!=3){break b}x[114292]=b;x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[f>>2]=b;return}x[e+12>>2]=d;x[d+8>>2]=e}c=x[f+4>>2];g:{if(!(c&2)){if(x[114296]==(f|0)){x[114296]=a;b=x[114293]+b|0;x[114293]=b;x[a+4>>2]=b|1;if(x[114295]!=(a|0)){break a}x[114292]=0;x[114295]=0;return}if(x[114295]==(f|0)){x[114295]=a;b=x[114292]+b|0;x[114292]=b;x[a+4>>2]=b|1;x[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=x[f+8>>2];c=c>>>3|0;d=x[f+12>>2];if((d|0)==(e|0)){i=457160,j=x[114290]&Cna(-2,c),x[i>>2]=j;break h}x[e+12>>2]=d;x[d+8>>2]=e;break h}h=x[f+24>>2];c=x[f+12>>2];i:{if((f|0)!=(c|0)){d=x[f+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break i}j:{d=f+20|0;e=x[d>>2];if(e){break j}d=f+16|0;e=x[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=x[d>>2];if(e){continue}d=c+16|0;e=x[c+16>>2];if(e){continue}break}x[g>>2]=0}if(!h){break h}e=x[f+28>>2];d=(e<<2)+457464|0;k:{if(x[d>>2]==(f|0)){x[d>>2]=c;if(c){break k}i=457164,j=x[114291]&Cna(-2,e),x[i>>2]=j;break h}x[h+(x[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}x[c+24>>2]=h;d=x[f+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[f+20>>2];if(!d){break h}x[c+20>>2]=d;x[d+24>>2]=c}x[a+4>>2]=b|1;x[a+b>>2]=b;if(x[114295]!=(a|0)){break g}x[114292]=b;return}x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[a+b>>2]=b}if(b>>>0<=255){c=(b&-8)+457200|0;d=x[114290];b=1<<(b>>>3);l:{if(!(d&b)){x[114290]=b|d;b=c;break l}b=x[c+8>>2]}x[c+8>>2]=a;x[b+12>>2]=a;x[a+12>>2]=c;x[a+8>>2]=b;return}e=31;if(b>>>0<=16777215){c=G(b>>>8|0);e=((b>>>38-c&1)-(c<<1)|0)+62|0}x[a+28>>2]=e;x[a+16>>2]=0;x[a+20>>2]=0;g=(e<<2)+457464|0;m:{d=x[114291];c=1<<e;n:{if(!(d&c)){x[114291]=c|d;x[g>>2]=a;x[a+24>>2]=g;break n}e=b<<((e|0)!=31?25-(e>>>1|0)|0:0);c=x[g>>2];while(1){d=c;if((x[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=x[g+16>>2];if(c){continue}break}x[g+16>>2]=a;x[a+24>>2]=d}x[a+12>>2]=a;x[a+8>>2]=a;return}b=x[d+8>>2];x[b+12>>2]=a;x[d+8>>2]=a;x[a+24>>2]=0;x[a+12>>2]=d;x[a+8>>2]=b}}function KL(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,j=0,k=E(0),l=0,m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=E(0),u=0;if(b){rp(a);c=a+24596|0;x[c>>2]=0;x[c+4>>2]=0;x[a+24588>>2]=0;x[a+24592>>2]=0;YL(a)}JL(a+24648|0);q=x[a+24620>>2];g=hb-144|0;hb=g;d=!b;e=a+393352|0;c=x[e+4>>2];if(c>>>0>=29){x[e+4>>2]=0;c=0}j=D(c,44)+81056|0;if(!((j|0)==x[e+4112>>2]&d)){x[e+4112>>2]=j;c=g+8|0;d=x[j+24>>2];x[c>>2]=d;f=x[j+16>>2];x[c+4>>2]=f;x[c+8>>2]=x[j+4>>2];l=(d|0)>(f|0)?d:f;if((l|0)<=-601){i=f;f=l+600|0;x[c+4>>2]=i-f;x[c>>2]=d-f}m=E(q>>>0);h=E(B[j+36>>2]*E(79.30999755859375));a:{if(E(F(h))<E(2147483648)){d=~~h;break a}d=-2147483648}x[c+16>>2]=d- -8192;h=E(E(B[j+32>>2]*E(117.9612045288086))+E(4915.05029296875));b:{if(E(F(h))<E(2147483648)){d=~~h;break b}d=-2147483648}x[c+20>>2]=(d|0)>=32512?32512:d;l=0;h=B[j+8>>2];k=E(E(H(B[j+20>>2],E(.10000000149011612)))*m);c:{if(E(F(k))<E(2147483648)){d=~~k;break c}d=-2147483648}f=(d|0)<=96?96:d;i=f-7500|0;n=f>>>0>=i>>>0?i:0;k=E(B[j+28>>2]*m);d:{if(E(F(k))<E(2147483648)){i=~~k;break d}i=-2147483648}d=n+(i+((d|0)<96?d-96|0:0)|0)|0;i=(d|0)<=128?128:d;r=i>>>0>=3800?3800:i;x[c+24>>2]=r;n=(d|0)<128?d-128|0:0;h=E(h*m);e:{if(E(F(h))<E(2147483648)){o=~~h;break e}o=-2147483648}d=i-3800|0;i=(o+n|0)+(d>>>0<=i>>>0?d:0)|0;x[c+32>>2]=i;n=f>>>0>=7500?7500:f;while(1){f=D(l,12);d=f+c|0;f=f+36480|0;w[d+42>>1]=z[f+10>>1];w[d+36>>1]=z[f+4>>1];o=z[f+6>>1]|z[f+8>>1]<<16;w[d+38>>1]=o;w[d+40>>1]=o>>>16;x[d+44>>2]=((D(x[f>>2],r)+50|0)/100|0)+n;l=l+1|0;if((l|0)!=8){continue}break}h=E(i|0);k=E(le(E(.0010000000474974513),(i|0)<4721?E(1):E(E(4720)/h))*E(32768));f:{if(E(F(k))<E(2147483648)){d=~~k;break f}d=-2147483648}x[c+12>>2]=d;h=E(B[j+12>>2]*h);s=c,t=le(E(.0010000000474974513),h>E(4720)?E(E(4720)/h):E(1)),B[s+28>>2]=t;x[e+4124>>2]=x[g+40>>2];c=eJ(fJ(x[g+16>>2]),m);w[e+4190>>1]=c;w[e+4188>>1]=c;c=z[g+24>>1]<<1;w[e+4198>>1]=c;w[e+4196>>1]=c;while(1){c=(p<<4)+e|0;d=(g+8|0)+D(p,12)|0;j=x[d+44>>2];x[c+4204>>2]=j;x[c+4208>>2]=j;w[c+4212>>1]=z[d+36>>1];w[c+4214>>1]=z[d+42>>1];w[c+4216>>1]=z[d+40>>1];w[c+4218>>1]=z[d+38>>1];p=p+1|0;if((p|0)!=8){continue}break}x[e+53996>>2]=x[g+32>>2];d=e+4184|0;c=x[g+12>>2];if((c|0)>-9e3){c=dJ(c)}else{c=0}x[d>>2]=c;d=e+54052|0;c=x[g+8>>2];if((c|0)>=-8999){c=dJ(c)}else{c=0}x[d>>2]=c;c=x[g+28>>2];d=e+54036|0;x[d>>2]=268464128;x[d+4>>2]=1879052288;c=c>>>0>=32512?32512:c;w[e+54010>>1]=c;w[e+54008>>1]=c;w[e+54006>>1]=c;w[e+54004>>1]=c;x[g+4>>2]=x[g+20>>2];_d(g+4|0,0,32752);c=z[g+4>>1];w[e+54018>>1]=c;w[e+54014>>1]=0;w[e+54016>>1]=0;w[e+54012>>1]=c;h=B[g+36>>2];s=g,u=eJ(E(h*h),m),x[s>>2]=u;_d(g,256,32512);c=z[g>>1];w[e+54026>>1]=c;w[e+54022>>1]=0;w[e+54024>>1]=0;w[e+54020>>1]=c}if(b){x[e+4120>>2]=0;hJ(e)}b=D(q,5);if(b>>>0>A[e+4124>>2]){x[e+4124>>2]=b}hb=g+144|0;b=a+1304392|0;if(zd(b)){XN(x[b>>2],x[a+24620>>2])}}function Pea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-80|0;hb=e;r=x[a+16>>2];x[e+56>>2]=a+112;x[e+48>>2]=0;x[e+52>>2]=0;t=e,u=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[t+60>>2]=u;b=x[a+128>>2];x[e+68>>2]=0;x[e+64>>2]=b;a:{if(!b){break a}f=a+8|0;t=e,u=Sf(f,b),x[t+48>>2]=u;x[e+52>>2]=lb;t=e,u=Te(f,d),x[t+24>>2]=u;x[e+28>>2]=lb;tf(a,e+24|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+68>>2]=d}i=x[a+44>>2];x[e+28>>2]=i;h=x[a+48>>2];x[e+32>>2]=h;j=x[a+52>>2];x[e+36>>2]=j;k=x[a+56>>2];x[e+40>>2]=k;l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];n=b;f=x[a>>2];x[e+16>>2]=f;x[e+20>>2]=b;b=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=b;b:{c:{if(!d){b=l>>12;g=m>>12;break c}while(1){f=x[e+68>>2]-1|0;x[e+68>>2]=f;b=x[e+16>>2];g=((x[e+20>>2]&2147483647)<<1|b>>>31)&-2;if(!f){x[e+48>>2]=0;x[e+52>>2]=0}f=g+r|0;x[e+72>>2]=b;x[e+76>>2]=0;d:{b=x[e+64>>2];if((b|0)<=0){break d}while(1){e:{i=x[e+72>>2];g=(x[e+76>>2]&2147483647)<<1|i>>>31;i=v[(g|1)+f|0];g=v[f+(g&-2)|0];x[114414]=0;P(1048,x[e+56>>2],g+i<<5);g=x[114414];x[114414]=0;if((g|0)==1){break e}x[114414]=0;P(1049,x[e+56>>2],4);g=x[114414];x[114414]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+72|0,e+48|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+56>>2];Tb(b,b+8|0);b=x[e+56>>2];g=x[b+4>>2];if(g){h=x[e+72>>2];i=(x[e+76>>2]&2147483647)<<1|h>>>31;h=v[(i|1)+f|0];f=v[f+(i&-2)|0];x[114414]=0;P(1048,b|0,f+h<<5);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(1049,x[e+56>>2],g|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[e+56>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114414]=0;b=O(1050,b|0,x[e+60>>2])|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}d=d-1|0;x[e+4>>2]=b;x[e>>2]=b;b=0;g=1;while(1){f=(b<<2)+e|0;o=x[f>>2];h=x[a+60>>2];i=(e+24|0)+(b<<3)|0;q=x[i+4>>2];j=Xb(q,-16777216,16776704);k=x[a+64>>2];n=Xb(x[i+8>>2],-16777216,16776704);b=x[a+68>>2];x[i+8>>2]=q;q=x[a+72>>2];o=o<<8;h=yna(h,h>>31,o,o>>31);s=lb;k=yna(k,k>>31,j,j>>31);j=k+h|0;h=lb+s|0;h=j>>>0<k>>>0?h+1|0:h;k=yna(b,b>>31,n,n>>31);j=k+j|0;b=lb+h|0;b=j>>>0<k>>>0?b+1|0:b;h=j+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;x[f>>2]=(b|0)/256;x[i+4>>2]=b-(o&q);f=g&1;g=0;b=1;if(f){continue}break}b=x[a+32>>2];m=x[a+28>>2]+m|0;g=m>>12;x[c>>2]=x[c>>2]+D(g,x[e>>2]);l=b+l|0;b=l>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[e+4>>2]);c=c+8|0;Tb(e+16|0,e+8|0);if(d){continue}break}k=x[e+40>>2];j=x[e+36>>2];h=x[e+32>>2];i=x[e+28>>2];f=x[e+16>>2];n=x[e+20>>2]}x[a>>2]=f;x[a+4>>2]=n;x[a+40>>2]=l;x[a+20>>2]=g;x[a+36>>2]=m;x[a+56>>2]=k;x[a+52>>2]=j;x[a+48>>2]=h;x[a+44>>2]=i;x[a+24>>2]=b;hb=e+80|0;return}b=N()|0;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;x[a+44>>2]=x[e+28>>2];x[a+48>>2]=x[e+32>>2];x[a+52>>2]=x[e+36>>2];x[a+56>>2]=x[e+40>>2];Q(b|0);p()}function _C(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=hb-176|0;hb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if(x[18880]>=(c|0)){lv(a+128|0,c);x[114414]=0;c=O(2,a+112|0,13624)|0;d=x[114414];x[114414]=0;if((d|0)==1){break E}x[114414]=0;T(3,a+144|0,a+128|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break D}x[114414]=0;d=O(4,a+80|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break C}x[114414]=0;e=O(2,a- -64|0,15366)|0;f=x[114414];x[114414]=0;if((f|0)==1){break B}x[114414]=0;T(5,a+96|0,d|0,e|0);f=x[114414];x[114414]=0;if((f|0)==1){break A}x[114414]=0;T(3,a+160|0,a+144|0,a+96|0);f=x[114414];x[114414]=0;if((f|0)==1){break z}xb(a+96|0);xb(e);xb(d);xb(a+144|0);xb(c);xb(a+128|0);c=x[b>>2]?x[b>>2]:17386;x[114414]=0;T(6,a+144|0,1,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break t}c=x[b+4>>2]?x[b+4>>2]:17386;x[114414]=0;T(6,a+128|0,1,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break s}b=x[b+8>>2];x[114414]=0;x[a+48>>2]=b;P(7,a+96|0,a+48|0);b=x[114414];x[114414]=0;if((b|0)==1){break r}x[114414]=0;b=O(8,460264,13503)|0;c=x[114414];x[114414]=0;if((c|0)==1){break q}x[114414]=0;T(9,a+48|0,0,a+144|0);c=x[114414];x[114414]=0;if((c|0)==1){break p}x[114414]=0;b=O(10,b|0,a+48|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break o}x[114414]=0;b=O(8,b|0,13227)|0;c=x[114414];x[114414]=0;if((c|0)==1){break o}x[114414]=0;T(9,a+32|0,0,a+96|0);c=x[114414];x[114414]=0;if((c|0)==1){break n}x[114414]=0;b=O(10,b|0,a+32|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break m}x[114414]=0;b=O(8,b|0,13224)|0;c=x[114414];x[114414]=0;if((c|0)==1){break m}x[114414]=0;b=O(8,b|0,13624)|0;c=x[114414];x[114414]=0;if((c|0)==1){break m}x[114414]=0;T(9,a+16|0,0,a+160|0);c=x[114414];x[114414]=0;if((c|0)==1){break l}x[114414]=0;b=O(10,b|0,a+16|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break k}x[114414]=0;b=O(8,b|0,9292)|0;c=x[114414];x[114414]=0;if((c|0)==1){break k}x[114414]=0;T(9,a|0,0,a+128|0);c=x[114414];x[114414]=0;if((c|0)==1){break j}x[114414]=0;b=O(10,b|0,a|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break i}x[114414]=0;b=O(8,b|0,9290)|0;c=x[114414];x[114414]=0;if((c|0)==1){break i}x[114414]=0;O(11,b|0,12)|0;b=x[114414];x[114414]=0;if((b|0)==1){break i}xb(a);xb(a+16|0);xb(a+32|0);xb(a+48|0);xb(a+96|0);xb(a+128|0);xb(a+144|0);xb(a+160|0)}hb=a+176|0;return}b=N()|0;break u}b=N()|0;break v}b=N()|0;break w}b=N()|0;break x}b=N()|0;break y}b=N()|0;xb(a+96|0)}xb(e)}xb(d)}xb(a+144|0)}xb(c)}xb(a+128|0);break a}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;break e}b=N()|0;break e}b=N()|0;break f}b=N()|0;break f}b=N()|0;break g}b=N()|0;break g}b=N()|0;break h}b=N()|0;break h}b=N()|0;xb(a)}xb(a+16|0)}xb(a+32|0)}xb(a+48|0)}xb(a+96|0)}xb(a+128|0)}xb(a+144|0)}xb(a+160|0)}Q(b|0);p()}function e4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=hb-176|0;hb=d;h=FI(d+160|0);x[h>>2]=82600;f=hb-16|0;hb=f;e=h+4|0;x[e>>2]=0;x[e+4>>2]=0;x[114414]=0;x[f+12>>2]=0;U(2183,e+8|0,f+12|0,f+8|0)|0;e=x[114414];x[114414]=0;a:{if((e|0)!=1){hb=f+16|0;break a}S(0)|0;zb();p()}f=a+24|0;jn(x[f>>2],h);e=y[a+62|0];g=y[a+61|0];j=y[a+60|0];k=x[f>>2];b=df(d+144|0,b);x[114414]=0;i=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=i;i=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=i;b=j?13:15;b=g?b&14:b;b=U(2175,k|0,d|0,(e?b&3:b)|0)|0;e=x[114414];x[114414]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((e|0)==1){break s}if(!b){b=ec(8);x[114414]=0;c=O(118,d+128|0,7854)|0;a=x[114414];x[114414]=0;if((a|0)!=1){a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}a=N()|0;xb(c);break c}a=N()|0;hc(b);break c}if(!y[a+63|0]){x[114414]=0;P(2176,a|0,a+36|0);b=x[114414];x[114414]=0;if((b|0)==1){break s}}v[a+28|0]=1;jn(x[f>>2],x[a+4>>2]);x[114414]=0;P(2177,d+128|0,h|0);b=x[114414];x[114414]=0;if((b|0)==1){break r}b=d+128|0;l=d,m=bc(b),x[l+120>>2]=m;l=d,m=dc(b),x[l+112>>2]=m;if(Hb(d+120|0,d+112|0)){f=a+68|0;while(1){b=x[d+120>>2];e=x[b>>2];x[114414]=0;g=e;e=b+4|0;T(2178,a|0,g|0,e|0);g=x[114414];x[114414]=0;if((g|0)==1){break f}b=x[b>>2];x[114414]=0;P(2179,d+48|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break g}x[114414]=0;T(9,d- -64|0,0,d+48|0);b=x[114414];x[114414]=0;if((b|0)==1){break i}x[114414]=0;b=O(118,d+32|0,13624)|0;g=x[114414];x[114414]=0;if((g|0)==1){break k}x[114414]=0;T(137,d+80|0,d- -64|0,b|0);g=x[114414];x[114414]=0;if((g|0)==1){break m}x[114414]=0;T(781,d+96|0,d+80|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break o}x[114414]=0;P(1547,f|0,d+96|0);e=x[114414];x[114414]=0;if((e|0)==1){break p}xb(d+96|0);xb(d+80|0);xb(b);xb(d- -64|0);xb(d+48|0);b=d+120|0;of(b);if(Hb(b,d+112|0)){continue}break}}l=d,m=Gj(c),x[l+96>>2]=m;l=d,m=Ti(c),x[l+80>>2]=m;t:{while(1){x[114414]=0;b=O(2180,d+96|0,d+80|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break e}if(!b){break q}x[114414]=0;c=R(2181,d+96|0)|0;b=x[114414];x[114414]=0;u:{if((b|0)==1){break u}x[114414]=0;b=O(117,d+16|0,c|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break u}x[114414]=0;X(2114,a|0,b|0,c+12|0,0);c=x[114414];x[114414]=0;if((c|0)==1){break t}xb(b);x[114414]=0;R(2182,d+96|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){continue}break e}break}a=N()|0;break d}a=N()|0;xb(b);break d}a=N()|0;break c}a=N()|0;break c}rx(d+128|0);zs(h);hb=d+176|0;return}a=N()|0;xb(d+96|0);break n}a=N()|0}xb(d+80|0);break l}a=N()|0}xb(b);break j}a=N()|0}xb(d- -64|0);break h}a=N()|0}xb(d+48|0);break d}a=N()|0;break d}a=N()|0;break d}a=N()|0}rx(d+128|0)}zs(h);Q(a|0)}p()}function II(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=hb-224|0;hb=f;x[f+216>>2]=c;x[f+220>>2]=d;a:{if(vj(b)){break a}g=y[rk(b)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}Fk(f+184|0,b,x[b+4>>2]-1|0);g=x[f+188>>2];x[b>>2]=x[f+184>>2];x[b+4>>2]=g}g=f+184|0;Hd(g);h=x[f+184>>2];Hd(f+168|0);i=qk(h,x[f+172>>2],b);Hd(g);g=x[b>>2];h=x[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==x[f+188>>2]){x[f+208>>2]=g;x[f+212>>2]=h;a=tc(f+200|0,17386);c=x[f+212>>2];x[f+16>>2]=x[f+208>>2];x[f+20>>2]=c;c=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=c;if(Kc(f+16|0,f+8|0)){a=ec(8);x[114414]=0;P(2173,f+168|0,f+216|0);b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;T(2152,f+184|0,13488,f+168|0);b=x[114414];x[114414]=0;if((b|0)==1){break g}a=oc(a,f+184|0);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(f+184|0);xb(f+168|0);break c}b=N()|0;break d}if(!e){break h}d=ec(8);x[114414]=0;c=O(2172,f+136|0,b|0)|0;a=x[114414];x[114414]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){x[114414]=0;T(2152,f+152|0,13524,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break p}x[114414]=0;T(2167,f+168|0,f+152|0,13498);b=x[114414];x[114414]=0;a=1;if((b|0)==1){break o}x[114414]=0;P(2173,f+120|0,f+216|0);a=x[114414];x[114414]=0;if((a|0)==1){break n}x[114414]=0;T(137,f+184|0,f+168|0,f+120|0);b=x[114414];x[114414]=0;a=1;if((b|0)==1){break m}a=oc(d,f+184|0);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(f+184|0);a=0;break l}b=N()|0;break i}b=N()|0;xb(c);break i}b=N()|0;break j}b=N()|0;a=1;break k}b=N()|0}xb(f+120|0)}xb(f+168|0)}xb(f+152|0);xb(c);if(!a){break c}}hc(d);break c}x[f+112>>2]=g;x[f+116>>2]=h;e=tc(f+104|0,17386);g=x[f+116>>2];x[f+64>>2]=x[f+112>>2];x[f+68>>2]=g;g=x[e+4>>2];x[f+56>>2]=x[e>>2];x[f+60>>2]=g;if(Kc(f- -64|0,f+56|0)){a=ec(8);x[114414]=0;P(2173,f+168|0,f+216|0);b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;T(2152,f+184|0,13488,f+168|0);b=x[114414];x[114414]=0;if((b|0)==1){break f}a=oc(a,f+184|0);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(f+184|0);xb(f+168|0);break c}b=N()|0;break e}e=x[b+4>>2];x[f+96>>2]=x[b>>2];x[f+100>>2]=e;e=tc(f+88|0,6914);g=x[f+100>>2];x[f+48>>2]=x[f+96>>2];x[f+52>>2]=g;g=x[e+4>>2];x[f+40>>2]=x[e>>2];x[f+44>>2]=g;if(Kc(f+48|0,f+40|0)){wI(a,Cc(c,d));break h}e=x[b+4>>2];x[f+80>>2]=x[b>>2];x[f+84>>2]=e;b=tc(f+72|0,4819);e=x[f+84>>2];x[f+32>>2]=x[f+80>>2];x[f+36>>2]=e;e=x[b+4>>2];x[f+24>>2]=x[b>>2];x[f+28>>2]=e;if(!Kc(f+32|0,f+24|0)){break h}b=Cc(c,d);x[x[a+32>>2]+40>>2]=b>>>0>3?1:b}hb=f+224|0;return}b=N()|0;xb(f+168|0);break d}b=N()|0;xb(f+168|0)}hc(a);break c}hc(a)}Q(b|0)}p()}function Lv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-96|0;hb=e;a:{if(Cd(a,11)|x[a+4>>2]){b=x[a+28>>2];d=x[a+12>>2];g=x[a+64>>2];c=g+x[a+8>>2]|0;d=Ug(e+80|0,c,c>>>0<g>>>0?d+1|0:d);c=x[d+12>>2];x[e+32>>2]=x[d+8>>2];x[e+36>>2]=c;c=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=c;lj(b,e+24|0);d=x[a+28>>2];if(gu(x[x[d>>2]-12>>2]+d|0)){Pg(a,1073741826);break a}c=x[a+92>>2];d=a+44|0;b=rd(d);b:{if(c>>>0>b>>>0){f=hb-32|0;hb=f;c:{b=c-b|0;d:{if(b>>>0<=x[yb(d)>>2]-x[d+4>>2]>>4>>>0){g=hb-16|0;hb=g;e:{c=Hm(g,d,b);b=x[c+4>>2];i=x[c+8>>2];if((b|0)!=(i|0)){while(1){h=yb(d);x[114414]=0;P(184,h|0,b|0);h=x[114414];x[114414]=0;if((h|0)==1){break e}b=b+16|0;x[c+4>>2]=b;if((b|0)!=(i|0)){continue}break}}Jb(c);hb=g+16|0;break d}a=N()|0;Jb(c);Q(a|0);p()}c=yb(d);c=kr(f+8|0,lr(d,rd(d)+b|0),rd(d),c);x[114414]=0;P(180,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}x[114414]=0;P(181,d|0,c|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}ND(c)}hb=f+32|0;break b}a=N()|0;ND(c);Q(a|0);p()}if(b>>>0>c>>>0){c=x[d>>2]+(c<<4)|0;rd(d);MD(d,c);LD(d)}}f=a+32|0;Uv(f,x[a+92>>2]<<2);if(x[a+92>>2]){c=0;while(1){b=x[a+28>>2];if(gu(x[x[b>>2]-12>>2]+b|0)){Pg(a,1073741828);break a}b=z[a+16>>1];w[e+78>>1]=b;if((b|0)==65535){Mv(x[a+28>>2],e+78|0)}j=e,k=wc(f),x[j+72>>2]=k;f:{if(!z[e+78>>1]){b=0;break f}b=z[e+78>>1];g=x[e+72>>2];if(b>>>0>-1-g>>>0){break f}Kv(f,b+g|0);mk(x[a+28>>2],Bc(f,x[e+72>>2]),z[e+78>>1]);b=z[e+78>>1]}j=vc(d,c),k=b,w[j+12>>1]=k;b=x[e+72>>2];j=vc(d,c),k=b,x[j>>2]=k;if(Cd(a,6)){Wj(x[a+28>>2],e+56|0);if(A[e+60>>2]>2147483647){Pg(a,1073741829);break a}b=x[e+56>>2];j=vc(d,c),k=b,x[j+4>>2]=k}b=x[a+4>>2];g:{if(b){j=vc(d,c),k=b,x[j+8>>2]=k;break g}if(!Cd(a,7)){break g}Wj(x[a+28>>2],e+56|0);if(A[e+60>>2]>2147483647){Pg(a,1073741829);break a}b=x[e+56>>2];j=vc(d,c),k=b,x[j+8>>2]=k}h:{if(x[vc(d,c)+8>>2]==-1){break h}if(Cd(a,6)){break h}if(c){b=c-1|0;b=x[vc(d,b)+4>>2]+x[vc(d,b)+8>>2]|0}else{b=0}j=vc(d,c),k=b,x[j+4>>2]=k}if(Cd(a,8)){w[e+56>>1]=0;Mv(x[a+28>>2],e+56|0);b=Cd(a,9);xl(x[a+28>>2],z[e+56>>1]<<b,-1)}c=c+1|0;if(c>>>0<A[a+92>>2]){continue}break}}vf(e+56|0,x[a+28>>2]);d=x[e+68>>2];x[a+72>>2]=x[e+64>>2];x[a+76>>2]=d}Xj(a,4,1);b=x[a+72>>2];f=x[a+76>>2];c=x[a+12>>2];d=x[a+88>>2];g=x[a+8>>2]+d|0;c=d>>>0>g>>>0?c+1|0:c;h=b;b=(d|0)==x[a+64>>2];d=b?h:g;x[a+80>>2]=d;c=b?f:c;x[a+84>>2]=c;b=x[a+28>>2];d=Ug(e+40|0,d,c);c=x[d+12>>2];x[e+16>>2]=x[d+8>>2];x[e+20>>2]=c;c=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=c;lj(b,e+8|0);if(Cd(a,6)){break a}if(!(Cd(a,7)|x[a+4>>2])|!x[a+92>>2]){break a}d=x[a+80>>2]-x[a+8>>2]|0;b=a+44|0;c=0;while(1){f=vc(b,c);x[f+4>>2]=d+x[f+4>>2];c=c+1|0;if(c>>>0<A[a+92>>2]){continue}break}}hb=e+96|0}function Sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-80|0;hb=e;o=x[a+16>>2];x[e+56>>2]=a+112;x[e+48>>2]=0;x[e+52>>2]=0;t=e,u=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[t+60>>2]=u;b=x[a+128>>2];x[e+68>>2]=0;x[e+64>>2]=b;a:{if(!b){break a}f=a+8|0;t=e,u=Sf(f,b),x[t+48>>2]=u;x[e+52>>2]=lb;t=e,u=Te(f,d),x[t+24>>2]=u;x[e+28>>2]=lb;tf(a,e+24|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+68>>2]=d}b=x[a+44>>2];x[e+28>>2]=b;g=x[a+48>>2];x[e+32>>2]=g;i=x[a+52>>2];x[e+36>>2]=i;h=x[a+56>>2];x[e+40>>2]=h;q=x[a+24>>2];r=x[a+20>>2];j=x[a+4>>2];f=x[a>>2];x[e+16>>2]=f;x[e+20>>2]=j;k=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=k;b:{if(d){while(1){f=x[e+68>>2]-1|0;x[e+68>>2]=f;b=x[e+16>>2];g=(((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1;if(!f){x[e+48>>2]=0;x[e+52>>2]=0}f=g+o|0;x[e+72>>2]=b;x[e+76>>2]=0;c:{b=x[e+64>>2];if((b|0)<=0){break c}while(1){d:{i=x[e+72>>2];g=(x[e+76>>2]&2147483647)<<1|i>>>31;i=w[(g<<1|2)+f>>1];g=w[f+((g&2147483646)<<1)>>1];x[114414]=0;P(1048,x[e+56>>2],(g+i|0)/8<<16>>16);g=x[114414];x[114414]=0;if((g|0)==1){break d}x[114414]=0;P(1049,x[e+56>>2],4);g=x[114414];x[114414]=0;if((g|0)==1){break d}g=b>>>0>1;Tb(e+72|0,e+48|0);b=b-1|0;if(g){continue}break c}break}break b}b=x[e+56>>2];Tb(b,b+8|0);b=x[e+56>>2];g=x[b+4>>2];if(g){h=x[e+72>>2];i=(x[e+76>>2]&2147483647)<<1|h>>>31;h=w[(i<<1|2)+f>>1];f=w[f+((i&2147483646)<<1)>>1];x[114414]=0;P(1048,b|0,(f+h|0)/8<<16>>16);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(1049,x[e+56>>2],g|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[e+56>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114414]=0;b=O(1050,b|0,x[e+60>>2])|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}d=d-1|0;x[e+4>>2]=b;x[e>>2]=b;b=0;g=1;while(1){f=(b<<2)+e|0;l=x[f>>2];h=x[a+60>>2];i=(e+24|0)+(b<<3)|0;m=x[i+4>>2];j=Xb(m,-16777216,16776704);k=x[a+64>>2];n=Xb(x[i+8>>2],-16777216,16776704);b=x[a+68>>2];x[i+8>>2]=m;m=x[a+72>>2];l=l<<8;h=yna(h,h>>31,l,l>>31);s=lb;k=yna(k,k>>31,j,j>>31);j=k+h|0;h=lb+s|0;h=j>>>0<k>>>0?h+1|0:h;k=yna(b,b>>31,n,n>>31);j=k+j|0;b=lb+h|0;b=j>>>0<k>>>0?b+1|0:b;h=j+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;x[f>>2]=(b|0)/256;x[i+4>>2]=b-(l&m);f=g&1;g=0;b=1;if(f){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],r);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],q);c=c+8|0;Tb(e+16|0,e+8|0);if(d){continue}break}h=x[e+40>>2];i=x[e+36>>2];g=x[e+32>>2];f=x[e+16>>2];j=x[e+20>>2];b=x[e+28>>2]}x[a>>2]=f;x[a+4>>2]=j;x[a+56>>2]=h;x[a+52>>2]=i;x[a+48>>2]=g;x[a+44>>2]=b;hb=e+80|0;return}b=N()|0;x[a+44>>2]=x[e+28>>2];x[a+48>>2]=x[e+32>>2];x[a+52>>2]=x[e+36>>2];x[a+56>>2]=x[e+40>>2];Q(b|0);p()}function mJ(a){var b=E(0),c=E(0),d=0,e=E(0),f=E(0),g=0,h=0,i=0,k=E(0),m=E(0),p=E(0),s=E(0),t=0,u=0,v=E(0),w=E(0);jN(a+4208|0,B[a+4272>>2]);b=E(E(B[a+4208>>2]*E(15920))+E(80));d=Ze(x[a+16>>2]);s=le(E(10),E(E(E(B[a+4216>>2]*E(30))+E(-15))*E(.02500000037252903)));c=E(E(b*E(6.2831854820251465))/E(d>>>0));b=MG(c);v=_o(c);w=b;f=E(E(E(c*E(.02888113260269165))*E(E(B[a+4212>>2]*E(35))+E(1)))/b);m=(l(2,(q(f),j(2))&-2147483648|1056964608),r());h=(q(f),j(2))&2147483647;c=(l(2,h),r());a:{if(h>>>0<=1118925334){b:{c:{d:{e:{f:{g:{i=(q(c),j(2));d=i&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=E(-1);if((i|0)<0){break b}if(d>>>0<1118925336){break g}b=E(c*E(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((i|0)>=0){d=1;e=E(905800061445916e-20);b=E(c+E(-.6931381225585938));break f}d=-1;e=E(-905800061445916e-20);b=E(c+E(.6931381225585938));break f}b=E(E(c*E(1.4426950216293335))+(l(2,(q(c),j(2))&-2147483648|1056964608),r()));h:{if(E(F(b))<E(2147483648)){d=~~b;break h}d=-2147483648}b=E(d|0);e=E(b*E(905800061445916e-20));b=E(c+E(b*E(-.6931381225585938)))}c=E(b-e);e=E(E(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=E(c*E(.5));k=E(c*b);p=E(E(k*E(E(k*E(.0015807170420885086))+E(-.03333321213722229)))+E(1));b=E(E(3)-E(p*b));p=E(k*E(E(p-b)/E(E(6)-E(c*b))));b=E(c-E(E(c*p)-k));if(!d){break b}e=E(E(E(c*E(p-e))-e)-k);i:{switch(d+1|0){case 0:b=E(E(E(c-e)*E(.5))+E(-.5));break b;case 2:b=E(E(e-E(c+E(.5)))*E(-2));if(c<E(-.25)){break b}b=E(c-e);b=E(E(b+b)+E(1));break b;default:break i}}i=d<<23;b=(l(2,i+1065353216|0),r());if(d>>>0>=57){c=E(E(c-e)+E(1));b=E(((d|0)==128?E(E(c+c)*E(17014118346046923e22)):E(c*b))+E(-1));break b}k=(l(2,1065353216-i|0),r());c=E((d>>>0<=22?E(E(E(1)-k)+E(c-e)):E(E(c-E(e+k))+E(1)))*b)}b=c}if(h>>>0<=1065353215){if(h>>>0<964689920){break a}f=E(m*E(E(b+b)-E(E(b*b)/E(b+E(1)))));break a}f=E(m*E(b+E(b/E(b+E(1)))));break a}m=E(E(m+m)*E(1661534994731145e20));b=E(c+E(-162.88958740234375));d=Mw(b)&2047;j:{k:{if(Mw(E(88))>>>0>d>>>0){break k}c=E(0);if(((q(b),j(2))|0)==-8388608){break j}c=E(b+b);if(Mw(E(Infinity))>>>0<=d>>>0){break j}if(b>E(88.72283172607422)){c=VG(0);break j}if(!(b<E(-103.97207641601562))){break k}c=UG(0);break j}g=C[7281]*+b;t=C[7280];u=g+t;g=g-(u-t);g=(C[7282]*g+C[7283])*(g*g)+(C[7284]*g+1);o(+u);j(1)|0;d=j(0)|0;i=d<<15;d=((d&31)<<3)+57952|0;h=x[d>>2];d=x[d+4>>2]+i|0;l(0,h|0);l(1,(h>>>0<h>>>0?d+1|0:d)|0);c=E(g*+n())}f=E(E(m*c)*E(1661534994731145e20))}c=E(w*f);f=E(c/s);b=E(f+E(1));B[a+4236>>2]=E(E(1)-f)/b;f=E(E(v*E(-2))/b);B[a+4232>>2]=f;c=E(c*s);B[a+4228>>2]=E(E(1)-c)/b;B[a+4224>>2]=f;B[a+4220>>2]=E(c+E(1))/b}function Tea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-80|0;hb=e;o=x[a+16>>2];x[e+56>>2]=a+112;x[e+48>>2]=0;x[e+52>>2]=0;t=e,u=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[t+60>>2]=u;b=x[a+128>>2];x[e+68>>2]=0;x[e+64>>2]=b;a:{if(!b){break a}f=a+8|0;t=e,u=Sf(f,b),x[t+48>>2]=u;x[e+52>>2]=lb;t=e,u=Te(f,d),x[t+24>>2]=u;x[e+28>>2]=lb;tf(a,e+24|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+68>>2]=d}b=x[a+44>>2];x[e+28>>2]=b;g=x[a+48>>2];x[e+32>>2]=g;i=x[a+52>>2];x[e+36>>2]=i;h=x[a+56>>2];x[e+40>>2]=h;q=x[a+24>>2];r=x[a+20>>2];j=x[a+4>>2];f=x[a>>2];x[e+16>>2]=f;x[e+20>>2]=j;k=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=k;b:{if(d){while(1){f=x[e+68>>2]-1|0;x[e+68>>2]=f;b=x[e+16>>2];g=((x[e+20>>2]&2147483647)<<1|b>>>31)&-2;if(!f){x[e+48>>2]=0;x[e+52>>2]=0}f=g+o|0;x[e+72>>2]=b;x[e+76>>2]=0;c:{b=x[e+64>>2];if((b|0)<=0){break c}while(1){d:{i=x[e+72>>2];g=(x[e+76>>2]&2147483647)<<1|i>>>31;i=v[(g|1)+f|0];g=v[f+(g&-2)|0];x[114414]=0;P(1048,x[e+56>>2],g+i<<5);g=x[114414];x[114414]=0;if((g|0)==1){break d}x[114414]=0;P(1049,x[e+56>>2],4);g=x[114414];x[114414]=0;if((g|0)==1){break d}g=b>>>0>1;Tb(e+72|0,e+48|0);b=b-1|0;if(g){continue}break c}break}break b}b=x[e+56>>2];Tb(b,b+8|0);b=x[e+56>>2];g=x[b+4>>2];if(g){h=x[e+72>>2];i=(x[e+76>>2]&2147483647)<<1|h>>>31;h=v[(i|1)+f|0];f=v[f+(i&-2)|0];x[114414]=0;P(1048,b|0,f+h<<5);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(1049,x[e+56>>2],g|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[e+56>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114414]=0;b=O(1050,b|0,x[e+60>>2])|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}d=d-1|0;x[e+4>>2]=b;x[e>>2]=b;b=0;g=1;while(1){f=(b<<2)+e|0;l=x[f>>2];h=x[a+60>>2];i=(e+24|0)+(b<<3)|0;m=x[i+4>>2];j=Xb(m,-16777216,16776704);k=x[a+64>>2];n=Xb(x[i+8>>2],-16777216,16776704);b=x[a+68>>2];x[i+8>>2]=m;m=x[a+72>>2];l=l<<8;h=yna(h,h>>31,l,l>>31);s=lb;k=yna(k,k>>31,j,j>>31);j=k+h|0;h=lb+s|0;h=j>>>0<k>>>0?h+1|0:h;k=yna(b,b>>31,n,n>>31);j=k+j|0;b=lb+h|0;b=j>>>0<k>>>0?b+1|0:b;h=j+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;x[f>>2]=(b|0)/256;x[i+4>>2]=b-(l&m);f=g&1;g=0;b=1;if(f){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],r);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],q);c=c+8|0;Tb(e+16|0,e+8|0);if(d){continue}break}h=x[e+40>>2];i=x[e+36>>2];g=x[e+32>>2];f=x[e+16>>2];j=x[e+20>>2];b=x[e+28>>2]}x[a>>2]=f;x[a+4>>2]=j;x[a+56>>2]=h;x[a+52>>2]=i;x[a+48>>2]=g;x[a+44>>2]=b;hb=e+80|0;return}b=N()|0;x[a+44>>2]=x[e+28>>2];x[a+48>>2]=x[e+32>>2];x[a+52>>2]=x[e+36>>2];x[a+56>>2]=x[e+40>>2];Q(b|0);p()}function Tja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{g=y[a+3|0];switch(g-4|0){case 23:break j;case 22:break k;case 21:break l;case 20:break m;case 18:break n;case 17:break o;case 16:break p;case 14:break q;case 13:break r;case 12:break s;case 11:break t;case 10:break u;case 9:break v;case 8:break w;case 5:break x;case 4:break y;case 0:break z;case 42:break c;case 37:break d;case 28:break e;case 27:break f;case 26:break g;case 25:break h;case 24:break i;default:break b}}v[a+3|0]=5;v[f+15|0]=y[a+5|0]>>>3;v[f+14|0]=15;b=y[rc(f+15|0,f+14|0)|0];v[f+13|0]=y[a+5|0]<<1&30;v[f+12|0]=15;h=a,i=y[rc(f+13|0,f+12|0)|0]|b<<4,v[h+5|0]=i;break a}v[a+3|0]=0;break a}if((y[a+5|0]-1&255)>>>0<=19){v[a+3|0]=16;break a}v[a+3|0]=0;break a}v[a+3|0]=13;b=y[a+5|0];A:{if(!e){if(b>>>0>152){break A}v[a+5|0]=D((b&240)>>>4|0,10)+(b&15);break a}v[a+5|0]=(b&127)+1>>>1;break a}v[a+3|0]=0;break a}v[a+3|0]=11;break a}v[a+3|0]=0;break a}e=y[a+5|0];if(!e){v[a+3|0]=14;break a}if(e>>>0<=240){v[a+3|0]=17;if(e>>>0<=2){v[a+5|0]=112;break a}h=a,i=Xt(+(yR(e,b,c,d)>>>0)*1e-4),v[h+5|0]=i;break a}v[a+3|0]=0;break a}v[a+3|0]=31;v[a+5|0]=y[a+5|0]|128;break a}v[a+3|0]=19;v[f+11|0]=15;h=a,i=y[rc(a+5|0,f+11|0)|0]|16,v[h+5|0]=i;break a}v[a+3|0]=19;v[f+10|0]=15;h=a,i=y[rc(a+5|0,f+10|0)|0]|32,v[h+5|0]=i;break a}v[a+3|0]=5;v[f+9|0]=(y[a+5|0]>>>4|0)+1;v[f+8|0]=15;b=rc(f+9|0,f+8|0);v[a+5|0]=y[a+5|0]&15|y[b|0]<<4;break a}v[a+3|0]=19;v[a+5|0]=y[a+5|0]&15|80;break a}v[a+3|0]=19;v[f+7|0]=15;h=a,i=y[rc(a+5|0,f+7|0)|0]|96,v[h+5|0]=i;break a}v[a+3|0]=19;v[f+6|0]=15;h=a,i=y[rc(a+5|0,f+6|0)|0]|192,v[h+5|0]=i;break a}v[a+3|0]=10;break a}v[a+3|0]=19;v[f+5|0]=15;h=a,i=y[rc(a+5|0,f+5|0)|0]|160,v[h+5|0]=i;break a}v[a+3|0]=19;v[f+4|0]=15;h=a,i=y[rc(a+5|0,f+4|0)|0]|176,v[h+5|0]=i;break a}b=y[a+5|0]-1<<24>>24;if((b|0)>=0){v[a+5|0]=b;v[a+3|0]=31;break a}v[a+3|0]=0;break a}v[a+3|0]=14;break a}v[a+3|0]=19;v[f+3|0]=15;h=a,i=y[rc(a+5|0,f+3|0)|0]|224,v[h+5|0]=i;break a}b=y[a+5|0];if(b>>>0>=16){v[a+3|0]=19;v[a+5|0]=b>>>4|208;break a}if(b){v[a+3|0]=19;v[a+5|0]=b|144;break a}v[a+3|0]=0;break a}if(!(y[a+5|0]|y[a+4|0])){if(!Af(a)){break a}v[a+5|0]=159;v[a+3|0]=20;break a}v[a+3|0]=0;break a}b=y[a+4|0];if(b){v[a+3|0]=41;h=a,i=gl(jd(((y[a+5|0]<<8&65280)>>>0)/(b>>>0)|0,0)),v[h+5|0]=i;break a}v[a+3|0]=0;break a}b=y[a+5|0];if((b+16&255)>>>0<=32){v[a+3|0]=9;h=a,i=Vk(((b^128)<<3)-896|0),v[h+5|0]=i;break a}v[a+3|0]=0;break a}if(g>>>0<=15){Fj(a);break a}v[a+3|0]=0}hb=f+16|0}function Wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,A=0,B=0,C=0,F=0,G=0,H=0,I=0,J=0;f=hb-32|0;hb=f;r=a+4|0;p=x[r>>2];n=a+20|0;t=x[Tc(n,b)+16>>2];a:{if(t+1>>>0<2){break a}g=(D(b,896)+p|0)+608|0;if(!Sh(g)){if(!y[Tc(n,b)+20|0]){break a}}h=D(b,896)+p|0;if(!x[h+712>>2]){break a}k=x[h+696>>2]&2;e=x[(k?h+692|0:h+684|0)>>2];m=x[h+692>>2];i=x[h+688>>2];u=$b(x[a>>2]+1074312|0,31);w=h+1356|0;l=y[w|0];A=h+616|0;j=Te(A,c);x[f+24>>2]=j;o=lb;x[f+28>>2]=o;if(y[h+696|0]&128){x[f+24>>2]=0-j;x[f+28>>2]=0-(((j|0)!=0)+o|0)}j=0;o=e;e=j;j=k;B=j?e:0;e=i;q=j?e:0;k=m-e|0;C=k<<1;e=D(b,896)+p|0;F=e+1308|0;m=e+1480|0;G=(l&17)!=1;b:{while(1){c:{if(d>>>0>s>>>0){e=(y[w|0]&17)==1;break c}v[m|0]=y[m|0]&254;i=Df(Zb(x[a>>2]+484344|0,z[x[r>>2]+60>>1]),x[x[r>>2]+48>>2],b);j=y[i+3|0];if(y[i+2|0]==11){e=f+16|0;My(e,x[a>>2],i,0);l=mc(e);tn(x[a>>2],g,x[e>>2]);e=1;if(y[l|0]){break c}}e=1;d:{switch(j-4|0){case 0:tn(x[a>>2],g,y[i+5|0]);break c;case 2:break d;default:break c}}tn(x[a>>2],g,0)}x[f+12>>2]=x[F>>2];if(u){Us(x[a>>2],g)}if(!G){FL(x[a>>2],g,f+12|0);e=1}if(!u){Us(x[a>>2],g)}x[f+8>>2]=0;HL(g,f+8|0);e:{f:{if(y[h+697|0]&2){break f}g:{if(!e){if(!y[Tc(n,b)+20|0]){break g}}if(y[m|0]&24){zO(g,E(1),0,x[a>>2]);e=y[m|0];v[m|0]=(e&16?-17:-9)&e}e=A;I=e,J=ly(x[a>>2],g,x[f+12>>2],0),x[I>>2]=J;x[e+4>>2]=lb;I=Tc(n,b),J=0,v[I+20|0]=J;e=Te(e,c);x[f+24>>2]=e;i=lb;x[f+28>>2]=i;if(!(y[h+696|0]&128)){break g}x[f+24>>2]=0-e;x[f+28>>2]=0-(((e|0)!=0)+i|0)}Tb(g,f+24|0);i=x[g>>2];e=x[g+4>>2];if(i>>>0<H>>>0&(e|0)<=(o|0)|(e|0)<(o|0)){if((e|0)>=(q|0)&i>>>0>=B>>>0|(e|0)>(q|0)){break f}j=x[f+28>>2];if((j|0)>0|(j|0)>=0){break f}}j=x[h+696>>2];if(!(j&2)){break e}if(j&4){if(i>>>0<B>>>0&(e|0)<=(q|0)|(e|0)<(q|0)){e=x[h+688>>2]<<1;x[f+16>>2]=0;x[f+20>>2]=e;I=g,J=qg(f+16|0,g),x[I>>2]=J;x[g+4>>2]=lb;x[h+696>>2]=x[h+696>>2]^128;e=x[f+24>>2];i=0-e|0;e=0-(x[f+28>>2]+((e|0)!=0)|0)|0;x[f+24>>2]=i;x[f+28>>2]=e;e=x[g+4>>2]}e=(e-x[h+688>>2]>>>0)%(C-$b(x[a>>2]+1074312|0,33)>>>0)|0;i=e>>>0<k>>>0;h:{if(!i){x[g+4>>2]=x[h+692>>2]+(k-e|0);e=x[h+696>>2];if(!(i^(e&128)>>>7)){break h}break f}x[g+4>>2]=e+x[h+688>>2];e=x[h+696>>2];if(i^(e&128)>>>7){break f}}x[h+696>>2]=e^128;e=x[f+24>>2];i=0-e|0;e=0-(x[f+28>>2]+((e|0)!=0)|0)|0;x[f+24>>2]=i;x[f+28>>2]=e;break f}l=x[h+692>>2];if(l+k>>>0<=e>>>0){e=l+((e-l>>>0)%(k>>>0)|0)|0}while(1){j=e;e=e-k|0;if(j>>>0>=l>>>0){continue}break}x[g>>2]=i;x[g+4>>2]=j}s=s+1|0;if((t|0)!=(s|0)){continue}break b}break}CO(g);x[(D(b,896)+p|0)+1316>>2]=0}I=Tc(n,b),J=0,x[I+16>>2]=J}hb=f+32|0}function eH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;h=hb-48|0;hb=h;o(+a);d=j(1)|0;i=j(0)|0;a:{b:{e=d;k=e&2147483647;c:{if(k>>>0<=1074752122){if((d&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+-6077100506506192e-26;d=1;break a}a=a+1.5707963267341256;c=a+6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(F(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;i=k>>>20|0;e:{if((i-(e>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;if((i-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;C[b>>3]=a}C[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;C[b>>3]=a;C[b+8>>3]=a;d=0;break a}l(0,i|0);l(1,e&1048575|1096810496);a=+n();d=0;i=1;while(1){m=(h+16|0)+(d<<3)|0;if(F(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);C[m>>3]=c;a=(a-c)*16777216;d=1;m=i;i=0;if(m){continue}break}C[h+32>>3]=a;d=2;while(1){i=d;d=d-1|0;if(C[(h+16|0)+(i<<3)>>3]==0){continue}break}d=fH(h+16|0,h,(k>>>20|0)-1046|0,i+1|0,1);a=C[h>>3];if((e|0)<0){C[b>>3]=-a;C[b+8>>3]=-C[h+8>>3];d=0-d|0;break a}C[b>>3]=a;C[b+8>>3]=C[h+8>>3]}hb=h+48|0;return d}function G2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-192|0;hb=d;a:{if(vj(b)){break a}e=y[rk(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Fk(d+160|0,b,x[b+4>>2]-1|0);e=x[d+164>>2];x[b>>2]=x[d+160>>2];x[b+4>>2]=e}g=d+160|0;Hd(g);e=x[d+160>>2];Hd(d+144|0);e=qk(e,x[d+148>>2],b);Hd(g);b:{c:{d:{e:{f:{g:{if((e|0)==x[d+164>>2]){a=x[b+4>>2];x[d+184>>2]=x[b>>2];x[d+188>>2]=a;a=tc(d+176|0,17386);e=x[d+188>>2];x[d+8>>2]=x[d+184>>2];x[d+12>>2]=e;e=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=e;if(Kc(d+8|0,d)){a=ec(8);x[114414]=0;c=O(118,d+160|0,6463)|0;b=x[114414];x[114414]=0;if((b|0)==1){break f}a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}f=0;if(!c){break g}c=ec(8);x[114414]=0;a=O(2172,d+144|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;T(2152,d+160|0,13524,a|0);b=x[114414];x[114414]=0;if((b|0)==1){break e}b=oc(c,d+160|0);x[114414]=0;T(2042,b|0,82448,2050);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=N()|0;xb(d+160|0);xb(a);break c}b=N()|0;break d}if(x[e+4>>2]!=2){a=ec(8);x[114414]=0;c=O(118,d+160|0,7464)|0;b=x[114414];x[114414]=0;if((b|0)!=1){a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}b=N()|0;hc(a);break c}c=x[b+4>>2];x[d+136>>2]=x[b>>2];x[d+140>>2]=c;c=tc(d+128|0,17386);e=x[d+140>>2];x[d+72>>2]=x[d+136>>2];x[d+76>>2]=e;e=x[c+4>>2];x[d+64>>2]=x[c>>2];x[d+68>>2]=e;if(Kc(d+72|0,d- -64|0)){a=ec(8);x[114414]=0;c=O(118,d+160|0,6463)|0;b=x[114414];x[114414]=0;if((b|0)!=1){a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}b=N()|0;hc(a);break c}c=x[b+4>>2];x[d+120>>2]=x[b>>2];x[d+124>>2]=c;c=tc(d+112|0,3991);e=x[d+124>>2];x[d+56>>2]=x[d+120>>2];x[d+60>>2]=e;e=x[c+4>>2];x[d+48>>2]=x[c>>2];x[d+52>>2]=e;if(Kc(d+56|0,d+48|0)){f=1;if(!y[a+28|0]){break g}f=65536/+A[x[a+24>>2]+480244>>2];break g}c=x[b+4>>2];x[d+104>>2]=x[b>>2];x[d+108>>2]=c;c=tc(d+96|0,4043);e=x[d+108>>2];x[d+40>>2]=x[d+104>>2];x[d+44>>2]=e;e=x[c+4>>2];x[d+32>>2]=x[c>>2];x[d+36>>2]=e;if(Kc(d+40|0,d+32|0)){f=1;if(!y[a+28|0]){break g}f=+A[x[a+24>>2]+480240>>2]*152587890625e-16;break g}c=x[b+4>>2];x[d+88>>2]=x[b>>2];x[d+92>>2]=c;b=tc(d+80|0,4061);c=x[d+92>>2];x[d+24>>2]=x[d+88>>2];x[d+28>>2]=c;c=x[b+4>>2];x[d+16>>2]=x[b>>2];x[d+20>>2]=c;f=0;if(!Kc(d+24|0,d+16|0)){break g}f=+A[x[a+24>>2]+480236>>2]*152587890625e-16}hb=d+192|0;return+f}b=N()|0;hc(a);break c}b=N()|0;xb(a)}hc(c)}Q(b|0)}p()}function g4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=hb-128|0;hb=e;a:{if(Wc(b)){break a}f=y[LI(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+112|0;Jr(f,b,0,Bb(b)-1|0);Db(b,f);xb(f)}g=e+112|0;Hd(g);f=x[e+112>>2];Hd(e+96|0);f=KI(f,x[e+100>>2],b);Hd(g);b:{c:{d:{e:{f:{if((f|0)==x[e+116>>2]){if(Td(b,17386)){a=ec(8);x[114414]=0;T(2166,e+112|0,13488,c|0);b=x[114414];x[114414]=0;if((b|0)==1){break e}a=oc(a,e+112|0);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break c}b=N()|0;xb(e+112|0);break d}if(!d){break f}a=ec(8);x[114414]=0;T(2166,e+80|0,13524,b|0);b=x[114414];x[114414]=0;g:{h:{i:{j:{if((b|0)!=1){x[114414]=0;T(2167,e+96|0,e+80|0,13498);b=x[114414];x[114414]=0;if((b|0)==1){break j}x[114414]=0;T(781,e+112|0,e+96|0,c|0);b=x[114414];x[114414]=0;c=1;if((b|0)==1){break i}b=oc(a,e+112|0);x[114414]=0;T(2042,b|0,82448,2050);b=x[114414];x[114414]=0;if((b|0)!=1){break c}b=N()|0;xb(e+112|0);c=0;break h}b=N()|0;break g}b=N()|0;xb(e+80|0);break g}b=N()|0}xb(e+96|0);xb(e+80|0);if(!c){break d}}hc(a);break d}k:{switch(x[f+4>>2]){case 0:xi(e+72|0,b);b=(LG(c)|0)!=0;c=x[e+76>>2];x[e>>2]=x[e+72>>2];x[e+4>>2]=c;JI(a,e,b,d);break f;case 1:xi(e- -64|0,b);b=hb-160|0;hb=b;c=bn(b+16|0,c,8);f=x[x[c>>2]-12>>2];x[114414]=0;g=$(121)|0;h=x[114414];x[114414]=0;l:{if((h|0)==1){break b}x[114414]=0;T(122,b+8|0,c+f|0,g|0);f=x[114414];x[114414]=0;if((f|0)==1){break b}Ob(b+8|0);x[114414]=0;f=O(153,c|0,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}g=x[x[f>>2]-12>>2];x[114414]=0;f=R(149,f+g|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}g=x[b>>2];h=x[b+4>>2];Lf(c);hb=b+160|0;b=f?0:g;c=f?0:h;break l}f=x[e+68>>2];x[e+8>>2]=x[e+64>>2];x[e+12>>2]=f;II(a,e+8|0,b,c,d);break f;case 2:xi(e+56|0,b);b=hb-160|0;hb=b;c=bn(b+16|0,c,8);f=x[x[c>>2]-12>>2];x[114414]=0;g=$(121)|0;h=x[114414];x[114414]=0;m:{if((h|0)==1){break b}x[114414]=0;T(122,b+8|0,c+f|0,g|0);f=x[114414];x[114414]=0;if((f|0)==1){break b}Ob(b+8|0);x[114414]=0;f=O(154,c|0,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}g=x[x[f>>2]-12>>2];x[114414]=0;f=R(149,f+g|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}i=C[b>>3];Lf(c);hb=b+160|0;i=f?0:i;break m}b=x[e+60>>2];x[e+16>>2]=x[e+56>>2];x[e+20>>2]=b;HI(a,e+16|0,i,d);break f;case 3:break k;default:break f}}xi(e+48|0,b);xi(e+40|0,c);b=x[e+52>>2];x[e+32>>2]=x[e+48>>2];x[e+36>>2]=b;b=x[e+44>>2];x[e+24>>2]=x[e+40>>2];x[e+28>>2]=b;GI(a,e+32|0,e+24|0,d)}hb=e+128|0;return}b=N()|0;hc(a)}Q(b|0)}p()}a=N()|0;Lf(c);Q(a|0);p()}function jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=hb-560|0;hb=f;a:{if(!Rc(b,1464)){break a}if(!Un(b,f+556|0)){break a}Nd(a,1);d=a+1074312|0;Ig(d,83);Nb(d,84,1);Nb(d,85,1);b:{if(Yd(f+556|0,23938)){d=f+32|0;e=Ub(d,4649);Db(a+1304436|0,e);xb(e);e=Ub(d,10337);Db(a+1304448|0,e);xb(e);d=Ub(d,10402);Db(a+1304460|0,d);break b}if(!Yd(f+556|0,11609)){break a}d=f+32|0;e=Ub(d,4807);Db(a+1304436|0,e);xb(e);e=Ub(d,8096);Db(a+1304448|0,e);xb(e);d=Ub(d,11259);Db(a+1304460|0,d)}xb(d);x[a+1304496>>2]=2;d=0;Rc(b,0);tA(b,a+1304400|0,20);w[a+480190>>1]=31;e=1;while(1){d=Pz(b,f+32|0,(D(e,104)+a|0)+484380|0,((e<<5)+a|0)+946304|0,1)+d|0;e=e+1|0;if((e|0)!=32){continue}break}if(d>>>0>40){break a}i=f+552|0;Ru(i,b);m=ed(i);if(y[i|0]>128){break a}d=f+32|0;e=hb-16|0;hb=e;c:{if(Qb(b,512)){g=e+8|0;YA(g,d);Dd(b,g);break c}AQ(d)}hb=e+16|0;e=0;d=y[m|0];while(1){n=d>>>0>=y[(f+32|0)+e|0];if(!n){break a}e=e+1|0;if((e|0)!=512){continue}break}if(!c){break a}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;x[a+480208>>2]=x[a+480208>>2]|18874368;uj(a,0);o=a+484360|0;mg(Vb(o),y[i|0]);w[f+30>>1]=0;j=a+484344|0;cg(j,y[i|0]);if(y[i|0]){while(1){s=uc(Vb(o),h),t=h,w[s>>1]=t;if(Tg(j,h&65535,64)){p=h<<2;g=0;while(1){Rc(b,(y[f+32+(g+p)|0]<<8)+1468|0);e=Df(Zb(j,h),0,g&65535);d=0;while(1){St(b,e);d:{e:{l=y[e+3|0];f:{if((l|0)!=14){if(!l){if(y[e+5|0]){break e}break f}if((l-5&255)>>>0<5){break f}break e}if(y[e+5|0]<=15){break e}}v[e+3|0]=0;break d}Fj(e)}e=e+24|0;d=d+1|0;if((d|0)!=64){continue}break}g=g+1|0;if((g|0)!=4){continue}break}s=f,t=bc(Zb(j,h)),x[s+24>>2]=t;g=0;while(1){d=0;while(1){e=d;d=y[x[f+24>>2]+3|0];g:{if((d|0)!=16&(d|0)!=17){break g}v[x[f+24>>2]+3|0]=16;k=0;if(y[x[f+24>>2]+5|0]<16){break g}d=y[x[f+24>>2]+5|0];if(!((d&15)==(d>>>4|0)|!(d&15))){d=y[x[f+24>>2]+5|0];q=d>>>4|0;r=d&15;k=1}d=x[f+24>>2];v[d+5|0]=y[d+5|0]>>>4}Nj(f+24|0);d=e+1|0;if((e&65535)>>>0<3){continue}break}v[f+30|0]=q;v[f+31|0]=r;d=k&255;if(d){Ll(Zb(j,h),Ie(lo(f+8|0,16,y[(d+f|0)+29|0]),g));d=k+1|0;k=(d&255)==3?1:d}else{k=0}g=g+1|0;if((g|0)!=64){continue}break}}h=h+1|0;if(h>>>0<y[i|0]){continue}break}}if(!(c&2)){break a}Rc(b,(y[m|0]<<8)+1468|0);e=1;while(1){c=(D(e,104)+a|0)+484380|0;if(x[c>>2]){Eg(ad(f+8|0,8,1,0,0),c,b)}e=e+1|0;if((e|0)!=32){continue}break}}hb=f+560|0;return n|0}function UU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-384|0;hb=f;Lc(b);e=hb-16|0;hb=e;d=e+8|0;h=f+344|0;IB(d,h);i=Eb(d);d=nc(b,ac(e,d));if((i|0)==(d|0)){cc(b,Eb(e+8|0))}hb=e+16|0;e=(d|0)==(i|0);if(!e){JB(h)}a:{b:{if(!e){break b}if(!VB(f+344|0)){break b}if(!Qb(b,jd(UB(f+344|0),lb))){break b}c:{if(!c){break c}Nd(a,2097152);Gi(a);g=1;uj(a,1);w[a+480188>>1]=8;x[a+480196>>2]=y[f+376|0];x[a+480204>>2]=D(y[f+377|0],1e4);w[a+480190>>1]=y[f+378|0];if(y[f+381|0]<y[f+380|0]){Se(Vb(a+484360|0),y[f+381|0])}e=f+80|0;d=Ub(e,2848);Db(a+1304436|0,d);xb(d);d=Ub(e,7023);Db(a+1304448|0,d);xb(d);x[a+1304496>>2]=4;Su(b,e);Dq(Vb(a+484360|0),e,y[f+380|0],65535,65535);if(z[a+480190>>1]){while(1){i=f+40|0;TB(b,i);j=hb-16|0;hb=j;k=g&65535;h=(D(k,104)+a|0)+484380|0;Ad(h,0);v[h+37|0]=y[i+22|0]<<4;v[j+15|0]=y[i+23|0];v[j+14|0]=64;m=h,n=y[rc(j+15|0,j+14|0)|0]<<2,w[m+30>>1]=n;v[h+36|0]=y[i+24|0];d=i+25|0;x[h>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);e=i+33|0;d:{if((y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))>>>0<3){break d}l=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=i+29|0;if(l>>>0<(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))+(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))>>>0){break d}w[h+34>>1]=z[h+34>>1]|2;x[h+4>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[h+8>>2]=(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))+(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))}hb=j+16|0;e=f+8|0;lm(e,2,i);d=f+24|0;Ic(d,e);x[114414]=0;O(334,((k<<5)+a|0)+946304|0,d|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break a}xb(f+24|0);g=g+1|0;if(z[a+480190>>1]>=(g&65535)>>>0){continue}break}}cc(b,D(64-y[f+378|0]|0,37));h=a+484344|0;cg(h,y[f+379|0]);if(y[f+379|0]){i=c&1;g=0;while(1){e:{f:{if(i){if(Tg(h,g&65535,64)){break f}}cc(b,2048);break e}e=Zb(h,g);m=f,n=bc(e),x[m+40>>2]=n;m=f,n=dc(e),x[m+24>>2]=n;if(!Hb(f+40|0,f+24|0)){break e}while(1){e=x[f+40>>2];d=f+8|0;km(d,b);j=ed(d);k=rf(d);l=$h(d);d=y[d|0];if((d-1&255)>>>0<=106){v[e|0]=d+13}v[e+1|0]=y[j|0];v[e+3|0]=y[k|0];v[e+5|0]=y[l|0];Fj(e);e=f+40|0;Nj(e);if(Hb(e,f+24|0)){continue}break}}g=g+1|0;if(g>>>0<y[f+379|0]){continue}break}}if(!(c&2)){break c}g=1;c=ad(f+40|0,8,1,0,0);if(!z[a+480190>>1]){break c}while(1){Eg(c,(D(g&65535,104)+a|0)+484380|0,b);g=g+1|0;if(z[a+480190>>1]>=(g&65535)>>>0){continue}break}}g=1}hb=f+384|0;return g|0}a=N()|0;xb(f+24|0);Q(a|0);p()}function Caa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=hb-16|0;hb=i;x[114414]=0;f=R(867,a|0)|0;h=x[114414];x[114414]=0;if((h|0)!=1){a:{b:{if(f){break b}x[114414]=0;f=R(403,a|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}j=Md(f+1|0,1,1024);x[114414]=0;k=d+484344|0;f=U(363,k|0,b|0,j|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}if(!f){break b}d=z[d+480188>>1];if(!d|!j){break b}l=d-1|0;h=0;while(1){x[114414]=0;d=O(226,a|0,1)|0;f=x[114414];x[114414]=0;c:{d:{if((f|0)!=1){if(!d){break b}x[114414]=0;f=R(403,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}if(f){break d}h=h+1|0;break c}break a}d=Zb(k,b);x[114414]=0;w[i+14>>1]=f&31;w[i+12>>1]=l;e=O(433,i+14|0,i+12|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}e=z[e>>1];x[114414]=0;d=U(427,d|0,h|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break a}if(f>>>0<32){break c}e:{if(f<<24>>24>=0){break e}x[114414]=0;e=R(403,a|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}v[d+5|0]=e;x[114414]=0;e=R(403,a|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}f:{if(e>>>0>=26){break f}e=y[e+35824|0];v[d+3|0]=e;g:{switch(e-1|0){case 0:if(!y[d+5|0]){break f}break e;case 12:if(y[d+2|0]){break e}v[d+2|0]=1;e=Md(y[d+5|0],0,64);v[d+5|0]=0;v[d+3|0]=0;v[d+4|0]=e;break e;case 5:case 6:case 10:case 23:case 28:e=y[d+5|0]&240;if(!e){break e}v[d+5|0]=e;break e;case 8:e=y[d+5|0];if(e>>>0<=128){x[114414]=0;e=R(860,e<<1)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}v[d+5|0]=e;break e}if((e|0)!=164){break e}v[d+5|0]=145;v[d+3|0]=20;break e;case 13:e=y[d+5|0];v[d+5|0]=D(e>>>4|0,10)+(e&15);break e;case 18:x[114414]=0;W(591,d|0);e=x[114414];x[114414]=0;if((e|0)!=1){break e}break a;case 16:if(y[d+5|0]>31){break e}v[d+3|0]=16;break e;case 27:break g;default:break e}}g=y[d+5|0];e=g&240;h:{if((e|0)==16){e=2}else{if((e|0)!=32){break h}e=3}v[d+3|0]=e}v[d+5|0]=g&15|224;break e}v[d+3|0]=0}i:{if(!(f&64)){break i}x[114414]=0;P(428,i+8|0,a|0);e=x[114414];x[114414]=0;if((e|0)==1){break a}e=i+8|0;g=ed(e);v[d+1|0]=y[e|0];e=y[g|0];v[d|0]=e;g=255;if((e|0)!=128){g=253;if(e>>>0<129){break i}}v[d|0]=g}if(!(f&32)){break c}v[d+2|0]=1;x[114414]=0;f=R(403,a|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break a}v[d+4|0]=f;if(!c){break c}v[d+4|0]=(f<<6>>>0)/127}if(h>>>0<j>>>0){continue}break}}Ab(a);hb=i+16|0;return}}b=N()|0;Ab(a);Q(b|0);p()}function E_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;k=hb-16|0;hb=k;m=Aw(g);o=ew(g);wg(k,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[114414]=0;g=O(2535,m|0,g<<24>>24)|0;i=x[114414];x[114414]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[114414]=0;g=O(2535,m|0,48)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;g=v[i+1|0];x[114414]=0;g=O(2535,m|0,g|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];x[114414]=0;j=$(2507)|0;l=x[114414];x[114414]=0;e:{if((l|0)==1){break e}x[114414]=0;h=nw(h,j);j=x[114414];x[114414]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];x[114414]=0;$(2507)|0;j=x[114414];x[114414]=0;if((j|0)==1){break a}x[114414]=0;h=ih(h);j=x[114414];x[114414]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Wc(k)){h=x[f>>2];x[114414]=0;Z(2523,m|0,i|0,g|0,h|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i<<2);break f}l=0;x[114414]=0;fk(i,g);h=x[114414];x[114414]=0;if((h|0)==1){break a}x[114414]=0;r=R(2520,o|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(g>>>0<=h>>>0){h=x[f>>2];x[114414]=0;Vo((i-a<<2)+d|0,h);i=x[114414];x[114414]=0;if((i|0)!=1){break f}break a}g:{if(v[pc(k,j)|0]<=0){break g}if(v[pc(k,j)|0]!=(l|0)){break g}l=x[f>>2];x[f>>2]=l+4;x[l>>2]=r;j=(Bb(k)-1>>>0>j>>>0)+j|0;l=0}q=v[h|0];x[114414]=0;q=O(2535,m|0,q|0)|0;n=x[114414];x[114414]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+4;x[n>>2]=q;h=h+1|0;l=l+1|0;continue}break}break a}h:{while(1){if(c>>>0>g>>>0){i=y[g|0];if((i|0)==46){x[114414]=0;i=R(2524,o|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}j=x[f>>2];h=j+4|0;x[f>>2]=h;x[j>>2]=i;g=g+1|0;break h}x[114414]=0;i=O(2535,m|0,i<<24>>24)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;g=g+1|0;continue}break}h=x[f>>2]}x[114414]=0;Z(2523,m|0,g|0,c|0,h|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g<<2)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;xb(k);hb=k+16|0;return}a=N()|0;xb(k);Q(a|0);p()}function LW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-336|0;hb=d;e=hb-16|0;hb=e;x[a>>2]=0;f=a+32|0;Uv(f,32);v[e+15|0]=0;Mo(f,e+15|0);hb=e+16|0;e=x[a+28>>2];a:{if(!Jf(x[x[e>>2]-12>>2]+e|0)){Pg(a,1073741825);break a}e=d- -64|0;vf(e,x[a+28>>2]);f=x[e+12>>2];x[a+8>>2]=x[e+8>>2];x[a+12>>2]=f;f=Fb(e,3);h=x[a+28>>2];g=d+24|0;e=0;if(x[f>>2]){while(1){Fh(h,e+g|0);e=e+1|0;if(e>>>0<A[f>>2]){continue}break}}if(cd(g,22720,3)){Pg(a,1073741827);break a}v[d+335|0]=0;Fh(x[a+28>>2],d+335|0);e=d- -64|0;SD(e);g=b;h=d+24|0;f=y[d+335|0];if(f){mk(x[a+28>>2],d- -64|0,f);b=y[d+335|0]}else{b=0}b=Jm(h,e,b);e=Nv(g,b);Gb(b);if(!e){Pg(a,1073741830)}if(y[a+3|0]&64){break a}Fh(x[a+28>>2],d+63|0);e=y[d+63|0];b=e&3;w[a+16>>1]=(b|0)==3?4:b;if(gi(e,6)){Xj(a,9,1)}x[d+56>>2]=0;RD(x[a+28>>2],d+56|0);b=x[d+56>>2];v[d+55|0]=0;if(b>>>0>=2){Fh(x[a+28>>2],d+63|0);f=y[d+63|0];if(!f){Fh(x[a+28>>2],d+55|0);f=y[d+63|0]}xl(x[a+28>>2],b+(f?-1:-2)|0,-1)}x[d+40>>2]=0;x[d+44>>2]=0;b:{if(!gi(e,4)){break b}Wj(x[a+28>>2],d+40|0);b=x[d+44>>2];f=x[d+40>>2];x[a+56>>2]=f;x[a+60>>2]=b;g=x[c+4>>2];if((g|0)==(b|0)&A[c>>2]>=f>>>0|b>>>0<g>>>0){break b}Pg(a,536871424)}if(gi(e,5)){Fh(x[a+28>>2],d+63|0);xl(x[a+28>>2],y[d+63|0],-1)}c:{if(!gi(y[d+55|0],0)){break c}Fh(x[a+28>>2],d+63|0);b=y[d+63|0];b=b&1?-1:b>>>1|0;w[a+16>>1]=b;if(b){break c}Pg(a,536871168)}x[a+4>>2]=0;b=1;if(gi(y[d+55|0],1)){RD(x[a+28>>2],a+4|0)}Xj(a,6,gi(e,2));Xj(a,7,gi(e,3));Xj(a,5,z[a+16>>1]!=0);Xj(a,8,gi(e,7));d:{if(Cd(a,5)){break d}if(Cd(a,6)){break d}if(Cd(a,7)){break d}b=Cd(a,8)}Xj(a,11,b);Cd(a,11);b=y[d+55|0];if(gi(b,2)){w[d+24>>1]=0;Mv(x[a+28>>2],d+24|0);xl(x[a+28>>2],D(z[d+24>>1],Cd(a,9)?2:1),-1);b=y[d+55|0]}if(gi(b,3)){xl(x[a+28>>2],5,-1)}Wj(x[a+28>>2],d+40|0);c=x[d+44>>2];b=x[d+40>>2];if(!c&b>>>0>=16001|c){Pg(a,1073741831);break a}x[a+92>>2]=b;if(!b){Pg(a,536871040)}e:{if(!Cd(a,11)){break e}Wj(x[a+28>>2],d+40|0);b=x[d+44>>2];if((b|0)==2147483647|b>>>0<2147483647){break e}Pg(a,1073741829);break a}b=d+8|0;vf(b,x[a+28>>2]);XD(d+24|0,b,x[a+8>>2],x[a+12>>2]);b=x[d+32>>2];c=x[d+36>>2];if(!(((c|0)>0|(c|0)>=0)&!c)){Pg(a,1073741832);break a}x[a+88>>2]=b;i=a,j=x[(Cd(a,11)?d+40|0:a+88|0)>>2],x[i+64>>2]=j;if(!Cd(a,11)){b=x[a+12>>2];c=x[a+88>>2];e=c+x[a+8>>2]|0;b=e>>>0<c>>>0?b+1|0:b;x[a+72>>2]=e;x[a+76>>2]=b}Xj(a,10,1)}hb=d+336|0}function hQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-80|0;hb=e;f=x[b>>2];g=x[b+4>>2];a:{if(x[b+4>>2]==x[d+4>>2]){x[e+72>>2]=f;x[e+76>>2]=g;b=x[c+4>>2];x[e+64>>2]=x[c>>2];x[e+68>>2]=b;f=Ed(e+56|0,d);b=x[e+76>>2];x[e+8>>2]=x[e+72>>2];x[e+12>>2]=b;b=x[e+68>>2];x[e>>2]=x[e+64>>2];x[e+4>>2]=b;b=hb-16|0;hb=b;d=Mi(e,e+8|0);x[b+12>>2]=d;b:{if((d|0)<=0){break b}c=x[e+12>>2];c:{if(!c){c=x[e+8>>2];break c}g=32-c|0;x[b+8>>2]=g;c=x[be(b+8|0,b+12|0)>>2];x[b+12>>2]=x[b+12>>2]-c;d=x[f>>2];g=-1<<x[e+12>>2]&-1>>>g-c;h=x[e+8>>2];x[d>>2]=x[d>>2]&(g^-1)|g&x[h>>2];c=c+x[f+4>>2]|0;x[f+4>>2]=c&31;x[f>>2]=d+(c>>>3&536870908);c=h+4|0;x[e+8>>2]=c;d=x[b+12>>2]}h=c;c=(d|0)/32|0;fQ(h,c,x[f>>2]);d=x[b+12>>2]-(c<<5)|0;x[b+12>>2]=d;g=c<<2;c=g+x[f>>2]|0;x[f>>2]=c;if((d|0)<=0){break b}g=g+x[e+8>>2]|0;x[e+8>>2]=g;h=c;j=x[c>>2];c=-1>>>32-d|0;x[h>>2]=j&(c^-1)|c&x[g>>2];x[f+4>>2]=x[b+12>>2]}Ed(a,f);hb=b+16|0;break a}x[e+48>>2]=f;x[e+52>>2]=g;b=x[c+4>>2];x[e+40>>2]=x[c>>2];x[e+44>>2]=b;g=Ed(e+32|0,d);b=x[e+52>>2];x[e+24>>2]=x[e+48>>2];x[e+28>>2]=b;b=x[e+44>>2];x[e+16>>2]=x[e+40>>2];x[e+20>>2]=b;f=hb-16|0;hb=f;d=Mi(e+16|0,e+24|0);x[f+12>>2]=d;d:{if((d|0)<=0){break d}b=x[e+28>>2];e:{if(!b){c=x[g+4>>2];b=x[e+24>>2];break e}c=32-b|0;x[f+8>>2]=c;d=f+8|0;b=x[be(d,f+12|0)>>2];x[f+12>>2]=x[f+12>>2]-b;h=x[g+4>>2];k=x[x[e+24>>2]>>2];j=x[e+28>>2];x[f+8>>2]=b;h=32-h|0;x[f+4>>2]=h;l=Mb(d,f+4|0);i=x[g>>2];k=k&(-1<<j&-1>>>c-b);c=x[g+4>>2];d=x[e+28>>2];j=h;h=x[l>>2];x[i>>2]=(c>>>0>d>>>0?k<<c-d:k>>>d-c|0)|x[i>>2]&(-1<<c&-1>>>j-h^-1);j=c+h|0;c=j&31;x[g+4>>2]=c;i=i+(j>>>3&536870908)|0;x[g>>2]=i;b=b-h|0;if((b|0)>0){x[i>>2]=x[i>>2]&(-1>>>32-b^-1)|k>>>d+h;x[g+4>>2]=b;c=b}d=x[f+12>>2];b=x[e+24>>2]+4|0}i=32-c|0;if((d|0)>=32){j=-1<<c;l=j^-1;h=x[g>>2];k=x[h>>2];while(1){d=x[b>>2];x[h>>2]=k&l|d<<c;k=j&x[h+4>>2]|d>>>i;x[h+4>>2]=k;m=x[f+12>>2];d=m-32|0;x[f+12>>2]=d;b=b+4|0;h=h+4|0;if((m|0)>63){continue}break}x[g>>2]=h}x[e+24>>2]=b;if((d|0)<=0){break d}k=x[b>>2];x[f+8>>2]=i;b=be(f+12|0,f+8|0);c=x[g>>2];h=x[g+4>>2];b=x[b>>2];j=x[c>>2]&(-1<<h&-1>>>i-b^-1);i=k&-1>>>32-d;x[c>>2]=j|i<<h;d=b+h|0;x[g+4>>2]=d&31;c=c+(d>>>3&536870908)|0;x[g>>2]=c;d=x[f+12>>2]-b|0;x[f+12>>2]=d;if((d|0)<=0){break d}x[c>>2]=x[c>>2]&(-1>>>32-d^-1)|i>>>b;x[g+4>>2]=x[f+12>>2]}Ed(a,g);hb=f+16|0}hb=e+80|0}function O_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;k=hb-16|0;hb=k;m=Hu(g);o=hw(g);wg(k,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[114414]=0;g=O(22,m|0,g<<24>>24)|0;i=x[114414];x[114414]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[114414]=0;g=O(22,m|0,48)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;g=v[i+1|0];x[114414]=0;g=O(22,m|0,g|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];x[114414]=0;j=$(2507)|0;l=x[114414];x[114414]=0;e:{if((l|0)==1){break e}x[114414]=0;h=nw(h,j);j=x[114414];x[114414]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];x[114414]=0;$(2507)|0;j=x[114414];x[114414]=0;if((j|0)==1){break a}x[114414]=0;h=ih(h);j=x[114414];x[114414]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Wc(k)){h=x[f>>2];x[114414]=0;Z(2503,m|0,i|0,g|0,h|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i|0);break f}l=0;x[114414]=0;fk(i,g);h=x[114414];x[114414]=0;if((h|0)==1){break a}x[114414]=0;r=R(2494,o|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(g>>>0<=h>>>0){h=x[f>>2];x[114414]=0;fk((i-a|0)+d|0,h);i=x[114414];x[114414]=0;if((i|0)!=1){break f}break a}g:{if(v[pc(k,j)|0]<=0){break g}if(v[pc(k,j)|0]!=(l|0)){break g}l=x[f>>2];x[f>>2]=l+1;v[l|0]=r;j=(Bb(k)-1>>>0>j>>>0)+j|0;l=0}q=v[h|0];x[114414]=0;q=O(22,m|0,q|0)|0;n=x[114414];x[114414]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+1;v[n|0]=q;h=h+1|0;l=l+1|0;continue}break}break a}while(1){h:{if(c>>>0>g>>>0){i=y[g|0];if((i|0)!=46){break h}x[114414]=0;i=R(2504,o|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0}i=x[f>>2];x[114414]=0;Z(2503,m|0,g|0,c|0,i|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g|0)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;xb(k);hb=k+16|0;return}x[114414]=0;i=O(22,m|0,i<<24>>24)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0;continue}}a=N()|0;xb(k);Q(a|0);p()}function Qea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=hb-48|0;hb=e;n=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;s=e,t=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[s+28>>2]=t;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}j=a+8|0;s=e,t=Sf(j,b),x[s+16>>2]=t;x[e+20>>2]=lb;s=e,t=Te(j,d),x[s+40>>2]=t;x[e+44>>2]=lb;tf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}h=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];f=x[a+4>>2];j=x[a>>2];x[e+8>>2]=j;x[e+12>>2]=f;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;b:{c:{if(!d){g=k>>12;i=l>>12;break c}while(1){j=b;f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];g=x[e+12>>2]<<1;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=g+n|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{g=w[f+(x[e+44>>2]<<1)>>1];x[114414]=0;P(1048,x[e+24>>2],(g|0)/4<<16>>16);g=x[114414];x[114414]=0;if((g|0)==1){break e}x[114414]=0;P(1049,x[e+24>>2],4);g=x[114414];x[114414]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];g=x[b+4>>2];if(g){f=w[f+(x[e+44>>2]<<1)>>1];x[114414]=0;P(1048,b|0,(f|0)/4<<16>>16);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(1049,x[e+24>>2],g|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[e+24>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114414]=0;i=O(1050,b|0,x[e+28>>2])|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[a+60>>2];f=Xb(j,-16777216,16776704);g=x[a+64>>2];h=Xb(h,-16777216,16776704);o=x[a+72>>2];q=x[a+32>>2];r=x[c>>2];m=i<<8;i=m;b=yna(b,b>>31,i,i>>31);i=lb;g=yna(g,g>>31,f,f>>31);f=g+b|0;b=lb+i|0;b=f>>>0<g>>>0?b+1|0:b;i=f;f=x[a+68>>2];f=yna(f,f>>31,h,h>>31);h=i+f|0;b=lb+b|0;b=f>>>0>h>>>0?b+1|0:b;l=x[a+28>>2]+l|0;i=l>>12;h=h+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;h=(b|0)/256|0;x[c>>2]=D(i,h)+r;k=k+q|0;g=k>>12;x[c+4>>2]=x[c+4>>2]+D(h,g);b=b-(m&o)|0;c=c+8|0;Tb(e+8|0,e);h=j;d=d-1|0;if(d){continue}break}j=x[e+8>>2];f=x[e+12>>2]}x[a>>2]=j;x[a+4>>2]=f;x[a+40>>2]=k;x[a+20>>2]=i;x[a+36>>2]=l;x[a+48>>2]=h;x[a+44>>2]=b;x[a+24>>2]=g;hb=e+48|0;return}b=N()|0;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=h;x[a+44>>2]=j;x[a+24>>2]=k>>12;Q(b|0);p()}function Hia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;k=hb-48|0;hb=k;f=x[a+4>>2];h=Ed(k+40|0,b);e=Ed(k+32|0,c);d=hb-16|0;hb=d;h=gQ(Ed(d+8|0,h),Ed(d,e));hb=d+16|0;d=h+x[a+4>>2]|0;x[a+4>>2]=d;if(!((d-1^f-1)>>>0<32?f:0)){x[x[a>>2]+((d>>>0>=33?d-1>>>5|0:0)<<2)>>2]=0}b=Ed(k+24|0,b);e=Ed(k+16|0,c);c=k+8|0;oo(c,a,f);h=hb-48|0;hb=h;a:{if(x[b+4>>2]==x[c+4>>2]){d=Ed(h+40|0,b);b=Ed(h+32|0,e);f=Ed(h+24|0,c);a=hb-16|0;hb=a;c=Mi(b,d);x[a+12>>2]=c;b:{if((c|0)<=0){break b}b=x[d+4>>2];c:{if(!b){b=x[d>>2];break c}e=32-b|0;x[a+8>>2]=e;b=x[be(a+8|0,a+12|0)>>2];x[a+12>>2]=x[a+12>>2]-b;c=x[f>>2];e=-1<<x[d+4>>2]&-1>>>e-b;x[c>>2]=x[c>>2]&(e^-1)|e&x[x[d>>2]>>2];b=b+x[f+4>>2]|0;x[f+4>>2]=b&31;x[f>>2]=c+(b>>>3&536870908);b=x[d>>2]+4|0;x[d>>2]=b;c=x[a+12>>2]}e=b;b=(c|0)/32|0;fQ(e,b,x[f>>2]);c=x[a+12>>2]-(b<<5)|0;x[a+12>>2]=c;b=b<<2;x[f>>2]=b+x[f>>2];if((c|0)<=0){break b}b=b+x[d>>2]|0;x[d>>2]=b;d=x[f>>2];c=-1>>>32-c|0;x[d>>2]=x[d>>2]&(c^-1)|c&x[b>>2];x[f+4>>2]=x[a+12>>2]}Ed(k,f);hb=a+16|0;break a}d=Ed(h+16|0,b);a=Ed(h+8|0,e);f=Ed(h,c);b=hb-16|0;hb=b;a=Mi(a,d);x[b+12>>2]=a;d:{if((a|0)<=0){break d}c=x[d+4>>2];e:{if(!c){c=x[f+4>>2];break e}c=32-c|0;x[b+8>>2]=c;e=b+8|0;a=x[be(e,b+12|0)>>2];x[b+12>>2]=x[b+12>>2]-a;g=x[f+4>>2];i=x[x[d>>2]>>2];j=x[d+4>>2];x[b+8>>2]=a;l=32-g|0;x[b+4>>2]=l;m=Mb(e,b+4|0);g=x[f>>2];i=i&(-1<<j&-1>>>c-a);c=x[f+4>>2];e=x[d+4>>2];j=c>>>0>e>>>0?i<<c-e:i>>>e-c|0;e=x[m>>2];x[g>>2]=j|x[g>>2]&(-1<<c&-1>>>l-e^-1);j=c+e|0;c=j&31;x[f+4>>2]=c;g=g+(j>>>3&536870908)|0;x[f>>2]=g;a=a-e|0;if((a|0)>0){x[g>>2]=x[g>>2]&(-1>>>32-a^-1)|i>>>e+x[d+4>>2];x[f+4>>2]=a;c=a}x[d>>2]=x[d>>2]+4;a=x[b+12>>2]}e=32-c|0;if((a|0)>=32){i=-1<<c;j=i^-1;g=x[d>>2];while(1){a=x[f>>2];g=x[g>>2];x[a>>2]=j&x[a>>2]|g<<c;x[f>>2]=a+4;x[a+4>>2]=i&x[a+4>>2]|g>>>e;l=x[b+12>>2];a=l-32|0;x[b+12>>2]=a;g=x[d>>2]+4|0;x[d>>2]=g;if((l|0)>63){continue}break}}if((a|0)<=0){break d}i=x[x[d>>2]>>2];x[b+8>>2]=e;c=be(b+12|0,b+8|0);d=x[f>>2];g=x[f+4>>2];c=x[c>>2];j=x[d>>2]&(-1<<g&-1>>>e-c^-1);e=i&-1>>>32-a;x[d>>2]=j|e<<g;a=c+g|0;x[f+4>>2]=a&31;a=d+(a>>>3&536870908)|0;x[f>>2]=a;d=x[b+12>>2]-c|0;x[b+12>>2]=d;if((d|0)<=0){break d}x[a>>2]=x[a>>2]&(-1>>>32-d^-1)|e>>>c;x[f+4>>2]=x[b+12>>2]}Ed(k,f);hb=b+16|0}hb=h+48|0;hb=k+48|0}function Rea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=hb-48|0;hb=e;n=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;s=e,t=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[s+28>>2]=t;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}j=a+8|0;s=e,t=Sf(j,b),x[s+16>>2]=t;x[e+20>>2]=lb;s=e,t=Te(j,d),x[s+40>>2]=t;x[e+44>>2]=lb;tf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}h=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];g=x[a+4>>2];j=x[a>>2];x[e+8>>2]=j;x[e+12>>2]=g;f=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=f;b:{c:{if(!d){f=k>>12;i=l>>12;break c}while(1){j=b;f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];g=x[e+12>>2];if(!f){x[e+16>>2]=0;x[e+20>>2]=0}g=g+n|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{f=v[g+x[e+44>>2]|0];x[114414]=0;P(1048,x[e+24>>2],f<<6);f=x[114414];x[114414]=0;if((f|0)==1){break e}x[114414]=0;P(1049,x[e+24>>2],4);f=x[114414];x[114414]=0;if((f|0)==1){break e}f=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(f){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];f=x[b+4>>2];if(f){g=v[g+x[e+44>>2]|0];x[114414]=0;P(1048,b|0,g<<6);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(1049,x[e+24>>2],f|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[e+24>>2];g=x[b>>2];x[b>>2]=g;x[b+4>>2]=0}x[114414]=0;i=O(1050,b|0,x[e+28>>2])|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[a+60>>2];g=Xb(j,-16777216,16776704);f=x[a+64>>2];h=Xb(h,-16777216,16776704);o=x[a+72>>2];q=x[a+32>>2];r=x[c>>2];m=i<<8;i=m;b=yna(b,b>>31,i,i>>31);i=lb;f=yna(f,f>>31,g,g>>31);g=f+b|0;b=lb+i|0;b=g>>>0<f>>>0?b+1|0:b;i=g;g=x[a+68>>2];g=yna(g,g>>31,h,h>>31);h=i+g|0;b=lb+b|0;b=g>>>0>h>>>0?b+1|0:b;l=x[a+28>>2]+l|0;i=l>>12;h=h+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;h=(b|0)/256|0;x[c>>2]=D(i,h)+r;k=k+q|0;f=k>>12;x[c+4>>2]=x[c+4>>2]+D(h,f);b=b-(m&o)|0;c=c+8|0;Tb(e+8|0,e);h=j;d=d-1|0;if(d){continue}break}j=x[e+8>>2];g=x[e+12>>2]}x[a>>2]=j;x[a+4>>2]=g;x[a+40>>2]=k;x[a+20>>2]=i;x[a+36>>2]=l;x[a+48>>2]=h;x[a+44>>2]=b;x[a+24>>2]=f;hb=e+48|0;return}b=N()|0;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=h;x[a+44>>2]=j;x[a+24>>2]=k>>12;Q(b|0);p()}function D4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Wb(a);x[114414]=0;V(83);c=x[114414];x[114414]=0;a:{b:{if((c|0)==1){c=Ya(82448,75016,74968,0)|0;c:{d:{e:{d=ib;if((d|0)==(ca(82448)|0)){c=Y(c|0)|0;x[114414]=0;O(2029,a|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break e}x[114414]=0;O(2029,a|0,13624)|0;b=x[114414];x[114414]=0;if((b|0)==1){break e}x[114414]=0;O(2029,a|0,13600)|0;b=x[114414];x[114414]=0;if((b|0)==1){break e}b=mb[x[x[c>>2]+8>>2]](c)|0;x[114414]=0;O(2029,a|0,(b?b:17386)|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break e}x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=N()|0;break a}f:{if((ca(75016)|0)==(d|0)){c=Y(c|0)|0;x[114414]=0;O(2029,a|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;O(2029,a|0,13624)|0;b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;O(2029,a|0,13575)|0;b=x[114414];x[114414]=0;if((b|0)==1){break f}b=mb[x[x[c>>2]+8>>2]](c)|0;x[114414]=0;O(2029,a|0,(b?b:17386)|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=N()|0;break a}e=ca(74968)|0;c=Y(c|0)|0;g:{if((d|0)==(e|0)){x[114414]=0;O(2029,a|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break g}x[114414]=0;O(2029,a|0,13624)|0;b=x[114414];x[114414]=0;if((b|0)==1){break g}x[114414]=0;O(2029,a|0,13591)|0;b=x[114414];x[114414]=0;if((b|0)==1){break g}b=mb[x[x[c>>2]+8>>2]](c)|0;x[114414]=0;O(2029,a|0,(b?b:17386)|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break g}x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=N()|0;break a}x[114414]=0;O(2029,a|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break d}x[114414]=0;O(2029,a|0,13624)|0;b=x[114414];x[114414]=0;if((b|0)==1){break d}x[114414]=0;O(2029,a|0,9549)|0;b=x[114414];x[114414]=0;if((b|0)==1){break d}x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=N()|0;break a}b=N()|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)!=1){break a}break c}b=N()|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)!=1){break a}break c}b=N()|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)==1){break c}break a}b=N()|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)!=1){break a}}S(0)|0;zb()}p()}return}xb(a);Q(b|0);p()}function I2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-160|0;hb=d;a:{if(vj(b)){break a}e=y[rk(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}Fk(d+128|0,b,x[b+4>>2]-1|0);e=x[d+132>>2];x[b>>2]=x[d+128>>2];x[b+4>>2]=e}f=d+128|0;Hd(f);e=x[d+128>>2];Hd(d+112|0);e=qk(e,x[d+116>>2],b);Hd(f);b:{c:{d:{e:{f:{g:{if((e|0)==x[d+132>>2]){a=x[b+4>>2];x[d+152>>2]=x[b>>2];x[d+156>>2]=a;a=tc(d+144|0,17386);e=x[d+156>>2];x[d+8>>2]=x[d+152>>2];x[d+12>>2]=e;e=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=e;if(Kc(d+8|0,d)){a=ec(8);x[114414]=0;c=O(118,d+128|0,6463)|0;b=x[114414];x[114414]=0;if((b|0)==1){break f}a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}e=0;f=0;if(!c){break g}c=ec(8);x[114414]=0;a=O(2172,d+112|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;T(2152,d+128|0,13524,a|0);b=x[114414];x[114414]=0;if((b|0)==1){break e}b=oc(c,d+128|0);x[114414]=0;T(2042,b|0,82448,2050);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=N()|0;xb(d+128|0);xb(a);break c}b=N()|0;break d}if(x[e+4>>2]!=1){a=ec(8);x[114414]=0;c=O(118,d+128|0,7464)|0;b=x[114414];x[114414]=0;if((b|0)!=1){a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}b=N()|0;hc(a);break c}c=x[b+4>>2];x[d+104>>2]=x[b>>2];x[d+108>>2]=c;c=tc(d+96|0,17386);e=x[d+108>>2];x[d+56>>2]=x[d+104>>2];x[d+60>>2]=e;e=x[c+4>>2];x[d+48>>2]=x[c>>2];x[d+52>>2]=e;if(Kc(d+56|0,d+48|0)){a=ec(8);x[114414]=0;c=O(118,d+128|0,6463)|0;b=x[114414];x[114414]=0;if((b|0)!=1){a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}b=N()|0;xb(c);break c}b=N()|0;hc(a);break c}c=x[b+4>>2];x[d+88>>2]=x[b>>2];x[d+92>>2]=c;c=tc(d+80|0,6914);e=x[d+92>>2];x[d+40>>2]=x[d+88>>2];x[d+44>>2]=e;e=x[c+4>>2];x[d+32>>2]=x[c>>2];x[d+36>>2]=e;if(Kc(d+40|0,d+32|0)){e=x[a+8>>2];f=e>>31;break g}c=x[b+4>>2];x[d+72>>2]=x[b>>2];x[d+76>>2]=c;b=tc(d- -64|0,4819);c=x[d+76>>2];x[d+24>>2]=x[d+72>>2];x[d+28>>2]=c;c=x[b+4>>2];x[d+16>>2]=x[b>>2];x[d+20>>2]=c;e=0;f=0;if(!Kc(d+24|0,d+16|0)){break g}e=x[x[a+32>>2]+40>>2];f=e>>31}hb=d+160|0;lb=f;return e|0}b=N()|0;hc(a);break c}b=N()|0;xb(a)}hc(c)}Q(b|0)}p()}function qaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-1136|0;hb=e;Lc(b);d=hb-16|0;hb=d;f=d+8|0;h=e+1112|0;$K(f,h);j=Eb(f);f=nc(b,ac(d,f));if((j|0)==(f|0)){cc(b,Eb(d+8|0))}hb=d+16|0;d=(f|0)==(j|0);if(!d){bL(h)}a:{if(!d){break a}if(!eL(e+1112|0)){break a}d=e+1120|0;if((y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))!=(fj(b)|0)){break a}h=e+1128|0;if((y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24))!=(uf(b)|0)){break a}if(!c){g=1;break a}d=e+1056|0;Sb(d,0,56);i=-2;b:{if(!d){break b}x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+8>>2]=0;f=x[d+32>>2];if(!f){x[d+32>>2]=2333;f=2333}if(!x[d+36>>2]){x[d+36>>2]=2334}f=mb[f|0](x[d+40>>2],1,43784)|0;i=-4;if(!f){break b}x[d+28>>2]=f;x[f+43780>>2]=1;x[f+10992>>2]=0;x[f+10996>>2]=0;x[f>>2]=0;x[f+11008>>2]=15;x[f+11e3>>2]=1;x[f+11004>>2]=0;i=0}if(i){break a}d=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);x[e+1052>>2]=d;g=e+1132|0;g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);k=(g|0)!=0;h=HS(e+1040|0,g);c:{d:{e:{f:{if(!d){j=1;break f}j=1;if(!g){break f}while(1){x[114414]=0;x[e+12>>2]=1024;d=O(297,e+12|0,e+1052|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break e}f=x[d>>2];x[114414]=0;U(229,b|0,e+16|0,f|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break d}x[114414]=0;l=U(1570,l|0,e+16|0,f|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break d}x[e+1072>>2]=g;x[e+1060>>2]=f;x[e+1056>>2]=e+16;d=x[h>>2];x[114414]=0;x[e+1068>>2]=d+m;n=O(1571,e+1056|0,0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break d}i=x[e+1052>>2];x[e+1052>>2]=i-f;j=(n|0)!=1;d=x[e+1072>>2];k=(d|0)!=0;if(!d|(f|0)==(i|0)){break f}m=(g+m|0)-d|0;g=d;if((n|0)!=1){continue}break}}x[114414]=0;R(1572,e+1056|0)|0;b=x[114414];x[114414]=0;g:{h:{if((b|0)!=1){g=0;b=e+1124|0;if(!((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))!=(l|0)|k|j)){x[114414]=0;P(812,e|0,h|0);b=x[114414];x[114414]=0;if((b|0)==1){break h}x[114414]=0;b=U(813,e+16|0,e|0,0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break h}x[114414]=0;g=U(1512,a|0,b|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break g}Ab(b)}$d(h);break a}a=N()|0;break c}a=N()|0;break c}a=N()|0;Ab(b);break c}a=N()|0;break c}a=N()|0}$d(h);Q(a|0);p()}hb=e+1136|0;return g|0}function E2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-160|0;hb=e;a:{if(vj(c)){break a}f=y[rk(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Fk(e+128|0,c,x[c+4>>2]-1|0);f=x[e+132>>2];x[c>>2]=x[e+128>>2];x[c+4>>2]=f}f=e+128|0;Hd(f);g=x[e+128>>2];Hd(e+112|0);h=qk(g,x[e+116>>2],c);Hd(f);f=x[c>>2];g=x[c+4>>2];b:{c:{d:{e:{f:{g:{if((h|0)==x[e+132>>2]){x[e+152>>2]=f;x[e+156>>2]=g;b=tc(e+144|0,17386);f=x[e+156>>2];x[e+8>>2]=x[e+152>>2];x[e+12>>2]=f;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;if(Kc(e+8|0,e)){a=ec(8);x[114414]=0;b=O(118,e+128|0,6463)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}a=oc(a,b);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}c=N()|0;xb(b);break c}if(d){b=ec(8);x[114414]=0;a=O(2172,e+112|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){x[114414]=0;T(2152,e+128|0,13524,a|0);c=x[114414];x[114414]=0;if((c|0)==1){break e}b=oc(b,e+128|0);x[114414]=0;T(2042,b|0,82448,2050);b=x[114414];x[114414]=0;if((b|0)!=1){break b}c=N()|0;xb(e+128|0);xb(a);break c}c=N()|0;break d}Wb(a);break g}x[e+104>>2]=f;x[e+108>>2]=g;d=tc(e+96|0,17386);f=x[e+108>>2];x[e+56>>2]=x[e+104>>2];x[e+60>>2]=f;f=x[d+4>>2];x[e+48>>2]=x[d>>2];x[e+52>>2]=f;if(Kc(e+56|0,e+48|0)){a=ec(8);x[114414]=0;b=O(118,e+128|0,6463)|0;c=x[114414];x[114414]=0;if((c|0)!=1){a=oc(a,b);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}c=N()|0;xb(b);break c}c=N()|0;hc(a);break c}d=x[c+4>>2];x[e+88>>2]=x[c>>2];x[e+92>>2]=d;d=tc(e+80|0,8168);f=x[e+92>>2];x[e+40>>2]=x[e+88>>2];x[e+44>>2]=f;f=x[d+4>>2];x[e+32>>2]=x[d>>2];x[e+36>>2]=f;if(Kc(e+40|0,e+32|0)){h:{switch(x[b+52>>2]){case 0:Ub(a,2087);break g;case 1:Ub(a,7165);break g;case 2:Ub(a,5177);break g;default:break h}}Wb(a);break g}d=x[c+4>>2];x[e+72>>2]=x[c>>2];x[e+76>>2]=d;c=tc(e- -64|0,7402);d=x[e+76>>2];x[e+24>>2]=x[e+72>>2];x[e+28>>2]=d;d=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=d;if(Kc(e+24|0,e+16|0)){i:{switch(x[b+56>>2]){case 0:Ub(a,11636);break g;case 1:Ub(a,11641);break g;case 2:Ub(a,8427);break g;case 3:Ub(a,5241);break g;default:break i}}Wb(a);break g}Wb(a)}hb=e+160|0;return}c=N()|0;hc(a);break c}c=N()|0;xb(a)}hc(b)}Q(c|0)}p()}function Ax(a){a=a|0;var b=0,c=0,d=E(0),e=0;Sb(a+4960|0,0,76);v[a+5044|0]=0;x[a+5036>>2]=0;x[a+5040>>2]=0;b=x[a+4292>>2];d=B[a+4268>>2];x[114414]=0;e=a+4504|0;if(d<E(4294967296)&d>=E(0)){c=~~d>>>0}else{c=0}ba(1950,e|0,67,5,c|0,b|0);b=x[114414];x[114414]=0;a:{if((b|0)==1){break a}b=x[a+4296>>2];x[114414]=0;ba(1950,a+4528|0,62,5,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[a+4300>>2];x[114414]=0;ba(1950,a+4552|0,53,5,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[a+4304>>2];x[114414]=0;ba(1950,a+4576|0,43,5,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[a+4308>>2];x[114414]=0;ba(1950,a+4600|0,32,5,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[a+4312>>2];x[114414]=0;ba(1950,a+4624|0,22,5,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[a+4316>>2];x[114414]=0;ba(1950,a+4648|0,75,5,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[a+4320>>2];x[114414]=0;ba(1950,a+4672|0,69,5,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[a+4324>>2];x[114414]=0;ba(1950,a+4696|0,60,5,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[a+4328>>2];x[114414]=0;ba(1950,a+4720|0,48,5,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[a+4332>>2];x[114414]=0;ba(1950,a+4744|0,36,5,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[a+4336>>2];x[114414]=0;ba(1950,a+4768|0,25,5,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}x[114414]=0;ba(1950,a+4792|0,0,0,0,0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[a+4344>>2];x[114414]=0;ba(1950,a+4816|0,3,0,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[a+4348>>2];x[114414]=0;ba(1950,a+4840|0,3,0,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}x[114414]=0;ba(1950,a+4864|0,407,1,c|0,0);b=x[114414];x[114414]=0;if((b|0)==1){break a}x[114414]=0;ba(1950,a+4888|0,400,1,c|0,0);b=x[114414];x[114414]=0;if((b|0)==1){break a}x[114414]=0;ba(1950,a+4912|0,10,0,c|0,-1);b=x[114414];x[114414]=0;if((b|0)==1){break a}x[114414]=0;ba(1950,a+4936|0,10,0,c|0,-1);c=x[114414];x[114414]=0;if((c|0)==1){break a}v[a+5045|0]=1;return}c=S(75016)|0;if((ib|0)==(ca(75016)|0)){Y(c|0)|0;v[a+5045|0]=0;_();return}Q(c|0);p()}function hla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0;c=hb-80|0;hb=c;d=hb-16|0;hb=d;e=d+8|0;g=b+16|0;WR(e,g);h=Eb(e);e=nc(a,ac(d,e));if((h|0)==(e|0)){cc(a,Eb(d+8|0))}hb=d+16|0;if((e|0)!=(h|0)){d=hb-16|0;hb=d;Sb(g,0,128);hb=d+16|0}uS(b+48|0);v[b+143|0]=0;x[b+152>>2]=-2147483648;x[b+156>>2]=-2147483648;d=c- -64|0;Bd(d,a,Gf(a));x[114414]=0;d=R(296,d|0)|0;e=x[114414];x[114414]=0;a:{b:{if((e|0)==1){break b}x[114414]=0;e=b+4|0;P(464,e|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break b}x[114414]=0;P(672,c+56|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break b}x[114414]=0;O(673,c- -64|0,c+56|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break b}x[114414]=0;d=R(391,a|0)|0;e=x[114414];x[114414]=0;c:{if((e|0)==1){break c}x[114414]=0;T(307,c+40|0,a|0,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;a=R(303,c+40|0)|0;d=x[114414];x[114414]=0;d:{if((d|0)!=1){e:{f:{if(!a){break f}while(1){g:{x[114414]=0;a=O(226,c+40|0,5)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!a){break f}x[114414]=0;O(674,c+40|0,c+36|0)|0;a=x[114414];x[114414]=0;h:{if((a|0)!=1){a=4;d=y[c+36|0]|y[c+37|0]<<8|(y[c+38|0]<<16|y[c+39|0]<<24);if((d|0)==1414682436|(d|0)==1196380752){break h}x[114414]=0;a=R(391,c+40|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break h}a=N()|0;break d}a=N()|0;break d}x[114414]=0;T(307,c+16|0,c+40|0,a|0);a=x[114414];x[114414]=0;i:{j:{k:{if((a|0)!=1){if((y[c+36|0]|y[c+37|0]<<8|(y[c+38|0]<<16|y[c+39|0]<<24))!=1414682436){break k}x[114414]=0;f=E(wa(675,c+16|0));a=x[114414];x[114414]=0;if((a|0)==1){break g}x[114414]=0;B[c+12>>2]=f;x[c+8>>2]=0;x[c+4>>2]=1065353216;a=U(676,c+12|0,c+8|0,c+4|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break g}f=B[a>>2];B[b+144>>2]=f;f=E(F(f));if(f<E(Infinity)&f>=E(11754943508222875e-54)){break j}x[b+144>>2]=0;break j}a=N()|0;break d}if((y[c+36|0]|y[c+37|0]<<8|(y[c+38|0]<<16|y[c+39|0]<<24))!=1196380752){break j}x[114414]=0;a=R(391,c+16|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break i}x[b+148>>2]=a}Ab(c+16|0);continue}}break}a=N()|0;Ab(c+16|0);break d}Ab(c+40|0);Ab(c- -64|0);hb=c+80|0;return}a=N()|0;break d}a=N()|0}Ab(c+40|0);break a}a=N()|0;break a}a=N()|0}Ab(c- -64|0);Q(a|0);p()}function pU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,B=0,C=0,E=0;f=hb-32|0;hb=f;j=_h(f+24|0);if(x[a+12>>2]){o=j+3|0;p=j+5|0;q=j+4|0;r=j+2|0;s=j+1|0;d=f+16|0;t=d|5;u=d|3;while(1){z=mm(a,l);while(1){a:{if(!Qb(c,1)){break a}d=pe(c);if((d|0)==255){break a}m=d<<24>>24;d=m&31;e=D(d,6)+z|0;h=zk(a)>>>0>d>>>0;i=h?e:j;b:{if(!(m&64)){g=pe(c);k=g<<24>>24;d=255;g=g&127;c:{d:{if((g|0)==1){break d}d=g-1|0;if(b?d>>>0<=120:0){break d}if((g-109&255)>>>0<159|b){break c}d=g+13|0}v[i|0]=d}C=h?e+1|0:s,E=pe(c),v[C|0]=E;if((k|0)>=0){break b}}g=h?e+3|0:o;d=h?e+5|0:p;n=h?e+4|0:q;k=h?e+2|0:r;while(1){x[f+16>>2]=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);w[f+20>>1]=y[i+4|0]|y[i+5|0]<<8;e=pe(c);h=e&63;B=e<<24>>24;e:{if(e&64){v[k|0]=1;v[n|0]=h;break e}e=pe(c);v[d|0]=e;f:{g:{if(h>>>0<=15){v[g|0]=h;Fj(i);h:{i:{j:{e=y[g|0];switch(e-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}v[g|0]=9;v[d|0]=D(y[d|0]&15,17);break f}v[g|0]=0;v[k|0]=1;x[f+12>>2]=y[d|0]+1>>>1;x[f+8>>2]=64;C=n,E=x[be(f+12|0,f+8|0)>>2],v[C|0]=E;break f}if((e|0)!=19){break f}if(y[d|0]==128){break g}XK(i);break f}if(h>>>0>44){break f}h=h-16|0;v[g|0]=y[h+23360|0];k:{switch(h|0){case 0:if(e>>>0>1){break g}v[d|0]=e|158;break f;case 1:case 2:v[f+12|0]=15;C=d,E=y[rc(f+12|0,d)|0]|224,v[C|0]=E;break f;case 5:case 6:x[f+12>>2]=16;x[f+8>>2]=e+1;C=d,E=x[be(f+12|0,f+8|0)>>2]/2|240,v[C|0]=E;break f;case 14:l:{m:{n:{o:{p:{h=e>>>4|0;switch(h-1|0){case 1:break n;case 0:break o;default:break p}}switch(h-10|0){case 1:break l;case 0:break m;default:break g}}v[g|0]=2;v[d|0]=e|240;break f}v[g|0]=3;v[d|0]=e|240;break f}v[g|0]=11;v[d|0]=(e<<3&120)+8|15;break f}v[g|0]=11;v[d|0]=(e&15)+1>>>1|240;break f;case 12:break k;default:break f}}x[f+12>>2]=e+1>>>1;x[f+8>>2]=64;C=d,E=x[be(f+12|0,f+8|0)>>2],v[C|0]=E;break f}v[g|0]=0}Yx(g,d,u,t);if(rn(y[f+19|0])>>>0<=rn(y[g|0])>>>0){break e}q:{if(y[k|0]){break q}if(!Zx(g,d,1)){break q}v[k|0]=y[g|0];v[n|0]=y[d|0]}v[g|0]=y[f+19|0];v[d|0]=y[f+21|0]}if((B|0)<0){continue}break}}if((m|0)>=0){continue}}break}l=l+1|0;if(l>>>0<A[a+12>>2]){continue}break}}hb=f+32|0}function xN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=hb-96|0;hb=f;v[f+95|0]=d;d=0;m=Kp(a);n=Bj(m);w[b>>1]=0;a:{if(n){while(1){o=z[uc(m,d&65535)>>1];b:{if(!kg(x[a+24>>2]+484344|0,o)){break b}d=z[b>>1];if(zc(a)>>>0<=d>>>0){x[c>>2]=0;a=1;break a}l=wd(a,z[b>>1]);Ej(f+72|0,l);Mk(f- -64|0,l);d=x[f+76>>2];x[f+32>>2]=x[f+72>>2];x[f+36>>2]=d;d=x[f+68>>2];x[f+24>>2]=x[f+64>>2];x[f+28>>2]=d;j=f+80|0;i=f+24|0;d=hb-32|0;hb=d;e=f+32|0;g=x[e>>2];h=x[e+4>>2];c:{if(y[f+95|0]){x[d+24>>2]=g;x[d+28>>2]=h;e=Mi(i,e);g=x[d+28>>2];x[d+8>>2]=x[d+24>>2];x[d+12>>2]=g;i=hb-16|0;hb=i;x[i+12>>2]=e;h=d+8|0;g=x[h>>2];k=x[h+4>>2];d:{if(k){x[i+8>>2]=32-k;e=x[Mb(i+8|0,i+12|0)>>2];k=x[g>>2]&(-1<<k&-1>>>x[i+8>>2]-e);if(k){dd(j,g,xna(k));break d}k=x[i+12>>2];if((k|0)==(e|0)){sN(j,h,e);break d}e=k-e|0;x[i+12>>2]=e;g=g+4|0}if(e>>>0>=32){while(1){h=x[g>>2];if(h){dd(j,g,xna(h));break d}e=e-32|0;x[i+12>>2]=e;g=g+4|0;if(e>>>0>31){continue}break}}e:{if(!e){break e}h=x[g>>2]&-1>>>32-e;if(!h){break e}dd(j,g,xna(h));break d}dd(j,g,e)}break c}x[d+16>>2]=g;x[d+20>>2]=h;e=Mi(i,e);g=x[d+20>>2];x[d>>2]=x[d+16>>2];x[d+4>>2]=g;i=hb-16|0;hb=i;x[i+12>>2]=e;g=x[d>>2];h=x[d+4>>2];f:{if(h){x[i+8>>2]=32-h;e=x[Mb(i+8|0,i+12|0)>>2];h=-1<<h&-1>>>x[i+8>>2]-e&(x[g>>2]^-1);if(h){dd(j,g,xna(h));break f}h=x[i+12>>2];if((h|0)==(e|0)){sN(j,d,e);break f}e=h-e|0;x[i+12>>2]=e;g=g+4|0}if(e>>>0>=32){while(1){h=x[g>>2];if((h|0)!=-1){dd(j,g,xna(h^-1));break f}e=e-32|0;x[i+12>>2]=e;g=g+4|0;if(e>>>0>31){continue}break}}g:{if(!e){break g}h=(x[g>>2]^-1)&-1>>>32-e;if(!h){break g}dd(j,g,xna(h));break f}dd(j,g,e)}}hb=i+16|0;hb=d+32|0;h:{if(y[f+95|0]){j=f+56|0;Mk(j,l);d=0;if(wN(f+80|0,j)){break h}if(y[f+95|0]){break b}}d=f+56|0;Mk(d,l);if(wN(f+80|0,d)^1){Ej(f+48|0,l);b=x[f+84>>2];a=x[f+80>>2];x[f+40>>2]=a;x[f+44>>2]=b;d=x[f+52>>2];x[f+16>>2]=x[f+48>>2];x[f+20>>2]=d;x[f+8>>2]=a;x[f+12>>2]=b;d=GP(f+16|0,f+8|0);break h}if(A[l+4>>2]>=A[Zb(x[a+24>>2]+484344|0,o)+12>>2]){break b}d=x[l+4>>2]}x[c>>2]=d;a=1;break a}d=z[b>>1]+1|0;w[b>>1]=d;if((d&65535)>>>0<n>>>0){continue}break}}w[b>>1]=65535;x[c>>2]=-1;a=0}hb=f+96|0;return a|0}function mea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=hb-32|0;hb=h;x[h+24>>2]=d;k=Vj(a,c);vf(h,x[a+28>>2]);d=x[h+12>>2];x[h+16>>2]=x[h+8>>2];x[h+20>>2]=d;a:{if(!k){if(Cd(a,5)){break a}}f=x[h+24>>2];d=hb-224|0;hb=d;i=pl(d+120|0,x[a+28>>2]);x[114414]=0;g=O(658,d+104|0,24352)|0;e=x[114414];x[114414]=0;b:{c:{d:{e:{if((e|0)!=1){x[114414]=0;x[d+88>>2]=19469590;x[d+92>>2]=0;T(659,i|0,g|0,d+88|0);e=x[114414];x[114414]=0;if((e|0)==1){break e}Gb(g);if(!(x[i>>2]&1073741824)){break d}break b}a=N()|0;break c}a=N()|0;Gb(g);break c}x[114414]=0;v[d+103|0]=0;g=O(658,d+88|0,1991)|0;e=x[114414];x[114414]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){x[114414]=0;U(660,i|0,d+103|0,g|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break q}Gb(g);g=Wb(d+72|0);x[114414]=0;e=O(658,d+56|0,6080)|0;j=x[114414];x[114414]=0;if((j|0)==1){break p}x[114414]=0;U(1169,i|0,g|0,e|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break o}Gb(e);x[114414]=0;T(13,d+40|0,(y[d+103|0]?0:f)|0,g|0);e=x[114414];x[114414]=0;if((e|0)==1){break n}x[114414]=0;P(442,b|0,d+40|0);e=x[114414];x[114414]=0;if((e|0)==1){break m}e=d+40|0;xb(e);x[114414]=0;w[d+38>>1]=0;e=O(658,e|0,6727)|0;f=x[114414];x[114414]=0;if((f|0)==1){break g}x[114414]=0;U(1170,i|0,d+38|0,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break l}Gb(e);sg(d+38|0,z[x[19563]+12>>1]);x[114414]=0;e=O(658,d+24|0,9264)|0;f=x[114414];x[114414]=0;if((f|0)==1){break k}f=x[Fb(d+16|0,z[d+38>>1])>>2];x[114414]=0;Z(1171,i|0,b|0,e|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break j}Gb(e);x[114414]=0;w[d+14>>1]=65535;e=O(658,d|0,5085)|0;f=x[114414];x[114414]=0;if((f|0)==1){break i}x[114414]=0;f=U(1170,i|0,d+14|0,e|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break h}j=z[d+38>>1];l=z[d+14>>1];Gb(e);if(!((f|0)==1|j>>>0<=l>>>0)){Se(b,z[d+14>>1])}xb(g);break b}a=N()|0;break c}a=N()|0;Gb(g);break c}a=N()|0;break f}a=N()|0;Gb(e);break f}a=N()|0;break f}a=N()|0;xb(d+40|0);break f}a=N()|0;Gb(e);break f}a=N()|0;break f}a=N()|0;Gb(e);break f}a=N()|0;break f}a=N()|0;Gb(e);break f}a=N()|0}xb(g)}Hg(i);Q(a|0);p()}Hg(i);hb=d+224|0}hj(a,k,c,h+16|0);hb=h+32|0}function _4(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=hb-96|0;hb=j;a:{b:{c:{k=Yo(1,32);d:{e:{if(!k){a=Yj(ec(4));x[114414]=0;T(2042,a|0,75016,26);a=x[114414];x[114414]=0;if((a|0)!=1){break a}i=S(0)|0;break e}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;x[k>>2]=c?c:2031;d=ot(j+80|0);f:{g:{h:{i:{if(!i){break i}c=x[i>>2];if(!c){break i}while(1){j:{e=x[i+4>>2];if(e){x[114414]=0;c=O(118,j- -64|0,c|0)|0;f=x[114414];x[114414]=0;k:{if((f|0)!=1){x[114414]=0;f=O(2043,d|0,c|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break k}x[114414]=0;O(439,f|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break k}break j}i=S(0)|0;break h}i=S(0)|0;xb(c);break h}x[114414]=0;c=O(118,j+48|0,c|0)|0;e=x[114414];x[114414]=0;l:{if((e|0)!=1){x[114414]=0;O(2044,d|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break l}break j}i=S(0)|0;break h}i=S(0)|0;xb(c);break h}xb(c);c=x[i+8>>2];i=i+8|0;if(c){continue}break}}c=x[a+8>>2];e=x[a+4>>2];f=x[a>>2];x[114414]=0;a=R(1404,96)|0;i=x[114414];x[114414]=0;m:{n:{if((i|0)!=1){x[114414]=0;x[j+44>>2]=c;x[j+40>>2]=e;x[j+36>>2]=f;x[j+32>>2]=b;b=O(2045,k|0,k+4|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break n}x[j+16>>2]=b;b=x[ip(j+24|0,j+16|0)>>2];x[114414]=0;c=x[j+44>>2];x[j+8>>2]=x[j+40>>2];x[j+12>>2]=c;c=x[j+36>>2];x[j>>2]=x[j+32>>2];x[j+4>>2]=c;b=Z(2119,a|0,j|0,b|0,d|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break g}i=S(0)|0;pd(j+16|0);break m}i=S(0)|0;break h}i=S(0)|0}_b(a)}Gk(d);Y(i|0)|0;x[114414]=0;X(2023,7220,k|0,g|0,h|0);a=x[114414];x[114414]=0;if((a|0)==1){break f}x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){a=x[k+28>>2];if(a){mb[x[x[a>>2]+4>>2]](a)}x[k+24>>2]=0;x[k+28>>2]=0;a=x[k+20>>2];if(a){_b(a);x[k+20>>2]=0}_b(k);k=0;break d}i=S(0)|0;break e}x[k+28>>2]=b;pd(j+16|0);a=x[k+28>>2];x[k+24>>2]=a?a+8|0:0;Gk(d);break d}i=S(0)|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)==1){break b}}Y(i|0)|0;k=0;x[114414]=0;X(2023,7220,0,g|0,h|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}_()}hb=j+96|0;return k|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)==1){break b}Q(a|0);p()}S(0)|0;zb()}p()}function hL(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-240|0;hb=f;a:{if(!y[84120]){if(!y[83996]){d=hb-16|0;hb=d;h=Wb(83972);c=hb-16|0;hb=c;x[114414]=0;b=U(85,83984,c+8|0,c|0)|0;a=x[114414];x[114414]=0;b:{c:{d:{if((a|0)!=1){hb=c+16|0;break d}break c}v[83988]=0;a=hb-16|0;hb=a;x[114414]=0;c=U(86,83992,a+8|0,a|0)|0;e=x[114414];x[114414]=0;e:{if((e|0)!=1){hb=a+16|0;break e}break c}x[114414]=0;a=$(82)|0;e=x[114414];x[114414]=0;f:{g:{h:{if((e|0)!=1){x[d+8>>2]=a;a=d+8|0;_s(b,ke(a));Ky(a);v[83988]=0;a=0;break h}a=ya(75016,74968)|0;e=ib;if((ca(75016)|0)==(e|0)){Y(a|0)|0;x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)==1){a=N()|0;x[114414]=0;V(20);f=x[114414];x[114414]=0;if((f|0)!=1){break g}S(0)|0;zb()}p()}if((ca(74968)|0)!=(e|0)){break g}Y(a|0)|0;v[83988]=0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)==1){a=N()|0;break g}a=y[83988]}if(a&255){break f}x[114414]=0;W(84,83968);a=x[114414];x[114414]=0;if((a|0)!=1){break f}a=N()|0}dg(c);Ky(b);xb(h);Q(a|0);p()}hb=d+16|0;break b}S(0)|0;zb();p()}v[83996]=1}c=hb+-64|0;hb=c;d=c+16|0;while(1){h=d+(i<<2)|0;a=0;b=0;e=hb-16|0;hb=e;Fb(e+8|0,83968);i:{j:{k:{l:{m:{if(zd(83984)){while(1){n:{g=x[20996];x[114414]=0;g=R(100,g|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break n}a=a|g;b=b+32|0;if(b>>>0<32){continue}break m}break}b=S(74968)|0;if((ib|0)!=(ca(74968)|0)){break j}Y(b|0)|0;v[83988]=0;x[114414]=0;W(84,83968);b=x[114414];x[114414]=0;if((b|0)==1){break l}x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break m}b=N()|0;break j}v[83988]=0}if(!y[83988]){b=x[20998];x[114414]=0;b=R(101,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break k}a=a^b}hb=e+16|0;break i}b=N()|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)!=1){break j}S(0)|0;zb();p()}b=N()|0}Q(b|0);p()}x[h>>2]=a;i=i+1|0;if((i|0)!=12){continue}break}b=Dk(c);x[114414]=0;T(106,b|0,d|0,d+48|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}x[114414]=0;a=f+120|0;U(104,a|0,b|0,0)|0;d=x[114414];x[114414]=0;o:{if((d|0)!=1){Ge(b);hb=c- -64|0;break o}break a}sc(84e3,sc(f,a,120),116);v[84120]=1}hb=f+240|0;return 84e3}c=N()|0;Ge(b);Q(c|0);p()}function EL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=hb-16|0;hb=h;a:{b:{c:{f=D(b,896)+a|0;if(y[f+1075074|0]&2){e=x[a+480180>>2];d:{e:{f:{if(x[a+480208>>2]&4096){if(!(e&16777248)){break f}if(x[a+480180>>2]==64){break e}if(x[a+480208>>2]&4){break d}break c}if((e|0)!=64){break c}break e}if(x[a+480180>>2]!=64){break d}}a=D(b,896)+a|0;b=a+1075823|0;d=y[b|0];if(d&1){x[c>>2]=x[c>>2]+D(y[a+1075828|0],167)}v[b|0]=d+1;break a}break b}if(!(y[f+1075654|0]&2)){break a}a=Ey(a,b);if(!a){break a}mb[x[x[a>>2]+84>>2]](a,0,0,b);break a}e=h+8|0;Kb(e,a+1074312|0,21);k=1;if(!Ib(e)){break b}e=D(b,896)+a|0;g=e+1075823|0;v[g|0]=y[g|0]+(y[e+1075827|0]<<2)}g=D(b,896)+a|0;i=g+1075826|0;j=g+1075823|0;e=ky(a,y[i|0],y[j|0]);g:{if(Dj(f+1074984|0)){B[d>>2]=E(E(D(y[g+1075828|0],e)|0)*E(6510417279059766e-21))+B[d>>2];c=g+1075856|0;d=y[c|0];v[c|0]=d&231|16;if(x[a+1074416>>2]!=(x[a+1074392>>2]+1|0)){break g}v[c|0]=d|24;break g}if((x[a+480208>>2]&2101248)==2101248|(y[a+480209|0]&16?x[a+480180>>2]&67633152:0)){break a}e=x[a+480180>>2]&5?(y[i|0]&3)==1?0-e|0:e:e;d=h+8|0;f=a+1074312|0;Kb(d,f,21);d=Ib(d);g=x[a+480208>>2];h:{if(d){d=g&4;e=d?e:0-e|0;d=d?5:6;break h}d=5;i:{if(g&131072){break i}d=8;if(x[a+480180>>2]==1024){break i}d=7;if(x[a+480180>>2]&524304|(y[a+480208|0]&4?0:x[a+480180>>2]&16777248)){break i}d=6}g=h+8|0;Kb(g,f,80);if(!Ib(g)){break h}d=y[(D(b,896)+a|0)+1075797|0]==26?d+2|0:d}d=(D(y[(D(b,896)+a|0)+1075828|0],e)|0)/(1<<d)|0;g=0-d|0;j:{if(!(y[a+480208|0]&16)|x[a+480180>>2]==4){break j}e=x[c>>2];f=e>>31;k:{if((d|0)<0){d=Dy(a,g>>>2|0);d=Cc(zna(yna(d,d>>31,e,f),lb,65536,0),lb);e=x[c>>2];d=d-e|0;f=g&3;if(!f){break j}f=EM(a,f);break k}i=d&3;d=Cy(a,d>>>2|0);d=Cc(zna(yna(d,d>>31,e,f),lb,65536,0),lb);e=x[c>>2];d=d-e|0;if(!i){break j}f=DM(a,i)}d=(Cc(zna(yna(f,f>>31,e,e>>31),lb,65536,0),lb)+d|0)-x[c>>2]|0}x[c>>2]=x[c>>2]+d;c=Ey(a,b);if(!c){break g}f=g<<16>>16;d=x[(D(b,896)+a|0)+1075640>>2];if(d){d=y[d+33|0]}else{d=2}mb[x[x[c>>2]+84>>2]](c,f,d<<24>>24,b)}if(!k){break a}c=h+8|0;Kb(c,a+1074312|0,21);if(Ib(c)){break a}v[j|0]=y[j|0]+y[(D(b,896)+a|0)+1075827|0]}hb=h+16|0}function Uea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;e=hb-48|0;hb=e;k=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;r=e,s=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[r+28>>2]=s;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}i=a+8|0;r=e,s=Sf(i,b),x[r+16>>2]=s;x[e+20>>2]=lb;r=e,s=Te(i,d),x[r+40>>2]=s;x[e+44>>2]=lb;tf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}h=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];b=x[a+44>>2];i=x[a+4>>2];g=i;f=x[a>>2];x[e+8>>2]=f;x[e+12>>2]=g;i=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=i;b:{c:{if(!d){i=h;break c}while(1){i=b;f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];g=x[e+12>>2]<<1;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=g+k|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{g=w[f+(x[e+44>>2]<<1)>>1];x[114414]=0;P(1048,x[e+24>>2],(g|0)/4<<16>>16);g=x[114414];x[114414]=0;if((g|0)==1){break e}x[114414]=0;P(1049,x[e+24>>2],4);g=x[114414];x[114414]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];g=x[b+4>>2];if(g){f=w[f+(x[e+44>>2]<<1)>>1];x[114414]=0;P(1048,b|0,(f|0)/4<<16>>16);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(1049,x[e+24>>2],g|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[e+24>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114414]=0;j=O(1050,b|0,x[e+28>>2])|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[a+60>>2];f=Xb(i,-16777216,16776704);g=x[a+64>>2];h=Xb(h,-16777216,16776704);n=x[a+72>>2];o=x[c>>2];j=j<<8;b=yna(b,b>>31,j,j>>31);q=lb;g=yna(g,g>>31,f,f>>31);f=g+b|0;b=lb+q|0;b=f>>>0<g>>>0?b+1|0:b;g=f;f=x[a+68>>2];f=yna(f,f>>31,h,h>>31);h=g+f|0;b=lb+b|0;b=f>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;h=(b|0)/256|0;x[c>>2]=D(h,m)+o;x[c+4>>2]=x[c+4>>2]+D(h,l);b=b-(j&n)|0;c=c+8|0;Tb(e+8|0,e);h=i;d=d-1|0;if(d){continue}break}f=x[e+8>>2];g=x[e+12>>2]}x[a>>2]=f;x[a+4>>2]=g;x[a+48>>2]=i;x[a+44>>2]=b;hb=e+48|0;return}b=N()|0;x[a+48>>2]=h;x[a+44>>2]=i;Q(b|0);p()}function Ll(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-16|0;hb=g;a:{b:{if(od(a)|A[a+12>>2]<=A[b+4>>2]){break b}c=z[b+8>>1]>=zk(a)>>>0;i=z[b+8>>1];if(c&(i|0)!=65535){break b}f=i;if((f&65535)==65535){i=zk(a)-1|0;f=0}e=Df(a,x[b+4>>2],f&65535);c:{h=y[b+12|0];d:{if(h&2){break d}k=i&65535;if(k>>>0<(f&65535)>>>0){break d}l=h&4;j=y[b+10|0];c=f;d=e;while(1){e:{if(!l){if((j|0)!=y[d+3|0]){break e}break c}if((j|0)==y[d+2|0]){break c}}d=d+6|0;c=c+1|0;if(k>>>0>=(c&65535)>>>0){continue}break}}j=i&65535;if(j>>>0>=(f&65535)>>>0){k=h&4;c=f;d=e;while(1){f:{if(!k){if(y[d+3|0]){break f}v[d+3|0]=y[b+10|0];v[d+5|0]=y[b+11|0];break c}if(y[d+2|0]){break f}v[d+2|0]=y[b+10|0];v[d+4|0]=y[b+11|0];break c}d=d+6|0;c=c+1|0;if(j>>>0>=(c&65535)>>>0){continue}break}}g:{if(!(h&1)){break g}h=x[qn(a)+480180>>2]&2;c=y[b+12|0];h:{if(c&4){break h}d=i&65535;if(d>>>0<(f&65535)>>>0){break h}while(1){i:{j:{switch(y[e+3|0]-9|0){case 4:if(!_K(x[qn(a)+8>>2],1)){break i}d=1;v[e+2|0]=1;v[e+4|0]=y[e+5|0];v[e+3|0]=y[b+10|0];v[e+5|0]=y[b+11|0];break a;case 0:break j;default:break i}}k:{if(h){c=y[e+5|0];if(c>>>0>128){break i}v[e+2|0]=2;v[e+3|0]=y[b+10|0];a=1;break k}v[e+2|0]=2;v[e+3|0]=y[b+10|0];c=y[e+5|0];a=2}v[e+4|0]=a+(c&255)>>>a;v[e+5|0]=y[b+11|0];break c}e=e+6|0;f=f+1|0;if(d>>>0>=(f&65535)>>>0){continue}break}c=y[b+12|0]}l:{m:{if(c&4){d=y[b+11|0];e=13;n:{switch(y[b+10|0]-1|0){case 1:d=gl(D(h?2:4,d));c=y[b+12|0];e=9;break;case 0:break n;default:break l}}v[b+11|0]=d;v[b+10|0]=e;c=c&254;break m}e=y[b+11|0];v[g+14|0]=e;f=b;d=y[b+10|0];o:{if(!(!h|(d|0)!=9)){if(e>>>0>128){break l}d=2;e=(e&254)>>>1|0;break o}v[g+15|0]=d;if(!Zx(g+15|0,g+14|0,1)){c=y[b+12|0];break l}c=y[b+12|0];d=y[g+15|0];if(!d){break l}e=y[g+14|0]}v[f+11|0]=e;v[b+10|0]=d;c=c&254}v[b+12|0]=c}d=1;if(c&1){break g}v[b+12|0]=c^4;if(Ll(a,b)){break a}}c=x[b>>2];p:{if((c|0)==1){if(A[a+12>>2]>x[b+4>>2]+1>>>0){x[b+4>>2]=x[b+4>>2]+1;break p}c=x[b>>2]}if((c|0)!=2){break b}d=0;c=x[b+4>>2];if(!c){break a}x[b+4>>2]=c-1}v[b+12|0]=y[b+12|0]|1;d=Ll(a,b);break a}d=1;break a}d=0}hb=g+16|0;return d|0}function OF(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=hb-128|0;hb=j;a:{b:{c:{if(!ul(f,g,h,i,0,0,0,0)){break c}l=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){k=4;if(n){break e}k=f|h|(g|l)?3:2;break d}k=!(f|h|(g|l))}}s=e>>>16|0;o=s&32767;if((o|0)==32767){break c}if(k){break b}}yd(j+16|0,b,c,d,e,f,g,h,i);b=x[j+16>>2];d=x[j+20>>2];e=x[j+24>>2];c=x[j+28>>2];PF(j,b,d,e,c,b,d,e,c);d=x[j+8>>2];e=x[j+12>>2];h=x[j>>2];i=x[j+4>>2];break a}k=d;p=e&2147483647;n=h;m=i&2147483647;if((ul(b,c,k,p,f,g,h,m)|0)<=0){if(ul(b,c,k,p,f,g,n,m)){h=b;i=c;break a}yd(j+112|0,b,c,d,e,0,0,0,0);d=x[j+120>>2];e=x[j+124>>2];h=x[j+112>>2];i=x[j+116>>2];break a}q=i>>>16&32767;if(o){i=c;h=b}else{yd(j+96|0,b,c,k,p,0,0,0,1081540608);k=x[j+104>>2];h=x[j+108>>2];p=h;o=(h>>>16|0)-120|0;i=x[j+100>>2];h=x[j+96>>2]}if(!q){yd(j+80|0,f,g,n,m,0,0,0,1081540608);n=x[j+88>>2];f=x[j+92>>2];m=f;q=(f>>>16|0)-120|0;g=x[j+84>>2];f=x[j+80>>2]}r=n;t=m&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){m=k-r|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-l|0;l=(p-((k>>>0<r>>>0)+t|0)|0)-(l>>>0>m>>>0)|0;f:{if((l|0)>0|(l|0)>=0){k=h;h=h-f|0;i=i-((f>>>0>k>>>0)+g|0)|0;if(!(h|n|(i|l))){yd(j+32|0,b,c,d,e,0,0,0,0);d=x[j+40>>2];e=x[j+44>>2];h=x[j+32>>2];i=x[j+36>>2];break a}l=l<<1|n>>>31;k=n<<1|i>>>31;break f}l=p<<1|k>>>31;k=k<<1|i>>>31}p=l;l=i<<1|h>>>31;h=h<<1;i=l;o=o-1|0;if((o|0)>(q|0)){continue}break}o=q}m=k-r|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-l|0;l=(p-((k>>>0<r>>>0)+t|0)|0)-(l>>>0>m>>>0)|0;m=l;g:{if((l|0)<0){n=k;m=p;break g}k=h;h=h-f|0;i=i-((f>>>0>k>>>0)+g|0)|0;if(h|n|(i|m)){break g}yd(j+48|0,b,c,d,e,0,0,0,0);d=x[j+56>>2];e=x[j+60>>2];h=x[j+48>>2];i=x[j+52>>2];break a}if((m|0)==65535|m>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m<<1|n>>>31;n=c|n<<1;m=b;if(b>>>0<65536){continue}break}}b=s&32768;if((o|0)<=0){yd(j- -64|0,h,i,n,m&65535|(b|o+120)<<16,0,0,0,1065811968);d=x[j+72>>2];e=x[j+76>>2];h=x[j+64>>2];i=x[j+68>>2];break a}d=n;e=m&65535|(b|o)<<16}x[a>>2]=h;x[a+4>>2]=i;x[a+8>>2]=d;x[a+12>>2]=e;hb=j+128|0}function YI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=hb-96|0;hb=j;a:{b:{c:{d:{e:{f:{k=Yo(1,28);if(!k){a=Yj(ec(4));x[114414]=0;T(2042,a|0,75016,26);a=x[114414];x[114414]=0;if((a|0)!=1){break a}break f}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;x[k>>2]=c?c:2031;d=ot(j+80|0);g:{h:{i:{j:{if(!i){break j}c=x[i>>2];if(!c){break j}while(1){k:{e=x[i+4>>2];if(e){x[114414]=0;c=O(118,j- -64|0,c|0)|0;f=x[114414];x[114414]=0;l:{if((f|0)!=1){x[114414]=0;f=O(2043,d|0,c|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break l}x[114414]=0;O(439,f|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break l}break k}i=S(0)|0;break i}i=S(0)|0;xb(c);break i}x[114414]=0;c=O(118,j+48|0,c|0)|0;e=x[114414];x[114414]=0;m:{if((e|0)!=1){x[114414]=0;O(2044,d|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break m}break k}i=S(0)|0;break i}i=S(0)|0;xb(c);break i}xb(c);c=x[i+8>>2];i=i+8|0;if(c){continue}break}}c=x[a+8>>2];e=x[a+4>>2];f=x[a>>2];x[114414]=0;a=R(1404,80)|0;i=x[114414];x[114414]=0;n:{o:{if((i|0)!=1){x[114414]=0;x[j+44>>2]=c;x[j+40>>2]=e;x[j+36>>2]=f;x[j+32>>2]=b;b=O(2045,k|0,k+4|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break o}x[j+16>>2]=b;b=x[ip(j+24|0,j+16|0)>>2];x[114414]=0;c=x[j+44>>2];x[j+8>>2]=x[j+40>>2];x[j+12>>2]=c;c=x[j+36>>2];x[j>>2]=x[j+32>>2];x[j+4>>2]=c;b=Z(2046,a|0,j|0,b|0,d|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break h}i=S(0)|0;pd(j+16|0);break n}i=S(0)|0;break i}i=S(0)|0}_b(a)}Gk(d);Y(i|0)|0;x[114414]=0;X(2023,10712,k|0,g|0,h|0);a=x[114414];x[114414]=0;if((a|0)==1){break g}x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)==1){break f}a=x[k+24>>2];if(a){_b(ys(a))}c=0;x[k+24>>2]=0;a=x[k+20>>2];if(a){_b(a);x[k+20>>2]=0}_b(k);break d}x[k+24>>2]=b;pd(j+16|0);Gk(d);c=k;break d}i=S(0)|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){break e}break b}i=S(0)|0}Y(i|0)|0;c=0;x[114414]=0;X(2023,10712,0,g|0,h|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}_()}hb=j+96|0;return c|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)==1){break b}Q(a|0);p()}S(0)|0;zb()}p()}function sfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=hb-48|0;hb=e;q=x[a+12>>2];g=q;a:{b:{c:{f=x[a+8>>2];d:{if((g|0)<=1&f>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&f>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&f>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&f>>>0>2147483648|g>>>0>1){break b}}q=b+196648|0;break a}q=b+131112|0;break a}q=b+262184|0}v=x[a+16>>2];j=x[a+44>>2];x[e+28>>2]=j;p=x[a+48>>2];x[e+32>>2]=p;h=x[a+52>>2];x[e+36>>2]=h;n=x[a+56>>2];x[e+40>>2]=n;r=x[a+40>>2];s=x[a+36>>2];b=x[a+4>>2];l=b;i=x[a>>2];x[e+16>>2]=i;x[e+20>>2]=b;x[e+8>>2]=f;x[e+12>>2]=g;e:{if(!d){b=r>>12;k=s>>12;break e}while(1){p=1;b=x[e+16>>2];m=((((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+v|0;b=(b>>>16&65520)+q|0;t=w[b+14>>1];u=w[b+12>>1];o=w[b+10>>1];g=w[b+8>>1];n=w[b+6>>1];l=w[b+4>>1];f=w[b+2>>1];i=w[b>>1];j=0;h=1;k=0;while(1){b=k<<1;x[(k<<2)+e>>2]=(((((((D(w[m+(b|-8)>>1],f)+D(w[m+(b|-12)>>1],i)|0)+D(w[m+(b|-4)>>1],l)|0)+D(w[b+m>>1],n)|0)+D(w[m+(b|4)>>1],g)|0)+D(w[m+(b|8)>>1],o)|0)+D(u,w[m+(b|12)>>1])|0)+D(t,w[m+(b|16)>>1])|0)/32768;b=h&1;h=0;k=1;if(b){continue}break}while(1){b=(j<<2)+e|0;l=x[b>>2];k=x[a+60>>2];j=(e+24|0)+(j<<3)|0;f=x[j+4>>2];h=Xb(f,-16777216,16776704);o=x[a+64>>2];t=Xb(x[j+8>>2],-16777216,16776704);i=x[a+68>>2];g=i>>31;x[j+8>>2]=f;n=x[a+72>>2];u=l<<8;f=u;f=yna(k,k>>31,f,f>>31);l=lb;k=f;f=yna(o,o>>31,h,h>>31);o=k+f|0;h=lb+l|0;h=f>>>0>o>>>0?h+1|0:h;f=yna(i,g,t,t>>31);l=f+o|0;i=lb+h|0;i=f>>>0>l>>>0?i+1|0:i;g=b;f=l+8388608|0;b=((f>>>0<8388608?i+1|0:i)&16777215)<<8|f>>>24;x[g>>2]=(b|0)/256;x[j+4>>2]=b-(n&u);j=1;b=p&1;p=0;if(b){continue}break}b=x[a+32>>2];s=x[a+28>>2]+s|0;k=s>>12;x[c>>2]=x[c>>2]+D(k,x[e>>2]);r=b+r|0;b=r>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[e+4>>2]);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}n=x[e+40>>2];h=x[e+36>>2];p=x[e+32>>2];j=x[e+28>>2];i=x[e+16>>2];l=x[e+20>>2]}x[a>>2]=i;x[a+4>>2]=l;x[a+40>>2]=r;x[a+20>>2]=k;x[a+36>>2]=s;x[a+56>>2]=n;x[a+52>>2]=h;x[a+48>>2]=p;x[a+44>>2]=j;x[a+24>>2]=b;hb=e+48|0}function Vea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;e=hb-48|0;hb=e;k=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;r=e,s=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[r+28>>2]=s;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}i=a+8|0;r=e,s=Sf(i,b),x[r+16>>2]=s;x[e+20>>2]=lb;r=e,s=Te(i,d),x[r+40>>2]=s;x[e+44>>2]=lb;tf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}h=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];b=x[a+44>>2];i=x[a+4>>2];f=i;g=x[a>>2];x[e+8>>2]=g;x[e+12>>2]=f;i=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=i;b:{c:{if(!d){i=h;break c}while(1){i=b;f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];g=x[e+12>>2];if(!f){x[e+16>>2]=0;x[e+20>>2]=0}g=g+k|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{f=v[g+x[e+44>>2]|0];x[114414]=0;P(1048,x[e+24>>2],f<<6);f=x[114414];x[114414]=0;if((f|0)==1){break e}x[114414]=0;P(1049,x[e+24>>2],4);f=x[114414];x[114414]=0;if((f|0)==1){break e}f=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(f){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];f=x[b+4>>2];if(f){g=v[g+x[e+44>>2]|0];x[114414]=0;P(1048,b|0,g<<6);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(1049,x[e+24>>2],f|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[e+24>>2];g=x[b>>2];x[b>>2]=g;x[b+4>>2]=0}x[114414]=0;j=O(1050,b|0,x[e+28>>2])|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[a+60>>2];g=Xb(i,-16777216,16776704);f=x[a+64>>2];h=Xb(h,-16777216,16776704);n=x[a+72>>2];o=x[c>>2];j=j<<8;b=yna(b,b>>31,j,j>>31);q=lb;f=yna(f,f>>31,g,g>>31);g=f+b|0;b=lb+q|0;b=g>>>0<f>>>0?b+1|0:b;f=g;g=x[a+68>>2];g=yna(g,g>>31,h,h>>31);h=f+g|0;b=lb+b|0;b=g>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=((h>>>0<8388608?b+1|0:b)&16777215)<<8|h>>>24;h=(b|0)/256|0;x[c>>2]=D(h,m)+o;x[c+4>>2]=x[c+4>>2]+D(h,l);b=b-(j&n)|0;c=c+8|0;Tb(e+8|0,e);h=i;d=d-1|0;if(d){continue}break}g=x[e+8>>2];f=x[e+12>>2]}x[a>>2]=g;x[a+4>>2]=f;x[a+48>>2]=i;x[a+44>>2]=b;hb=e+48|0;return}b=N()|0;x[a+48>>2]=h;x[a+44>>2]=i;Q(b|0);p()}function Vga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=hb+-64|0;hb=d;w[d+62>>1]=c;sg(d+62|0,32);f=jm(a);x[114414]=0;P(772,f|0,z[d+62>>1]);a=x[114414];x[114414]=0;a:{if((a|0)!=1){b:{c:{if(!z[d+62>>1]){break c}while(1){a=z[b+480190>>1]+1|0;w[d+60>>1]=a;d:{e:{if((a&65535)>>>0<4e3){break e}w[d+24>>1]=1;f:{if(!z[b+480190>>1]){break f}while(1){g:{if(Be(Zp(b,z[d+24>>1]))){break g}j=d,k=Lz(bc(f),dc(f),d+24|0),x[j+48>>2]=k;j=d,k=dc(f),x[j+40>>2]=k;if(!Os(d+48|0,d+40|0)){break g}w[d+60>>1]=z[d+24>>1];a=1;if(!z[b+480192>>1]){break f}while(1){c=x[(((a&65535)<<2)+b|0)+900380>>2];h:{if(!c){break h}c=c+236|0;e=Et(c);if((c|0)==(e|0)){break h}while(1){if(z[c>>1]==z[d+60>>1]){w[c>>1]=0}c=c+2|0;if((e|0)!=(c|0)){continue}break}}a=a+1|0;if(z[b+480192>>1]>=(a&65535)>>>0){continue}break}break f}a=z[d+24>>1]+1|0;w[d+24>>1]=a;if(z[b+480190>>1]>=(a&65535)>>>0){continue}break}}if(z[d+60>>1]<4e3){break e}a=Ot(d+48|0);x[114414]=0;c=O(1038,b|0,a|0)|0;e=x[114414];x[114414]=0;i:{j:{if((e|0)==1){break j}k:{if(c){x[114414]=0;O(1039,b|0,a|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break j}e=1;if(!z[b+480192>>1]){break k}while(1){c=x[(((e&65535)<<2)+b|0)+900380>>2];l:{if(!c){break l}c=c+236|0;g=Et(c);if((c|0)==(g|0)){break l}while(1){m:{if(A[a+4>>2]<=z[c>>1]){break m}h=d+40|0;oe(h,a,z[c>>1]);if(Ib(h)){break m}w[c>>1]=0}c=c+2|0;if((g|0)!=(c|0)){continue}break}}e=e+1|0;if(z[b+480192>>1]>=(e&65535)>>>0){continue}break}break k}ce(a);break c}c=d+24|0;Ej(c,a);x[114414]=0;T(1040,d+32|0,c|0,1);c=x[114414];x[114414]=0;if((c|0)!=1){c=d+16|0;Mk(c,a);x[114414]=0;v[d+15|0]=0;X(1041,d+40|0,d+32|0,c|0,d+15|0);c=x[114414];x[114414]=0;if((c|0)!=1){break i}}}c=N()|0;ce(a);break a}Ej(d,a);j=d,k=Mi(d+40|0,d),w[j+60>>1]=k;ce(a);if(z[d+60>>1]>=4e3){break d}}x[114414]=0;P(413,f|0,d+60|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}if(z[b+480190>>1]>=z[d+60>>1]){break d}w[b+480190>>1]=z[d+60>>1]}i=i+1|0;if(z[d+62>>1]>(i&65535)>>>0){continue}break}}hb=d- -64|0;return}c=N()|0;break a}c=N()|0}qf(f);Q(c|0);p()}function tfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;f=hb-48|0;hb=f;q=x[a+12>>2];g=q;a:{b:{c:{e=x[a+8>>2];d:{if((g|0)<=1&e>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&e>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&e>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&e>>>0>2147483648|g>>>0>1){break b}}q=b+196648|0;break a}q=b+131112|0;break a}q=b+262184|0}y=x[a+16>>2];i=x[a+44>>2];x[f+28>>2]=i;p=x[a+48>>2];x[f+32>>2]=p;j=x[a+52>>2];x[f+36>>2]=j;n=x[a+56>>2];x[f+40>>2]=n;r=x[a+40>>2];s=x[a+36>>2];b=x[a+4>>2];k=b;h=x[a>>2];x[f+16>>2]=h;x[f+20>>2]=b;x[f+8>>2]=e;x[f+12>>2]=g;e:{if(!d){b=r>>12;e=s>>12;break e}while(1){b=x[f+16>>2];m=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+y|0;b=(b>>>16&65520)+q|0;l=w[b+14>>1];t=w[b+12>>1];u=w[b+10>>1];o=w[b+8>>1];g=w[b+6>>1];n=w[b+4>>1];k=w[b+2>>1];e=w[b>>1];i=0;p=1;j=1;b=0;while(1){x[(b<<2)+f>>2]=(((((((D(v[m+(b|-4)|0],k)+D(v[m+(b|-6)|0],e)|0)+D(v[m+(b|-2)|0],n)|0)+D(v[b+m|0],g)|0)+D(v[m+(b|2)|0],o)|0)+D(v[m+(b|4)|0],u)|0)+D(t,v[m+(b|6)|0])|0)+D(l,v[m+(b|8)|0])<<8)/32768;h=j&1;j=0;b=1;if(h){continue}break}while(1){b=(i<<2)+f|0;k=x[b>>2];j=x[a+60>>2];i=(f+24|0)+(i<<3)|0;e=x[i+4>>2];l=Xb(e,-16777216,16776704);o=x[a+64>>2];t=Xb(x[i+8>>2],-16777216,16776704);h=x[a+68>>2];g=h>>31;x[i+8>>2]=e;n=x[a+72>>2];u=k<<8;e=u;e=yna(j,j>>31,e,e>>31);k=lb;j=e;e=yna(o,o>>31,l,l>>31);o=j+e|0;l=lb+k|0;l=e>>>0>o>>>0?l+1|0:l;e=yna(h,g,t,t>>31);k=e+o|0;h=lb+l|0;h=e>>>0>k>>>0?h+1|0:h;g=b;e=k+8388608|0;b=((e>>>0<8388608?h+1|0:h)&16777215)<<8|e>>>24;x[g>>2]=(b|0)/256;x[i+4>>2]=b-(n&u);i=1;b=p&1;p=0;if(b){continue}break}b=x[a+32>>2];s=x[a+28>>2]+s|0;e=s>>12;x[c>>2]=x[c>>2]+D(e,x[f>>2]);r=b+r|0;b=r>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[f+4>>2]);c=c+8|0;Tb(f+16|0,f+8|0);d=d-1|0;if(d){continue}break}n=x[f+40>>2];j=x[f+36>>2];p=x[f+32>>2];i=x[f+28>>2];h=x[f+16>>2];k=x[f+20>>2]}x[a>>2]=h;x[a+4>>2]=k;x[a+40>>2]=r;x[a+20>>2]=e;x[a+36>>2]=s;x[a+56>>2]=n;x[a+52>>2]=j;x[a+48>>2]=p;x[a+44>>2]=i;x[a+24>>2]=b;hb=f+48|0}function XZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0;j=hb-1072|0;hb=j;x[j+16>>2]=f;x[j+20>>2]=g;x[j+24>>2]=h;x[j+28>>2]=i;a=j+960|0;x[j+956>>2]=a;k=mw(a,100,7031,j+16|0);x[j+48>>2]=2484;a=j+48|0;n=Pd(j+536|0,0,a);x[j+48>>2]=2484;l=Pd(j+528|0,0,a);m=j+544|0;a:{b:{c:{d:{if(k>>>0>=100){x[114414]=0;a=$(2507)|0;k=x[114414];x[114414]=0;if((k|0)==1){break d}x[j>>2]=f;x[j+4>>2]=g;x[114414]=0;x[j+8>>2]=h;x[j+12>>2]=i;k=Z(2527,j+956|0,a|0,7031,j|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break d}e:{if((k|0)!=-1){we(n,x[j+956>>2]);we(l,sd(k<<2));if(!Aj(l)){break e}}x[114414]=0;V(2485);a=x[114414];x[114414]=0;if((a|0)==1){break d}break a}m=x[l>>2]}x[114414]=0;Dc(j+520|0,d);a=x[114414];x[114414]=0;f:{g:{h:{i:{j:{k:{if((a|0)!=1){x[114414]=0;q=R(2510,j+520|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break k}x[114414]=0;a=x[j+956>>2];Z(2523,q|0,a|0,a+k|0,m|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break k}o=(k|0)>0?y[x[j+956>>2]]==45:o;h=Wb(j+488|0);f=Cg(j+472|0);g=Cg(j+456|0);x[114414]=0;ja(2564,c|0,o|0,j+520|0,j+512|0,j+508|0,j+504|0,h|0,f|0,g|0,j+452|0);a=x[114414];x[114414]=0;if((a|0)==1){break j}x[j+36>>2]=2484;i=Pd(j+40|0,0,j+36|0);c=j+48|0;a=x[j+452>>2];l:{if((a|0)<(k|0)){a=(((Bb(g)+(k-a<<1)|0)+Bb(f)|0)+x[j+452>>2]|0)+1|0;break l}a=((Bb(g)+Bb(f)|0)+x[j+452>>2]|0)+2|0}if(a>>>0<101){break i}we(i,sd(a<<2));c=x[i>>2];if(c){break i}x[114414]=0;V(2485);a=x[114414];x[114414]=0;if((a|0)!=1){break a}break h}k=N()|0;break b}k=N()|0;break f}k=N()|0;break g}a=x[d+4>>2];x[114414]=0;oa(2565,c|0,j+36|0,j+32|0,a|0,m|0,(k<<2)+m|0,q|0,o|0,j+512|0,x[j+508>>2],x[j+504>>2],h|0,f|0,g|0,x[j+452>>2]);a=x[114414];x[114414]=0;if((a|0)!=1){x[114414]=0;a=ga(2539,b|0,c|0,x[j+36>>2],x[j+32>>2],d|0,e|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break c}}}k=N()|0;Jc(i)}Nc(g);Nc(f);xb(h)}Ob(j+520|0);break b}k=N()|0;break b}Jc(i);Nc(g);Nc(f);xb(h);Ob(j+520|0);Jc(l);Jc(n);hb=j+1072|0;return a|0}Jc(l);Jc(n);Q(k|0);p()}p()}function kw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=x[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=x[d>>2];if(!g){break l}if(!a){d=c;break j}x[d>>2]=0;d=c;break k}m:{if(!x[x[114284]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=v[e|0];if(d){x[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}x[a>>2]=0;x[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return wf(e)|0}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=y[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}f=e+1|0;n:{if(!(g&33554432)){break n}if((y[f|0]&192)!=128){e=e-1|0;break d}f=e+2|0;if(!(g&524288)){break n}if((y[f|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=y[e|0];o:{if(e&3|g-1>>>0>126){break o}g=x[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=x[e+4>>2];e=e+4|0;if(!((g-16843009|g)&-2139062144)){continue}break}}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=x[(f<<2)+61440>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=y[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=x[e>>2];if((g|g-16843009)&-2139062144){break s}x[a>>2]=g&255;x[a+4>>2]=y[e+1|0];x[a+8>>2]=y[e+2|0];x[a+12>>2]=y[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=y[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}x[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=x[(f<<2)+61440>>2];f=1;continue}i=y[e|0];f=i>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{h=e+1|0;f=i-128|g<<6;v:{if((f|0)>=0){break v}i=y[h|0]-128|0;if(i>>>0>63){break u}h=e+2|0;f=i|f<<6;if((f|0)>=0){break v}h=y[h|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;x[a>>2]=f;d=d-1|0;a=a+4|0;break t}x[114240]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=y[e|0]}if(g&255){break d}if(a){x[a>>2]=0;x[b>>2]=0}return c-d|0}x[114240]=25;if(!a){break b}}x[b>>2]=e}return-1}x[b>>2]=e;return c|0}function bI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;h=x[a+8>>2];x[e+28>>2]=e+36;x[e+24>>2]=e+40;b=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=b;x[e+16>>2]=a;x[e+20>>2]=e+44;b=x[e+20>>2];x[e>>2]=x[e+16>>2];x[e+4>>2]=b;a:{b:{switch(x[h+40>>2]){case 0:c=hb-80|0;hb=c;b=x[e>>2];d=x[b+4>>2];g=x[b+24>>2];x[c+40>>2]=x[b+20>>2];x[c+44>>2]=g;g=x[b+16>>2];x[c+32>>2]=x[b+12>>2];x[c+36>>2]=g;Nh(c- -64|0,c+32|0,d);b=Mc(c+48|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];f=x[x[e+8>>2]>>2];d=x[c+76>>2];x[c+24>>2]=x[c+72>>2];x[c+28>>2]=d;d=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=d;x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;if(g){k=c+16|0;while(1){d=0;if(f){while(1){j=C[kh(c,d,i)>>3];gc(h,d);j=Qd(Fg(j)*32768);c:{if(F(j)<2147483648){b=~~j;break c}b=-2147483648}b=Uc(b);o=hn(k,d,i),p=b,w[o>>1]=p;d=d+1|0;if((f|0)!=(d|0)){continue}break}}i=i+1|0;if((g|0)!=(i|0)){continue}break}}hb=c+80|0;break a;case 2:kx(e,yb(h));break a;case 3:h=ah(h);d=0;b=hb-80|0;hb=b;c=x[e>>2];i=x[c+4>>2];g=x[c+24>>2];x[b+40>>2]=x[c+20>>2];x[b+44>>2]=g;g=x[c+16>>2];x[b+32>>2]=x[c+12>>2];x[b+36>>2]=g;Nh(b- -64|0,b+32|0,i);c=Mc(b+48|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);i=x[x[e+12>>2]>>2];g=x[x[e+8>>2]>>2];f=x[b+76>>2];x[b+24>>2]=x[b+72>>2];x[b+28>>2]=f;f=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=f;x[b+8>>2]=x[c+8>>2];f=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=f;if(i){k=b+16|0;l=h+16|0;while(1){c=0;if(g){while(1){j=C[kh(b,c,d)>>3];f=$e(h,c);m=f;f=Cj(Qd(j*134217728))+(x[f>>2]>>1)|0;n=f;f=ps(l)+f&-4096;x[m>>2]=n-f;j=Qd(Fg(+(f|0)*7.450580596923828e-9)*32768);d:{if(F(j)<2147483648){f=~~j;break d}f=-2147483648}f=Uc(f);o=hn(k,c,d),p=f,w[o>>1]=p;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((i|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:kx(e,yb(h));break a;default:break b}}kx(e,yb(h))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function Vaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;c=hb-208|0;hb=c;j=1;h=x[a+12>>2];i=1<<h;m=2;g=h;if(g>>>0>=2){f=i;while(1){l=f>>>2|0;if(f>>>0>=4){v=l>>>0<=1?1:l;w=D(j,3);y=j<<1;g=0;while(1){e=c+192|0;mL(e,vc(a,g<<1));f=c+176|0;mL(f,vc(a,g));Rh(c+160|0,f,e);f=g<<m;r=j+f|0;if(f>>>0<r>>>0){while(1){d=vc(b,f);e=x[d+12>>2];x[c+152>>2]=x[d+8>>2];x[c+156>>2]=e;e=x[d+4>>2];x[c+144>>2]=x[d>>2];x[c+148>>2]=e;s=f+j|0;d=vc(b,s);e=x[d+12>>2];x[c+136>>2]=x[d+8>>2];x[c+140>>2]=e;e=x[d+4>>2];x[c+128>>2]=x[d>>2];x[c+132>>2]=e;t=f+y|0;d=vc(b,t);e=x[d+12>>2];x[c+120>>2]=x[d+8>>2];x[c+124>>2]=e;e=x[d+4>>2];x[c+112>>2]=x[d>>2];x[c+116>>2]=e;u=f+w|0;d=vc(b,u);e=x[d+12>>2];x[c+104>>2]=x[d+8>>2];x[c+108>>2]=e;e=x[d+4>>2];x[c+96>>2]=x[d>>2];x[c+100>>2]=e;n=c+80|0;d=c+144|0;e=c+128|0;Ak(n,d,e);o=c- -64|0;Fi(o,d,e);p=c+48|0;d=c+112|0;e=c+96|0;Ak(p,d,e);k=c+16|0;Fi(k,d,e);q=c+32|0;Rh(q,35024,k);Ak(k,n,p);d=vc(b,f);e=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=e;e=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=e;Ak(c,o,q);Rh(k,c+192|0,c);d=vc(b,s);e=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=e;e=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=e;Fi(c,n,p);Rh(k,c+176|0,c);d=vc(b,t);e=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=e;e=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=e;Fi(c,o,q);Rh(k,c+160|0,c);d=vc(b,u);e=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=e;e=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=e;f=f+1|0;if((r|0)!=(f|0)){continue}break}}g=g+1|0;if((v|0)!=(g|0)){continue}break}g=x[a+12>>2]}j=j<<2;f=l;m=m+2|0;if(m>>>0<=g>>>0){continue}break}}if(!(!(g&1)|!h)){g=i>>>1|0;l=g>>>0<=1?1:g;f=0;while(1){i=f+g|0;h=vc(b,i);a=x[h+12>>2];x[c+200>>2]=x[h+8>>2];x[c+204>>2]=a;a=x[h+4>>2];x[c+192>>2]=x[h>>2];x[c+196>>2]=a;h=c+192|0;Fi(c+176|0,vc(b,f),h);i=vc(b,i);a=x[c+188>>2];x[i+8>>2]=x[c+184>>2];x[i+12>>2]=a;a=x[c+180>>2];x[i>>2]=x[c+176>>2];x[i+4>>2]=a;ay(vc(b,f),h);f=f+1|0;if((l|0)!=(f|0)){continue}break}}hb=c+208|0}function Wea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-48|0;hb=e;l=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;m=e,n=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[m+28>>2]=n;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}f=a+8|0;m=e,n=Sf(f,b),x[m+16>>2]=n;x[e+20>>2]=lb;m=e,n=Te(f,d),x[m+40>>2]=n;x[e+44>>2]=lb;tf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];g=b;f=x[a>>2];x[e+8>>2]=f;x[e+12>>2]=b;b=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=b;b:{c:{if(!d){b=i>>12;h=j>>12;break c}while(1){f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];g=(((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=g+l|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{h=x[e+40>>2];g=(x[e+44>>2]&2147483647)<<1|h>>>31;h=w[(g<<1|2)+f>>1];g=w[f+((g&2147483646)<<1)>>1];x[114414]=0;P(1048,x[e+24>>2],(g+h|0)/8<<16>>16);g=x[114414];x[114414]=0;if((g|0)==1){break e}x[114414]=0;P(1049,x[e+24>>2],4);g=x[114414];x[114414]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];g=x[b+4>>2];if(g){k=x[e+40>>2];h=(x[e+44>>2]&2147483647)<<1|k>>>31;k=w[(h<<1|2)+f>>1];f=w[f+((h&2147483646)<<1)>>1];x[114414]=0;P(1048,b|0,(f+k|0)/8<<16>>16);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(1049,x[e+24>>2],g|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[e+24>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114414]=0;f=O(1050,b|0,x[e+28>>2])|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[a+32>>2];j=x[a+28>>2]+j|0;h=j>>12;x[c>>2]=x[c>>2]+D(f,h);i=b+i|0;b=i>>12;x[c+4>>2]=x[c+4>>2]+D(f,b);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}f=x[e+8>>2];g=x[e+12>>2]}x[a>>2]=f;x[a+4>>2]=g;x[a+40>>2]=i;x[a+20>>2]=h;x[a+36>>2]=j;x[a+24>>2]=b;hb=e+48|0;return}b=N()|0;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;Q(b|0);p()}function tn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;x[b+88>>2]=x[b+88>>2]|524288;a:{b:{if(!(y[a+480208|0]&8)){if($b(a+1074312|0,15)){break b}}if(x[a+480180>>2]!=268435456){break a}}c=c?c:y[b+831|0];v[b+832|0]=c;v[b+831|0]=c}if(c){x[b+776>>2]=c}c:{d:{if(Dj(b)){c=x[b+776>>2];if(!c){break d}e=x[a+1074392>>2];d=x[b+708>>2];if(!(!((c|0)<0&(d|0)>0)&((c|0)<=0|(d|0)>=0))){c=0-c|0;x[b+776>>2]=c}f=x[b+880>>2];g=(+(e>>>0)+1)*+(c|0)/+A[a+1074416>>2];e:{if(F(g)<2147483648){a=~~g;break e}a=-2147483648}x[b+880>>2]=a;if(y[b+90|0]&16){a=D(x[x[x[b+656>>2]+44>>2]+36>>2]+1|0,a);x[b+880>>2]=a}a=a-(e?f:0)|0;c=a>>31;e=d>>31;if((e^d)-e>>>0<=(a^c)-c>>>0){if(!d){break d}x[b+708>>2]=0;x[b+876>>2]=d+x[b+876>>2];break c}x[b+708>>2]=d-a;x[b+876>>2]=a+x[b+876>>2];break c}e=1;f:{if(!(v[b+872|0]&1)|x[a+480180>>2]&524352){break f}if(x[a+1074416>>2]==1){if($b(a+1074312|0,6)){break f}}e=0;if(x[a+480180>>2]!=8){break f}e=(y[a+480208|0]&2)>>>1|0}f=x[b+776>>2];h=x[a+480180>>2];i=y[b+872|0];j=x[a+480180>>2];c=x[b+700>>2];g:{if(!c){d=x[b+708>>2];c=0;break g}d=x[b+708>>2];if(!d){break g}k=e;e=(h|0)==268435456&(f|0)>239;if(!((e?i:k)&1)){break g}e=e?f-240|0:f;e=(j|0)==64?D(e,10):e;h:{if((c|0)<(d|0)){i:{j:{if(!(y[a+480208|0]&16)){break j}c=x[b+700>>2];if(x[a+480180>>2]==4){break j}d=x[((e>>>0>=255?255:e)<<2)+30400>>2];d=yna(d,d>>31,c,c>>31);c=lb;d=d+32768|0;c=d>>>0<32768?c+1|0:c;d=Cc(zna(d,c,65536,0),lb);c=x[b+700>>2];d=d-c|0;d=(d|0)<=1?1:d;break i}d=e<<2}c=c+d|0;d=x[b+708>>2];c=(c|0)<(d|0)?c:d;break h}if((c|0)<=(d|0)){break g}k:{l:{if(!(y[a+480208|0]&16)){break l}c=x[b+700>>2];if(x[a+480180>>2]==4){break l}d=x[((e>>>0>=255?255:e)<<2)+31424>>2];d=yna(d,d>>31,c,c>>31);c=lb;d=d+32768|0;c=d>>>0<32768?c+1|0:c;d=Cc(zna(d,c,65536,0),lb);c=x[b+700>>2];d=d-c|0;d=(d|0)>=-1?-1:d;break k}d=0-(e<<2)|0}c=c+d|0;d=x[b+708>>2];c=(c|0)>(d|0)?c:d}x[b+700>>2]=c}if((c|0)!=(d|0)){break d}if(!$b(a+1074312|0,25)&x[a+480180>>2]!=1){break d}x[b+708>>2]=0}return}v[b+872|0]=y[b+872|0]|16}function $Z(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0;j=hb-464|0;hb=j;x[j+16>>2]=f;x[j+20>>2]=g;x[j+24>>2]=h;x[j+28>>2]=i;a=j+352|0;x[j+348>>2]=a;k=mw(a,100,7031,j+16|0);x[j+48>>2]=2484;a=j+48|0;n=Pd(j+232|0,0,a);x[j+48>>2]=2484;l=Pd(j+224|0,0,a);m=j+240|0;a:{b:{c:{d:{if(k>>>0>=100){x[114414]=0;a=$(2507)|0;k=x[114414];x[114414]=0;if((k|0)==1){break d}x[j>>2]=f;x[j+4>>2]=g;x[114414]=0;x[j+8>>2]=h;x[j+12>>2]=i;k=Z(2527,j+348|0,a|0,7031,j|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break d}e:{if((k|0)!=-1){we(n,x[j+348>>2]);we(l,sd(k));if(!Aj(l)){break e}}x[114414]=0;V(2485);a=x[114414];x[114414]=0;if((a|0)==1){break d}break a}m=x[l>>2]}x[114414]=0;Dc(j+216|0,d);a=x[114414];x[114414]=0;f:{g:{h:{i:{j:{k:{if((a|0)!=1){x[114414]=0;q=R(21,j+216|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break k}x[114414]=0;a=x[j+348>>2];Z(2503,q|0,a|0,a+k|0,m|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break k}o=(k|0)>0?y[x[j+348>>2]]==45:o;h=Wb(j+192|0);f=Wb(j+176|0);g=Wb(j+160|0);x[114414]=0;ja(2562,c|0,o|0,j+216|0,j+208|0,j+207|0,j+206|0,h|0,f|0,g|0,j+156|0);a=x[114414];x[114414]=0;if((a|0)==1){break j}x[j+36>>2]=2484;i=Pd(j+40|0,0,j+36|0);c=j+48|0;a=x[j+156>>2];l:{if((a|0)<(k|0)){a=(((Bb(g)+(k-a<<1)|0)+Bb(f)|0)+x[j+156>>2]|0)+1|0;break l}a=((Bb(g)+Bb(f)|0)+x[j+156>>2]|0)+2|0}if(a>>>0<101){break i}we(i,sd(a));c=x[i>>2];if(c){break i}x[114414]=0;V(2485);a=x[114414];x[114414]=0;if((a|0)!=1){break a}break h}k=N()|0;break b}k=N()|0;break f}k=N()|0;break g}a=x[d+4>>2];x[114414]=0;oa(2563,c|0,j+36|0,j+32|0,a|0,m|0,k+m|0,q|0,o|0,j+208|0,v[j+207|0],v[j+206|0],h|0,f|0,g|0,x[j+156>>2]);a=x[114414];x[114414]=0;if((a|0)!=1){x[114414]=0;a=ga(17,b|0,c|0,x[j+36>>2],x[j+32>>2],d|0,e|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break c}}}k=N()|0;Jc(i)}xb(g);xb(f);xb(h)}Ob(j+216|0);break b}k=N()|0;break b}Jc(i);xb(g);xb(f);xb(h);Ob(j+216|0);Jc(l);Jc(n);hb=j+464|0;return a|0}Jc(l);Jc(n);Q(k|0);p()}p()}function oO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;a:{if(!Be(a)){break a}Dn(a);if(c){n=hb-16|0;hb=n;if(Be(a)){r=b+1304360|0;d=b+1074984|0;c=z[a+34>>1];f=c&4;s=c&2;l=c&16;t=c&8;g=x[a+8>>2];o=x[a+4>>2];h=x[a+16>>2];p=x[a+12>>2];while(1){b:{if(x[d+104>>2]!=(a|0)){break b}e=x[d+76>>2];if(!e){break b}c:{d:{e:{f:{m=x[a>>2];if(!t|(h>>>0<=p>>>0|h>>>0>m>>>0)){break f}i=x[d+88>>2];if(i&2048){break f}x[d+84>>2]=h;x[d+80>>2]=p;e=h;c=l;break e}if(!s|(g>>>0<=o>>>0|g>>>0>m>>>0)){break d}x[d+84>>2]=g;x[d+80>>2]=o;i=x[d+88>>2];e=g;c=f}x[d+76>>2]=e;k=i|2;q=d+88|0;i=(c|0)!=0;c=1;break c}q=d+88|0;k=x[d+88>>2]&-3;i=0;c=0}j=c;k=k&-5|(i?c?4:0:0);x[d+88>>2]=k;if(A[d+4>>2]>e>>>0){k=k&-129;x[d+88>>2]=k;c=x[d+80>>2];x[d>>2]=0;x[d+4>>2]=c}if(!i){x[q>>2]=k&-129}if(j){break b}x[d+76>>2]=m}d=d+896|0;if((r|0)!=(d|0)){continue}break}}hb=n+16|0}if((Rq(a)|0)==2){d=0;h=hb-48|0;hb=h;e=Je(a);l=e<<6;g=x[a+20>>2];f=g+(D(e,x[a>>2])<<1)|0;while(1){if(e){j=D(d,e);i=D(e,d^-1);c=0;while(1){w[f+(c+j<<1)>>1]=z[f+(c-e<<1)>>1];w[g+(c+i<<1)>>1]=z[g+(c<<1)>>1];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=f+(e<<5)|0;c=z[a+34>>1];if(c&2){f=x[a+4>>2];j=x[a+8>>2]-f|0;nO(h+24|0,d,g+(D(e,f)<<1)|0,j,e,(c&4)>>>2|0,$b(b+1074312|0,33));c=z[a+34>>1]}if(c&8){f=x[a+16>>2];a=x[a+12>>2];f=f-a|0;nO(h,d+(l<<1)|0,g+(D(a,e)<<1)|0,f,e,(c&16)>>>4|0,$b(b+1074312|0,33))}hb=h+48|0;return}if((Rq(a)|0)!=1){break a}d=0;h=hb-48|0;hb=h;e=Je(a);l=e<<6;g=x[a+20>>2];f=g+D(e,x[a>>2])|0;while(1){if(e){j=D(d,e);i=D(e,d^-1);c=0;while(1){v[f+(c+j|0)|0]=y[f+(c-e|0)|0];v[g+(c+i|0)|0]=y[c+g|0];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=f+(e<<4)|0;c=z[a+34>>1];if(c&2){f=x[a+4>>2];j=x[a+8>>2]-f|0;mO(h+24|0,d,g+D(e,f)|0,j,e,(c&4)>>>2|0,$b(b+1074312|0,33));c=z[a+34>>1]}if(c&8){f=x[a+16>>2];a=x[a+12>>2];f=f-a|0;mO(h,d+l|0,g+D(a,e)|0,f,e,(c&16)>>>4|0,$b(b+1074312|0,33))}hb=h+48|0}}function $r(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return sd(b)}if(b>>>0>=4294967232){x[114240]=48;return 0}g=b>>>0<11?16:b+11&-8;f=a-8|0;j=x[f+4>>2];e=j&-8;a:{if(!(j&3)){if(g>>>0<256){break a}if(e>>>0>=g+4>>>0){c=f;if(e-g>>>0<=x[114410]<<1>>>0){break a}}c=0;break a}h=e+f|0;b:{if(e>>>0>=g>>>0){d=e-g|0;if(d>>>0<16){break b}x[f+4>>2]=j&1|g|2;c=f+g|0;x[c+4>>2]=d|3;x[h+4>>2]=x[h+4>>2]|1;_r(c,d);break b}if(x[114296]==(h|0)){e=e+x[114293]|0;if(e>>>0<=g>>>0){break a}x[f+4>>2]=j&1|g|2;d=f+g|0;c=e-g|0;x[d+4>>2]=c|1;x[114293]=c;x[114296]=d;break b}if(x[114295]==(h|0)){d=e+x[114292]|0;if(d>>>0<g>>>0){break a}c=d-g|0;c:{if(c>>>0>=16){x[f+4>>2]=j&1|g|2;e=f+g|0;x[e+4>>2]=c|1;d=d+f|0;x[d>>2]=c;x[d+4>>2]=x[d+4>>2]&-2;break c}x[f+4>>2]=d|j&1|2;c=d+f|0;x[c+4>>2]=x[c+4>>2]|1;c=0;e=0}x[114295]=e;x[114292]=c;break b}d=x[h+4>>2];if(d&2){break a}k=e+(d&-8)|0;if(k>>>0<g>>>0){break a}m=k-g|0;d:{if(d>>>0<=255){e=x[h+8>>2];c=d>>>3|0;d=x[h+12>>2];if((d|0)==(e|0)){n=457160,o=x[114290]&Cna(-2,c),x[n>>2]=o;break d}x[e+12>>2]=d;x[d+8>>2]=e;break d}l=x[h+24>>2];i=x[h+12>>2];e:{if((i|0)!=(h|0)){c=x[h+8>>2];x[c+12>>2]=i;x[i+8>>2]=c;break e}f:{e=h+20|0;c=x[e>>2];if(c){break f}e=h+16|0;c=x[e>>2];if(c){break f}i=0;break e}while(1){d=e;i=c;e=c+20|0;c=x[e>>2];if(c){continue}e=i+16|0;c=x[i+16>>2];if(c){continue}break}x[d>>2]=0}if(!l){break d}d=x[h+28>>2];c=(d<<2)+457464|0;g:{if(x[c>>2]==(h|0)){x[c>>2]=i;if(i){break g}n=457164,o=x[114291]&Cna(-2,d),x[n>>2]=o;break d}x[(x[l+16>>2]==(h|0)?16:20)+l>>2]=i;if(!i){break d}}x[i+24>>2]=l;c=x[h+16>>2];if(c){x[i+16>>2]=c;x[c+24>>2]=i}c=x[h+20>>2];if(!c){break d}x[i+20>>2]=c;x[c+24>>2]=i}if(m>>>0<=15){x[f+4>>2]=j&1|k|2;c=f+k|0;x[c+4>>2]=x[c+4>>2]|1;break b}x[f+4>>2]=j&1|g|2;d=f+g|0;x[d+4>>2]=m|3;c=f+k|0;x[c+4>>2]=x[c+4>>2]|1;_r(d,m)}c=f}if(c){return c+8|0}f=sd(b);if(!f){return 0}c=x[a-4>>2];c=(c&3?-4:-8)+(c&-8)|0;sc(f,a,b>>>0>c>>>0?c:b);_b(a);return f}function zi(a,b,c,d,e,f){var g=0,h=0,i=0,j=E(0),k=E(0),l=0,m=0,n=E(0),o=E(0),p=0;if(!(mb[x[x[a>>2]+132>>2]](a)|0)){g=y[x[a+20>>2]+25|0]}j=B[x[a+20>>2]+144>>2];k=E(1);if(!(mb[x[x[a>>2]+132>>2]](a)|0)){k=B[x[a+20>>2]+144>>2]}j=E(E(1)-j);a:{if((mb[x[x[a>>2]+148>>2]](a)|0)<=0){break a}if(!QJ(x[a+20>>2])){break a}j=E(E(j+j)+E(-1));k=E(-j)}n=B[a+4196>>2];k=E(n*k);j=E(n*j);l=a+44|0;m=Od(l,0);l=Od(l,1);b:{c:{switch(g|0){case 4:if(!f){break b}while(1){g=i<<2;h=g+b|0;p=h;k=E(B[g+m>>2]+B[h>>2]);h=c+g|0;B[p>>2]=E(k-E(B[g+l>>2]+E(k+B[h>>2])))+E(B[d+g>>2]*j);B[h>>2]=E(B[e+g>>2]*j)-k;i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 3:if(!f){break b}while(1){g=i<<2;h=g+b|0;B[h>>2]=E(E(B[g+m>>2]*j)-B[d+g>>2])+B[h>>2];h=c+g|0;B[h>>2]=E(E(B[g+l>>2]*j)-B[e+g>>2])+B[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 2:if(!f){break b}while(1){g=i<<2;h=g+b|0;B[h>>2]=E(B[h>>2]+B[d+g>>2])-E(B[g+m>>2]*k);h=c+g|0;B[h>>2]=E(B[h>>2]+B[e+g>>2])-E(B[g+l>>2]*k);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 1:if(!f){break b}while(1){g=i<<2;h=g+b|0;B[h>>2]=E(B[h>>2]+B[g+m>>2])-E(B[d+g>>2]*j);h=c+g|0;B[h>>2]=E(B[h>>2]+B[g+l>>2])-E(B[e+g>>2]*j);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 0:if(!f){break b}while(1){g=i<<2;h=g+b|0;B[h>>2]=E(E(B[g+m>>2]*k)+E(B[d+g>>2]*j))+B[h>>2];h=c+g|0;B[h>>2]=E(E(B[g+l>>2]*k)+E(B[e+g>>2]*j))+B[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 5:break c;default:break b}}g=QJ(x[a+20>>2]);if(!f){break b}j=g?E(j*E(.5)):j;k=g?E(k*E(.5)):k;while(1){g=i<<2;h=g+b|0;n=E(B[d+g>>2]-B[g+m>>2]);o=E(B[g+l>>2]-B[e+g>>2]);B[h>>2]=E(B[h>>2]+E(n*j))+E(o*k);g=c+g|0;B[g>>2]=E(E(o*j)+E(n*k))+B[g>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break}}d:{if(!((y[x[a+20>>2]+24|0]&4)>>>2|0)){break d}if(mb[x[x[a>>2]+132>>2]](a)|!f){break d}d=0;while(1){a=d<<2;e=a+b|0;B[e>>2]=B[e>>2]+B[a+m>>2];e=a+c|0;B[e>>2]=B[e>>2]+B[a+l>>2];d=d+1|0;if((f|0)!=(d|0)){continue}break}}}function Z4(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=hb+-64|0;hb=k;a:{b:{c:{j=Yo(1,32);d:{e:{if(!j){a=Yj(ec(4));x[114414]=0;T(2042,a|0,75016,26);a=x[114414];x[114414]=0;if((a|0)!=1){break a}i=S(0)|0;break e}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;x[j>>2]=c?c:2031;d=ot(k+48|0);f:{g:{h:{i:{if(!i){break i}c=x[i>>2];if(!c){break i}while(1){j:{e=x[i+4>>2];if(e){x[114414]=0;c=O(118,k+32|0,c|0)|0;f=x[114414];x[114414]=0;k:{if((f|0)!=1){x[114414]=0;f=O(2043,d|0,c|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break k}x[114414]=0;O(439,f|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break k}break j}i=S(0)|0;break h}i=S(0)|0;xb(c);break h}x[114414]=0;c=O(118,k+16|0,c|0)|0;e=x[114414];x[114414]=0;l:{if((e|0)!=1){x[114414]=0;O(2044,d|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break l}break j}i=S(0)|0;break h}i=S(0)|0;xb(c);break h}xb(c);c=x[i+8>>2];i=i+8|0;if(c){continue}break}}x[114414]=0;c=R(1404,96)|0;e=x[114414];x[114414]=0;m:{n:{if((e|0)!=1){x[114414]=0;e=O(2045,j|0,j+4|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break n}x[k>>2]=e;e=x[ip(k+8|0,k)>>2];x[114414]=0;a=aa(2120,c|0,a|0,b|0,e|0,d|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break g}i=S(0)|0;pd(k);break m}i=S(0)|0;break h}i=S(0)|0}_b(c)}Gk(d);Y(i|0)|0;x[114414]=0;X(2023,1480,j|0,g|0,h|0);a=x[114414];x[114414]=0;if((a|0)==1){break f}x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){a=x[j+28>>2];if(a){mb[x[x[a>>2]+4>>2]](a)}x[j+24>>2]=0;x[j+28>>2]=0;a=x[j+20>>2];if(a){_b(a);x[j+20>>2]=0}_b(j);j=0;break d}i=S(0)|0;break e}x[j+28>>2]=a;pd(k);a=x[j+28>>2];x[j+24>>2]=a?a+8|0:0;Gk(d);break d}i=S(0)|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)==1){break b}}Y(i|0)|0;j=0;x[114414]=0;X(2023,1480,0,g|0,h|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}_()}hb=k- -64|0;return j|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)==1){break b}Q(a|0);p()}S(0)|0;zb()}p()}function cI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;h=x[a+8>>2];x[e+28>>2]=e+36;x[e+24>>2]=e+40;b=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=b;x[e+16>>2]=a;x[e+20>>2]=e+44;b=x[e+20>>2];x[e>>2]=x[e+16>>2];x[e+4>>2]=b;a:{b:{switch(x[h+40>>2]){case 0:c=hb-80|0;hb=c;b=x[e>>2];d=x[b+4>>2];g=x[b+24>>2];x[c+40>>2]=x[b+20>>2];x[c+44>>2]=g;g=x[b+16>>2];x[c+32>>2]=x[b+12>>2];x[c+36>>2]=g;Nh(c- -64|0,c+32|0,d);b=Mc(c+48|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];f=x[x[e+8>>2]>>2];d=x[c+76>>2];x[c+24>>2]=x[c+72>>2];x[c+28>>2]=d;d=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=d;x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;if(g){b=c+16|0;while(1){d=0;if(f){while(1){j=x[Rf(c,d,i)>>2];gc(h,d);j=j-2147481600>>>12|0;j=j>>>0<=491520?491520:j;n=hn(b,d,i),o=(j|0)>=557055?557055:j,w[n>>1]=o;d=d+1|0;if((f|0)!=(d|0)){continue}break}}i=i+1|0;if((g|0)!=(i|0)){continue}break}}hb=c+80|0;break a;case 2:lx(e,yb(h));break a;case 3:h=ah(h);d=0;b=hb-80|0;hb=b;c=x[e>>2];i=x[c+4>>2];g=x[c+24>>2];x[b+40>>2]=x[c+20>>2];x[b+44>>2]=g;g=x[c+16>>2];x[b+32>>2]=x[c+12>>2];x[b+36>>2]=g;Nh(b- -64|0,b+32|0,i);c=Mc(b+48|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);i=x[x[e+12>>2]>>2];g=x[x[e+8>>2]>>2];f=x[b+76>>2];x[b+24>>2]=x[b+72>>2];x[b+28>>2]=f;f=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=f;x[b+8>>2]=x[c+8>>2];f=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=f;if(i){j=b+16|0;l=h+16|0;while(1){c=0;if(g){while(1){f=x[Rf(b,c,d)>>2];k=$e(h,c);f=f+(x[k>>2]>>1)|0;m=f;f=ps(l)+f&-4096;x[k>>2]=m-f;f=f-2147481600>>>12|0;f=f>>>0<=491520?491520:f;n=hn(j,c,d),o=(f|0)>=557055?557055:f,w[n>>1]=o;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((i|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:lx(e,yb(h));break a;default:break b}}lx(e,yb(h))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=hb-48|0;hb=e;p=x[a+12>>2];i=p;a:{b:{c:{f=x[a+8>>2];d:{if((i|0)<=1&f>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&f>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&f>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&f>>>0>2147483648|i>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}t=x[a+16>>2];b=x[a+44>>2];x[e+28>>2]=b;h=x[a+48>>2];x[e+32>>2]=h;j=x[a+52>>2];x[e+36>>2]=j;o=x[a+56>>2];x[e+40>>2]=o;u=x[a+24>>2];v=x[a+20>>2];k=x[a+4>>2];g=x[a>>2];x[e+16>>2]=g;x[e+20>>2]=k;x[e+8>>2]=f;x[e+12>>2]=i;if(d){while(1){o=1;b=x[e+16>>2];m=((((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(b>>>16&65520)+p|0;l=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];n=w[b+8>>1];s=w[b+6>>1];i=w[b+4>>1];k=w[b+2>>1];f=w[b>>1];j=0;b=1;h=0;while(1){g=h<<1;x[(h<<2)+e>>2]=(((((((D(w[m+(g|-8)>>1],k)+D(w[m+(g|-12)>>1],f)|0)+D(w[m+(g|-4)>>1],i)|0)+D(w[g+m>>1],s)|0)+D(w[m+(g|4)>>1],n)|0)+D(w[m+(g|8)>>1],r)|0)+D(w[m+(g|12)>>1],q)|0)+D(l,w[m+(g|16)>>1])|0)/32768;g=b;b=0;h=1;if(g){continue}break}while(1){b=(j<<2)+e|0;k=x[b>>2];h=x[a+60>>2];j=(e+24|0)+(j<<3)|0;f=x[j+4>>2];l=Xb(f,-16777216,16776704);n=x[a+64>>2];q=Xb(x[j+8>>2],-16777216,16776704);g=x[a+68>>2];s=g>>31;x[j+8>>2]=f;i=x[a+72>>2];r=k<<8;f=r;f=yna(h,h>>31,f,f>>31);k=lb;h=f;f=yna(n,n>>31,l,l>>31);n=h+f|0;l=lb+k|0;l=f>>>0>n>>>0?l+1|0:l;f=yna(g,s,q,q>>31);k=f+n|0;g=lb+l|0;g=f>>>0>k>>>0?g+1|0:g;h=b;f=k+8388608|0;b=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[h>>2]=(b|0)/256;x[j+4>>2]=b-(i&r);j=1;b=o&1;o=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],v);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],u);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}o=x[e+40>>2];j=x[e+36>>2];h=x[e+32>>2];g=x[e+16>>2];k=x[e+20>>2];b=x[e+28>>2]}x[a>>2]=g;x[a+4>>2]=k;x[a+56>>2]=o;x[a+52>>2]=j;x[a+48>>2]=h;x[a+44>>2]=b;hb=e+48|0}function O3(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=0,f=E(0),g=E(0),h=E(0),i=E(0),k=E(0),m=E(0),n=0;d=hb-16|0;hb=d;a:{b:{c:{d:{switch(b-1|0){case 0:c=B[a+48>>2];a=x[a+48>>2];e:{f:{g:{if((a|0)<=8388607){f=E(E(-1)/E(c*c));if(!(a&2147483647)){break e}f=E(E(c-c)/E(0));if((a|0)<0){break e}a=(q(E(c*E(33554432))),j(2));b=-152;break g}if(a>>>0>2139095039){break f}b=-127;c=E(0);if((a|0)==1065353216){break f}}a=a+4913933|0;m=E((a>>>23|0)+b|0);c=E((l(2,(a&8388607)+1060439283|0),r())+E(-1));g=E(c*E(c*E(.5)));h=E(c/E(c+E(2)));i=E(h*h);k=E(i*i);f=c;c=(l(2,(q(E(c-g)),j(2))&-4096),r());g=E(E(h*E(g+E(E(i*E(E(k*E(.2849878668785095))+E(.6666666269302368)))+E(k*E(E(k*E(.24279078841209412))+E(.40000972151756287))))))+E(E(f-c)-g));c=E(E(m*E(.3010292053222656))+E(E(c*E(.434326171875))+E(E(g*E(.434326171875))+E(E(m*E(7.903415166765626e-7))+E(E(g+c)*E(-3168997136526741e-20))))))}f=c}c=E(f*E(2e3));if(!(E(F(c))<E(2147483648))){break c}a=~~c;break b;case 1:a=(D(x[x[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:b=hb-16|0;hb=b;h:{i:{j:{k:{a=y[x[a+24>>2]+24648|0];if(a>>>0>=6){a=ec(8);x[114414]=0;b=O(118,b|0,1613)|0;d=x[114414];x[114414]=0;if((d|0)==1){break k}a=oc(a,b);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break i}d=N()|0;xb(b);break j}hb=b+16|0;a=x[(a<<24>>24<<2)+37664>>2];break h}d=N()|0;hc(a)}Q(d|0)}p()}break b;case 3:x[d>>2]=0;b=hb-80|0;hb=b;a=x[a+24>>2]+24604|0;x[b+40>>2]=x[a+32>>2];x[b>>2]=x[a+36>>2];e=b+40|0;n=x[Bf(e,b)>>2];l:{if(x[a+32>>2]==x[Vp(e)+32>>2]){e=-1;if(x[a+36>>2]==x[Vp(b)+36>>2]){break l}}e=0;if((n|0)<=0){break l}e=(n+500>>>0)/1e3|0}x[d>>2]=e;hb=b+80|0;a=x[d>>2];break b;default:break d}}a=ec(8);x[114414]=0;d=O(118,d|0,6366)|0;b=x[114414];x[114414]=0;m:{if((b|0)!=1){a=oc(a,d);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}b=N()|0;xb(d);break m}b=N()|0;hc(a)}Q(b|0);p()}a=-2147483648}hb=d+16|0;return a|0}p()}function P6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,p=0,q=E(0),r=E(0),s=0,t=0,u=0,v=0,w=E(0),y=E(0),z=0,A=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=E(0),O=E(0),P=E(0),Q=E(0),R=E(0);k=a+44|0;if(Bh(k)){z=Od(k,0);A=Od(k,1);C=ld(k,0);D=ld(k,1);m=x[a+4300>>2];p=x[a+4296>>2];if(d){j=a+4304|0;i=p+1|0;s=i+x[a+4272>>2]&4095;n=j+(s<<4)|0;t=i+x[a+4276>>2]&4095;f=((t<<4)+j|0)+4|0;u=i+x[a+4280>>2]&4095;F=((u<<4)+j|0)+8|0;v=i+x[a+4284>>2]&4095;G=((v<<4)+j|0)+12|0;g=x[a+4288>>2]+m|0;o=x[a+4292>>2]+m|0;I=a+69840|0;J=a+78032|0;H=d;while(1){t=t-1&4095;i=((t<<4)+j|0)+4|0;e=B[i>>2];K=g&1023;g=(K<<3)+I|0;h=B[g>>2];N=B[G>>2];O=B[F>>2];P=B[f>>2];Q=B[n>>2];w=B[A>>2];R=B[z>>2];L=m<<3;f=L+I|0;y=B[a+4232>>2];s=s-1&4095;n=(s<<4)+j|0;q=B[n>>2];r=E(E(B[g+4>>2]*y)-E(q*E(.6180340051651001)));B[f>>2]=E(r*E(.6180340051651001))+q;l=e;e=E(E(y*h)+E(e*E(.6180340051651001)));B[f+4>>2]=l-E(e*E(.6180340051651001));B[n>>2]=e;B[i>>2]=r;M=o&1023;f=(M<<3)+J|0;y=B[f+4>>2];u=u-1&4095;o=(u<<4)+j|0;F=o+8|0;h=B[F>>2];q=B[a+4236>>2];l=E(q*B[f>>2]);v=v-1&4095;f=(v<<4)+j|0;G=f+12|0;r=B[G>>2];e=E(l+E(r*E(.6180340051651001)));g=J+L|0;B[g+4>>2]=r-E(e*E(.6180340051651001));l=h;h=E(E(y*q)-E(h*E(.6180340051651001)));B[g>>2]=l+E(h*E(.6180340051651001));B[o+8>>2]=e;B[f+12>>2]=h;l=E(B[n>>2]+e);e=E(R+E(1.0000000031710769e-30));B[C>>2]=l+E(B[a+4224>>2]*e);h=E(w+E(1.0000000031710769e-30));B[D>>2]=E(E(B[a+4224>>2]*h)+B[i>>2])+B[f+12>>2];g=(p<<4)+j|0;w=B[a+4228>>2];e=E(w*e);B[g>>2]=E(E(B[a+4240>>2]*B[n>>2])+e)+E(Q*B[a+4244>>2]);h=E(w*h);B[g+4>>2]=E(E(B[a+4248>>2]*B[i>>2])+h)+E(P*B[a+4252>>2]);B[g+8>>2]=E(E(B[a+4256>>2]*B[o+8>>2])-h)+E(O*B[a+4260>>2]);B[g+12>>2]=E(E(B[a+4264>>2]*B[f+12>>2])+e)+E(N*B[a+4268>>2]);D=D+4|0;C=C+4|0;A=A+4|0;z=z+4|0;o=M-1|0;g=K-1|0;m=m-1&1023;p=p-1&4095;f=i;H=H-1|0;if(H){continue}break}}x[a+4300>>2]=m;x[a+4296>>2]=p;zi(a,b,c,ld(k,0),ld(k,1),d)}}function Xea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-48|0;hb=e;l=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;m=e,n=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[m+28>>2]=n;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}f=a+8|0;m=e,n=Sf(f,b),x[m+16>>2]=n;x[e+20>>2]=lb;m=e,n=Te(f,d),x[m+40>>2]=n;x[e+44>>2]=lb;tf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];g=b;f=x[a>>2];x[e+8>>2]=f;x[e+12>>2]=b;b=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=b;b:{c:{if(!d){b=i>>12;h=j>>12;break c}while(1){f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];g=((x[e+12>>2]&2147483647)<<1|b>>>31)&-2;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=g+l|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{h=x[e+40>>2];g=(x[e+44>>2]&2147483647)<<1|h>>>31;h=v[(g|1)+f|0];g=v[f+(g&-2)|0];x[114414]=0;P(1048,x[e+24>>2],g+h<<5);g=x[114414];x[114414]=0;if((g|0)==1){break e}x[114414]=0;P(1049,x[e+24>>2],4);g=x[114414];x[114414]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];g=x[b+4>>2];if(g){k=x[e+40>>2];h=(x[e+44>>2]&2147483647)<<1|k>>>31;k=v[(h|1)+f|0];f=v[f+(h&-2)|0];x[114414]=0;P(1048,b|0,f+k<<5);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(1049,x[e+24>>2],g|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[e+24>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114414]=0;f=O(1050,b|0,x[e+28>>2])|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[a+32>>2];j=x[a+28>>2]+j|0;h=j>>12;x[c>>2]=x[c>>2]+D(f,h);i=b+i|0;b=i>>12;x[c+4>>2]=x[c+4>>2]+D(f,b);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}f=x[e+8>>2];g=x[e+12>>2]}x[a>>2]=f;x[a+4>>2]=g;x[a+40>>2]=i;x[a+20>>2]=h;x[a+36>>2]=j;x[a+24>>2]=b;hb=e+48|0;return}b=N()|0;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;Q(b|0);p()}function xfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;e=hb-48|0;hb=e;p=x[a+12>>2];g=p;a:{b:{c:{f=x[a+8>>2];d:{if((g|0)<=1&f>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&f>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&f>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&f>>>0>2147483648|g>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}t=x[a+16>>2];b=x[a+44>>2];x[e+28>>2]=b;i=x[a+48>>2];x[e+32>>2]=i;j=x[a+52>>2];x[e+36>>2]=j;o=x[a+56>>2];x[e+40>>2]=o;u=x[a+24>>2];y=x[a+20>>2];m=x[a+4>>2];h=x[a>>2];x[e+16>>2]=h;x[e+20>>2]=m;x[e+8>>2]=f;x[e+12>>2]=g;if(d){while(1){b=x[e+16>>2];k=(((x[e+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=(b>>>16&65520)+p|0;q=w[b+14>>1];l=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];n=w[b+6>>1];g=w[b+4>>1];m=w[b+2>>1];f=w[b>>1];j=0;o=1;i=1;b=0;while(1){x[(b<<2)+e>>2]=(((((((D(v[k+(b|-4)|0],m)+D(v[k+(b|-6)|0],f)|0)+D(v[k+(b|-2)|0],g)|0)+D(v[b+k|0],n)|0)+D(v[k+(b|2)|0],s)|0)+D(v[k+(b|4)|0],r)|0)+D(v[k+(b|6)|0],l)|0)+D(q,v[k+(b|8)|0])<<8)/32768;h=i;i=0;b=1;if(h){continue}break}while(1){b=(j<<2)+e|0;i=x[b>>2];q=x[a+60>>2];j=(e+24|0)+(j<<3)|0;f=x[j+4>>2];l=Xb(f,-16777216,16776704);n=x[a+64>>2];r=Xb(x[j+8>>2],-16777216,16776704);h=x[a+68>>2];g=h>>31;x[j+8>>2]=f;m=x[a+72>>2];s=i<<8;f=s;f=yna(q,q>>31,f,f>>31);i=lb;k=f;f=yna(n,n>>31,l,l>>31);n=k+f|0;l=lb+i|0;l=f>>>0>n>>>0?l+1|0:l;f=yna(h,g,r,r>>31);i=f+n|0;h=lb+l|0;h=f>>>0>i>>>0?h+1|0:h;g=b;f=i+8388608|0;b=((f>>>0<8388608?h+1|0:h)&16777215)<<8|f>>>24;x[g>>2]=(b|0)/256;x[j+4>>2]=b-(m&s);j=1;b=o&1;o=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],y);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],u);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}o=x[e+40>>2];j=x[e+36>>2];i=x[e+32>>2];h=x[e+16>>2];m=x[e+20>>2];b=x[e+28>>2]}x[a>>2]=h;x[a+4>>2]=m;x[a+56>>2]=o;x[a+52>>2]=j;x[a+48>>2]=i;x[a+44>>2]=b;hb=e+48|0}function ZH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;c=x[a+8>>2];x[e+28>>2]=e+36;x[e+24>>2]=e+40;b=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=b;x[e+16>>2]=a;x[e+20>>2]=e+44;b=x[e+20>>2];x[e>>2]=x[e+16>>2];x[e+4>>2]=b;a:{b:{switch(x[c+40>>2]){case 0:b=hb-80|0;hb=b;d=x[e>>2];g=x[d+4>>2];x[b+40>>2]=x[d+20>>2];h=x[d+16>>2];x[b+32>>2]=x[d+12>>2];x[b+36>>2]=h;gn(b- -64|0,b+32|0,g);d=Mc(b+48|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];h=x[x[e+8>>2]>>2];x[b+24>>2]=x[b+72>>2];f=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=f;x[b+8>>2]=x[d+8>>2];f=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=f;if(g){k=b+16|0;while(1){d=0;if(h){while(1){i=C[kh(b,d,j)>>3];gc(c,d);i=Qd(Fg(i)*32768);c:{if(F(i)<2147483648){f=~~i;break c}f=-2147483648}f=Uc(f);o=fn(k,d,j),p=f,w[o>>1]=p;d=d+1|0;if((h|0)!=(d|0)){continue}break}}j=j+1|0;if((g|0)!=(j|0)){continue}break}}hb=b+80|0;break a;case 2:hx(e,yb(c));break a;case 3:j=ah(c);d=0;b=hb-80|0;hb=b;c=x[e>>2];g=x[c+4>>2];x[b+40>>2]=x[c+20>>2];h=x[c+16>>2];x[b+32>>2]=x[c+12>>2];x[b+36>>2]=h;gn(b- -64|0,b+32|0,g);c=Mc(b+48|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];h=x[x[e+8>>2]>>2];x[b+24>>2]=x[b+72>>2];f=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=f;x[b+8>>2]=x[c+8>>2];f=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=f;if(g){k=b+16|0;l=j+16|0;while(1){c=0;if(h){while(1){i=C[kh(b,c,d)>>3];f=$e(j,c);m=f;f=Cj(Qd(i*134217728))+(x[f>>2]>>1)|0;n=f;f=ps(l)+f&-4096;x[m>>2]=n-f;i=Qd(Fg(+(f|0)*7.450580596923828e-9)*32768);d:{if(F(i)<2147483648){f=~~i;break d}f=-2147483648}f=Uc(f);o=fn(k,c,d),p=f,w[o>>1]=p;c=c+1|0;if((h|0)!=(c|0)){continue}break}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:hx(e,yb(c));break a;default:break b}}hx(e,yb(c))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function sK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=hb-16|0;hb=g;h=Fb(g+8|0,b);$t(h);if(x[a>>2]==(b|0)){x[a>>2]=x[h>>2]}d=yb(a);x[d>>2]=x[d>>2]-1;a=x[mc(a)>>2];a:{b:{d=b;e=x[b>>2];if(e){if(!x[b+4>>2]){break b}c=x[b+4>>2];c:{if(!c){if(!Gg(d)){while(1){d=x[d+8>>2];if(!Gg(d)){continue}break}}d=x[d+8>>2];break c}d=kR(c)}e=x[d>>2];if(e){break b}}e=x[d+4>>2];if(e){break b}e=0;i=1;break a}x[e+8>>2]=x[d+8>>2];i=0}d:{e:{if(Gg(d)){x[x[d+8>>2]>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=x[d+8>>2]+4|0;break e}x[x[d+8>>2]+4>>2]=e;c=x[d+8>>2]}c=x[c>>2]}j=!y[d+12|0];if((b|0)!=(d|0)){x[d+8>>2]=x[b+8>>2];f:{if(Gg(b)){f=x[d+8>>2];break f}f=x[d+8>>2]+4|0}x[f>>2]=d;f=x[b>>2];x[d>>2]=f;Pn(f,d);f=x[b+4>>2];x[d+4>>2]=f;if(f){Pn(f,d)}v[d+12|0]=y[b+12|0];a=(a|0)==(b|0)?d:a}if(!(j|!a)){g:{if(i){while(1){d=Gg(c);b=y[c+12|0];h:{i:{if(!d){if(!b){v[c+12|0]=1;v[x[c+8>>2]+12|0]=0;hq(x[c+8>>2]);b=x[c>>2];a=(b|0)==(a|0)?c:a;c=x[b+4>>2]}d=x[c>>2];j:{k:{l:{if(!(y[d+12|0]?0:d)){b=x[c+4>>2];if(y[b+12|0]?0:b){break l}v[c+12|0]=0;m:{b=x[c+8>>2];if((b|0)!=(a|0)){if(y[b+12|0]){break m}a=b}v[a+12|0]=1;break g}if(!Gg(b)){break i}b=x[b+8>>2]+4|0;break h}b=x[c+4>>2];if(!b){break k}}if(!y[b+12|0]){break j}}v[d+12|0]=1;v[c+12|0]=0;gq(c);c=x[c+8>>2]}v[c+12|0]=y[x[c+8>>2]+12|0];v[x[c+8>>2]+12|0]=1;v[x[c+4>>2]+12|0]=1;hq(x[c+8>>2]);break g}if(!b){v[c+12|0]=1;v[x[c+8>>2]+12|0]=0;gq(x[c+8>>2]);b=x[c+4>>2];a=(b|0)==(a|0)?c:a;c=x[b>>2]}d=x[c>>2];n:{if(y[d+12|0]?0:d){break n}b=x[c+4>>2];if(!(y[b+12|0]?0:b)){v[c+12|0]=0;b=x[c+8>>2];if(!((a|0)!=(b|0)?y[b+12|0]:0)){v[b+12|0]=1;break g}if(Gg(b)){b=x[b+8>>2]+4|0;break h}b=x[b+8>>2];break h}if(d){if(!y[d+12|0]){break n}b=x[c+4>>2]}v[b+12|0]=1;v[c+12|0]=0;hq(c);c=x[c+8>>2]}v[c+12|0]=y[x[c+8>>2]+12|0];v[x[c+8>>2]+12|0]=1;v[x[c>>2]+12|0]=1;gq(x[c+8>>2]);break g}b=x[b+8>>2]}c=x[b>>2];continue}}v[e+12|0]=1}}hb=g+16|0;return x[h>>2]}function XI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=hb+-64|0;hb=k;a:{b:{c:{d:{e:{f:{j=Yo(1,28);if(!j){a=Yj(ec(4));x[114414]=0;T(2042,a|0,75016,26);a=x[114414];x[114414]=0;if((a|0)!=1){break a}break f}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;x[j>>2]=c?c:2031;d=ot(k+48|0);g:{h:{i:{j:{if(!i){break j}c=x[i>>2];if(!c){break j}while(1){k:{e=x[i+4>>2];if(e){x[114414]=0;c=O(118,k+32|0,c|0)|0;f=x[114414];x[114414]=0;l:{if((f|0)!=1){x[114414]=0;f=O(2043,d|0,c|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break l}x[114414]=0;O(439,f|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break l}break k}i=S(0)|0;break i}i=S(0)|0;xb(c);break i}x[114414]=0;c=O(118,k+16|0,c|0)|0;e=x[114414];x[114414]=0;m:{if((e|0)!=1){x[114414]=0;O(2044,d|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break m}break k}i=S(0)|0;break i}i=S(0)|0;xb(c);break i}xb(c);c=x[i+8>>2];i=i+8|0;if(c){continue}break}}x[114414]=0;c=R(1404,80)|0;e=x[114414];x[114414]=0;n:{o:{if((e|0)!=1){x[114414]=0;e=O(2045,j|0,j+4|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break o}x[k>>2]=e;e=x[ip(k+8|0,k)>>2];x[114414]=0;a=aa(2047,c|0,a|0,b|0,e|0,d|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break h}i=S(0)|0;pd(k);break n}i=S(0)|0;break i}i=S(0)|0}_b(c)}Gk(d);Y(i|0)|0;x[114414]=0;X(2023,10668,j|0,g|0,h|0);a=x[114414];x[114414]=0;if((a|0)==1){break g}x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)==1){break f}a=x[j+24>>2];if(a){_b(ys(a))}c=0;x[j+24>>2]=0;a=x[j+20>>2];if(a){_b(a);x[j+20>>2]=0}_b(j);break d}x[j+24>>2]=a;pd(k);Gk(d);c=j;break d}i=S(0)|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){break e}break b}i=S(0)|0}Y(i|0)|0;c=0;x[114414]=0;X(2023,10668,0,g|0,h|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}_()}hb=k- -64|0;return c|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)==1){break b}Q(a|0);p()}S(0)|0;zb()}p()}function bja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;v[a|0]=0;c=y[b|0];if(c){v[a|0]=c>>>0>96?-1:c+12|0}v[a+1|0]=y[b+1|0];c=y[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){v[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch(((c&240)+96&240)>>>4|0){case 0:v[a+2|0]=4;c=c&15;break b;case 1:v[a+2|0]=3;c=c&15;break b;case 2:v[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}v[a+2|0]=5;c=c&15}v[a+4|0]=c}c=y[b+6|0];e=y[b+4|0];d=y[b+5|0];d:{if(!(c|(e|d))){break d}e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(e>>>0<=28){switch(e|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((e|0)==128){break e}if((e|0)!=157){break d}v[a+2|0]=15;v[a+3|0]=20;v[a+4|0]=c>>>3;v[f+15|0]=15;h=a,i=y[rc(b+5|0,f+15|0)|0]|208,v[h+5|0]=i;break d}v[a+5|0]=d;v[a+3|0]=c;Fj(a);g=y[b+6|0]==15;break d}v[a+3|0]=2;h=a,i=Vk(c<<4|(d&240)>>>4),v[h+5|0]=i;break d}v[a+3|0]=3;h=a,i=Vk(c<<4|(d&240)>>>4),v[h+5|0]=i;break d}v[a+3|0]=4;h=a,i=Vk(c<<4|(d&240)>>>4),v[h+5|0]=i;break d}v[a+3|0]=5;v[a+5|0]=c&240|(d&240)>>>4;break d}if(d){v[a+5|0]=d;v[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}v[a+5|0]=145;v[a+3|0]=20;break d}v[a+3|0]=13;v[a+5|0]=c>>>1;break d}if(c){v[a+5|0]=c;v[a+3|0]=17;break d}v[a+3|0]=16;v[a+5|0]=d&15;break d}v[a+5|0]=d;v[a+3|0]=c;vz(a,1);g=(y[a+3|0]&254)==16;break d}v[a+5|0]=d;v[a+3|0]=18;break d}v[a+3|0]=31;v[a+5|0]=c>>>1;break d}v[a+3|0]=31;v[a+5|0]=c>>>1&120;break d}v[a+5|0]=159;v[a+3|0]=20;break d}v[a+3|0]=21;v[a+5|0]=c>>>2}b=y[b+3|0];t:{if(!b){break t}if(!y[a+3|0]){v[a+5|0]=b;v[a+3|0]=9;break t}if(y[a+2|0]){break t}v[a+2|0]=2;v[a+4|0]=b>>>2}hb=f+16|0;return g|0}function Xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c=hb-208|0;hb=c;g=1;d=x[a+12>>2];j=1<<d;if(d&1){l=j>>>1|0;e=l>>>0<=1?1:l;d=0;while(1){i=d+l|0;g=vc(b,i);m=x[g+12>>2];x[c+200>>2]=x[g+8>>2];x[c+204>>2]=m;m=x[g+4>>2];x[c+192>>2]=x[g>>2];x[c+196>>2]=m;m=c+192|0;Fi(c+176|0,vc(b,d),m);g=vc(b,i);i=x[c+188>>2];x[g+8>>2]=x[c+184>>2];x[g+12>>2]=i;i=x[c+180>>2];x[g>>2]=x[c+176>>2];x[g+4>>2]=i;ay(vc(b,d),m);d=d+1|0;if((e|0)!=(d|0)){continue}break}d=x[a+12>>2];g=2;j=j>>>3|0}else{j=j>>>2|0}i=d&-2;if(i){while(1){if(g){t=D(j,3);u=j<<1;l=0;while(1){d=vc(a,l<<1);e=x[d+12>>2];x[c+200>>2]=x[d+8>>2];x[c+204>>2]=e;e=x[d+4>>2];x[c+192>>2]=x[d>>2];x[c+196>>2]=e;d=vc(a,l);e=x[d+12>>2];x[c+184>>2]=x[d+8>>2];x[c+188>>2]=e;e=x[d+4>>2];x[c+176>>2]=x[d>>2];x[c+180>>2]=e;Rh(c+160|0,c+176|0,c+192|0);d=l<<i;m=j+d|0;if(d>>>0<m>>>0){while(1){e=vc(b,d);h=x[e+12>>2];x[c+152>>2]=x[e+8>>2];x[c+156>>2]=h;h=x[e+4>>2];x[c+144>>2]=x[e>>2];x[c+148>>2]=h;h=c+128|0;q=d+j|0;Rh(h,c+192|0,vc(b,q));e=c+112|0;r=d+u|0;Rh(e,c+176|0,vc(b,r));f=c+96|0;s=d+t|0;Rh(f,c+160|0,vc(b,s));k=c+80|0;n=c+144|0;Ak(k,n,e);o=c- -64|0;Fi(o,n,e);n=c+48|0;Ak(n,h,f);e=c+16|0;Vl(e,-C[4378],-C[4379]);Fi(c,h,f);h=c+32|0;Rh(h,e,c);Ak(e,k,n);f=vc(b,d);p=x[c+28>>2];x[f+8>>2]=x[c+24>>2];x[f+12>>2]=p;p=x[c+20>>2];x[f>>2]=x[c+16>>2];x[f+4>>2]=p;Fi(e,k,n);f=vc(b,q);k=x[c+28>>2];x[f+8>>2]=x[c+24>>2];x[f+12>>2]=k;k=x[c+20>>2];x[f>>2]=x[c+16>>2];x[f+4>>2]=k;Ak(e,o,h);f=vc(b,r);k=x[c+28>>2];x[f+8>>2]=x[c+24>>2];x[f+12>>2]=k;k=x[c+20>>2];x[f>>2]=x[c+16>>2];x[f+4>>2]=k;Fi(e,o,h);e=vc(b,s);h=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=h;h=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=h;d=d+1|0;if((m|0)!=(d|0)){continue}break}}l=l+1|0;if((l|0)!=(g|0)){continue}break}}j=j>>>2|0;g=g<<2;i=i-2|0;if(i){continue}break}}hb=c+208|0}function L2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-96|0;hb=e;a:{if(Wc(c)){break a}f=y[LI(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+80|0;Jr(f,c,0,Bb(c)-1|0);Db(c,f);xb(f)}f=e+80|0;Hd(f);g=x[e+80>>2];Hd(e+72|0);g=KI(g,x[e+76>>2],c);Hd(f);b:{c:{d:{e:{f:{if((g|0)==x[e+84>>2]){if(Td(c,17386)){a=ec(8);x[114414]=0;b=O(118,e+80|0,6463)|0;c=x[114414];x[114414]=0;if((c|0)==1){break d}a=oc(a,b);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}c=N()|0;xb(b);break c}if(!d){break f}a=ec(8);x[114414]=0;T(2166,e+80|0,13524,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){a=oc(a,e+80|0);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break b}c=N()|0;xb(e+80|0);break c}c=N()|0;hc(a);break c}f=Wb(e+80|0);g:{h:{i:{j:{switch(x[g+4>>2]){case 0:xi(e- -64|0,c);x[114414]=0;c=x[e+68>>2];x[e+8>>2]=x[e+64>>2];x[e+12>>2]=c;b=U(2110,b|0,e+8|0,d|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){x[114414]=0;v[e+72|0]=b;P(2171,a|0,e+72|0);a=x[114414];x[114414]=0;if((a|0)!=1){break g}}break i;case 1:xi(e+56|0,c);x[114414]=0;c=x[e+60>>2];x[e+16>>2]=x[e+56>>2];x[e+20>>2]=c;b=VD(b,e+16|0,d);c=lb;d=x[114414];x[114414]=0;if((d|0)!=1){x[114414]=0;x[e+72>>2]=b;x[e+76>>2]=c;P(2173,a|0,e+72|0);a=x[114414];x[114414]=0;if((a|0)!=1){break g}}break i;case 2:xi(e+48|0,c);x[114414]=0;c=x[e+52>>2];x[e+24>>2]=x[e+48>>2];x[e+28>>2]=c;h=+ka(2112,b|0,e+24|0,d|0);b=x[114414];x[114414]=0;if((b|0)!=1){x[114414]=0;C[e+72>>3]=h;P(2174,a|0,e+72|0);a=x[114414];x[114414]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}xi(e+40|0,c);x[114414]=0;c=x[e+44>>2];x[e+32>>2]=x[e+40>>2];x[e+36>>2]=c;X(2113,a|0,b|0,e+32|0,d|0);a=x[114414];x[114414]=0;if((a|0)!=1){break g}}c=N()|0;xb(f);break c}Jd(a,f)}xb(f);break e}Wb(a)}hb=e+96|0;return}c=N()|0;hc(a)}Q(c|0)}p()}function cfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=hb-48|0;hb=e;u=x[a+16>>2];j=x[a+44>>2];x[e+28>>2]=j;o=x[a+48>>2];x[e+32>>2]=o;g=x[a+52>>2];x[e+36>>2]=g;m=x[a+56>>2];x[e+40>>2]=m;p=x[a+40>>2];q=x[a+36>>2];f=x[a+4>>2];k=f;h=x[a>>2];x[e+16>>2]=h;x[e+20>>2]=f;f=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=f;a:{if(!d){b=p>>12;i=q>>12;break a}v=b+24|0;while(1){o=1;b=x[e+16>>2];l=((((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+u|0;b=v+(((b>>>16|0)+4&131064)<<1)|0;r=w[b+14>>1];s=w[b+12>>1];n=w[b+10>>1];t=w[b+8>>1];m=w[b+6>>1];k=w[b+4>>1];f=w[b+2>>1];h=w[b>>1];j=0;g=1;i=0;while(1){b=i<<1;x[(i<<2)+e>>2]=(((((D(w[l+(b|8)>>1],n)+D(w[l+(b|4)>>1],t)|0)+D(s,w[l+(b|12)>>1])|0)+D(r,w[l+(b|16)>>1])|0)/2|0)+((((D(w[l+(b|-8)>>1],f)+D(w[l+(b|-12)>>1],h)|0)+D(w[l+(b|-4)>>1],k)|0)+D(w[b+l>>1],m)|0)/2|0)|0)/16384;b=g&1;g=0;i=1;if(b){continue}break}while(1){b=(j<<2)+e|0;k=x[b>>2];i=x[a+60>>2];j=(e+24|0)+(j<<3)|0;f=x[j+4>>2];g=Xb(f,-16777216,16776704);n=x[a+64>>2];r=Xb(x[j+8>>2],-16777216,16776704);h=x[a+68>>2];t=h>>31;x[j+8>>2]=f;m=x[a+72>>2];s=k<<8;f=s;f=yna(i,i>>31,f,f>>31);k=lb;i=f;f=yna(n,n>>31,g,g>>31);n=i+f|0;g=lb+k|0;g=f>>>0>n>>>0?g+1|0:g;f=yna(h,t,r,r>>31);k=f+n|0;h=lb+g|0;h=f>>>0>k>>>0?h+1|0:h;i=b;f=k+8388608|0;b=((f>>>0<8388608?h+1|0:h)&16777215)<<8|f>>>24;x[i>>2]=(b|0)/256;x[j+4>>2]=b-(m&s);j=1;b=o&1;o=0;if(b){continue}break}b=x[a+32>>2];q=x[a+28>>2]+q|0;i=q>>12;x[c>>2]=x[c>>2]+D(i,x[e>>2]);p=b+p|0;b=p>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[e+4>>2]);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}m=x[e+40>>2];g=x[e+36>>2];o=x[e+32>>2];j=x[e+28>>2];h=x[e+16>>2];k=x[e+20>>2]}x[a>>2]=h;x[a+4>>2]=k;x[a+40>>2]=p;x[a+20>>2]=i;x[a+36>>2]=q;x[a+56>>2]=m;x[a+52>>2]=g;x[a+48>>2]=o;x[a+44>>2]=j;x[a+24>>2]=b;hb=e+48|0}function _H(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;c=x[a+8>>2];x[e+28>>2]=e+36;x[e+24>>2]=e+40;b=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=b;x[e+16>>2]=a;x[e+20>>2]=e+44;b=x[e+20>>2];x[e>>2]=x[e+16>>2];x[e+4>>2]=b;a:{b:{switch(x[c+40>>2]){case 0:b=hb-80|0;hb=b;d=x[e>>2];g=x[d+4>>2];x[b+40>>2]=x[d+20>>2];h=x[d+16>>2];x[b+32>>2]=x[d+12>>2];x[b+36>>2]=h;gn(b- -64|0,b+32|0,g);d=Mc(b+48|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];h=x[x[e+8>>2]>>2];x[b+24>>2]=x[b+72>>2];f=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=f;x[b+8>>2]=x[d+8>>2];f=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=f;if(g){f=b+16|0;while(1){d=0;if(h){while(1){i=x[Rf(b,d,j)>>2];gc(c,d);i=i-2147481600>>>12|0;i=i>>>0<=491520?491520:i;n=fn(f,d,j),o=(i|0)>=557055?557055:i,w[n>>1]=o;d=d+1|0;if((h|0)!=(d|0)){continue}break}}j=j+1|0;if((g|0)!=(j|0)){continue}break}}hb=b+80|0;break a;case 2:ix(e,yb(c));break a;case 3:j=ah(c);d=0;b=hb-80|0;hb=b;c=x[e>>2];g=x[c+4>>2];x[b+40>>2]=x[c+20>>2];h=x[c+16>>2];x[b+32>>2]=x[c+12>>2];x[b+36>>2]=h;gn(b- -64|0,b+32|0,g);c=Mc(b+48|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];h=x[x[e+8>>2]>>2];x[b+24>>2]=x[b+72>>2];f=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=f;x[b+8>>2]=x[c+8>>2];f=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=f;if(g){i=b+16|0;l=j+16|0;while(1){c=0;if(h){while(1){f=x[Rf(b,c,d)>>2];k=$e(j,c);f=f+(x[k>>2]>>1)|0;m=f;f=ps(l)+f&-4096;x[k>>2]=m-f;f=f-2147481600>>>12|0;f=f>>>0<=491520?491520:f;n=fn(i,c,d),o=(f|0)>=557055?557055:f,w[n>>1]=o;c=c+1|0;if((h|0)!=(c|0)){continue}break}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:ix(e,yb(c));break a;default:break b}}ix(e,yb(c))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function Hea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-32|0;hb=f;d=b&5;a:{if(!(c&5)){if(!d){break a}i=a,j=yt(v[a+36|0],v[a+37|0]),x[i+24>>2]=j;w[a+36>>1]=0;if((b|0)!=1){break a}e=yna(x[a+24>>2],0,8272,0);d=lb;e=e+4181|0;d=e>>>0<4181?d+1|0:d;i=a,j=jd(Bna(e,d,8363,0),lb),x[i+24>>2]=j;break a}if(d){break a}if((c|0)==1){e=yna(x[a+24>>2],0,8363,0);d=lb;e=e+4136|0;d=e>>>0<4136?d+1|0:d;i=a,j=jd(Bna(e,d,8272,0),lb),x[i+24>>2]=j}e=hb-16|0;hb=e;g=e+8|0;d=hb-16|0;hb=d;h=x[a+24>>2];b:{if(!h){v[g|0]=0;v[g+1|0]=0;break b}dH(d+8|0,Xb(Cn(Zo(+(h>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);v[d+7|0]=x[d+8>>2];v[d+6|0]=x[d+12>>2];iz(g,d+7|0,d+6|0)}hb=d+16|0;Fb(Fb(e,a+36|0)+4|0,a+37|0);v[x[e>>2]]=y[g|0];v[x[e+4>>2]]=y[g+1|0];hb=e+16|0}if(c&3){w[a+38>>1]=0;w[a+40>>1]=0;v[a+36|0]=0;w[a+34>>1]=z[a+34>>1]&65499}if(c&7){w[a+32>>1]=64;d=z[a+34>>1];if(d&8){e=x[a+16>>2];x[a+4>>2]=x[a+12>>2];x[a+8>>2]=e;d=d&16?d|6:d&65529|2}x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=d&65511}c:{d:{e:{if(c&4){d=z[a+34>>1];if(!(d&32)){w[a+28>>1]=128;w[a+34>>1]=d|32}_e(a+40|0,15);_e(a+41|0,63);if(c&16777248?b&4:0){break e}if(!(b&16777248)){break c}if(y[a+41|0]){break d}break c}if(!(b&4)|!(c&16777248)){break c}if(y[a+41|0]){break d}break c}if(!y[a+41|0]){break c}}d=y[a+40|0];if(!d){break c}b=y[a+39|0];if(b){b=gl(jd(((d<<8|b>>>1)>>>0)/(b>>>0)|0,0))}else{b=255}v[a+39|0]=b}f:{g:{if((c|0)!=4){if((c|0)==16777216){break f}if((c|0)!=32|y[a+38|0]!=2){break g}v[a+38|0]=3;break g}if(y[a+38|0]!=4){break g}v[a+38|0]=0}w[a+34>>1]=z[a+34>>1]&49151}h:{if(!(!(y[a+35|0]&2)|c&16777218)){x[f+24>>2]=0;x[f+8>>2]=0;x[f+16>>2]=0;x[f+20>>2]=0;x[f>>2]=0;x[f+4>>2]=0;Tp(a,0,f);break h}if(!(y[a+35|0]&2)|(c|0)!=2){break h}a=a+68|0;b=gc(a,8);v[b|0]=y[b|0]&3;a=gc(a,9);v[a|0]=y[a|0]&3}hb=f+32|0}function w1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;d=-2;a:{if(!a){break a}c=x[a+28>>2];if(!c){break a}b=(b|0)==1?2:b;if(b>>>0>4|!(1<<b&21)){break a}f=x[c+11e3>>2];k=x[a+4>>2];x[c+11e3>>2]=0;b:{if(x[c+43780>>2]<0){break b}h=(b|0)==4;g=x[c+11004>>2];if(!(g?h:1)){break a}d=x[c+11008>>2]>0?9:8;x[c+11004>>2]=h|g;if(!(!f|(b|0)!=4)){x[e+12>>2]=x[a+4>>2];x[e+8>>2]=x[a+16>>2];b=x[a+12>>2];b=CH(c,x[a>>2],e+12|0,b,b,e+8|0,d|4);x[c+43780>>2]=b;d=x[e+12>>2];x[a>>2]=d+x[a>>2];x[a+4>>2]=x[a+4>>2]-d;x[a+8>>2]=d+x[a+8>>2];x[a+48>>2]=x[c+28>>2];d=x[e+8>>2];x[a+12>>2]=d+x[a+12>>2];x[a+16>>2]=x[a+16>>2]-d;x[a+20>>2]=d+x[a+20>>2];d=-3;if((b|0)<0){break a}if(!b){d=1;break a}x[c+43780>>2]=-1;d=-5;break a}f=x[c+10996>>2];if(!f){j=(b|0)!=4;l=j?d|2:d;h=c+11012|0;g=x[c+10992>>2];while(1){b=x[a+4>>2];x[e+8>>2]=32768-g;x[e+12>>2]=b;f=CH(c,x[a>>2],e+12|0,h,h+g|0,e+8|0,l);x[c+43780>>2]=f;b=x[e+12>>2];x[a>>2]=b+x[a>>2];x[a+4>>2]=x[a+4>>2]-b;x[a+8>>2]=b+x[a+8>>2];x[a+48>>2]=x[c+28>>2];b=x[e+8>>2];x[c+10996>>2]=b;d=x[a+16>>2];b=b>>>0<d>>>0?b:d;sc(x[a+12>>2],h+x[c+10992>>2]|0,b);x[a+12>>2]=b+x[a+12>>2];x[a+16>>2]=x[a+16>>2]-b;x[a+20>>2]=b+x[a+20>>2];i=x[c+10996>>2];x[c+10996>>2]=i-b;g=b+x[c+10992>>2]&32767;x[c+10992>>2]=g;if((f|0)<0){break b}d=-5;if(!k&(f|0)==1){break a}if(!j){if(!f){d=(b|0)==(i|0)?1:-5;break a}if(x[a+16>>2]){continue}break a}if(f){d=0;if(!x[a+4>>2]|!x[a+16>>2]){break a}if((b|0)==(i|0)){continue}break a}break}d=(b|0)==(i|0);break a}b=x[a+16>>2];b=b>>>0>f>>>0?f:b;sc(x[a+12>>2],(x[c+10992>>2]+c|0)+11012|0,b);x[a+12>>2]=b+x[a+12>>2];x[a+16>>2]=x[a+16>>2]-b;x[a+20>>2]=b+x[a+20>>2];a=x[c+10996>>2];x[c+10996>>2]=a-b;x[c+10992>>2]=b+x[c+10992>>2]&32767;d=0;if(x[c+43780>>2]){break a}d=(a|0)==(b|0);break a}d=-3}hb=e+16|0;return d|0}function Yea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-48|0;hb=e;k=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;l=e,m=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[l+28>>2]=m;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}f=a+8|0;l=e,m=Sf(f,b),x[l+16>>2]=m;x[e+20>>2]=lb;l=e,m=Te(f,d),x[l+40>>2]=m;x[e+44>>2]=lb;tf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}h=x[a+40>>2];i=x[a+36>>2];b=x[a+4>>2];g=b;f=x[a>>2];x[e+8>>2]=f;x[e+12>>2]=b;b=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=b;b:{c:{if(!d){b=h>>12;j=i>>12;break c}while(1){f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];g=x[e+12>>2]<<1;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=g+k|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{g=w[f+(x[e+44>>2]<<1)>>1];x[114414]=0;P(1048,x[e+24>>2],(g|0)/4<<16>>16);g=x[114414];x[114414]=0;if((g|0)==1){break e}x[114414]=0;P(1049,x[e+24>>2],4);g=x[114414];x[114414]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];g=x[b+4>>2];if(g){f=w[f+(x[e+44>>2]<<1)>>1];x[114414]=0;P(1048,b|0,(f|0)/4<<16>>16);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(1049,x[e+24>>2],g|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[e+24>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114414]=0;f=O(1050,b|0,x[e+28>>2])|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[a+32>>2];i=x[a+28>>2]+i|0;j=i>>12;x[c>>2]=x[c>>2]+D(f,j);h=b+h|0;b=h>>12;x[c+4>>2]=x[c+4>>2]+D(f,b);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}f=x[e+8>>2];g=x[e+12>>2]}x[a>>2]=f;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=b;hb=e+48|0;return}b=N()|0;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;Q(b|0);p()}function dfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;f=hb-48|0;hb=f;u=x[a+16>>2];i=x[a+44>>2];x[f+28>>2]=i;o=x[a+48>>2];x[f+32>>2]=o;h=x[a+52>>2];x[f+36>>2]=h;m=x[a+56>>2];x[f+40>>2]=m;p=x[a+40>>2];q=x[a+36>>2];e=x[a+4>>2];j=e;g=x[a>>2];x[f+16>>2]=g;x[f+20>>2]=e;e=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=e;a:{if(!d){b=p>>12;e=q>>12;break a}y=b+24|0;while(1){b=x[f+16>>2];l=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+u|0;o=1;b=(((b>>>16|0)+4&131064)<<1)+y|0;k=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];n=w[b+8>>1];t=w[b+6>>1];m=w[b+4>>1];j=w[b+2>>1];e=w[b>>1];i=0;h=1;b=0;while(1){x[(b<<2)+f>>2]=((((D(v[l+(b|4)|0],s)+D(v[l+(b|2)|0],n)|0)+D(r,v[l+(b|6)|0])|0)+D(k,v[l+(b|8)|0])<<8>>1)+(((D(v[l+(b|-4)|0],j)+D(v[l+(b|-6)|0],e)|0)+D(v[l+(b|-2)|0],m)|0)+D(v[b+l|0],t)<<8>>1)|0)/16384;g=h&1;h=0;b=1;if(g){continue}break}while(1){b=(i<<2)+f|0;j=x[b>>2];h=x[a+60>>2];i=(f+24|0)+(i<<3)|0;e=x[i+4>>2];k=Xb(e,-16777216,16776704);n=x[a+64>>2];r=Xb(x[i+8>>2],-16777216,16776704);g=x[a+68>>2];t=g>>31;x[i+8>>2]=e;m=x[a+72>>2];s=j<<8;e=s;e=yna(h,h>>31,e,e>>31);j=lb;h=e;e=yna(n,n>>31,k,k>>31);n=h+e|0;k=lb+j|0;k=e>>>0>n>>>0?k+1|0:k;e=yna(g,t,r,r>>31);j=e+n|0;g=lb+k|0;g=e>>>0>j>>>0?g+1|0:g;h=b;e=j+8388608|0;b=((e>>>0<8388608?g+1|0:g)&16777215)<<8|e>>>24;x[h>>2]=(b|0)/256;x[i+4>>2]=b-(m&s);i=1;b=o&1;o=0;if(b){continue}break}b=x[a+32>>2];q=x[a+28>>2]+q|0;e=q>>12;x[c>>2]=x[c>>2]+D(e,x[f>>2]);p=b+p|0;b=p>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[f+4>>2]);c=c+8|0;Tb(f+16|0,f+8|0);d=d-1|0;if(d){continue}break}m=x[f+40>>2];h=x[f+36>>2];o=x[f+32>>2];i=x[f+28>>2];g=x[f+16>>2];j=x[f+20>>2]}x[a>>2]=g;x[a+4>>2]=j;x[a+40>>2]=p;x[a+20>>2]=e;x[a+36>>2]=q;x[a+56>>2]=m;x[a+52>>2]=h;x[a+48>>2]=o;x[a+44>>2]=i;x[a+24>>2]=b;hb=f+48|0}function D_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=hb-432|0;hb=i;x[i+424>>2]=37;x[i+428>>2]=0;m=Dr(i+424|1,9666,x[c+4>>2]);x[i+380>>2]=i+384;a=ie();a:{if(m){k=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=k;a=ff(i+384|0,30,a,i+424|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;a=ff(i+384|0,30,a,i+424|0,i+80|0)}x[i+128>>2]=2484;k=Pd(i+368|0,0,i+128|0);l=i+384|0;j=l;b:{c:{d:{e:{if((a|0)>=30){f:{if(m){x[114414]=0;a=$(2507)|0;j=x[114414];x[114414]=0;if((j|0)==1){break d}j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i>>2]=j;x[114414]=0;x[i+8>>2]=e;x[i+12>>2]=f;a=Z(2527,i+380|0,a|0,i+424|0,i|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){break f}break d}x[114414]=0;a=$(2507)|0;j=x[114414];x[114414]=0;if((j|0)==1){break d}x[i+32>>2]=e;x[i+36>>2]=f;x[114414]=0;x[i+40>>2]=g;x[i+44>>2]=h;a=Z(2527,i+380|0,a|0,i+424|0,i+32|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break d}}if((a|0)==-1){x[114414]=0;V(2485);a=x[114414];x[114414]=0;if((a|0)==1){break d}break e}we(k,x[i+380>>2]);j=x[i+380>>2]}f=a+j|0;g=vg(j,f,c);x[i+116>>2]=2484;e=Pd(i+120|0,0,i+116|0);g:{h:{if(x[i+380>>2]==(i+384|0)){a=i+128|0;break h}a=sd(a<<3);if(!a){x[114414]=0;V(2485);a=x[114414];x[114414]=0;if((a|0)!=1){break e}b=N()|0;break g}we(e,a);l=x[i+380>>2]}x[114414]=0;Dc(i+104|0,c);h=x[114414];x[114414]=0;i:{j:{if((h|0)!=1){x[114414]=0;fa(2538,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=x[114414];x[114414]=0;if((f|0)==1){break j}Ob(i+104|0);x[114414]=0;a=ga(2539,b|0,a|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break i}Jc(e);Jc(k);hb=i+432|0;break b}b=N()|0;break g}b=N()|0;Ob(i+104|0);break g}b=N()|0}Jc(e);break c}p()}b=N()|0}Jc(k);Q(b|0);p()}return a|0}function N_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=hb-256|0;hb=i;x[i+248>>2]=37;x[i+252>>2]=0;m=Dr(i+248|1,9666,x[c+4>>2]);x[i+204>>2]=i+208;a=ie();a:{if(m){k=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=k;a=ff(i+208|0,30,a,i+248|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;a=ff(i+208|0,30,a,i+248|0,i+80|0)}x[i+128>>2]=2484;k=Pd(i+192|0,0,i+128|0);l=i+208|0;j=l;b:{c:{d:{e:{if((a|0)>=30){f:{if(m){x[114414]=0;a=$(2507)|0;j=x[114414];x[114414]=0;if((j|0)==1){break d}j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i>>2]=j;x[114414]=0;x[i+8>>2]=e;x[i+12>>2]=f;a=Z(2527,i+204|0,a|0,i+248|0,i|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){break f}break d}x[114414]=0;a=$(2507)|0;j=x[114414];x[114414]=0;if((j|0)==1){break d}x[i+32>>2]=e;x[i+36>>2]=f;x[114414]=0;x[i+40>>2]=g;x[i+44>>2]=h;a=Z(2527,i+204|0,a|0,i+248|0,i+32|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break d}}if((a|0)==-1){x[114414]=0;V(2485);a=x[114414];x[114414]=0;if((a|0)==1){break d}break e}we(k,x[i+204>>2]);j=x[i+204>>2]}f=a+j|0;g=vg(j,f,c);x[i+116>>2]=2484;e=Pd(i+120|0,0,i+116|0);g:{h:{if(x[i+204>>2]==(i+208|0)){a=i+128|0;break h}a=sd(a<<1);if(!a){x[114414]=0;V(2485);a=x[114414];x[114414]=0;if((a|0)!=1){break e}b=N()|0;break g}we(e,a);l=x[i+204>>2]}x[114414]=0;Dc(i+104|0,c);h=x[114414];x[114414]=0;i:{j:{if((h|0)!=1){x[114414]=0;fa(2528,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=x[114414];x[114414]=0;if((f|0)==1){break j}Ob(i+104|0);x[114414]=0;a=ga(17,b|0,a|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break i}Jc(e);Jc(k);hb=i+256|0;break b}b=N()|0;break g}b=N()|0;Ob(i+104|0);break g}b=N()|0}Jc(e);break c}p()}b=N()|0}Jc(k);Q(b|0);p()}return a|0}function $7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=E(0),g=0,h=0,i=E(0),j=0,k=0,l=0,m=E(0),n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=E(0),v=0,w=0,y=E(0),z=0,A=0,C=0,D=E(0);a:{if(!x[a+4276>>2]){break a}j=a+44|0;if(!Bh(j)){break a}o=Od(j,0);p=Od(j,1);q=ld(j,0);r=ld(j,1);w=mb[x[x[a>>2]+188>>2]](a)|0;e=E(mb[x[x[a>>2]+196>>2]](a));u=E(mb[x[x[a>>2]+184>>2]](a));s=mb[x[x[a>>2]+208>>2]](a)|0;if(d){y=E(e*E(.009999999776482582));z=s&1;k=a+4260|0;h=x[a+4256>>2];l=x[a+4272>>2];t=d;while(1){i=B[o>>2];m=B[p>>2];h=nn(a,h+l|0);l=nn(a,l);e=B[Pb(k,h)>>2];C=Pb(k,l),D=E(E(y*e)+E(E(m+i)*E(.5))),B[C>>2]=D;b:{if(w){f=B[a+4244>>2];e=E(B[a+4236>>2]+f);B[a+4236>>2]=e;f=E(f+B[a+4240>>2]);B[a+4240>>2]=f;if(!(e<=E(1))){e=E(e+E(-2));B[a+4236>>2]=e}if(!(f<=E(1))){B[a+4240>>2]=f+E(-2)}e=E(F(e));e=E(E(e+e)+E(-1));f=E(F(B[a+4240>>2]));f=E(E(f+f)+E(-1));break b}f=B[a+4244>>2];n=B[a+4240>>2];e=E(E(f*n)+B[a+4236>>2]);B[a+4236>>2]=e;f=E(n-E(e*f));B[a+4240>>2]=f}n=B[Pb(k,nn(a,x[a+4280>>2]+x[a+4272>>2]|0))>>2];C=q,D=E(E(E(E(n-i)+E(E(E(B[Pb(k,nn(a,x[a+4284>>2]+x[a+4272>>2]|0))>>2]-n)*E(.000244140625))*E(x[a+4280>>2]&4095)))*u)+i),B[C>>2]=D;i=B[Pb(k,nn(a,x[a+4288>>2]+x[a+4272>>2]|0))>>2];C=r,D=E(E(E(E(i-m)+E(E(E(B[Pb(k,nn(a,x[a+4292>>2]+x[a+4272>>2]|0))>>2]-i)*E(.000244140625))*E(x[a+4288>>2]&4095)))*u)+m),B[C>>2]=D;h=x[a+4272>>2];l=(((h|0)<=0?x[a+4276>>2]<<12:0)+h|0)-4096|0;x[a+4272>>2]=l;h=x[a+4256>>2];i=B[a+4248>>2];m=E(i*(z?f:e));c:{if(E(F(m))<E(2147483648)){g=~~m;break c}g=-2147483648}v=h+(s>>>0>1?g:0-g|0)|0;x[a+4288>>2]=v;A=s>>>0<4;p=p+4|0;o=o+4|0;e=E(i*e);d:{if(E(F(e))<E(2147483648)){g=~~e;break d}g=-2147483648}g=(A?g:0-g|0)+h|0;x[a+4280>>2]=g;x[a+4292>>2]=v+4096;x[a+4284>>2]=g+4096;r=r+4|0;q=q+4|0;t=t-1|0;if(t){continue}break}}zi(a,b,c,ld(j,0),ld(j,1),d)}}function $H(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0);e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;f=x[a+8>>2];x[e+28>>2]=e+36;x[e+24>>2]=e+40;b=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=b;x[e+16>>2]=a;x[e+20>>2]=e+44;b=x[e+20>>2];x[e>>2]=x[e+16>>2];x[e+4>>2]=b;a:{b:{switch(x[f+40>>2]){case 0:c=hb-80|0;hb=c;b=x[e>>2];d=x[b+4>>2];i=x[b+24>>2];x[c+40>>2]=x[b+20>>2];x[c+44>>2]=i;i=x[b+16>>2];x[c+32>>2]=x[b+12>>2];x[c+36>>2]=i;Nh(c- -64|0,c+32|0,d);b=Mc(c+48|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);i=x[x[e+12>>2]>>2];h=x[x[e+8>>2]>>2];d=x[c+76>>2];x[c+24>>2]=x[c+72>>2];x[c+28>>2]=d;d=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=d;x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;if(i){b=c+16|0;while(1){d=0;if(h){while(1){j=C[kh(c,d,g)>>3];gc(f,d);l=In(b,d,g),m=E(j),B[l>>2]=m;d=d+1|0;if((h|0)!=(d|0)){continue}break}}g=g+1|0;if((i|0)!=(g|0)){continue}break}}hb=c+80|0;break a;case 2:jx(e,yb(f));break a;case 3:i=ah(f);d=0;b=hb-80|0;hb=b;c=x[e>>2];f=x[c+4>>2];g=x[c+24>>2];x[b+40>>2]=x[c+20>>2];x[b+44>>2]=g;g=x[c+16>>2];x[b+32>>2]=x[c+12>>2];x[b+36>>2]=g;Nh(b- -64|0,b+32|0,f);c=Mc(b+48|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);f=x[x[e+12>>2]>>2];g=x[x[e+8>>2]>>2];h=x[b+76>>2];x[b+24>>2]=x[b+72>>2];x[b+28>>2]=h;h=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=h;x[b+8>>2]=x[c+8>>2];h=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=h;if(f){h=b+16|0;while(1){c=0;if(g){while(1){j=C[kh(b,c,d)>>3];$e(i,c);k=Cj(Qd(j*134217728));l=In(h,c,d),m=E(+(k|0)*7.450580596923828e-9),B[l>>2]=m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((f|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:jx(e,yb(f));break a;default:break b}}jx(e,yb(f))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function Yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-32|0;hb=f;i=c+484344|0;cg(i,y[b+70|0]|y[b+71|0]<<8);a:{if(y[b+70|0]|y[b+71|0]<<8){while(1){d=x[a+8>>2];g=Gf(a);cc(a,1);b:{if((y[b+58|0]|y[b+59|0]<<8)==258){c=pe(a)+1|0;break b}c=pg(a)}e=pg(a);Rc(a,d+g|0);Bd(f+16|0,a,e);x[114414]=0;c=U(363,i|0,h&65535,(c?c>>>0>=1024?1024:c:64)|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}c:{if(!(c&(e|0)!=0)){break c}c=Zb(i,h);k=f,l=bc(c),x[k+8>>2]=l;k=f,l=dc(c),x[k>>2]=l;if(!Hb(f+8|0,f)){break c}while(1){e=x[f+8>>2];x[114414]=0;c=R(403,f+16|0)|0;d=x[114414];x[114414]=0;d:{e:{f:{if((d|0)!=1){d=c<<24>>24;if((d|0)>=0){break f}if(d&1){x[114414]=0;c=R(403,f+16|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}v[e|0]=c}c=d&255;if(d&2){break e}break d}break a}v[e|0]=d;c=255}x[114414]=0;d=R(403,f+16|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}v[e+1|0]=d}d=0;if(c&4){x[114414]=0;d=R(403,f+16|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}}if(c&8){x[114414]=0;g=R(403,f+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break a}v[e+3|0]=g}if(c&16){x[114414]=0;c=R(403,f+16|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}v[e+5|0]=c}g:{h:{c=y[e|0];if(!c){break h}g=255;if((c|0)==97){break g}if(c>>>0>96){break h}g=c+12|0;break g}g=0}v[e|0]=g;i:{if(y[e+5|0]|y[e+3|0]){x[114414]=0;W(541,e|0);c=x[114414];x[114414]=0;if((c|0)!=1){break i}break a}v[e+3|0]=0}if(y[e+1|0]==255){v[e+1|0]=0}c=d-16|0;j:{if((c&255)>>>0<=64){v[e+4|0]=c;v[e+2|0]=1;break j}if(d>>>0<96){break j}c=d&15;v[e+4|0]=c;d=d-96>>>4|0;v[e+2|0]=y[d+24078|0];if((d|0)!=6){break j}v[e+4|0]=c<<2}c=f+8|0;Nj(c);if(Hb(c,f)){continue}break}}Ab(f+16|0);h=h+1|0;if(h>>>0<(y[b+70|0]|y[b+71|0]<<8)>>>0){continue}break}}hb=f+32|0;return}a=N()|0;Ab(f+16|0);Q(a|0);p()}function o8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{switch(b|0){case 0:e=hb-16|0;hb=e;f=Wb(a);c:{d:{if(Bb(c)){while(1){a=x[qj(c,i)>>2];e:{if(a>>>0>=2097152){x[114414]=0;P(107,f|0,63);a=x[114414];x[114414]=0;if((a|0)!=1){break e}break d}d=0;f:{g:{while(1){h=a&63;v[(e+10|0)+d|0]=h;if(a>>>0<64){break g}a=a>>>6|0;d=d+1|0;if((d|0)!=6){continue}break}b=7;d=6;break f}if(d){b=d+1|0;if((b|0)!=2){break f}d=1;b=2;if((h|0)!=1){break f}a=y[e+10|0]|64}else{a=y[e+10|0]}x[114414]=0;P(107,f|0,a<<24>>24);a=x[114414];x[114414]=0;if((a|0)!=1){break e}break d}d=(-1<<b^-1)<<7-d;h=b+e|0;a=b;while(1){h:{if((a|0)==(b|0)){g=v[h+9|0];x[114414]=0;P(107,f|0,(d|g)<<24>>24);g=x[114414];x[114414]=0;if((g|0)==1){break d}a=a-1|0;break h}x[114414]=0;a=a-1|0;P(107,f|0,v[a+(e+10|0)|0]|-128);g=x[114414];x[114414]=0;if((g|0)==1){break d}}if(a){continue}break}}i=i+1|0;if(Bb(c)>>>0>i>>>0){continue}break}}hb=e+16|0;break c}a=N()|0;xb(f);Q(a|0);p()}return;case 1:b=0;a=Wb(a);d=Bb(c);x[114414]=0;P(108,a|0,d|0);d=x[114414];x[114414]=0;i:{if((d|0)!=1){j:{if(Bb(c)){while(1){d=x[qj(c,b)>>2];x[114414]=0;P(107,a|0,(d>>>0>=128?63:d)<<24>>24);d=x[114414];x[114414]=0;if((d|0)==1){break j}b=b+1|0;if(Bb(c)>>>0>b>>>0){continue}break}}break i}}break a}return;case 2:b=0;a=Wb(a);d=Bb(c);x[114414]=0;P(108,a|0,d|0);d=x[114414];x[114414]=0;k:{if((d|0)!=1){l:{if(Bb(c)){while(1){d=x[qj(c,b)>>2];x[114414]=0;P(107,a|0,(d>>>0>=256?63:d)<<24>>24);d=x[114414];x[114414]=0;if((d|0)==1){break l}b=b+1|0;if(Bb(c)>>>0>b>>>0){continue}break}}break k}}break a}return;case 3:kp(a,c,17600);return;case 4:kp(a,c,18624);return;case 5:kp(a,c,19648);return;case 6:kp(a,c,20672);return;case 7:kp(a,c,21696);return;default:break b}}Wb(a);return}b=N()|0;xb(a);Q(b|0);p()}function Zea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-48|0;hb=e;k=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;l=e,m=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[l+28>>2]=m;b=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=b;a:{if(!b){break a}f=a+8|0;l=e,m=Sf(f,b),x[l+16>>2]=m;x[e+20>>2]=lb;l=e,m=Te(f,d),x[l+40>>2]=m;x[e+44>>2]=lb;tf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}h=x[a+40>>2];i=x[a+36>>2];b=x[a+4>>2];g=b;f=x[a>>2];x[e+8>>2]=f;x[e+12>>2]=b;b=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=b;b:{c:{if(!d){b=h>>12;j=i>>12;break c}while(1){g=x[e+36>>2]-1|0;x[e+36>>2]=g;b=x[e+8>>2];f=x[e+12>>2];if(!g){x[e+16>>2]=0;x[e+20>>2]=0}f=f+k|0;x[e+40>>2]=b;x[e+44>>2]=0;d:{b=x[e+32>>2];if((b|0)<=0){break d}while(1){e:{g=v[f+x[e+44>>2]|0];x[114414]=0;P(1048,x[e+24>>2],g<<6);g=x[114414];x[114414]=0;if((g|0)==1){break e}x[114414]=0;P(1049,x[e+24>>2],4);g=x[114414];x[114414]=0;if((g|0)==1){break e}g=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(g){continue}break d}break}break b}b=x[e+24>>2];Tb(b,b+8|0);b=x[e+24>>2];g=x[b+4>>2];if(g){f=v[f+x[e+44>>2]|0];x[114414]=0;P(1048,b|0,f<<6);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(1049,x[e+24>>2],g|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[e+24>>2];f=x[b>>2];x[b>>2]=f;x[b+4>>2]=0}x[114414]=0;f=O(1050,b|0,x[e+28>>2])|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[a+32>>2];i=x[a+28>>2]+i|0;j=i>>12;x[c>>2]=x[c>>2]+D(f,j);h=b+h|0;b=h>>12;x[c+4>>2]=x[c+4>>2]+D(f,b);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}f=x[e+8>>2];g=x[e+12>>2]}x[a>>2]=f;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=b;hb=e+48|0;return}b=N()|0;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;Q(b|0);p()}function Qf(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=x[a+8>>2]+(D(z[a+14>>1],(y[a+80|0]?c:0)+b|0)>>>1|0)|0;x[a+8>>2]=i;j=y[a+79|0]?z[x[a>>2]+3836>>1]:j;g=z[a+20>>1];l=z[a+22>>1];m=z[a+70>>1];a:{b:{c:{d:{switch(x[a+16>>2]){case 1:b=z[x[a>>2]+3832>>1];c=z[a+26>>1]?z[a+48>>1]>>>z[x[a+52>>2]+((b>>>z[a+44>>1]&7)<<1)>>1]|0:0;h=b;b=z[a+46>>1];f=g+(b?h&b?0:c:c)|0;w[a+20>>1]=f;b=2;c=z[a+28>>1];if((c|0)<=f<<16>>16){break c}break b;case 2:if(y[a+78|0]){break b}case 3:b=0;c=z[x[a>>2]+3832>>1];f=z[a+30>>1]?z[a+60>>1]>>>z[x[a+64>>2]+((c>>>z[a+56>>1]&7)<<1)>>1]|0:0;h=c;c=z[a+58>>1];c=g+(c?h&c?0:f:f)|0;w[a+20>>1]=c;if(c<<16>>16<511){break b}x[a+16>>2]=-1;w[a+20>>1]=511;x[a+72>>2]=0;break a;default:b=0;x[a+72>>2]=0;break a;case 0:break d}}b=1;c=0;f=z[x[a>>2]+3832>>1];h=z[a+24>>1]?D((g^-1)<<16>>16,z[a+36>>1]>>>z[x[a+40>>2]+((f>>>z[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;k=z[a+34>>1];f=g+(k?f&k?0:h:h)|0;w[a+20>>1]=f;if(f<<16>>16>0){break b}}x[a+16>>2]=b;w[a+20>>1]=c}g=((g+l|0)+m|0)+j<<3;if(e){d=(w[a+74>>1]+w[a+72>>1]>>e)+d|0}d=(i>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(z[a+12>>1]){case 0:d=(b&512)>>>9|0;b=z[((b&256?c^255:c)<<1)+24944>>1];break e;case 1:d=0;b=z[((b&512?0:b&256?c^255:c)<<1)+24944>>1];break e;case 2:d=0;b=z[((b&256?c^255:c)<<1)+24944>>1];break e;case 3:d=0;b=z[((b&256?0:c)<<1)+24944>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=z[(e<<1)+24944>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=z[(b<<1)+24944>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}w[a+74>>1]=z[a+72>>1];c=a;a=b+g&65535;a=a>>>0>=8191?8191:a;b=0-d^z[((a&255)<<1)+24432>>1]+1024>>>(a>>>8)<<1;w[c+72>>1]=b}return b<<16>>16}function Ws(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=hb-160|0;hb=h;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}f=x[c+4>>2];if(!f&A[c>>2]>=Vg(b)>>>0|f){break h}b=ec(8);x[114414]=0;a=O(29,b|0,17386)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break g}a=N()|0;hc(b);break a}if(!x[b>>2]){b=ec(8);x[114414]=0;a=O(1411,b|0,17386)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break f}a=N()|0;hc(b);break a}f=fi(h+128|0,b);d=hb-16|0;hb=d;g=d+8|0;Ko(g,fi(d,f));e=hb-16|0;hb=e;i=fi(e+8|0,g);g=hb-16|0;hb=g;f=h+136|0;mD(f,Ed(g+8|0,i));hb=g+16|0;hb=e+16|0;x[f+16>>2]=0;x[f+12>>2]=0;hb=d+16|0;i:{j:{if(a&2){d=tp(h+104|0,f);x[114414]=0;j=O(1412,d|0,c|0)|0;e=x[114414];x[114414]=0;d=1;if((e|0)==1){break i}if((j|0)==1){break j}e=tp(h+80|0,f);x[114414]=0;e=O(1413,e|0,c|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break e}k=(e|0)==1;if(k){break j}g=tp(h+56|0,f);x[114414]=0;g=O(1414,g|0,c|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}l=(g|0)==1;if(l){break j}i=tp(h+32|0,f);x[114414]=0;i=O(1415,i|0,c|0)|0;m=x[114414];x[114414]=0;if((m|0)==1){break c}if((i|0)==1){break j}d=(j|0)==-1?-1:0;d=k?d:(e|0)==-1?-1:d;j=(i|0)==-1?-1:l?d:(g|0)==-1?-1:d}if(a&1){a=76752;while(1){d=x[a>>2];if(d){e=tp(h+8|0,f);x[114414]=0;e=O(d|0,e|0,c|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break b}d=1;if((e|0)==1){break j}j=(e|0)==-1?-1:j}a=a+12|0;if((a|0)!=77208){continue}break}}if(c){d=0;if((j|0)!=-1){break j}a=x[c+4>>2];c=x[c>>2];x[114414]=0;a=_f(396,c,a);c=x[114414];x[114414]=0;if((c|0)!=1){d=Vg(b)>>>0<a>>>0?-1:0;break j}a=N()|0;break a}d=0;if((j|0)!=-1){break j}d=Vg(b)>>>0>2047?1:-1}hb=h+160|0;return d}a=N()|0;break a}da(a|0,75288,25);p()}da(a|0,75184,25);p()}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0}Q(a|0);p()}function Y2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-80|0;hb=e;g=oh(a);a=b+24|0;f=Vb(x[a>>2]+484360|0);x[114414]=0;i=R(2221,f|0)|0;f=x[114414];x[114414]=0;a:{b:{c:{if((f|0)==1){break c}x[114414]=0;P(1545,g|0,i|0);f=x[114414];x[114414]=0;if((f|0)==1){break c}d:{e:{if(i){f=0;while(1){c=z[uc(Vb(x[a>>2]+484360|0),f)>>1];d=x[a>>2];x[114414]=0;d=O(890,d+484344|0,c|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break b}f:{if(d){c=Zb(x[a>>2]+484344|0,z[uc(Vb(x[a>>2]+484360|0),f)>>1]);x[114414]=0;P(2219,e+48|0,c|0);c=x[114414];x[114414]=0;g:{h:{i:{if((c|0)!=1){x[114414]=0;T(2213,e- -64|0,b|0,e+48|0);c=x[114414];x[114414]=0;if((c|0)==1){break i}x[114414]=0;P(1547,g|0,e- -64|0);c=x[114414];x[114414]=0;if((c|0)==1){break h}xb(e- -64|0);xb(e+48|0);break f}a=N()|0;break a}a=N()|0;break g}a=N()|0;xb(e- -64|0)}xb(e+48|0);break a}x[114414]=0;d=$(933)|0;h=x[114414];x[114414]=0;if((h|0)==1){break b}if((c|0)==(d|0)){x[114414]=0;c=O(118,e+32|0,5211)|0;d=x[114414];x[114414]=0;j:{if((d|0)!=1){x[114414]=0;P(1547,g|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break j}xb(c);break f}a=N()|0;break a}a=N()|0;xb(c);break a}x[114414]=0;d=$(932)|0;h=x[114414];x[114414]=0;if((h|0)==1){break b}if((c|0)==(d|0)){x[114414]=0;c=O(118,e+16|0,5173)|0;d=x[114414];x[114414]=0;k:{if((d|0)!=1){x[114414]=0;P(1547,g|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break k}xb(c);break f}a=N()|0;break a}a=N()|0;xb(c);break a}x[114414]=0;c=O(118,e|0,10152)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}x[114414]=0;P(1547,g|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break d}xb(c)}f=f+1|0;if((i|0)!=(f|0)){continue}break}}hb=e+80|0;return}a=N()|0;break a}a=N()|0;xb(c);break a}a=N()|0;break a}a=N()|0}qd(g);Q(a|0);p()}function MO(a){a=a|0;var b=0,c=0,d=0;Sb(a,0,288);c=a+288|0;qz(c);d=a+800|0;Xp(d);v[a+2|0]=y[9928];b=y[9926]|y[9927]<<8;v[a|0]=b;v[a+1|0]=b>>>8;b=y[9985]|y[9986]<<8;v[a+32|0]=b;v[a+33|0]=b>>>8;v[a+34|0]=y[9987];b=y[1982]|y[1983]<<8|(y[1984]<<16|y[1985]<<24);v[a+96|0]=b;v[a+97|0]=b>>>8;v[a+98|0]=b>>>16;v[a+99|0]=b>>>24;b=y[1985]|y[1986]<<8|(y[1987]<<16|y[1988]<<24);v[a+99|0]=b;v[a+100|0]=b>>>8;v[a+101|0]=b>>>16;v[a+102|0]=b>>>24;b=y[11701]|y[11702]<<8|(y[11703]<<16|y[11704]<<24);v[a+128|0]=b;v[a+129|0]=b>>>8;v[a+130|0]=b>>>16;v[a+131|0]=b>>>24;b=y[11704]|y[11705]<<8|(y[11706]<<16|y[11707]<<24);v[a+131|0]=b;v[a+132|0]=b>>>8;v[a+133|0]=b>>>16;v[a+134|0]=b>>>24;v[a+260|0]=y[5240];b=y[5236]|y[5237]<<8|(y[5238]<<16|y[5239]<<24);v[a+256|0]=b;v[a+257|0]=b>>>8;v[a+258|0]=b>>>16;v[a+259|0]=b>>>24;a=hb-80|0;hb=a;x[a+76>>2]=0;b=Ub(a- -64|0,1439);x[114414]=0;P(468,a+48|0,c|0);c=x[114414];x[114414]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[114414]=0;O(426,a+48|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break d}xb(b);break c}a=N()|0;xb(b);break b}hb=a+80|0;break a}Q(a|0);p()}b=0;a=hb+-64|0;hb=a;e:{f:{g:{h:{i:{j:{while(1){x[a+60>>2]=b;x[a+60>>2]=b<<3;UA(a+32|0,b>>>0<16?11437:17386);x[114414]=0;P(466,a+16|0,a+60|0);c=x[114414];x[114414]=0;if((c|0)==1){break j}x[114414]=0;T(467,a+48|0,a+32|0,a+16|0);c=x[114414];x[114414]=0;if((c|0)==1){break i}x[114414]=0;P(468,a+8|0,(b<<5)+d|0);c=x[114414];x[114414]=0;if((c|0)==1){break h}x[114414]=0;O(426,a+8|0,a+48|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break h}xb(a+48|0);xb(a+16|0);Gb(a+32|0);b=b+1|0;if((b|0)!=128){continue}break}hb=a- -64|0;break e}b=N()|0;break f}b=N()|0;break g}b=N()|0;xb(a+48|0)}xb(a+16|0)}Gb(a+32|0);Q(b|0);p()}}function X_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;h=Wb(a+208|0);x[114414]=0;Dc(a+16|0,d);b=x[114414];x[114414]=0;a:{b:{c:{d:{if((b|0)!=1){x[114414]=0;b=R(2510,a+16|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break d}x[114414]=0;Z(2523,b|0,64928,64954,a+224|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break d}Ob(a+16|0);c=Wb(a+192|0);b=Fc(c);x[114414]=0;P(1649,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=pc(c,0);x[a+188>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){e:{x[114414]=0;d=O(2515,a+344|0,a+336|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break e}if(d){break c}if(x[a+188>>2]==(Bb(c)+b|0)){d=Bb(c);b=Bb(c);x[114414]=0;P(1649,c|0,b<<1);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=Fc(c);x[114414]=0;P(1649,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=pc(c,0);x[a+188>>2]=d+b}x[114414]=0;d=R(2516,a+344|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break e}x[114414]=0;d=ik(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=x[114414];x[114414]=0;if((g|0)==1){break e}if(d){break c}x[114414]=0;R(2518,a+344|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){continue}}break}break b}b=N()|0;break a}b=N()|0;Ob(a+16|0);break a}x[114414]=0;P(1649,c|0,x[a+188>>2]-b|0);b=x[114414];x[114414]=0;f:{if((b|0)==1){break f}b=Rb(c);x[114414]=0;d=$(2507)|0;g=x[114414];x[114414]=0;if((g|0)==1){break f}x[a>>2]=f;x[114414]=0;b=Z(2508,b|0,d|0,5233,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break f}if((b|0)!=1){x[e>>2]=4}x[114414]=0;b=O(2515,a+344|0,a+336|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(c);xb(h);hb=a+352|0;return b|0}}b=N()|0;xb(c)}xb(h);Q(b|0);p()}function gaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=hb-208|0;hb=c;e=pl(c+104|0,a);x[114414]=0;d=O(658,c+88|0,35963)|0;a=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){x[114414]=0;x[c+72>>2]=19469590;x[c+76>>2]=0;T(659,e|0,d|0,c+72|0);a=x[114414];x[114414]=0;if((a|0)==1){break n}Gb(d);if(x[e>>2]&1073741824){break e}x[114414]=0;d=O(658,c+72|0,9198)|0;a=x[114414];x[114414]=0;if((a|0)==1){break m}x[114414]=0;Z(1584,e|0,b|0,d|0,1585)|0;a=x[114414];x[114414]=0;if((a|0)==1){break l}Gb(d);x[114414]=0;x[c+68>>2]=0;x[c+64>>2]=0;d=O(658,c+48|0,12606)|0;a=x[114414];x[114414]=0;if((a|0)==1){break k}x[114414]=0;U(1586,e|0,c+68|0,d|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break j}Gb(d);x[114414]=0;d=O(658,c+32|0,12596)|0;a=x[114414];x[114414]=0;if((a|0)==1){break i}x[114414]=0;U(1586,e|0,c- -64|0,d|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break h}Gb(d);a=x[c+64>>2];d=x[c+68>>2];o:{if(!d){break o}if(a>>>0<d>>>0|d>>>0>A[x[qn(b)+8>>2]+40>>2]){break o}if(a>>>0>A[x[qn(b)+8>>2]+40>>2]){break o}x[b+20>>2]=a;x[b+16>>2]=d}d=Dk(c+16|0);x[114414]=0;f=O(658,c|0,9885)|0;a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;Z(1587,e|0,d|0,f|0,651)|0;a=x[114414];x[114414]=0;if((a|0)==1){break g}Gb(f);if(od(d)){break f}a=x[b+16>>2];x[114414]=0;T(1424,d|0,a|0,16777216);a=x[114414];x[114414]=0;if((a|0)!=1){break f}break c}a=N()|0;break a}a=N()|0;Gb(d);break a}a=N()|0;break a}a=N()|0;Gb(d);break a}a=N()|0;break a}a=N()|0;Gb(d);break a}a=N()|0;break a}a=N()|0;Gb(d);break a}a=N()|0;Gb(f);break b}x[114414]=0;P(1588,b|0,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}Ge(d)}Hg(e);hb=c+208|0;return}a=N()|0;break b}a=N()|0}Ge(d)}Hg(e);Q(a|0);p()}function i$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-272|0;hb=a;x[a+256>>2]=c;x[a+264>>2]=b;h=Wb(a+208|0);x[114414]=0;Dc(a+16|0,d);b=x[114414];x[114414]=0;a:{b:{c:{d:{if((b|0)!=1){x[114414]=0;b=R(21,a+16|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break d}x[114414]=0;Z(2503,b|0,64928,64954,a+224|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break d}Ob(a+16|0);c=Wb(a+192|0);b=Fc(c);x[114414]=0;P(1649,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=pc(c,0);x[a+188>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){e:{x[114414]=0;d=O(2486,a+264|0,a+256|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break e}if(d){break c}if(x[a+188>>2]==(Bb(c)+b|0)){d=Bb(c);b=Bb(c);x[114414]=0;P(1649,c|0,b<<1);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=Fc(c);x[114414]=0;P(1649,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}b=pc(c,0);x[a+188>>2]=d+b}x[114414]=0;d=R(2487,a+264|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break e}x[114414]=0;d=jk(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=x[114414];x[114414]=0;if((g|0)==1){break e}if(d){break c}x[114414]=0;R(2489,a+264|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){continue}}break}break b}b=N()|0;break a}b=N()|0;Ob(a+16|0);break a}x[114414]=0;P(1649,c|0,x[a+188>>2]-b|0);b=x[114414];x[114414]=0;f:{if((b|0)==1){break f}b=Rb(c);x[114414]=0;d=$(2507)|0;g=x[114414];x[114414]=0;if((g|0)==1){break f}x[a>>2]=f;x[114414]=0;b=Z(2508,b|0,d|0,5233,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break f}if((b|0)!=1){x[e>>2]=4}x[114414]=0;b=O(2486,a+264|0,a+256|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];xb(c);xb(h);hb=a+272|0;return b|0}}b=N()|0;xb(c)}xb(h);Q(b|0);p()}function Zba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=hb-32|0;hb=h;b=a+8|0;Ys(b,Pe(b));l=yb(b),m=0,x[l>>2]=m;l=b,m=mc(b),x[l>>2]=m;l=mc(b),m=0,x[l>>2]=m;x[a+32>>2]=0;x[a+36>>2]=0;g=a+4|0;x[x[g>>2]>>2]=0;x[x[g>>2]+40>>2]=x[x[a>>2]+480196>>2];x[x[g>>2]+44>>2]=x[x[a>>2]+480204>>2];x[x[g>>2]+68>>2]=x[x[a>>2]+480200>>2];c=z[x[a>>2]+480188>>1];x[h+24>>2]=0;x[h+28>>2]=0;x[h+16>>2]=0;x[h+20>>2]=0;x[h+8>>2]=0;x[h+12>>2]=0;d=h+8|0;b=d;x[b>>2]=0;x[b+4>>2]=0;v[b+21|0]=255;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;x[b+8>>2]=0;x[b+12>>2]=0;i=hb-16|0;hb=i;x[i+12>>2]=c;b=a+20|0;a:{if(af(b)>>>0>=c>>>0){l=i,m=xd(b),x[l+8>>2]=m;c=x[b>>2];e=x[Mb(i+12|0,i+8|0)>>2];if(e){while(1){f=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=f;f=z[d+18>>1]|z[d+20>>1]<<16;j=z[d+14>>1]|z[d+16>>1]<<16;w[c+14>>1]=j;w[c+16>>1]=j>>>16;w[c+18>>1]=f;w[c+20>>1]=f>>>16;f=x[d+12>>2];x[c+8>>2]=x[d+8>>2];x[c+12>>2]=f;c=c+24|0;e=e-1|0;if(e){continue}break}}c=x[i+12>>2];e=x[i+8>>2];if(c>>>0>e>>>0){xM(b,c-e|0,d);break a}d=x[b>>2]+D(c,24)|0;xd(b);yM(b,d);Yp(b);break a}if(x[b>>2]){xd(b);AM(b);Yp(b);xp(yb(b),x[b>>2],af(b));l=yb(b),m=0,x[l>>2]=m;x[b>>2]=0;x[b+4>>2]=0}f=Zk(b,c);e=hb-16|0;hb=e;if(NT(b)>>>0<f>>>0){Vc();p()}vM(e+8|0,yb(b),f);f=x[e+8>>2];x[b+4>>2]=f;x[b>>2]=f;j=x[e+12>>2];l=yb(b),m=f+D(j,24)|0,x[l>>2]=m;Yk(b,0);hb=e+16|0;xM(b,c,d)}hb=i+16|0;if(z[x[a>>2]+480188>>1]){while(1){b=D(k,896);Hn((b+x[g>>2]|0)+608|0,7,x[a>>2],k&65535,1024);v[(b+x[g>>2]|0)+1445|0]=0;v[(b+x[g>>2]|0)+1444|0]=0;v[(b+x[g>>2]|0)+1429|0]=0;v[(b+x[g>>2]|0)+1432|0]=0;v[(b+x[g>>2]|0)+1427|0]=0;k=k+1|0;if(k>>>0<z[x[a>>2]+480188>>1]){continue}break}}hb=h+32|0}function Zka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-32|0;hb=g;x[g+24>>2]=d;i=Vj(a,c);vf(g,x[a+28>>2]);d=x[g+12>>2];x[g+16>>2]=x[g+8>>2];x[g+20>>2]=d;a:{if(!i){if(Cd(a,5)){break a}}j=x[g+24>>2];d=hb-192|0;hb=d;h=pl(d+88|0,x[a+28>>2]);x[114414]=0;f=O(658,d+72|0,24359)|0;e=x[114414];x[114414]=0;b:{c:{d:{e:{if((e|0)!=1){x[114414]=0;x[d+8>>2]=19469590;x[d+12>>2]=0;T(659,h|0,f|0,d+8|0);e=x[114414];x[114414]=0;if((e|0)==1){break e}Gb(f);if(!(x[h>>2]&1073741824)){break d}break b}e=N()|0;break c}e=N()|0;Gb(f);break c}x[114414]=0;v[d+71|0]=0;v[d+70|0]=0;f=O(658,d+56|0,6080)|0;e=x[114414];x[114414]=0;f:{if((e|0)!=1){x[114414]=0;U(1174,h|0,d+71|0,f|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break f}Gb(f);if(!y[d+71|0]){break b}_e(d+71|0,50);x[114414]=0;f=O(658,d+40|0,9079)|0;e=x[114414];x[114414]=0;g:{h:{i:{j:{if((e|0)!=1){x[114414]=0;U(1174,h|0,d+70|0,f|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break j}Gb(f);f=Vh(b);e=y[d+71|0];if(f>>>0<e>>>0){f=hz(d+8|0,x[b+12>>2]);x[114414]=0;T(1175,b|0,e|0,f|0);e=x[114414];x[114414]=0;if((e|0)==1){break i}Kk(f)}e=0;f=z[Ni(b,0)+28>>1];v[d+7|0]=0;if(y[d+71|0]){while(1){Se(Ni(b,e&255),f);e=Ni(b,y[d+7|0]);x[114414]=0;P(1176,d+8|0,d+7|0);k=x[114414];x[114414]=0;if((k|0)==1){break h}x[114414]=0;X(1177,h|0,e|0,d+8|0,j|0);e=x[114414];x[114414]=0;if((e|0)==1){break g}Gb(d+8|0);e=y[d+7|0]+1|0;v[d+7|0]=e;if(y[d+71|0]>(e&255)>>>0){continue}break}}e=y[d+70|0];f=Vh(b);v[b+16|0]=e>>>0<f>>>0?y[d+70|0]:0;break b}e=N()|0;break c}e=N()|0;Gb(f);break c}e=N()|0;Kk(f);break c}e=N()|0;break c}e=N()|0;Gb(d+8|0);break c}e=N()|0;break c}e=N()|0;Gb(f)}Hg(h);Q(e|0);p()}Hg(h);hb=d+192|0}hj(a,i,c,g+16|0);hb=g+32|0}function gfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=hb-48|0;hb=e;s=x[a+16>>2];m=x[a+44>>2];x[e+28>>2]=m;h=x[a+48>>2];x[e+32>>2]=h;i=x[a+52>>2];x[e+36>>2]=i;o=x[a+56>>2];x[e+40>>2]=o;t=x[a+24>>2];u=x[a+20>>2];f=x[a+4>>2];j=f;g=x[a>>2];x[e+16>>2]=g;x[e+20>>2]=f;f=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=f;if(d){v=b+24|0;while(1){o=1;b=x[e+16>>2];l=((((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+s|0;b=(((b>>>16|0)+4&131064)<<1)+v|0;k=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];n=w[b+8>>1];r=w[b+6>>1];m=w[b+4>>1];j=w[b+2>>1];f=w[b>>1];i=0;b=1;h=0;while(1){g=h<<1;x[(h<<2)+e>>2]=(((((D(w[l+(g|8)>>1],q)+D(w[l+(g|4)>>1],n)|0)+D(p,w[l+(g|12)>>1])|0)+D(k,w[l+(g|16)>>1])|0)/2|0)+((((D(w[l+(g|-8)>>1],j)+D(w[l+(g|-12)>>1],f)|0)+D(w[l+(g|-4)>>1],m)|0)+D(w[g+l>>1],r)|0)/2|0)|0)/16384;g=b&1;b=0;h=1;if(g){continue}break}while(1){b=(i<<2)+e|0;j=x[b>>2];h=x[a+60>>2];i=(e+24|0)+(i<<3)|0;f=x[i+4>>2];k=Xb(f,-16777216,16776704);n=x[a+64>>2];p=Xb(x[i+8>>2],-16777216,16776704);g=x[a+68>>2];r=g>>31;x[i+8>>2]=f;m=x[a+72>>2];q=j<<8;f=q;f=yna(h,h>>31,f,f>>31);j=lb;h=f;f=yna(n,n>>31,k,k>>31);n=h+f|0;k=lb+j|0;k=f>>>0>n>>>0?k+1|0:k;f=yna(g,r,p,p>>31);j=f+n|0;g=lb+k|0;g=f>>>0>j>>>0?g+1|0:g;h=b;f=j+8388608|0;b=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[h>>2]=(b|0)/256;x[i+4>>2]=b-(m&q);i=1;b=o&1;o=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],u);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],t);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}o=x[e+40>>2];i=x[e+36>>2];h=x[e+32>>2];j=x[e+20>>2];m=x[e+28>>2];g=x[e+16>>2]}x[a>>2]=g;x[a+4>>2]=j;x[a+56>>2]=o;x[a+52>>2]=i;x[a+48>>2]=h;x[a+44>>2]=m;hb=e+48|0}function f_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=hb-624|0;hb=a;x[a+608>>2]=c;x[a+616>>2]=b;x[a+16>>2]=2542;b=Pd(a+200|0,a+208|0,a+16|0);x[114414]=0;Dc(a+192|0,e);h=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){x[114414]=0;h=R(2510,a+192|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break j}v[a+191|0]=0;e=x[e+4>>2];x[114414]=0;c=pa(2554,a+616|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,h|0,b|0,a+196|0,a+608|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!c){break f}c=y[10190]|y[10191]<<8|(y[10192]<<16|y[10193]<<24);v[a+183|0]=c;v[a+184|0]=c>>>8;v[a+185|0]=c>>>16;v[a+186|0]=c>>>24;c=y[10187]|y[10188]<<8|(y[10189]<<16|y[10190]<<24);x[a+176>>2]=y[10183]|y[10184]<<8|(y[10185]<<16|y[10186]<<24);x[a+180>>2]=c;x[114414]=0;Z(2523,h|0,a+176|0,a+186|0,a+128|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break i}x[a+4>>2]=2484;d=Pd(a+8|0,0,a+4|0);e=a+16|0;if((x[a+196>>2]-x[b>>2]|0)<393){break g}we(d,sd((x[a+196>>2]-x[b>>2]>>2)+2|0));if(x[d>>2]){break h}x[114414]=0;V(2485);c=x[114414];x[114414]=0;if((c|0)==1){break d}break a}c=N()|0;break b}c=N()|0;break c}c=N()|0;break c}e=x[d>>2]}if(y[a+191|0]){v[e|0]=45;e=e+1|0}c=x[b>>2];while(1){if(A[a+196>>2]<=c>>>0){v[e|0]=0;x[a>>2]=g;if((GF(a+16|0,a)|0)!=1){x[114414]=0;W(2544,4205);c=x[114414];x[114414]=0;if((c|0)!=1){break a}break d}Jc(d)}else{h=a+128|0;j=e,k=y[(a+176|0)+(cw(h,h+40|0,c)-h>>2)|0],v[j|0]=k;e=e+1|0;c=c+4|0;continue}break}}x[114414]=0;c=O(2515,a+616|0,a+608|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(c){x[f>>2]=x[f>>2]|2}c=x[a+616>>2];Ob(a+192|0);Jc(b);hb=a+624|0;return c|0}c=N()|0;break c}c=N()|0;Jc(d)}Ob(a+192|0)}Jc(b);Q(c|0);p()}p()}function m_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=hb-288|0;hb=a;x[a+272>>2]=c;x[a+280>>2]=b;x[a+16>>2]=2542;b=Pd(a+152|0,a+160|0,a+16|0);x[114414]=0;Dc(a+144|0,e);h=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){x[114414]=0;h=R(21,a+144|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break j}v[a+143|0]=0;e=x[e+4>>2];x[114414]=0;c=pa(2543,a+280|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,h|0,b|0,a+148|0,a+260|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!c){break f}c=y[10190]|y[10191]<<8|(y[10192]<<16|y[10193]<<24);v[a+135|0]=c;v[a+136|0]=c>>>8;v[a+137|0]=c>>>16;v[a+138|0]=c>>>24;c=y[10187]|y[10188]<<8|(y[10189]<<16|y[10190]<<24);x[a+128>>2]=y[10183]|y[10184]<<8|(y[10185]<<16|y[10186]<<24);x[a+132>>2]=c;x[114414]=0;Z(2503,h|0,a+128|0,a+138|0,a+118|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break i}x[a+4>>2]=2484;d=Pd(a+8|0,0,a+4|0);e=a+16|0;if((x[a+148>>2]-x[b>>2]|0)<99){break g}we(d,sd((x[a+148>>2]-x[b>>2]|0)+2|0));if(x[d>>2]){break h}x[114414]=0;V(2485);c=x[114414];x[114414]=0;if((c|0)==1){break d}break a}c=N()|0;break b}c=N()|0;break c}c=N()|0;break c}e=x[d>>2]}if(y[a+143|0]){v[e|0]=45;e=e+1|0}c=x[b>>2];while(1){if(A[a+148>>2]<=c>>>0){v[e|0]=0;x[a>>2]=g;if((GF(a+16|0,a)|0)!=1){x[114414]=0;W(2544,4205);c=x[114414];x[114414]=0;if((c|0)!=1){break a}break d}Jc(d)}else{h=a+118|0;j=e,k=y[((Gl(h,h+10|0,c)-a|0)+a|0)+10|0],v[j|0]=k;e=e+1|0;c=c+1|0;continue}break}}x[114414]=0;c=O(2486,a+280|0,a+272|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(c){x[f>>2]=x[f>>2]|2}c=x[a+280>>2];Ob(a+144|0);Jc(b);hb=a+288|0;return c|0}c=N()|0;break c}c=N()|0;Jc(d)}Ob(a+144|0)}Jc(b);Q(c|0);p()}p()}function kK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=hb-16|0;hb=i;a:{if((b|0)==(c|0)){break a}x[i+12>>2]=-1953789045;jK(b,c,i+12|0);k=c-b|0;d=k>>2;x[i+8>>2]=d;e=Lb(a);c=11;b:{if(k>>>0>2488){break b}c=7;if(k>>>0>268){break b}c=5;if(k>>>0>152){break b}c=3;if(k>>>0>24){break b}c=d-1>>>1|0}j=1;m=e+1|0;x[i+4>>2]=m;k=x[_c(i+4|0,i+8|0)>>2];g=d-c>>>1|0;d=(g<<2)+b|0;f=D(Js(x[((x[i+8>>2]<<2)+b|0)-4>>2]^(x[d>>2]^x[b>>2])),1664525);x[d>>2]=f+x[d>>2];c=c+g|0;d=(c<<2)+b|0;l=d;h=x[d>>2];d=e+f|0;x[l>>2]=h+d;x[b>>2]=d;d=c;c=x[i+8>>2];d=(d>>>0)%(c>>>0)|0;g=(g>>>0)%(c>>>0)|0;f=c-1|0;c=0;if(e){while(1){g=g+1|0;h=x[i+8>>2];g=(h|0)!=(g|0)?g:0;l=(g<<2)+b|0;c=c+1|0;c=(c|0)!=(h|0)?c:0;n=(c<<2)+b|0;f=f+1|0;f=(f|0)!=(h|0)?f:0;o=D(Js(x[l>>2]^x[n>>2]^x[(f<<2)+b>>2]),1664525);x[l>>2]=o+x[l>>2];l=x[Pb(a,j-1|0)>>2]+(c+o|0)|0;d=d+1|0;d=(d|0)!=(h|0)?d:0;h=(d<<2)+b|0;x[h>>2]=l+x[h>>2];x[n>>2]=l;j=j+1|0;if(e>>>0>=j>>>0){continue}break}}if(k>>>0>m>>>0){while(1){a=g+1|0;e=a;a=x[i+8>>2];g=(e|0)!=(a|0)?e:0;e=(g<<2)+b|0;c=c+1|0;c=(a|0)!=(c|0)?c:0;h=(c<<2)+b|0;f=f+1|0;f=(a|0)!=(f|0)?f:0;j=D(Js(x[e>>2]^x[h>>2]^x[(f<<2)+b>>2]),1664525);x[e>>2]=j+x[e>>2];d=d+1|0;d=(a|0)!=(d|0)?d:0;a=(d<<2)+b|0;e=a;l=x[a>>2];a=c+j|0;x[e>>2]=l+a;x[h>>2]=a;m=m+1|0;if((k|0)!=(m|0)){continue}break}}e=x[i+8>>2];if(k>>>0>=k+e>>>0){break a}a=k;while(1){f=f+1|0;f=(e|0)!=(f|0)?f:0;g=g+1|0;g=(e|0)!=(g|0)?g:0;j=(g<<2)+b|0;c=c+1|0;c=(c|0)!=(e|0)?c:0;h=(c<<2)+b|0;m=D(Js(x[(f<<2)+b>>2]+(x[j>>2]+x[h>>2]|0)|0),1566083941);x[j>>2]=m^x[j>>2];d=d+1|0;d=(d|0)!=(e|0)?d:0;e=(d<<2)+b|0;l=e;j=x[e>>2];e=m-c|0;x[l>>2]=j^e;x[h>>2]=e;a=a+1|0;e=x[i+8>>2];if(a>>>0<k+e>>>0){continue}break}}hb=i+16|0}function aU(){var a=0,b=0,c=0,d=0,e=0,f=0;if(!y[460789]){c=x[15166];b=hb-16|0;hb=b;a=Zr(460436);x[a+40>>2]=460492;x[a+32>>2]=c;x[a>>2]=60680;v[a+52|0]=0;x[a+48>>2]=-1;d=b+8|0;Tr(d,a);e=x[x[a>>2]+8>>2];x[114414]=0;P(e|0,a|0,d|0);d=x[114414];x[114414]=0;a:{if((d|0)!=1){Ob(b+8|0);hb=b+16|0;break a}c=N()|0;Ob(b+8|0);zl(a);Q(c|0);p()}a=rs(459760);x[114938]=59180;x[a>>2]=59200;x[114939]=0;x[114414]=0;P(2451,a|0,460436);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}d=x[15167];aG(460500,d,460548);tw(459928,460500);e=x[14652];aG(460556,e,460604);tw(460096,460556);tw(460264,x[(x[x[115024]-12>>2]+460096|0)+24>>2]);Lr(x[x[114938]-12>>2]+459752|0,459928);_F(x[x[115024]-12>>2]+460096|0);Lr(x[x[115024]-12>>2]+460096|0,459928);b=hb-16|0;hb=b;a=nG(460612);x[a+40>>2]=460668;x[a+32>>2]=c;x[a>>2]=60884;v[a+52|0]=0;x[a+48>>2]=-1;c=b+8|0;Tr(c,a);f=x[x[a>>2]+8>>2];x[114414]=0;P(f|0,a|0,c|0);c=x[114414];x[114414]=0;d:{if((c|0)!=1){Ob(b+8|0);hb=b+16|0;break d}c=N()|0;Ob(b+8|0);Xo(a);Q(c|0);p()}a=YF(459848);x[114960]=59340;x[a>>2]=59360;x[114961]=0;x[114414]=0;P(2453,a|0,460612);b=x[114414];x[114414]=0;if((b|0)==1){break c}ZF(460676,d,460724);sw(460012,460676);ZF(460732,e,460780);sw(460180,460732);sw(460348,x[(x[x[115045]-12>>2]+460180|0)+24>>2]);Lr(x[x[114960]-12>>2]+459840|0,460012);_F(x[x[115045]-12>>2]+460180|0);Lr(x[x[115045]-12>>2]+460180|0,460012);break b}b=N()|0;gh(a);Q(b|0);p()}v[460789]=1}a=hb-16|0;hb=a;e:{if(Oa(a+12|0,a+8|0)|0){break e}b=sd((x[a+12>>2]<<2)+4|0);x[115199]=b;if(!b){break e}b=sd(x[a+8>>2]);if(b){x[x[115199]+(x[a+12>>2]<<2)>>2]=0;if(!(Na(x[115199],b|0)|0)){break e}}x[115199]=0}hb=a+16|0;rL();x[114284]=457016;x[114266]=42}function Zx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;e=1;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=y[a|0];switch(d|0){case 0:break a;case 3:break j;case 2:break k;case 13:break l;case 5:break b;case 9:break d;case 11:break e;case 20:break f;case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break g;case 4:break i;default:break h}}v[a|0]=1;v[f+15|0]=64;i=b,j=y[rc(b,f+15|0)|0],v[i|0]=j;break a}d=y[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}v[b|0]=(d&252)>>>2;v[a|0]=12;e=1;break a}d=y[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}v[b|0]=(d&252)>>>2;v[a|0]=13;e=1;break a}g=y[b|0];if(g>>>0<240){d=0;while(1){h=y[d+25920|0];m:{n:{if(c){if(g>>>0<=h>>>0){break n}break m}if((g|0)!=(h|0)){break m}}v[a|0]=11;v[b|0]=d;break a}e=d>>>0<9;d=d+1|0;if((d|0)!=10){continue}break}break a}v[a|0]=11;v[b|0]=9;break a}if((d|0)==26){break c}}e=0;break a}e=0;o:{p:{q:{d=y[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}v[b|0]=0;v[a|0]=0;e=1;break a}v[a|0]=2;v[b|0]=y[b|0]<<2&60|2;e=1;break a}e=0;c=y[b|0];if(!c){break a}d=c&15;if(!d){v[b|0]=c>>>4;v[a|0]=3;e=1;break a}g=c&240;if(!g){v[a|0]=4;e=1;break a}if((d|0)==15){v[b|0]=c>>>4;v[a|0]=5;e=1;break a}if((g|0)!=240){break a}v[b|0]=d;v[a|0]=6;e=1;break a}c=b;b=y[b|0];v[c|0]=(b|0)==255?64:b>>>2|0;v[a|0]=2;break a}r:{if(c){v[b|0]=0;break r}e=0;if(y[b|0]){break a}}v[a|0]=8;e=1;break a}s:{if(c){v[f+14|0]=y[b|0]&15;v[f+13|0]=9;d=y[rc(f+14|0,f+13|0)|0];break s}e=0;d=y[b|0];if(d>>>0>15|(d&14)>>>0>9){break a}}v[b|0]=d&15;v[a|0]=8;e=1}hb=f+16|0;return e}function XH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0);e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;c=x[a+8>>2];x[e+28>>2]=e+36;x[e+24>>2]=e+40;b=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=b;x[e+16>>2]=a;x[e+20>>2]=e+44;b=x[e+20>>2];x[e>>2]=x[e+16>>2];x[e+4>>2]=b;a:{b:{switch(x[c+40>>2]){case 0:b=hb-80|0;hb=b;d=x[e>>2];g=x[d+4>>2];x[b+40>>2]=x[d+20>>2];i=x[d+16>>2];x[b+32>>2]=x[d+12>>2];x[b+36>>2]=i;ep(b- -64|0,b+32|0,g);d=Mc(b+48|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];i=x[x[e+8>>2]>>2];x[b+24>>2]=x[b+72>>2];f=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=f;x[b+8>>2]=x[d+8>>2];f=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=f;if(g){f=b+16|0;while(1){d=0;if(i){while(1){j=C[kh(b,d,h)>>3];gc(c,d);l=Rf(f,d,h),m=E(j),B[l>>2]=m;d=d+1|0;if((i|0)!=(d|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}hb=b+80|0;break a;case 2:gx(e,yb(c));break a;case 3:i=ah(c);d=0;b=hb-80|0;hb=b;c=x[e>>2];h=x[c+4>>2];x[b+40>>2]=x[c+20>>2];g=x[c+16>>2];x[b+32>>2]=x[c+12>>2];x[b+36>>2]=g;ep(b- -64|0,b+32|0,h);c=Mc(b+48|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);h=x[x[e+12>>2]>>2];g=x[x[e+8>>2]>>2];x[b+24>>2]=x[b+72>>2];f=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=f;x[b+8>>2]=x[c+8>>2];f=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=f;if(h){f=b+16|0;while(1){c=0;if(g){while(1){j=C[kh(b,c,d)>>3];$e(i,c);k=Cj(Qd(j*134217728));l=Rf(f,c,d),m=E(+(k|0)*7.450580596923828e-9),B[l>>2]=m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:gx(e,yb(c));break a;default:break b}}gx(e,yb(c))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function ufa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;i=hb-16|0;hb=i;g=x[a+12>>2];f=g;a:{b:{c:{e=x[a+8>>2];d:{if((f|0)<=1&e>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&e>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&e>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&e>>>0>2147483648|f>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}m=b;n=x[a+16>>2];g=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];j=x[a+44>>2];h=x[a+4>>2];b=x[a>>2];x[i+8>>2]=b;x[i+12>>2]=h;x[i>>2]=e;x[i+4>>2]=f;e:{if(!d){e=k>>12;f=l>>12;break e}while(1){b=(x[i+8>>2]>>>16&65520)+m|0;h=w[b>>1];e=(x[i+12>>2]<<1)+n|0;o=w[e-6>>1];p=w[b+2>>1];q=w[e-4>>1];r=w[b+4>>1];s=w[e-2>>1];t=w[b+6>>1];u=w[e>>1];v=w[b+8>>1];y=w[e+2>>1];z=w[b+10>>1];A=w[e+4>>1];B=w[b+12>>1];C=w[e+6>>1];E=w[b+14>>1];F=w[e+8>>1];e=x[a+60>>2];b=j;j=Xb(b,-16777216,16776704);f=x[a+64>>2];g=Xb(g,-16777216,16776704);G=x[a+72>>2];H=x[a+32>>2];I=x[c>>2];f=yna(f,f>>31,j,j>>31);J=lb;j=(((((((D(p,q)+D(h,o)|0)+D(r,s)|0)+D(t,u)|0)+D(v,y)|0)+D(z,A)|0)+D(B,C)|0)+D(E,F)|0)/32768<<8;h=yna(e,e>>31,j,j>>31);f=h+f|0;e=lb+J|0;e=f>>>0<h>>>0?e+1|0:e;h=f;f=x[a+68>>2];f=yna(f,f>>31,g,g>>31);g=h+f|0;e=lb+e|0;e=f>>>0>g>>>0?e+1|0:e;l=x[a+28>>2]+l|0;f=l>>12;g=g+8388608|0;g=((g>>>0<8388608?e+1|0:e)&16777215)<<8|g>>>24;h=(g|0)/256|0;x[c>>2]=D(f,h)+I;k=k+H|0;e=k>>12;x[c+4>>2]=x[c+4>>2]+D(h,e);j=g-(j&G)|0;c=c+8|0;Tb(i+8|0,i);g=b;d=d-1|0;if(d){continue}break}b=x[i+8>>2];h=x[i+12>>2]}x[a>>2]=b;x[a+4>>2]=h;x[a+40>>2]=k;x[a+20>>2]=f;x[a+36>>2]=l;x[a+48>>2]=g;x[a+44>>2]=j;x[a+24>>2]=e;hb=i+16|0}function vfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=hb-16|0;hb=h;l=x[a+12>>2];g=l;a:{b:{c:{f=x[a+8>>2];d:{if((g|0)<=1&f>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&f>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&f>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&f>>>0>2147483648|g>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}r=x[a+16>>2];j=x[a+48>>2];m=x[a+40>>2];n=x[a+36>>2];e=x[a+44>>2];k=x[a+4>>2];p=k;b=x[a>>2];x[h+8>>2]=b;x[h+12>>2]=k;x[h>>2]=f;x[h+4>>2]=g;e:{if(!d){g=m>>12;k=n>>12;break e}while(1){f=x[h+12>>2]+r|0;s=v[f+4|0];b=(x[h+8>>2]>>>16&65520)+l|0;t=w[b+14>>1];u=v[f+3|0];y=w[b+12>>1];z=v[f+2|0];A=w[b+10>>1];B=v[f+1|0];C=w[b+8>>1];E=v[f|0];F=w[b+6>>1];G=v[f-1|0];H=w[b+4>>1];I=v[f-2|0];J=w[b+2>>1];K=v[f-3|0];q=w[b>>1];f=x[a+60>>2];b=e;i=Xb(e,-16777216,16776704);e=x[a+64>>2];o=Xb(j,-16777216,16776704);p=x[a+72>>2];g=x[a+32>>2];k=x[c>>2];e=yna(e,e>>31,i,i>>31);j=lb;i=e;e=x[a+68>>2];e=yna(e,e>>31,o,o>>31);o=i+e|0;i=lb+j|0;i=e>>>0>o>>>0?i+1|0:i;q=(((((((D(I,J)+D(q,K)|0)+D(G,H)|0)+D(E,F)|0)+D(B,C)|0)+D(z,A)|0)+D(u,y)|0)+D(s,t)<<8)/32768<<8;e=q;e=yna(f,f>>31,e,e>>31);j=e+o|0;f=lb+i|0;f=e>>>0>j>>>0?f+1|0:f;i=k;n=x[a+28>>2]+n|0;k=n>>12;e=j+8388608|0;e=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;f=(e|0)/256|0;x[c>>2]=i+D(k,f);m=g+m|0;g=m>>12;x[c+4>>2]=x[c+4>>2]+D(f,g);e=e-(p&q)|0;c=c+8|0;Tb(h+8|0,h);j=b;d=d-1|0;if(d){continue}break}b=x[h+8>>2];p=x[h+12>>2]}x[a>>2]=b;x[a+4>>2]=p;x[a+40>>2]=m;x[a+20>>2]=k;x[a+36>>2]=n;x[a+48>>2]=j;x[a+44>>2]=e;x[a+24>>2]=g;hb=h+16|0}function Hp(a,b,c,d){var e=E(0),f=E(0),g=0,h=E(0),i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,p=0;g=hb-16|0;hb=g;x[g+12>>2]=w[b+792>>1]+y[b+857|0];x[g+8>>2]=w[b+794>>1]+(y[b+858|0]&127);_d(g+12|0,0,127);_d(g+8|0,0,127);k=a+1074312|0;j=$b(k,1);i=x[g+12>>2];if(!j){w[b+792>>1]=0;v[b+857|0]=i;j=x[g+8>>2];w[b+794>>1]=0;v[b+858|0]=j}i=D(i,d+256|0);j=(i|0)/256|0;n=$b(k,36);l=x[g+8>>2];a:{if(!(l|!n|(i|0)<65024)){j=-1;a=b+810|0;if(!Af(a)){break a}if(it(a)|z[b+808>>1]|!(y[b+872|0]&2)){break a}x[b+88>>2]=x[b+88>>2]&-32769;break a}x[b+88>>2]=x[b+88>>2]|32768;f=le(E(10),E(E(0-l|0)*E(.00937500037252903)));i=hb-16|0;hb=i;e=E(D(x[g+12>>2],d+256|0)>>>0);b:{if(x[a+480180>>2]!=33554432){h=E(110);e=E(E(e/(y[a+480209|0]&128?E(10240):E(12288)))+E(.25));break b}h=E(125);e=E(e*E(9227362170349807e-20))}o=i,p=Uh(E(le(E(2),e)*h)),x[o+12>>2]=p;_d(i+12|0,120,2e4);hb=i+16|0;d=x[a+24620>>2];i=x[i+12>>2];e=E(E(((d|0)<i<<1?d>>>1|0:i)>>>0)*E(6.2831854820251465));c:{if(!(!$b(k,36)|y[a+480209|0]&128)){h=E(E(A[a+24620>>2])/e);e=E(E(f+E(-1))+E(h*f));B[g+4>>2]=e;f=E(h*h);break c}h=E(e/E(A[a+24620>>2]));f=E(f+f);B[g+4>>2]=h*E(E(1)-f);jN(g+4|0,E(2));e=E(E(f-B[g+4>>2])/h);B[g+4>>2]=e;f=E(E(1)/E(h*h))}h=E(E(e+f)+E(1));e=E(E(E(f+f)+e)/h);m=E(E(16777216)/h);f=E(E(-f)/h);d:{if(y[b+865|0]==1){o=b,p=Uh(E(E(16777216)-m)),x[o+60>>2]=p;o=b,p=Uh(E(e*E(16777216))),x[o+64>>2]=p;o=b,p=Uh(E(f*E(16777216))),x[o+68>>2]=p;a=-1;break d}o=b,p=Uh(m),x[o+60>>2]=p;o=b,p=Uh(E(e*E(16777216))),x[o+64>>2]=p;o=b,p=Uh(E(f*E(16777216))),x[o+68>>2]=p;a=0;if(x[b+60>>2]){break d}x[b+60>>2]=1}x[b+72>>2]=a;if(!c){break a}x[b+44>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;x[b+56>>2]=0}hb=g+16|0;return j}function hfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;e=hb-48|0;hb=e;s=x[a+16>>2];g=x[a+44>>2];x[e+28>>2]=g;m=x[a+48>>2];x[e+32>>2]=m;i=x[a+52>>2];x[e+36>>2]=i;o=x[a+56>>2];x[e+40>>2]=o;t=x[a+24>>2];u=x[a+20>>2];f=x[a+4>>2];j=f;h=x[a>>2];x[e+16>>2]=h;x[e+20>>2]=f;f=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=f;if(d){y=b+24|0;while(1){b=x[e+16>>2];k=(((x[e+20>>2]&2147483647)<<1|b>>>31)&-2)+s|0;o=1;b=(((b>>>16|0)+4&131064)<<1)+y|0;l=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];n=w[b+8>>1];r=w[b+6>>1];m=w[b+4>>1];j=w[b+2>>1];f=w[b>>1];i=0;b=1;g=0;while(1){x[(g<<2)+e>>2]=((((D(v[k+(g|4)|0],q)+D(v[k+(g|2)|0],n)|0)+D(p,v[k+(g|6)|0])|0)+D(l,v[k+(g|8)|0])<<8>>1)+(((D(v[k+(g|-4)|0],j)+D(v[k+(g|-6)|0],f)|0)+D(v[k+(g|-2)|0],m)|0)+D(v[g+k|0],r)<<8>>1)|0)/16384;h=b&1;b=0;g=1;if(h){continue}break}while(1){b=(i<<2)+e|0;j=x[b>>2];k=x[a+60>>2];i=(e+24|0)+(i<<3)|0;f=x[i+4>>2];l=Xb(f,-16777216,16776704);n=x[a+64>>2];p=Xb(x[i+8>>2],-16777216,16776704);h=x[a+68>>2];r=h>>31;x[i+8>>2]=f;m=x[a+72>>2];q=j<<8;f=q;f=yna(k,k>>31,f,f>>31);j=lb;g=f;f=yna(n,n>>31,l,l>>31);n=g+f|0;l=lb+j|0;l=f>>>0>n>>>0?l+1|0:l;f=yna(h,r,p,p>>31);j=f+n|0;h=lb+l|0;h=f>>>0>j>>>0?h+1|0:h;g=b;f=j+8388608|0;b=((f>>>0<8388608?h+1|0:h)&16777215)<<8|f>>>24;x[g>>2]=(b|0)/256;x[i+4>>2]=b-(m&q);i=1;b=o&1;o=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],u);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],t);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}o=x[e+40>>2];i=x[e+36>>2];m=x[e+32>>2];j=x[e+20>>2];g=x[e+28>>2];h=x[e+16>>2]}x[a>>2]=h;x[a+4>>2]=j;x[a+56>>2]=o;x[a+52>>2]=i;x[a+48>>2]=m;x[a+44>>2]=g;hb=e+48|0}function lz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=hb-32|0;hb=f;d=c&4;a:{if(!(b&4)){if(!d){break a}v[a+15|0]=y[a+16|0];b=y[a+12|0];v[a+12|0]=b&247;e=!(b&2);b=y[a+14|0];if(e|b>>>0<=y[a+13|0]){break a}if(Lb(a)>>>0<=b>>>0){break a}while(1){d=Ec(a,b);w[d>>1]=z[d>>1]+1;b=b+1|0;if(Lb(a)>>>0>b>>>0){continue}break}break a}if(d){break a}b=y[a+14|0];b:{if(b>>>0>=y[a+15|0]){break b}d=y[a+12|0];if(!(d&2)){break b}v[a+12|0]=d&251}if(!(y[a+12|0]&2)|b>>>0<=y[a+13|0]){break a}if(Lb(a)>>>0<=b>>>0){break a}d=z[Ec(a,y[a+14|0])>>1];e=Ec(a,y[a+14|0]-1|0);b=y[a+14|0];if(z[e>>1]<(d-1|0)){b=z[Ec(a,b)>>1]-1&65535;d=Up(a,b,64,64);o=f,q=bc(a),x[o+8>>2]=q;o=f,q=Gn(f+8|0,y[a+14|0]),x[o+16>>2]=q;e=td(f+24|0,f+16|0);h=eq(f,b,d&255);g=hb-48|0;hb=g;x[g+32>>2]=x[e>>2];b=x[a>>2];o=g,q=bc(a),x[o+8>>2]=q;b=b+(Zt(g+32|0,g+8|0)<<2)|0;c:{d:{if(A[a+4>>2]<A[yb(a)>>2]){i=x[a+4>>2];if((i|0)!=(b|0)){break d}KR(a,h);break c}d=yb(a);d=po(g+8|0,ze(a,Lb(a)+1|0),b-x[a>>2]>>2,d);x[114414]=0;P(1147,d|0,h|0);e=x[114414];x[114414]=0;e:{if((e|0)==1){break e}x[114414]=0;b=U(1148,a|0,d|0,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break e}_i(d);break c}a=N()|0;_i(d);Q(a|0);p()}l=hb-16|0;hb=l;n=x[a+4>>2];d=(n-(b+4|0)|0)+b|0;j=je(l,a,i-d>>2);f:{g:{if(d>>>0<i>>>0){k=x[j+4>>2];e=d;while(1){m=yb(a);x[114414]=0;T(741,m|0,k|0,e|0);m=x[114414];x[114414]=0;if((m|0)==1){break g}k=k+4|0;x[j+4>>2]=k;e=e+4|0;if(i>>>0>e>>>0){continue}break}}Jb(j);bq(b,d,n);hb=l+16|0;break f}a=N()|0;Jb(j);Q(a|0);p()}v[b+2|0]=y[h+2|0];w[b>>1]=z[h>>1]}Fb(g+40|0,b);hb=g+48|0;break a}v[a+14|0]=b-1}if((c|0)!=16777216){v[a+17|0]=255}hb=f+32|0}function Ifa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;t=x[a+16>>2];j=x[a+44>>2];x[b+28>>2]=j;m=x[a+48>>2];x[b+32>>2]=m;h=x[a+52>>2];x[b+36>>2]=h;i=x[a+56>>2];x[b+40>>2]=i;p=x[a+40>>2];q=x[a+36>>2];g=x[a+4>>2];f=g;e=x[a>>2];x[b+16>>2]=e;x[b+20>>2]=f;g=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=g;a:{if(!d){g=p>>12;k=q>>12;break a}while(1){m=1;e=x[b+16>>2];n=((((x[b+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+t|0;e=(e>>>21&2040)+32976|0;s=w[e+6>>1];i=w[e+4>>1];f=w[e+2>>1];g=w[e>>1];j=0;h=1;k=0;while(1){e=k<<1;x[(k<<2)+b>>2]=(((D(w[e+n>>1],f)+D(w[n+(e|-4)>>1],g)|0)+D(i,w[n+(e|4)>>1])|0)+D(s,w[n+(e|8)>>1])|0)/16384;e=h&1;h=0;k=1;if(e){continue}break}while(1){e=(j<<2)+b|0;i=x[e>>2];o=x[a+60>>2];r=(b+24|0)+(j<<3)|0;f=x[r+4>>2];l=Xb(f,-16777216,16776704);h=x[a+64>>2];j=Xb(x[r+8>>2],-16777216,16776704);g=x[a+68>>2];n=g>>31;x[r+8>>2]=f;s=x[a+72>>2];k=i<<8;f=k;f=yna(o,o>>31,f,f>>31);i=lb;o=f;f=yna(h,h>>31,l,l>>31);h=o+f|0;l=lb+i|0;l=f>>>0>h>>>0?l+1|0:l;f=yna(g,n,j,j>>31);i=f+h|0;g=lb+l|0;g=f>>>0>i>>>0?g+1|0:g;o=e;f=i+8388608|0;e=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[o>>2]=(e|0)/256;x[r+4>>2]=e-(k&s);j=1;e=m&1;m=0;if(e){continue}break}e=x[a+32>>2];q=x[a+28>>2]+q|0;k=q>>12;x[c>>2]=x[c>>2]+D(k,x[b>>2]);p=e+p|0;g=p>>12;x[c+4>>2]=x[c+4>>2]+D(g,x[b+4>>2]);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}i=x[b+40>>2];h=x[b+36>>2];m=x[b+32>>2];j=x[b+28>>2];e=x[b+16>>2];f=x[b+20>>2]}x[a>>2]=e;x[a+4>>2]=f;x[a+40>>2]=p;x[a+20>>2]=k;x[a+36>>2]=q;x[a+56>>2]=i;x[a+52>>2]=h;x[a+48>>2]=m;x[a+44>>2]=j;x[a+24>>2]=g;hb=b+48|0}function Hr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=hb-128|0;hb=i;x[i+120>>2]=b;k=kt(c,d);x[i+4>>2]=2484;n=Pd(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=sd(k);if(!j){x[114414]=0;V(2485);a=x[114414];x[114414]=0;if((a|0)!=1){break a}break b}we(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[114414]=0;h=O(2486,a|0,i+120|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break f}if((h|!k)==1){x[114414]=0;b=O(2486,a|0,i+120|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}x[114414]=0;o=R(2487,a|0)|0;b=x[114414];x[114414]=0;g:{if((b|0)!=1){if(g){break g}x[114414]=0;o=O(2488,e|0,o|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break g}}break b}l=r+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){r=l;if(!s){continue e}x[114414]=0;R(2489,a|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Bb(b)|0)==(l|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}q=y[pc(b,r)|0];j:{if(g){break j}x[114414]=0;q=O(2488,e|0,q<<24>>24)|0;t=x[114414];x[114414]=0;if((t|0)!=1){break j}break b}k:{if((o&255)==(q&255)){s=1;if((Bb(b)|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=Wc(b);v[h|0]=l?2:1;h=h+1|0;b=b+12|0;m=l+m|0;k=k-l|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Jc(n);hb=i+128|0;return d|0}}a=N()|0;Jc(n);Q(a|0)}p()}function Y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=hb-384|0;hb=a;x[a+368>>2]=c;x[a+376>>2]=b;dw(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Wb(a+200|0);b=Fc(d);x[114414]=0;P(1649,d|0,b|0);b=x[114414];x[114414]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);x[a+196>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;while(1){d:{x[114414]=0;b=O(2515,a+376|0,a+368|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}if(b){break c}if(x[a+196>>2]==(Bb(d)+c|0)){b=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+196>>2]=b+c}x[114414]=0;b=R(2516,a+376|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}x[114414]=0;b=Er(b,a+23|0,a+22|0,c,a+196|0,x[a+236>>2],x[a+232>>2],a+216|0,a+32|0,a+28|0,a+24|0,a+240|0);g=x[114414];x[114414]=0;if((g|0)==1){break d}if(b){break c}x[114414]=0;R(2518,a+376|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+216|0)|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}x[114414]=0;X(2506,a|0,c|0,x[a+196>>2],e|0);b=x[114414];x[114414]=0;f:{if((b|0)==1){break f}b=x[a+8>>2];c=x[a+12>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;x[f+8>>2]=b;x[f+12>>2]=c;x[114414]=0;De(a+216|0,a+32|0,x[a+28>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2515,a+376|0,a+368|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+376>>2];xb(d);xb(a+216|0);hb=a+384|0;break a}}b=N()|0;xb(d);xb(a+216|0);Q(b|0);p()}return b|0}function k$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=hb-288|0;hb=a;x[a+272>>2]=c;x[a+280>>2]=b;fw(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Wb(a+208|0);b=Fc(d);x[114414]=0;P(1649,d|0,b|0);b=x[114414];x[114414]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);x[a+204>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;while(1){d:{x[114414]=0;b=O(2486,a+280|0,a+272|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}if(b){break c}if(x[a+204>>2]==(Bb(d)+c|0)){b=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+204>>2]=b+c}x[114414]=0;b=R(2487,a+280|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}x[114414]=0;b=Gr(b,a+23|0,a+22|0,c,a+204|0,v[a+239|0],v[a+238|0],a+224|0,a+32|0,a+28|0,a+24|0,a+240|0);g=x[114414];x[114414]=0;if((g|0)==1){break d}if(b){break c}x[114414]=0;R(2489,a+280|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+224|0)|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}x[114414]=0;X(2506,a|0,c|0,x[a+204>>2],e|0);b=x[114414];x[114414]=0;f:{if((b|0)==1){break f}b=x[a+8>>2];c=x[a+12>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;x[f+8>>2]=b;x[f+12>>2]=c;x[114414]=0;De(a+224|0,a+32|0,x[a+28>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2486,a+280|0,a+272|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+280>>2];xb(d);xb(a+224|0);hb=a+288|0;break a}}b=N()|0;xb(d);xb(a+224|0);Q(b|0);p()}return b|0}function gU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-32|0;hb=g;e=Eb(b);v[g+12|0]=0;k=mB(g+16|0,e,g+12|0);i=Eb(b);h=x[a>>2];e=x[k>>2];j=Vg(a);f=Eb(b);x[g+12>>2]=f;a:{b:{if(!j|!f){break b}while(1){a=y[h|0];x[114414]=0;a=R(418,a|0)|0;d=x[114414];x[114414]=0;c:{d:{if((d|0)!=1){d=j-1|0;if(!(!d|(a|0)!=(c|0))){a=y[h+1|0];x[114414]=0;a=R(419,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}x[114414]=0;x[g+8>>2]=a;a=O(35,g+8|0,g+12|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}e:{d=j-2|0;if(!d){break e}a=x[a>>2];if(!(a&255)){break e}d=y[h+2|0];x[114414]=0;d=R(418,d|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break a}h=h+3|0;while(1){v[e|0]=d;f=x[g+12>>2]-1|0;x[g+12>>2]=f;e=e+1|0;a=a-1|0;if(a&255){continue}break}d=j-3|0;break c}h=h+2|0;v[e|0]=c;break d}h=h+1|0;v[e|0]=a;break d}break a}f=x[g+12>>2]-1|0;x[g+12>>2]=f;e=e+1|0}if(!d){break b}j=d;if(f){continue}break}}j=x[k>>2];a=x[b>>2];x[114414]=0;l=R(420,a|0)|0;a=x[114414];x[114414]=0;f:{g:{if((a|0)!=1){c=i-f|0;if(!c){break f}e=128;h=0;d=0;break g}break a}while(1){m=y[j|0];a=0;f=0;while(1){i=d+l|0;v[i|0]=y[i|0]|D(e&m,257)>>>(f-a&7);d=d+1|0;i=Eb(b)>>>0<=d>>>0;d=i?0:d;e=(e<<8|e)>>>1&255;f=f+i|0;i=a&65535;a=a+1|0;if(i>>>0<7){continue}break}e=(e<<8|e)>>>f&255;j=j+1|0;h=h+1|0;if((h|0)!=(c|0)){continue}break}}f=0;a=x[b>>2];x[114414]=0;e=R(420,a|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){if(c){while(1){d=f<<24>>24;b=v[e|0];a=128;h:{if((b|0)==-128){break h}a=b;if((a|0)>=0){break h}a=0-(b&127)|0}f=d-(a&255)|0;v[e|0]=f;e=e+1|0;c=c-1|0;if(c){continue}break}}Oq(k);hb=g+32|0;return}}a=N()|0;Oq(k);Q(a|0);p()}function Fr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=hb-128|0;hb=i;x[i+120>>2]=b;k=kt(c,d);x[i+4>>2]=2484;n=Pd(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=sd(k);if(!j){x[114414]=0;V(2485);a=x[114414];x[114414]=0;if((a|0)!=1){break a}break b}we(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[114414]=0;h=O(2515,a|0,i+120|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break f}if((h|!k)==1){x[114414]=0;b=O(2515,a|0,i+120|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}x[114414]=0;o=R(2516,a|0)|0;b=x[114414];x[114414]=0;g:{if((b|0)!=1){if(g){break g}x[114414]=0;o=O(2517,e|0,o|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break g}}break b}l=r+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){r=l;if(!s){continue e}x[114414]=0;R(2518,a|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Bb(b)|0)==(l|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}q=x[qj(b,r)>>2];j:{if(g){break j}x[114414]=0;q=O(2517,e|0,q|0)|0;t=x[114414];x[114414]=0;if((t|0)!=1){break j}break b}k:{if((o|0)==(q|0)){s=1;if((Bb(b)|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=Wc(b);v[h|0]=l?2:1;h=h+1|0;b=b+12|0;m=l+m|0;k=k-l|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Jc(n);hb=i+128|0;return d|0}}a=N()|0;Jc(n);Q(a|0)}p()}function Jfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;t=x[a+16>>2];k=x[a+44>>2];x[b+28>>2]=k;m=x[a+48>>2];x[b+32>>2]=m;i=x[a+52>>2];x[b+36>>2]=i;j=x[a+56>>2];x[b+40>>2]=j;p=x[a+40>>2];q=x[a+36>>2];g=x[a+4>>2];f=g;e=x[a>>2];x[b+16>>2]=e;x[b+20>>2]=f;g=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=g;a:{if(!d){h=p>>12;g=q>>12;break a}while(1){e=x[b+16>>2];n=(((x[b+20>>2]&2147483647)<<1|e>>>31)&-2)+t|0;e=(e>>>21&2040)+32976|0;s=w[e+6>>1];j=w[e+4>>1];f=w[e+2>>1];g=w[e>>1];k=0;m=1;i=1;h=0;while(1){x[(h<<2)+b>>2]=(((D(v[h+n|0],f)+D(v[n+(h|-2)|0],g)|0)+D(j,v[n+(h|2)|0])|0)+D(s,v[n+(h|4)|0])<<8)/16384;e=i&1;i=0;h=1;if(e){continue}break}while(1){e=(k<<2)+b|0;j=x[e>>2];o=x[a+60>>2];r=(b+24|0)+(k<<3)|0;f=x[r+4>>2];l=Xb(f,-16777216,16776704);i=x[a+64>>2];h=Xb(x[r+8>>2],-16777216,16776704);g=x[a+68>>2];n=g>>31;x[r+8>>2]=f;s=x[a+72>>2];k=j<<8;f=k;f=yna(o,o>>31,f,f>>31);j=lb;o=f;f=yna(i,i>>31,l,l>>31);i=o+f|0;l=lb+j|0;l=f>>>0>i>>>0?l+1|0:l;f=yna(g,n,h,h>>31);j=f+i|0;g=lb+l|0;g=f>>>0>j>>>0?g+1|0:g;o=e;f=j+8388608|0;e=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[o>>2]=(e|0)/256;x[r+4>>2]=e-(k&s);k=1;e=m&1;m=0;if(e){continue}break}e=x[a+32>>2];q=x[a+28>>2]+q|0;g=q>>12;x[c>>2]=x[c>>2]+D(g,x[b>>2]);p=e+p|0;h=p>>12;x[c+4>>2]=x[c+4>>2]+D(h,x[b+4>>2]);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}j=x[b+40>>2];i=x[b+36>>2];m=x[b+32>>2];k=x[b+28>>2];e=x[b+16>>2];f=x[b+20>>2]}x[a>>2]=e;x[a+4>>2]=f;x[a+40>>2]=p;x[a+20>>2]=g;x[a+36>>2]=q;x[a+56>>2]=j;x[a+52>>2]=i;x[a+48>>2]=m;x[a+44>>2]=k;x[a+24>>2]=h;hb=b+48|0}function $2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=hb+-64|0;hb=c;f=oh(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(vi(b)){gp(c+56|0);break n}x[114414]=0;P(2217,c+40|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break m}x[114414]=0;a=R(2204,c+40|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break l}x[c+56>>2]=a;Mf(c+40|0)}if(vi(b)){a=b+36|0}else{a=x[c+56>>2]}e=xd(a);x[114414]=0;P(1545,f|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break k}h=c,i=bc(a),x[h+32>>2]=i;h=c,i=dc(a),x[h+24>>2]=i;if(Hb(c+32|0,c+24|0)){a=b+24|0;while(1){e=x[c+32>>2];b=Ni(x[a>>2]+484360|0,y[e+16|0]);x[114414]=0;P(2218,c+8|0,b|0);d=x[114414];x[114414]=0;if((d|0)==1){break j}x[114414]=0;T(9,c+40|0,0,c+8|0);d=x[114414];x[114414]=0;if((d|0)==1){break i}x[114414]=0;P(1547,f|0,c+40|0);d=x[114414];x[114414]=0;if((d|0)==1){break h}xb(c+40|0);xb(c+8|0);o:{if(!Wc(qI(f))){break o}d=y[e+12|0];x[114414]=0;d=O(513,b|0,d|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break c}if(!d){break o}d=x[a>>2];x[114414]=0;d=R(661,d|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break f}b=Zb(x[a>>2]+484344|0,z[uc(b,x[e+12>>2])>>1]);x[114414]=0;P(2219,c+8|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break e}x[114414]=0;X(387,c+40|0,0,d|0,c+8|0);b=x[114414];x[114414]=0;if((b|0)==1){break d}b=c+40|0;Db(qI(f),b);xb(b);xb(c+8|0)}b=c+32|0;Xi(b);if(Hb(b,c+24|0)){continue}break}}sk(c+56|0);hb=c- -64|0;return}b=N()|0;break a}b=N()|0;Mf(c+40|0);break a}b=N()|0;break b}b=N()|0;break b}b=N()|0;break g}b=N()|0;xb(c+40|0)}xb(c+8|0);break b}b=N()|0;break b}b=N()|0;break b}b=N()|0;xb(c+8|0);break b}b=N()|0}sk(c+56|0)}qd(f);Q(b|0);p()}function Kia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-16|0;hb=e;a:{if(!Qb(a,2)){Tg(c+484344|0,b,64);break a}j=c+484344|0;h=Md(Du(a),1,1024);if(!Tg(j,b,h)|!h){break a}k=z[c+480188>>1];while(1){m=mm(Zb(j,b),i);g=0;if(k){while(1){d=e+8|0;km(d,a);n=ed(d);o=rf(d);c=D(g,6)+m|0;f=y[$h(d)|0];v[c+5|0]=f;l=0;d=y[d|0];if((d-1&255)>>>0<=35){v[c|0]=d+48;l=y[n|0]+1|0}d=c+5|0;v[c+1|0]=l;b:{c:{d:{switch(y[o|0]){case 1:v[c+3|0]=2;v[d|0]=f&15;break b;case 2:v[c+3|0]=3;v[d|0]=f&15;break b;case 12:if(!f){break b}v[c+3|0]=1;break b;case 13:if(!f){break b}v[c+3|0]=36;v[e+7|0]=15;p=d,q=y[rc(e+7|0,d)|0]|16,v[p|0]=q;break b;case 30:if(!f){break b}v[c+3|0]=35;v[e+6|0]=15;p=d,q=y[rc(e+6|0,d)|0]|16,v[p|0]=q;break b;case 21:if(!f){break b}v[c+3|0]=36;v[e+5|0]=15;p=d,q=y[rc(e+5|0,d)|0]|80,v[p|0]=q;break b;case 17:if(!f){break b}v[c+3|0]=35;v[e+4|0]=15;p=d,q=y[rc(e+4|0,d)|0]|80,v[p|0]=q;break b;case 15:v[c+3|0]=19;v[d|0]=(f|0)!=0;break b;case 25:v[c+3|0]=12;break b;case 27:Nt(c);v[c|0]=255;break b;case 28:v[c+3|0]=16;break b;case 31:v[c+3|0]=11;e:{f:{g:{switch(f>>>4|0){case 4:if((f|0)==64){break f}v[d|0]=f&15;break b;case 5:v[d|0]=f<<4;break b;case 6:v[e+3|0]=f&15;v[e+2|0]=14;p=d,q=y[rc(e+3|0,e+2|0)|0]|240,v[p|0]=q;break b;case 0:case 1:case 2:case 3:break f;case 7:break g;default:break e}}v[e+1|0]=f&15;v[e|0]=14;p=d,q=y[rc(e+1|0,e)|0]<<4|15,v[p|0]=q;break b}v[c+4|0]=f;v[c+2|0]=1}v[c+3|0]=0;break c;case 0:break c;default:break d}}v[c+3|0]=0}v[d|0]=0}g=g+1|0;if((k|0)!=(g|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}hb=e+16|0}function ph(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;a:{if((b|0)==189){v[a+3843|0]=c>>>7;v[a+3844|0]=c>>>6&1;break a}d=b&224;if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=D(b>>>0<3?b:b+6|0,44)+a|0;g=e+148|0;e=e+16|0;h=c&d;b:{if(h){An(e,g);break b}An(e,0)}v[g+40|0]=!h;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}v[a+3842|0]=c>>>6&1;b=0;while(1){cz((D(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if(d-160>>>0<=32){d=b&15;if(d>>>0>8){break a}a=(D(b&256?d+9|0:d,44)+a|0)+16|0;x[f+8>>2]=a;d=x[a+36>>2];x[f+12>>2]=d;d=d?2:1;c:{b=b&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}g=c&3;e=c>>>2&7;b=0;c=(c&32)!=0;while(1){a=x[(f+8|0)+(b<<2)>>2];YN(x[a>>2],c);YN(x[a+4>>2],c);w[a+22>>1]=e;bz(a);cz(a);v[a+21|0]=g;bz(a);cz(a);b=b+1|0;if((d|0)!=(b|0)){continue}break}break a}b=0;while(1){a=x[(f+8|0)+(b<<2)>>2];w[a+20>>1]=z[a+20>>1]&768|c&255;bz(a);b=b+1|0;if((d|0)!=(b|0)){continue}break}break a}v[a+42|0]=(c&32)>>>5;v[a+41|0]=(c&16)>>>4;b=c>>>1&7;w[a+30>>1]=b?9-b|0:0;w[a+32>>1]=c&1;break a}if((d|0)!=224&d>>>0>=129|-4144960>>>b&1){break a}e=a;a=v[(b&31)+25536|0];a=(e+D(b&256?a+18|0:a,84)|0)+808|0;d:{switch(d-32>>>5|0){case 0:v[a+79|0]=c>>>7;v[a+80|0]=(c&64)>>>6;v[a+78|0]=(c&32)>>>5;v[a+77|0]=(c&16)>>>4;Bn(a);w[a+14>>1]=z[((c&15)<<1)+25568>>1];break a;case 1:w[a+68>>1]=y[(c>>>6|0)+17383|0];ZN(a);w[a+22>>1]=(c&63)<<2;break a;case 2:w[a+24>>1]=c>>>4;Bn(a);w[a+26>>1]=c&15;Bn(a);break a;case 3:b=c>>>4|0;w[a+28>>1]=b>>>0>=15?496:b<<4;w[a+30>>1]=c&15;Bn(a);break a;case 6:break d;default:break a}}w[a+12>>1]=c&7}hb=f+16|0}function yJ(a){var b=E(0),c=0,d=0,e=0,f=0,g=0,h=E(0),i=E(0),k=0,l=E(0);d=hb-16|0;hb=d;k=d,l=E(Bx(B[a+4216>>2])/E(Ze(x[a+16>>2])>>>0)),B[k+12>>2]=l;x[d+8>>2]=1056964608;b=E(M(E(E(_o(E(B[Hl(d+12|0,d+8|0)>>2]*E(6.2831854820251465)))*E(.4000000059604645))+E(.6000000238418579))));B[a+4236>>2]=b;B[a+4240>>2]=M(E(E(1)-E(b*b)));b=E(E(B[a+4212>>2]*E(29))+E(2));a:{if(b<E(4294967296)&b>=E(0)){c=~~b>>>0;break a}c=0}v[a+4272|0]=c;e=2;b:{if(c>>>0<4){break b}e=3;if(c>>>0<8){break b}e=c>>>0<16?4:5}v[a+4273|0]=e;h=le(E(10),E(E(E(B[a+4208>>2]*E(60))+E(-60))*E(.05000000074505806)));k=d,l=E(Bx(B[a+4220>>2])/E(Ze(x[a+16>>2])>>>0)),B[k+12>>2]=l;x[d+8>>2]=1056964608;i=B[Hl(d+12|0,d+8|0)>>2];k=d,l=E(Bx(B[a+4224>>2])/E(Ze(x[a+16>>2])>>>0)),B[k+12>>2]=l;x[d+8>>2]=1056964608;b=E(B[Hl(d+12|0,d+8|0)>>2]*E(3.1415927410125732));g=hb-16|0;hb=g;e=(q(b),j(2));c=e&2147483647;c:{if(c>>>0<=1061752794){if(c>>>0<964689920){break c}b=cn(+b,0);break c}if(c>>>0<=1081824209){f=+b;if(c>>>0<=1075235811){b=cn(((e|0)<0?1.5707963267948966:-1.5707963267948966)+f,1);break c}b=cn(((e|0)<0?3.141592653589793:-3.141592653589793)+f,0);break c}if(c>>>0<=1088565717){f=+b;if(c>>>0<=1085271519){b=cn(((e|0)<0?4.71238898038469:-4.71238898038469)+f,1);break c}b=cn(((e|0)<0?6.283185307179586:-6.283185307179586)+f,0);break c}if(c>>>0>=2139095040){b=E(b-b);break c}c=Rw(b,g+8|0);b=cn(C[g+8>>3],c&1)}hb=g+16|0;B[a+4268>>2]=E(E(1)-b)/E(b+E(1));b=_o(E(i*E(6.2831854820251465)));B[a+4264>>2]=-b;h=E(h*E(M(E(E(1)-E(b*b)))));b=B[a+4268>>2];B[a+4260>>2]=E(h*E(M(E(E(1)-E(b*b)))))*B[(y[a+4272|0]<<2)+36128>>2];hb=d+16|0}function F_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-384|0;hb=f;x[f+376>>2]=37;x[f+380>>2]=0;h=Dr(f+376|1,17386,x[c+4>>2]);x[f+332>>2]=f+336;a=ie();a:{if(h){i=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=i;a=ff(f+336|0,30,a,f+376|0,f+32|0);break a}C[f+48>>3]=e;a=ff(f+336|0,30,a,f+376|0,f+48|0)}x[f+80>>2]=2484;i=Pd(f+320|0,0,f+80|0);j=f+336|0;g=j;b:{c:{d:{e:{if((a|0)>=30){f:{if(h){x[114414]=0;a=$(2507)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}x[f>>2]=x[c+8>>2];x[114414]=0;C[f+8>>3]=e;a=Z(2527,f+332|0,a|0,f+376|0,f|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){break f}break d}x[114414]=0;a=$(2507)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}C[f+16>>3]=e;x[114414]=0;a=Z(2527,f+332|0,a|0,f+376|0,f+16|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}}if((a|0)==-1){x[114414]=0;V(2485);a=x[114414];x[114414]=0;if((a|0)==1){break d}break e}we(i,x[f+332>>2]);g=x[f+332>>2]}h=a+g|0;k=vg(g,h,c);x[f+68>>2]=2484;g=Pd(f+72|0,0,f+68|0);g:{h:{if(x[f+332>>2]==(f+336|0)){a=f+80|0;break h}a=sd(a<<3);if(!a){x[114414]=0;V(2485);a=x[114414];x[114414]=0;if((a|0)!=1){break e}b=N()|0;break g}we(g,a);j=x[f+332>>2]}x[114414]=0;Dc(f+56|0,c);l=x[114414];x[114414]=0;i:{j:{if((l|0)!=1){x[114414]=0;fa(2538,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=x[114414];x[114414]=0;if((h|0)==1){break j}Ob(f+56|0);x[114414]=0;a=ga(2539,b|0,a|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break i}Jc(g);Jc(i);hb=f+384|0;break b}b=N()|0;break g}b=N()|0;Ob(f+56|0);break g}b=N()|0}Jc(g);break c}p()}b=N()|0}Jc(i);Q(b|0);p()}return a|0}function Q_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-208|0;hb=f;x[f+200>>2]=37;x[f+204>>2]=0;h=Dr(f+200|1,17386,x[c+4>>2]);x[f+156>>2]=f+160;a=ie();a:{if(h){i=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=i;a=ff(f+160|0,30,a,f+200|0,f+32|0);break a}C[f+48>>3]=e;a=ff(f+160|0,30,a,f+200|0,f+48|0)}x[f+80>>2]=2484;i=Pd(f+144|0,0,f+80|0);j=f+160|0;g=j;b:{c:{d:{e:{if((a|0)>=30){f:{if(h){x[114414]=0;a=$(2507)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}x[f>>2]=x[c+8>>2];x[114414]=0;C[f+8>>3]=e;a=Z(2527,f+156|0,a|0,f+200|0,f|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){break f}break d}x[114414]=0;a=$(2507)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}C[f+16>>3]=e;x[114414]=0;a=Z(2527,f+156|0,a|0,f+200|0,f+16|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}}if((a|0)==-1){x[114414]=0;V(2485);a=x[114414];x[114414]=0;if((a|0)==1){break d}break e}we(i,x[f+156>>2]);g=x[f+156>>2]}h=a+g|0;k=vg(g,h,c);x[f+68>>2]=2484;g=Pd(f+72|0,0,f+68|0);g:{h:{if(x[f+156>>2]==(f+160|0)){a=f+80|0;break h}a=sd(a<<1);if(!a){x[114414]=0;V(2485);a=x[114414];x[114414]=0;if((a|0)!=1){break e}b=N()|0;break g}we(g,a);j=x[f+156>>2]}x[114414]=0;Dc(f+56|0,c);l=x[114414];x[114414]=0;i:{j:{if((l|0)!=1){x[114414]=0;fa(2528,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=x[114414];x[114414]=0;if((h|0)==1){break j}Ob(f+56|0);x[114414]=0;a=ga(17,b|0,a|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break i}Jc(g);Jc(i);hb=f+208|0;break b}b=N()|0;break g}b=N()|0;Ob(f+56|0);break g}b=N()|0}Jc(g);break c}p()}b=N()|0}Jc(i);Q(b|0);p()}return a|0}function Cda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-48|0;hb=e;Ad(b,2);d=e+16|0;Wk(d,2,a+1|0);f=e+32|0;Ic(f,d);x[114414]=0;O(335,b+43|0,f|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){xb(e+32|0);a:{if(!(y[a|0]?y[a|0]!=1:0)){if(y[a|0]==1){d=a+16|0;x[b>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+20|0;x[e+32>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[e+16>>2]=x[b>>2]-1;f=e+32|0;h=b,i=x[Mb(f,e+16|0)>>2],x[h+4>>2]=i;d=a+24|0;x[e+32>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);h=b,i=x[Mb(f,b)>>2],x[h+8>>2]=i;w[b+34>>1]=z[b+34>>1]&65533|y[a+31|0]<<1&2}d=x[b+8>>2];if(d>>>0>=2&d>>>0>A[b+4>>2]){break a}w[b+34>>1]=0;x[b+4>>2]=0;x[b+8>>2]=0;break a}if(y[a|0]!=2){break a}f=e+16|0;Eh(f,a+16|0);d=e+32|0;g=x[f>>2];g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[d|0]=g;v[d+1|0]=g>>>8;v[d+2|0]=g>>>16;v[d+3|0]=g>>>24;Eh(f,a+20|0);g=x[e+16>>2];g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[d+4|0]=g;v[d+5|0]=g>>>8;v[d+6|0]=g>>>16;v[d+7|0]=g>>>24;Eh(f,a+24|0);f=x[e+16>>2];f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[d+8|0]=f;v[d+9|0]=f>>>8;v[d+10|0]=f>>>16;v[d+11|0]=f>>>24;x[e+8>>2]=x[e+40>>2];d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;Tp(b,1,e)}v[e+32|0]=y[a+28|0];v[e+16|0]=64;h=b,i=y[rc(e+32|0,e+16|0)|0]<<2,w[h+30>>1]=i;d=a+32|0;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[b+24>>2]=d;b=b+24|0;b:{if(!c){break b}if(y[a|0]==2){d=z[b>>1];x[b>>2]=d;break b}xc(b,65535);d=x[b>>2]}c:{d:{if(!d){a=8363;break d}a=1024;if(d>>>0>1023){break c}}x[b>>2]=a}hb=e+48|0;return}a=N()|0;xb(e+32|0);Q(a|0);p()}function Jla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-96|0;hb=d;b=b&4095;w[d+94>>1]=b;a:{b:{c:{d:{e:{f:{g:{if(b>>>0>=81){e=((b|0)==4095?c:b-80|0)+734016|0;c=yna(e,e>>31,1e4,0);b=lb;c=c+14780|0;b=c>>>0<14780?b+1|0:b;b=zna(c,b,3652425,0);c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}e=Ub(d- -64|0,10596);x[114414]=0;P(187,d+80|0,e|0);f=x[114414];x[114414]=0;h=(D(c,100)+52|0)/3060|0;h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=1){x[114414]=0;g=b;b=h+2|0;f=(b|0)/12|0;x[d+44>>2]=g+f;P(159,d+48|0,d+44|0);g=x[114414];x[114414]=0;if((g|0)==1){break o}x[114414]=0;x[d+28>>2]=(b-D(f,12)|0)+1;P(161,d+32|0,d+28|0);b=x[114414];x[114414]=0;if((b|0)==1){break n}x[114414]=0;x[d+12>>2]=(((D(h,306)+5|0)/-10|0)+c|0)+1;P(161,d+16|0,d+12|0);b=x[114414];x[114414]=0;if((b|0)==1){break m}x[114414]=0;ba(596,a|0,d+80|0,d+48|0,d+32|0,d+16|0);a=x[114414];x[114414]=0;if((a|0)==1){break l}xb(d+16|0);xb(d+32|0);xb(d+48|0);Gb(d+80|0);xb(e);break g}b=N()|0;break h}b=N()|0;break i}b=N()|0;break j}b=N()|0;break k}b=N()|0;xb(d+16|0)}xb(d+32|0)}xb(d+48|0)}Gb(d+80|0)}xb(e);break a}c=Ub(d,11484);x[114414]=0;P(187,d+80|0,c|0);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;P(597,d+48|0,d+94|0);b=x[114414];x[114414]=0;if((b|0)==1){break e}x[114414]=0;T(215,a|0,d+80|0,d+48|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}xb(d+48|0);Gb(d+80|0);xb(c)}hb=d+96|0;return}b=N()|0;break b}b=N()|0;break c}b=N()|0;xb(d+48|0)}Gb(d+80|0)}xb(c)}Q(b|0);p()}function GD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-128|0;hb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{b=x[b>>2];l:{if(!b){Ub(a,5662);break l}if(!(b&65535)){e=Ub(c+96|0,11105);x[114414]=0;P(187,c+112|0,e|0);d=x[114414];x[114414]=0;m:{n:{o:{p:{q:{r:{if((d|0)!=1){x[114414]=0;x[c+24>>2]=b>>>24;P(188,c+80|0,c+24|0);d=x[114414];x[114414]=0;if((d|0)==1){break r}x[114414]=0;x[c+8>>2]=b>>>16&255;P(189,c- -64|0,c+8|0);b=x[114414];x[114414]=0;if((b|0)==1){break q}x[114414]=0;X(190,a|0,c+112|0,c+80|0,c- -64|0);a=x[114414];x[114414]=0;if((a|0)==1){break p}xb(c- -64|0);xb(c+80|0);Gb(c+112|0);xb(e);break l}b=N()|0;break m}b=N()|0;break n}b=N()|0;break o}b=N()|0;xb(c- -64|0)}xb(c+80|0)}Gb(c+112|0)}break a}e=Ub(c+48|0,10510);x[114414]=0;P(187,c+112|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break k}x[114414]=0;x[c+44>>2]=b>>>24;P(188,c+80|0,c+44|0);d=x[114414];x[114414]=0;if((d|0)==1){break j}x[114414]=0;x[c+40>>2]=b>>>16&255;P(189,c- -64|0,c+40|0);d=x[114414];x[114414]=0;if((d|0)==1){break i}x[114414]=0;x[c+20>>2]=b>>>8&255;P(189,c+24|0,c+20|0);d=x[114414];x[114414]=0;if((d|0)==1){break h}x[114414]=0;x[c+4>>2]=b&255;P(189,c+8|0,c+4|0);b=x[114414];x[114414]=0;if((b|0)==1){break g}x[114414]=0;ia(191,a|0,c+112|0,c+80|0,c- -64|0,c+24|0,c+8|0);a=x[114414];x[114414]=0;if((a|0)==1){break f}xb(c+8|0);xb(c+24|0);xb(c- -64|0);xb(c+80|0);Gb(c+112|0);xb(e)}hb=c+128|0;return}b=N()|0;break a}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;break e}b=N()|0;xb(c+8|0)}xb(c+24|0)}xb(c- -64|0)}xb(c+80|0)}Gb(c+112|0)}xb(e);Q(b|0);p()}function __(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=E(0);a=hb-368|0;hb=a;x[a+352>>2]=c;x[a+360>>2]=b;dw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Wb(a+184|0);b=Fc(d);x[114414]=0;P(1649,d|0,b|0);b=x[114414];x[114414]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;while(1){d:{x[114414]=0;b=O(2515,a+360|0,a+352|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}if(b){break c}if(x[a+180>>2]==(Bb(d)+c|0)){b=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+180>>2]=b+c}x[114414]=0;b=R(2516,a+360|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}x[114414]=0;b=Er(b,a+7|0,a+6|0,c,a+180|0,x[a+220>>2],x[a+216>>2],a+200|0,a+16|0,a+12|0,a+8|0,a+224|0);g=x[114414];x[114414]=0;if((g|0)==1){break d}if(b){break c}x[114414]=0;R(2518,a+360|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+200|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}x[114414]=0;h=E(sa(2502,c|0,x[a+180>>2],e|0));b=x[114414];x[114414]=0;f:{if((b|0)==1){break f}B[f>>2]=h;x[114414]=0;De(a+200|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2515,a+360|0,a+352|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+360>>2];xb(d);xb(a+200|0);hb=a+368|0;break a}}b=N()|0;xb(d);xb(a+200|0);Q(b|0);p()}return b|0}function o$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=E(0);a=hb-272|0;hb=a;x[a+256>>2]=c;x[a+264>>2]=b;fw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Wb(a+192|0);b=Fc(d);x[114414]=0;P(1649,d|0,b|0);b=x[114414];x[114414]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;while(1){d:{x[114414]=0;b=O(2486,a+264|0,a+256|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}if(b){break c}if(x[a+188>>2]==(Bb(d)+c|0)){b=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=b+c}x[114414]=0;b=R(2487,a+264|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}x[114414]=0;b=Gr(b,a+7|0,a+6|0,c,a+188|0,v[a+223|0],v[a+222|0],a+208|0,a+16|0,a+12|0,a+8|0,a+224|0);g=x[114414];x[114414]=0;if((g|0)==1){break d}if(b){break c}x[114414]=0;R(2489,a+264|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}x[114414]=0;h=E(sa(2502,c|0,x[a+188>>2],e|0));b=x[114414];x[114414]=0;f:{if((b|0)==1){break f}B[f>>2]=h;x[114414]=0;De(a+208|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2486,a+264|0,a+256|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];xb(d);xb(a+208|0);hb=a+272|0;break a}}b=N()|0;xb(d);xb(a+208|0);Q(b|0);p()}return b|0}function RI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);d=hb-48|0;hb=d;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==x[x[a>>2]+24604>>2]){break d}c=d+8|0;sc(c,x[a>>2]+24604|0,40);x[d+8>>2]=b;ny(x[a>>2],c);break d;case 2:b=a+24|0;a=x[b>>2];e=a+24664|0;f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;e=a+24656|0;f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;e=x[a+24652>>2];x[d+8>>2]=x[a+24648>>2];x[d+12>>2]=e;e=hb-16|0;hb=e;a=3;f:{g:{h:{if(!c|(c|0)>7){break h}a=2;if((c|0)>2){break h}a=1;if((c|0)==2){break h}a=0;if((c|0)>0){break h}b=ec(8);x[114414]=0;c=O(118,e|0,6770)|0;a=x[114414];x[114414]=0;i:{if((a|0)!=1){a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break g}a=N()|0;xb(c);break i}a=N()|0;hc(b)}Q(a|0);p()}hb=e+16|0;break f}p()}v[d+8|0]=a;if(!tx(d+8|0,x[b>>2]+24648|0)){break d}my(x[b>>2],d+8|0);break d;case 3:b=d+8|0;a=a+24|0;sc(b,x[a>>2]+24604|0,40);e=hb-48|0;hb=e;j:{if((c|0)==-1){Nl(b,x[Vp(e+8|0)+32>>2]);An(b,x[Vp(e+8|0)+36>>2]);break j}if((c|0)<=0){Nl(b,0);An(b,0);break j}c=D(c,1e3);Nl(b,c);An(b,c)}hb=e+48|0;if(x[x[a>>2]+24636>>2]==x[d+40>>2]&x[x[a>>2]+24640>>2]==x[d+44>>2]){break d}ny(x[a>>2],d+8|0);break d;default:a=ec(8);x[114414]=0;c=O(118,d+8|0,6366)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break b;case 0:break e}}g=a,h=le(E(10),E(E(c|0)*E(.0005000000237487257))),B[g+48>>2]=h}hb=d+48|0;return}b=N()|0;hc(a)}Q(b|0)}p()}function Z_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-368|0;hb=a;x[a+352>>2]=c;x[a+360>>2]=b;dw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Wb(a+184|0);b=Fc(d);x[114414]=0;P(1649,d|0,b|0);b=x[114414];x[114414]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;while(1){d:{x[114414]=0;b=O(2515,a+360|0,a+352|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}if(b){break c}if(x[a+180>>2]==(Bb(d)+c|0)){b=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+180>>2]=b+c}x[114414]=0;b=R(2516,a+360|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}x[114414]=0;b=Er(b,a+7|0,a+6|0,c,a+180|0,x[a+220>>2],x[a+216>>2],a+200|0,a+16|0,a+12|0,a+8|0,a+224|0);g=x[114414];x[114414]=0;if((g|0)==1){break d}if(b){break c}x[114414]=0;R(2518,a+360|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+200|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}x[114414]=0;h=+ka(2505,c|0,x[a+180>>2],e|0);b=x[114414];x[114414]=0;f:{if((b|0)==1){break f}C[f>>3]=h;x[114414]=0;De(a+200|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2515,a+360|0,a+352|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+360>>2];xb(d);xb(a+200|0);hb=a+368|0;break a}}b=N()|0;xb(d);xb(a+200|0);Q(b|0);p()}return b|0}function zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=hb-16|0;hb=g;e=x[a+12>>2];i=e;a:{b:{c:{k=x[a+8>>2];d:{if((e|0)<=1&k>>>0<=805306368|(e|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}p=x[a+16>>2];e=x[a+48>>2];q=x[a+24>>2];r=x[a+20>>2];h=x[a+44>>2];b=x[a+4>>2];m=b;f=x[a>>2];x[g+8>>2]=f;x[g+12>>2]=b;x[g>>2]=k;x[g+4>>2]=i;e:{if(!d){b=e;break e}while(1){f=x[g+12>>2]+p|0;s=v[f+4|0];b=(x[g+8>>2]>>>16&65520)+o|0;t=w[b+14>>1];u=v[f+3|0];y=w[b+12>>1];z=v[f+2|0];A=w[b+10>>1];B=v[f+1|0];C=w[b+8>>1];E=v[f|0];F=w[b+6>>1];G=v[f-1|0];H=w[b+4>>1];I=v[f-2|0];J=w[b+2>>1];K=v[f-3|0];n=w[b>>1];f=x[a+60>>2];i=f>>31;b=h;j=Xb(b,-16777216,16776704);h=x[a+64>>2];l=Xb(e,-16777216,16776704);m=x[a+72>>2];k=x[c>>2];e=yna(h,h>>31,j,j>>31);h=lb;j=e;e=x[a+68>>2];e=yna(e,e>>31,l,l>>31);l=j+e|0;j=lb+h|0;j=e>>>0>l>>>0?j+1|0:j;n=(((((((D(I,J)+D(n,K)|0)+D(G,H)|0)+D(E,F)|0)+D(B,C)|0)+D(z,A)|0)+D(u,y)|0)+D(s,t)<<8)/32768<<8;e=n;e=yna(f,i,e,e>>31);h=e+l|0;f=lb+j|0;f=e>>>0>h>>>0?f+1|0:f;e=h+8388608|0;e=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;f=(e|0)/256|0;x[c>>2]=D(f,r)+k;x[c+4>>2]=x[c+4>>2]+D(f,q);h=e-(m&n)|0;c=c+8|0;Tb(g+8|0,g);e=b;d=d-1|0;if(d){continue}break}f=x[g+8>>2];m=x[g+12>>2]}x[a>>2]=f;x[a+4>>2]=m;x[a+48>>2]=b;x[a+44>>2]=h;hb=g+16|0}function yfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;g=hb-16|0;hb=g;f=x[a+12>>2];j=f;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((j|0)>=-2&h>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&h>>>0>2147483647|(j|0)==-1){break d}break b}if((j|0)==1&h>>>0>2147483648|j>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=x[a+16>>2];f=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];i=x[a+44>>2];b=x[a+4>>2];k=b;e=x[a>>2];x[g+8>>2]=e;x[g+12>>2]=b;x[g>>2]=h;x[g+4>>2]=j;e:{if(!d){b=f;break e}while(1){b=(x[g+8>>2]>>>16&65520)+l|0;k=w[b>>1];e=(x[g+12>>2]<<1)+m|0;p=w[e-6>>1];q=w[b+2>>1];r=w[e-4>>1];s=w[b+4>>1];t=w[e-2>>1];u=w[b+6>>1];v=w[e>>1];y=w[b+8>>1];z=w[e+2>>1];A=w[b+10>>1];B=w[e+4>>1];C=w[b+12>>1];E=w[e+6>>1];F=w[b+14>>1];G=w[e+8>>1];e=x[a+60>>2];b=i;h=Xb(b,-16777216,16776704);i=x[a+64>>2];j=Xb(f,-16777216,16776704);H=x[a+72>>2];I=x[c>>2];f=yna(i,i>>31,h,h>>31);i=lb;h=(((((((D(q,r)+D(k,p)|0)+D(s,t)|0)+D(u,v)|0)+D(y,z)|0)+D(A,B)|0)+D(C,E)|0)+D(F,G)|0)/32768<<8;k=yna(e,e>>31,h,h>>31);e=k+f|0;f=lb+i|0;f=e>>>0<k>>>0?f+1|0:f;k=e;e=x[a+68>>2];i=yna(e,e>>31,j,j>>31);e=k+i|0;f=lb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;e=(f|0)/256|0;x[c>>2]=D(e,o)+I;x[c+4>>2]=x[c+4>>2]+D(e,n);i=f-(h&H)|0;c=c+8|0;Tb(g+8|0,g);f=b;d=d-1|0;if(d){continue}break}e=x[g+8>>2];k=x[g+12>>2]}x[a>>2]=e;x[a+4>>2]=k;x[a+48>>2]=b;x[a+44>>2]=i;hb=g+16|0}function m$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-272|0;hb=a;x[a+256>>2]=c;x[a+264>>2]=b;fw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Wb(a+192|0);b=Fc(d);x[114414]=0;P(1649,d|0,b|0);b=x[114414];x[114414]=0;a:{b:{c:{if((b|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;while(1){d:{x[114414]=0;b=O(2486,a+264|0,a+256|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}if(b){break c}if(x[a+188>>2]==(Bb(d)+c|0)){b=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=b+c}x[114414]=0;b=R(2487,a+264|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}x[114414]=0;b=Gr(b,a+7|0,a+6|0,c,a+188|0,v[a+223|0],v[a+222|0],a+208|0,a+16|0,a+12|0,a+8|0,a+224|0);g=x[114414];x[114414]=0;if((g|0)==1){break d}if(b){break c}x[114414]=0;R(2489,a+264|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}x[114414]=0;h=+ka(2505,c|0,x[a+188>>2],e|0);b=x[114414];x[114414]=0;f:{if((b|0)==1){break f}C[f>>3]=h;x[114414]=0;De(a+208|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2486,a+264|0,a+256|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];xb(d);xb(a+208|0);hb=a+272|0;break a}}b=N()|0;xb(d);xb(a+208|0);Q(b|0);p()}return b|0}function _fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;t=x[a+16>>2];m=x[a+44>>2];x[b+28>>2]=m;o=x[a+48>>2];x[b+32>>2]=o;k=x[a+52>>2];x[b+36>>2]=k;h=x[a+56>>2];x[b+40>>2]=h;p=x[a+40>>2];q=x[a+36>>2];g=x[a+4>>2];e=g;f=x[a>>2];x[b+16>>2]=f;x[b+20>>2]=e;g=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=g;a:{if(!d){j=p>>12;i=q>>12;break a}while(1){e=x[b+16>>2];g=e>>>18|0;m=1;h=((((x[b+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+t|0;j=0;k=1;i=0;while(1){f=i<<1;e=w[f+h>>1];x[(i<<2)+b>>2]=e+((D(g,w[h+(f|4)>>1]-e|0)|0)/16384|0);f=k&1;k=0;i=1;if(f){continue}break}while(1){f=(j<<2)+b|0;h=x[f>>2];n=x[a+60>>2];r=(b+24|0)+(j<<3)|0;e=x[r+4>>2];l=Xb(e,-16777216,16776704);i=x[a+64>>2];s=Xb(x[r+8>>2],-16777216,16776704);g=x[a+68>>2];k=g>>31;x[r+8>>2]=e;o=x[a+72>>2];j=h<<8;e=j;e=yna(n,n>>31,e,e>>31);h=lb;n=e;e=yna(i,i>>31,l,l>>31);i=n+e|0;l=lb+h|0;l=e>>>0>i>>>0?l+1|0:l;e=yna(g,k,s,s>>31);h=e+i|0;g=lb+l|0;g=e>>>0>h>>>0?g+1|0:g;n=f;e=h+8388608|0;f=((e>>>0<8388608?g+1|0:g)&16777215)<<8|e>>>24;x[n>>2]=(f|0)/256;x[r+4>>2]=f-(j&o);j=1;f=m&1;m=0;if(f){continue}break}f=x[a+32>>2];q=x[a+28>>2]+q|0;i=q>>12;x[c>>2]=x[c>>2]+D(i,x[b>>2]);p=f+p|0;j=p>>12;x[c+4>>2]=x[c+4>>2]+D(j,x[b+4>>2]);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}h=x[b+40>>2];k=x[b+36>>2];o=x[b+32>>2];m=x[b+28>>2];f=x[b+16>>2];e=x[b+20>>2]}x[a>>2]=f;x[a+4>>2]=e;x[a+40>>2]=p;x[a+20>>2]=i;x[a+36>>2]=q;x[a+56>>2]=h;x[a+52>>2]=k;x[a+48>>2]=o;x[a+44>>2]=m;x[a+24>>2]=j;hb=b+48|0}function VZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0;t=hb-16|0;hb=t;x[c>>2]=a;z=d&512;A=h<<2;while(1){if((u|0)==4){if(Bb(n)>>>0>1){C=t,D=ud(n),x[C+8>>2]=D;C=c,D=ZE(Gn(t+8|0,1),gk(n),x[c>>2]),x[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}hb=t+16|0}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];h=Pr(g,32);p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 3:if(Wc(n)){break a}h=x[qj(n,0)>>2];p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 2:if(Wc(m)|!z){break a}C=c,D=ZE(ud(m),gk(m),x[c>>2]),x[C>>2]=D;break a;case 4:break b;default:break a}}B=x[c>>2];e=e+A|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!lk(g,64,x[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=x[c>>2];r=o;while(1){if(!(!r|e>>>0>=h>>>0)){h=h-4|0;s=x[h>>2];q=p+4|0;x[c>>2]=q;x[p>>2]=s;r=r-1|0;p=q;continue}break}d:{if(!r){q=0;break d}q=Pr(g,48);p=x[c>>2]}while(1){s=p+4|0;if((r|0)>0){x[p>>2]=q;r=r-1|0;p=s;continue}break}x[c>>2]=s;x[p>>2]=j}e:{if((e|0)==(h|0)){p=Pr(g,48);q=x[c>>2];h=q+4|0;x[c>>2]=h;x[q>>2]=p;break e}if(Wc(l)){q=-1}else{q=v[pc(l,0)|0]}p=0;r=0;while(1){if((e|0)!=(h|0)){f:{if((p|0)!=(q|0)){s=p;break f}q=x[c>>2];x[c>>2]=q+4;x[q>>2]=k;s=0;r=r+1|0;if(Bb(l)>>>0<=r>>>0){q=p;break f}if(y[pc(l,r)|0]==127){q=-1;break f}q=v[pc(l,r)|0]}h=h-4|0;p=x[h>>2];w=x[c>>2];x[c>>2]=w+4;x[w>>2]=p;p=s+1|0;continue}break}h=x[c>>2]}Vo(B,h)}u=u+1|0;continue}break}}function $fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;t=x[a+16>>2];o=x[a+44>>2];x[b+28>>2]=o;m=x[a+48>>2];x[b+32>>2]=m;k=x[a+52>>2];x[b+36>>2]=k;j=x[a+56>>2];x[b+40>>2]=j;p=x[a+40>>2];q=x[a+36>>2];g=x[a+4>>2];e=g;f=x[a>>2];x[b+16>>2]=f;x[b+20>>2]=e;g=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=g;a:{if(!d){i=p>>12;h=q>>12;break a}while(1){e=x[b+16>>2];g=e>>>10&4194048;e=(((x[b+20>>2]&2147483647)<<1|e>>>31)&-2)+t|0;h=0;m=1;k=1;i=0;while(1){f=v[e+i|0];x[(i<<2)+b>>2]=((D(g,v[e+(i|2)|0]-f|0)|0)/16384|0)+(f<<8);f=k&1;k=0;i=1;if(f){continue}break}while(1){f=(h<<2)+b|0;j=x[f>>2];n=x[a+60>>2];r=(b+24|0)+(h<<3)|0;e=x[r+4>>2];l=Xb(e,-16777216,16776704);h=x[a+64>>2];s=Xb(x[r+8>>2],-16777216,16776704);g=x[a+68>>2];k=g>>31;x[r+8>>2]=e;o=x[a+72>>2];i=j<<8;e=i;e=yna(n,n>>31,e,e>>31);j=lb;n=e;e=yna(h,h>>31,l,l>>31);h=n+e|0;l=lb+j|0;l=e>>>0>h>>>0?l+1|0:l;e=yna(g,k,s,s>>31);j=e+h|0;g=lb+l|0;g=e>>>0>j>>>0?g+1|0:g;n=f;e=j+8388608|0;f=((e>>>0<8388608?g+1|0:g)&16777215)<<8|e>>>24;x[n>>2]=(f|0)/256;x[r+4>>2]=f-(i&o);h=1;f=m&1;m=0;if(f){continue}break}f=x[a+32>>2];q=x[a+28>>2]+q|0;h=q>>12;x[c>>2]=x[c>>2]+D(h,x[b>>2]);p=f+p|0;i=p>>12;x[c+4>>2]=x[c+4>>2]+D(i,x[b+4>>2]);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}j=x[b+40>>2];k=x[b+36>>2];m=x[b+32>>2];o=x[b+28>>2];f=x[b+16>>2];e=x[b+20>>2]}x[a>>2]=f;x[a+4>>2]=e;x[a+40>>2]=p;x[a+20>>2]=h;x[a+36>>2]=q;x[a+56>>2]=j;x[a+52>>2]=k;x[a+48>>2]=m;x[a+44>>2]=o;x[a+24>>2]=i;hb=b+48|0}function g8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=hb-16|0;hb=i;f=b+1304396|0;if(!zd(f)){d=hb-16|0;hb=d;e=Me(12);x[114414]=0;g=R(1786,e|0)|0;c=x[114414];x[114414]=0;a:{if((c|0)!=1){c=hb-16|0;hb=c;x[114414]=0;x[c+12>>2]=g;e=U(1792,d+8|0,c+12|0,c+8|0)|0;g=x[114414];x[114414]=0;b:{if((g|0)!=1){hb=c+16|0;break b}S(0)|0;zb();p()}hb=d+16|0;e=x[e>>2];break a}a=N()|0;_b(e);Q(a|0);p()}x[i+8>>2]=e;e=i+8|0;iM(f,ke(e));yy(e)}e=x[f>>2];c=hb-80|0;hb=c;f=Ub(c+48|0,bM(a));x[114414]=0;P(1631,c- -64|0,f|0);d=x[114414];x[114414]=0;c:{d:{e:{if((d|0)!=1){xb(f);k=c,l=bc(e),x[k+40>>2]=l;k=c,l=dc(e),x[k+32>>2]=l;if(!Hb(c+40|0,c+32|0)){d=0;break c}f=0;e=0;while(1){d=0;g=x[c+40>>2];if(x[x[g>>2]+32>>2]==(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))){d=x[x[g>>2]+36>>2]==(y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))}h=x[g>>2];x[114414]=0;P(1787,c|0,h+8|0);h=x[114414];x[114414]=0;f:{g:{h:{i:{if((h|0)!=1){x[114414]=0;P(1631,c+16|0,c|0);h=x[114414];x[114414]=0;if((h|0)==1){break i}j=c+16|0;h=yf(j,c- -64|0);xb(j);xb(c);if((d&h)!=1){break g}f=x[g>>2];e=3;break f}d=N()|0;break h}d=N()|0;xb(c)}f=c- -64|0;break d}if((e|0)<2&d){f=x[g>>2];e=2;break f}d=h&(e|0)<=0;f=d?x[g>>2]:f;e=d?1:e}d=c+40|0;fe(d);if(Hb(d,c+32|0)){continue}break}break e}d=N()|0;break d}d=0;if(!f){break c}e=x[f+4>>2];if(!e){break c}x[114414]=0;a=U(e|0,f|0,b|0,a|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){d=(a|0)!=0;break c}d=N()|0;f=c- -64|0}xb(f);Q(d|0);p()}xb(c- -64|0);hb=c+80|0;hb=i+16|0;return d|0}function bna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=hb-32|0;hb=h;Rj(a);j=x[b+4>>2];f=yb(a);d=Fb(h+16|0,c);g=Fb(h+8|0,x[a>>2]);e=Fb(h,x[b+4>>2]);i=x[d>>2];e=x[e>>2];d=hb-48|0;hb=d;x[d+32>>2]=x[g>>2];x[d+40>>2]=i;x[d+24>>2]=e;x[d+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(495,d+40|0,d+32|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break e}if(!e){break d}e=MT(d+24|0);g=NA(d+40|0);x[114414]=0;T(481,f|0,e|0,g|0);e=x[114414];x[114414]=0;if((e|0)==1){break e}dm(d+40|0);dm(d+24|0);continue}break}Y(S(0)|0)|0;a=Mc(d,f,d+16|0,d+24|0);x[114414]=0;W(496,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=d+48|0;d=x[d+24>>2];break a}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb()}p()}x[h+24>>2]=d;x[b+4>>2]=x[h+24>>2];e=yb(a);g=x[a+4>>2];f=hb-32|0;hb=f;d=x[b+8>>2];x[f+28>>2]=d;x[f+24>>2]=d;f:{g:{if((c|0)!=(g|0)){while(1){x[114414]=0;T(481,e|0,d|0,c|0);i=x[114414];x[114414]=0;if((i|0)==1){break g}d=d+2|0;x[f+28>>2]=d;c=c+2|0;if((g|0)!=(c|0)){continue}break}}hb=f+32|0;break f}Y(S(0)|0)|0;a=Mc(f+8|0,e,f+24|0,f+28|0);x[114414]=0;W(497,a|0);a=x[114414];x[114414]=0;h:{i:{if((a|0)!=1){x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break i}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break h}S(0)|0;zb()}p()}Q(a|0);p()}x[b+8>>2]=d;Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Mq(a,qc(a));hb=h+32|0;return j|0}function d$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=ch(d);h=Um(d,a+224|0);Tm(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114414]=0;g=O(2515,a+344|0,a+336|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}if(g){break c}if(x[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=g+c}x[114414]=0;g=R(2516,a+344|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}x[114414]=0;g=ik(g,b,c,a+188|0,a+8|0,x[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=x[114414];x[114414]=0;if((i|0)==1){break d}if(g){break c}x[114414]=0;R(2518,a+344|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}h=x[a+12>>2];if((h-(a+16|0)|0)>159){break e}x[a+12>>2]=h+4;x[h>>2]=x[a+8>>2]}x[114414]=0;b=Lo(2496,c,x[a+188>>2],e,b);c=lb;h=x[114414];x[114414]=0;f:{if((h|0)==1){break f}x[f>>2]=b;x[f+4>>2]=c;x[114414]=0;De(a+208|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2515,a+344|0,a+336|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=N()|0;xb(d);xb(a+208|0);Q(b|0);p()}return b|0}function $_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=ch(d);h=Um(d,a+224|0);Tm(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114414]=0;g=O(2515,a+344|0,a+336|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}if(g){break c}if(x[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=g+c}x[114414]=0;g=R(2516,a+344|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}x[114414]=0;g=ik(g,b,c,a+188|0,a+8|0,x[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=x[114414];x[114414]=0;if((i|0)==1){break d}if(g){break c}x[114414]=0;R(2518,a+344|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}h=x[a+12>>2];if((h-(a+16|0)|0)>159){break e}x[a+12>>2]=h+4;x[h>>2]=x[a+8>>2]}x[114414]=0;b=Lo(2500,c,x[a+188>>2],e,b);c=lb;h=x[114414];x[114414]=0;f:{if((h|0)==1){break f}x[f>>2]=b;x[f+4>>2]=c;x[114414]=0;De(a+208|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2515,a+344|0,a+336|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=N()|0;xb(d);xb(a+208|0);Q(b|0);p()}return b|0}function Nfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-48|0;hb=e;r=x[a+16>>2];b=x[a+44>>2];x[e+28>>2]=b;i=x[a+48>>2];x[e+32>>2]=i;j=x[a+52>>2];x[e+36>>2]=j;m=x[a+56>>2];x[e+40>>2]=m;s=x[a+24>>2];t=x[a+20>>2];f=x[a+4>>2];h=f;g=x[a>>2];x[e+16>>2]=g;x[e+20>>2]=f;f=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=f;if(d){while(1){m=1;b=x[e+16>>2];k=((((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=(b>>>21&2040)+32976|0;p=w[b+6>>1];q=w[b+4>>1];h=w[b+2>>1];f=w[b>>1];j=0;b=1;i=0;while(1){g=i<<1;x[(i<<2)+e>>2]=(((D(w[g+k>>1],h)+D(w[k+(g|-4)>>1],f)|0)+D(w[k+(g|4)>>1],q)|0)+D(p,w[k+(g|8)>>1])|0)/16384;g=b;b=0;i=1;if(g){continue}break}while(1){b=(j<<2)+e|0;h=x[b>>2];n=x[a+60>>2];o=(e+24|0)+(j<<3)|0;f=x[o+4>>2];l=Xb(f,-16777216,16776704);k=x[a+64>>2];i=Xb(x[o+8>>2],-16777216,16776704);g=x[a+68>>2];p=g>>31;x[o+8>>2]=f;q=x[a+72>>2];j=h<<8;f=j;f=yna(n,n>>31,f,f>>31);h=lb;n=f;f=yna(k,k>>31,l,l>>31);k=n+f|0;l=lb+h|0;l=f>>>0>k>>>0?l+1|0:l;f=yna(g,p,i,i>>31);h=f+k|0;g=lb+l|0;g=f>>>0>h>>>0?g+1|0:g;n=b;f=h+8388608|0;b=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[n>>2]=(b|0)/256;x[o+4>>2]=b-(j&q);j=1;b=m&1;m=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],s);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}m=x[e+40>>2];j=x[e+36>>2];i=x[e+32>>2];g=x[e+16>>2];h=x[e+20>>2];b=x[e+28>>2]}x[a>>2]=g;x[a+4>>2]=h;x[a+56>>2]=m;x[a+52>>2]=j;x[a+48>>2]=i;x[a+44>>2]=b;hb=e+48|0}function e$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=ch(d);h=Um(d,a+224|0);Tm(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114414]=0;g=O(2515,a+344|0,a+336|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}if(g){break c}if(x[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=g+c}x[114414]=0;g=R(2516,a+344|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}x[114414]=0;g=ik(g,b,c,a+188|0,a+8|0,x[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=x[114414];x[114414]=0;if((i|0)==1){break d}if(g){break c}x[114414]=0;R(2518,a+344|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}h=x[a+12>>2];if((h-(a+16|0)|0)>159){break e}x[a+12>>2]=h+4;x[h>>2]=x[a+8>>2]}x[114414]=0;b=Z(2492,c|0,x[a+188>>2],e|0,b|0)|0;c=x[114414];x[114414]=0;f:{if((c|0)==1){break f}x[f>>2]=b;x[114414]=0;De(a+208|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2515,a+344|0,a+336|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=N()|0;xb(d);xb(a+208|0);Q(b|0);p()}return b|0}function c$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=ch(d);h=Um(d,a+224|0);Tm(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114414]=0;g=O(2515,a+344|0,a+336|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}if(g){break c}if(x[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=g+c}x[114414]=0;g=R(2516,a+344|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}x[114414]=0;g=ik(g,b,c,a+188|0,a+8|0,x[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=x[114414];x[114414]=0;if((i|0)==1){break d}if(g){break c}x[114414]=0;R(2518,a+344|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}h=x[a+12>>2];if((h-(a+16|0)|0)>159){break e}x[a+12>>2]=h+4;x[h>>2]=x[a+8>>2]}x[114414]=0;b=Z(2497,c|0,x[a+188>>2],e|0,b|0)|0;c=x[114414];x[114414]=0;f:{if((c|0)==1){break f}w[f>>1]=b;x[114414]=0;De(a+208|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2515,a+344|0,a+336|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=N()|0;xb(d);xb(a+208|0);Q(b|0);p()}return b|0}function b$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=ch(d);h=Um(d,a+224|0);Tm(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114414]=0;g=O(2515,a+344|0,a+336|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}if(g){break c}if(x[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=g+c}x[114414]=0;g=R(2516,a+344|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}x[114414]=0;g=ik(g,b,c,a+188|0,a+8|0,x[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=x[114414];x[114414]=0;if((i|0)==1){break d}if(g){break c}x[114414]=0;R(2518,a+344|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}h=x[a+12>>2];if((h-(a+16|0)|0)>159){break e}x[a+12>>2]=h+4;x[h>>2]=x[a+8>>2]}x[114414]=0;b=Z(2498,c|0,x[a+188>>2],e|0,b|0)|0;c=x[114414];x[114414]=0;f:{if((c|0)==1){break f}x[f>>2]=b;x[114414]=0;De(a+208|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2515,a+344|0,a+336|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=N()|0;xb(d);xb(a+208|0);Q(b|0);p()}return b|0}function a$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=ch(d);h=Um(d,a+224|0);Tm(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114414]=0;g=O(2515,a+344|0,a+336|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}if(g){break c}if(x[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=g+c}x[114414]=0;g=R(2516,a+344|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}x[114414]=0;g=ik(g,b,c,a+188|0,a+8|0,x[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=x[114414];x[114414]=0;if((i|0)==1){break d}if(g){break c}x[114414]=0;R(2518,a+344|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}h=x[a+12>>2];if((h-(a+16|0)|0)>159){break e}x[a+12>>2]=h+4;x[h>>2]=x[a+8>>2]}x[114414]=0;b=Z(2499,c|0,x[a+188>>2],e|0,b|0)|0;c=x[114414];x[114414]=0;f:{if((c|0)==1){break f}x[f>>2]=b;x[114414]=0;De(a+208|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2515,a+344|0,a+336|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=N()|0;xb(d);xb(a+208|0);Q(b|0);p()}return b|0}function w$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-272|0;hb=a;x[a+256>>2]=c;x[a+264>>2]=b;b=ch(d);Vm(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114414]=0;g=O(2486,a+264|0,a+256|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break d}if(g){break c}if(x[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=g+c}x[114414]=0;g=R(2487,a+264|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break d}x[114414]=0;g=jk(g,b,c,a+188|0,a+8|0,v[a+255|0],a+208|0,a+16|0,a+12|0,64928);h=x[114414];x[114414]=0;if((h|0)==1){break d}if(g){break c}x[114414]=0;R(2489,a+264|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}x[114414]=0;b=Lo(2496,c,x[a+188>>2],e,b);c=lb;g=x[114414];x[114414]=0;f:{if((g|0)==1){break f}x[f>>2]=b;x[f+4>>2]=c;x[114414]=0;De(a+208|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2486,a+264|0,a+256|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];xb(d);xb(a+208|0);hb=a+272|0;break a}}b=N()|0;xb(d);xb(a+208|0);Q(b|0);p()}return b|0}function vy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=89;h=92;i=91;j=85;k=84;l=83;m=5;n=107;o=106;p=96;c=88;q=82;r=80;s=78;t=79;u=77;v=57;w=47;d=10;e=8;x=7;a=Wq(a);a:{b:{c:{d:{switch(b-1|0){default:c=(b|0)==16777216;if(!c&(b|0)!=32){break c}Nb(a,0,1);Nb(a,7,1);Nb(a,8,1);Nb(a,9,1);Nb(a,10,1);Nb(a,11,1);Nb(a,12,1);Nb(a,13,1);Nb(a,14,1);Nb(a,15,1);Nb(a,16,1);Nb(a,17,1);Nb(a,18,1);Nb(a,19,1);Nb(a,20,1);Nb(a,21,1);Nb(a,22,1);Nb(a,23,1);Nb(a,24,1);Nb(a,25,1);Nb(a,26,1);Nb(a,27,1);Nb(a,28,1);Nb(a,29,1);Nb(a,30,1);Nb(a,31,1);Nb(a,32,1);Nb(a,33,1);Nb(a,34,1);Nb(a,35,1);Nb(a,36,1);Nb(a,37,1);Nb(a,38,1);Nb(a,39,1);Nb(a,40,1);Nb(a,41,1);Nb(a,42,1);Nb(a,43,1);Nb(a,44,1);Nb(a,45,1);Nb(a,46,1);Nb(a,47,1);Nb(a,48,1);Nb(a,103,1);Nb(a,50,1);Nb(a,87,1);Nb(a,88,1);Nb(a,100,1);Nb(a,102,1);Nb(a,104,1);if(!c){break a}d=105;e=99;break b;case 3:Nb(a,0,1);Nb(a,4,1);Nb(a,8,1);Nb(a,9,1);Nb(a,10,1);Nb(a,17,1);Nb(a,40,1);Nb(a,51,1);Nb(a,52,1);Nb(a,53,1);Nb(a,54,1);Nb(a,55,1);Nb(a,56,1);Nb(a,57,1);Nb(a,58,1);Nb(a,59,1);Nb(a,60,1);Nb(a,61,1);Nb(a,62,1);Nb(a,63,1);Nb(a,64,1);Nb(a,65,1);Nb(a,66,1);Nb(a,67,1);Nb(a,68,1);n=98;o=93;p=90;c=89;q=88;r=86;s=76;t=75;u=74;v=73;w=72;d=71;e=70;f=69;case 1:Nb(a,f,1);Nb(a,e,1);Nb(a,d,1);Nb(a,w,1);Nb(a,v,1);Nb(a,u,1);m=t;l=s;k=r;j=q;i=c;h=p;c=o;g=n;break;case 2:break c;case 0:break d}}Nb(a,m,1);Nb(a,l,1);Nb(a,k,1);Nb(a,j,1);f=i;x=h;e=c;d=g}Nb(a,f,1);Nb(a,x,1)}Nb(a,e,1);Nb(a,d,1)}}function q$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-272|0;hb=a;x[a+256>>2]=c;x[a+264>>2]=b;b=ch(d);Vm(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114414]=0;g=O(2486,a+264|0,a+256|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break d}if(g){break c}if(x[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=g+c}x[114414]=0;g=R(2487,a+264|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break d}x[114414]=0;g=jk(g,b,c,a+188|0,a+8|0,v[a+255|0],a+208|0,a+16|0,a+12|0,64928);h=x[114414];x[114414]=0;if((h|0)==1){break d}if(g){break c}x[114414]=0;R(2489,a+264|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}x[114414]=0;b=Lo(2500,c,x[a+188>>2],e,b);c=lb;g=x[114414];x[114414]=0;f:{if((g|0)==1){break f}x[f>>2]=b;x[f+4>>2]=c;x[114414]=0;De(a+208|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2486,a+264|0,a+256|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];xb(d);xb(a+208|0);hb=a+272|0;break a}}b=N()|0;xb(d);xb(a+208|0);Q(b|0);p()}return b|0}function ZZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0;u=hb-16|0;hb=u;x[c>>2]=a;A=d&512;while(1){if((w|0)==4){if(Bb(n)>>>0>1){C=u,D=ud(n),x[C+8>>2]=D;C=c,D=_E(Fe(u+8|0,1),jf(n),x[c>>2]),x[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}hb=u+16|0}else{a:{b:{switch(v[i+w|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];q=al(g,32);p=x[c>>2];x[c>>2]=p+1;v[p|0]=q;break a;case 3:if(Wc(n)){break a}q=y[pc(n,0)|0];p=x[c>>2];x[c>>2]=p+1;v[p|0]=q;break a;case 2:if(Wc(m)|!A){break a}C=c,D=_E(ud(m),jf(m),x[c>>2]),x[C>>2]=D;break a;case 4:break b;default:break a}}B=x[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!zg(g,64,v[r|0])){break c}r=r+1|0;continue}break}q=o;if((q|0)>0){while(1){if(!(!q|e>>>0>=r>>>0)){r=r-1|0;p=y[r|0];s=x[c>>2];x[c>>2]=s+1;v[s|0]=p;q=q-1|0;continue}break}if(q){p=al(g,48)}else{p=0}while(1){s=x[c>>2];x[c>>2]=s+1;if((q|0)>0){v[s|0]=p;q=q-1|0;continue}break}v[s|0]=j}d:{if((e|0)==(r|0)){q=al(g,48);p=x[c>>2];x[c>>2]=p+1;v[p|0]=q;break d}if(Wc(l)){p=-1}else{p=v[pc(l,0)|0]}q=0;t=0;while(1){if((e|0)==(r|0)){break d}e:{if((q|0)!=(p|0)){s=q;break e}p=x[c>>2];x[c>>2]=p+1;v[p|0]=k;s=0;t=t+1|0;if(Bb(l)>>>0<=t>>>0){p=q;break e}if(y[pc(l,t)|0]==127){p=-1;break e}p=v[pc(l,t)|0]}r=r-1|0;q=y[r|0];z=x[c>>2];x[c>>2]=z+1;v[z|0]=q;q=s+1|0;continue}}fk(B,x[c>>2])}w=w+1|0;continue}break}}function y$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-272|0;hb=a;x[a+256>>2]=c;x[a+264>>2]=b;b=ch(d);Vm(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114414]=0;g=O(2486,a+264|0,a+256|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break d}if(g){break c}if(x[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=g+c}x[114414]=0;g=R(2487,a+264|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break d}x[114414]=0;g=jk(g,b,c,a+188|0,a+8|0,v[a+255|0],a+208|0,a+16|0,a+12|0,64928);h=x[114414];x[114414]=0;if((h|0)==1){break d}if(g){break c}x[114414]=0;R(2489,a+264|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}x[114414]=0;b=Z(2492,c|0,x[a+188>>2],e|0,b|0)|0;c=x[114414];x[114414]=0;f:{if((c|0)==1){break f}x[f>>2]=b;x[114414]=0;De(a+208|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2486,a+264|0,a+256|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];xb(d);xb(a+208|0);hb=a+272|0;break a}}b=N()|0;xb(d);xb(a+208|0);Q(b|0);p()}return b|0}function u$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-272|0;hb=a;x[a+256>>2]=c;x[a+264>>2]=b;b=ch(d);Vm(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114414]=0;g=O(2486,a+264|0,a+256|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break d}if(g){break c}if(x[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=g+c}x[114414]=0;g=R(2487,a+264|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break d}x[114414]=0;g=jk(g,b,c,a+188|0,a+8|0,v[a+255|0],a+208|0,a+16|0,a+12|0,64928);h=x[114414];x[114414]=0;if((h|0)==1){break d}if(g){break c}x[114414]=0;R(2489,a+264|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}x[114414]=0;b=Z(2497,c|0,x[a+188>>2],e|0,b|0)|0;c=x[114414];x[114414]=0;f:{if((c|0)==1){break f}w[f>>1]=b;x[114414]=0;De(a+208|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2486,a+264|0,a+256|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];xb(d);xb(a+208|0);hb=a+272|0;break a}}b=N()|0;xb(d);xb(a+208|0);Q(b|0);p()}return b|0}function s$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-272|0;hb=a;x[a+256>>2]=c;x[a+264>>2]=b;b=ch(d);Vm(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114414]=0;g=O(2486,a+264|0,a+256|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break d}if(g){break c}if(x[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=g+c}x[114414]=0;g=R(2487,a+264|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break d}x[114414]=0;g=jk(g,b,c,a+188|0,a+8|0,v[a+255|0],a+208|0,a+16|0,a+12|0,64928);h=x[114414];x[114414]=0;if((h|0)==1){break d}if(g){break c}x[114414]=0;R(2489,a+264|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}x[114414]=0;b=Z(2498,c|0,x[a+188>>2],e|0,b|0)|0;c=x[114414];x[114414]=0;f:{if((c|0)==1){break f}x[f>>2]=b;x[114414]=0;De(a+208|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2486,a+264|0,a+256|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];xb(d);xb(a+208|0);hb=a+272|0;break a}}b=N()|0;xb(d);xb(a+208|0);Q(b|0);p()}return b|0}function r$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-272|0;hb=a;x[a+256>>2]=c;x[a+264>>2]=b;b=ch(d);Vm(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;a:{b:{c:{if((c|0)!=1){c=pc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[114414]=0;g=O(2486,a+264|0,a+256|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break d}if(g){break c}if(x[a+188>>2]==(Bb(d)+c|0)){g=Bb(d);c=Bb(d);x[114414]=0;P(1649,d|0,c<<1);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=Fc(d);x[114414]=0;P(1649,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c=pc(d,0);x[a+188>>2]=g+c}x[114414]=0;g=R(2487,a+264|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break d}x[114414]=0;g=jk(g,b,c,a+188|0,a+8|0,v[a+255|0],a+208|0,a+16|0,a+12|0,64928);h=x[114414];x[114414]=0;if((h|0)==1){break d}if(g){break c}x[114414]=0;R(2489,a+264|0)|0;g=x[114414];x[114414]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}x[114414]=0;b=Z(2499,c|0,x[a+188>>2],e|0,b|0)|0;c=x[114414];x[114414]=0;f:{if((c|0)==1){break f}x[f>>2]=b;x[114414]=0;De(a+208|0,a+16|0,x[a+12>>2],e);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;b=O(2486,a+264|0,a+256|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];xb(d);xb(a+208|0);hb=a+272|0;break a}}b=N()|0;xb(d);xb(a+208|0);Q(b|0);p()}return b|0}function Ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-48|0;hb=e;r=x[a+16>>2];h=x[a+44>>2];x[e+28>>2]=h;b=x[a+48>>2];x[e+32>>2]=b;j=x[a+52>>2];x[e+36>>2]=j;m=x[a+56>>2];x[e+40>>2]=m;s=x[a+24>>2];t=x[a+20>>2];f=x[a+4>>2];i=f;g=x[a>>2];x[e+16>>2]=g;x[e+20>>2]=f;f=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=f;if(d){while(1){b=x[e+16>>2];k=(((x[e+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=(b>>>21&2040)+32976|0;p=w[b+6>>1];q=w[b+4>>1];i=w[b+2>>1];f=w[b>>1];j=0;m=1;b=1;h=0;while(1){x[(h<<2)+e>>2]=(((D(v[h+k|0],i)+D(v[k+(h|-2)|0],f)|0)+D(v[k+(h|2)|0],q)|0)+D(p,v[k+(h|4)|0])<<8)/16384;g=b;b=0;h=1;if(g){continue}break}while(1){b=(j<<2)+e|0;i=x[b>>2];n=x[a+60>>2];o=(e+24|0)+(j<<3)|0;f=x[o+4>>2];l=Xb(f,-16777216,16776704);k=x[a+64>>2];h=Xb(x[o+8>>2],-16777216,16776704);g=x[a+68>>2];p=g>>31;x[o+8>>2]=f;q=x[a+72>>2];j=i<<8;f=j;f=yna(n,n>>31,f,f>>31);i=lb;n=f;f=yna(k,k>>31,l,l>>31);k=n+f|0;l=lb+i|0;l=f>>>0>k>>>0?l+1|0:l;f=yna(g,p,h,h>>31);i=f+k|0;g=lb+l|0;g=f>>>0>i>>>0?g+1|0:g;n=b;f=i+8388608|0;b=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[n>>2]=(b|0)/256;x[o+4>>2]=b-(j&q);j=1;b=m&1;m=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],s);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}m=x[e+40>>2];j=x[e+36>>2];h=x[e+28>>2];g=x[e+16>>2];i=x[e+20>>2];b=x[e+32>>2]}x[a>>2]=g;x[a+4>>2]=i;x[a+56>>2]=m;x[a+52>>2]=j;x[a+48>>2]=b;x[a+44>>2]=h;hb=e+48|0}function nx(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-208|0;hb=d;a:{b:{c:{if(y[c|0]&2){if(x[b>>2]==-2147483648){e=Lj(d+48|0,1,45);b=x[b>>2];x[114414]=0;x[d+188>>2]=b;T(136,d+192|0,d+188|0,c|0);b=x[114414];x[114414]=0;d:{e:{if((b|0)!=1){x[114414]=0;T(137,a|0,e|0,d+192|0);a=x[114414];x[114414]=0;if((a|0)==1){break e}xb(d+192|0);xb(e);break b}c=N()|0;break d}c=N()|0;xb(d+192|0)}xb(e);break a}e=x[b>>2];if((e|0)>=0){break c}e=Lj(d+48|0,1,45);b=x[b>>2];x[114414]=0;x[d+188>>2]=0-b;T(136,d+192|0,d+188|0,c|0);b=x[114414];x[114414]=0;f:{g:{if((b|0)!=1){x[114414]=0;T(137,a|0,e|0,d+192|0);a=x[114414];x[114414]=0;if((a|0)==1){break g}xb(d+192|0);xb(e);break b}c=N()|0;break f}c=N()|0;xb(d+192|0)}xb(e);break a}e=lh(d+48|0);f=x[x[e>>2]-12>>2];x[114414]=0;g=$(121)|0;h=x[114414];x[114414]=0;h:{i:{j:{k:{l:{if((h|0)==1){break l}x[114414]=0;T(122,d+40|0,e+f|0,g|0);f=x[114414];x[114414]=0;if((f|0)==1){break l}Ob(d+40|0);x[114414]=0;P(138,e|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break l}x[114414]=0;P(123,e|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break l}x[114414]=0;P(124,d+8|0,e|0);b=x[114414];x[114414]=0;if((b|0)==1){break l}x[114414]=0;T(139,d+24|0,d+8|0,c|0);b=x[114414];x[114414]=0;if((b|0)==1){break k}x[114414]=0;T(140,a|0,d+24|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break j}xb(d+24|0);xb(d+8|0);Xd(e);break b}c=N()|0;break h}c=N()|0;break i}c=N()|0;xb(d+24|0)}xb(d+8|0)}Xd(e);break a}x[d+48>>2]=e;vs(a,d+48|0,c)}hb=d+208|0;return}Q(c|0);p()}function zV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=hb-48|0;hb=g;Lc(b);gr(a);a:{if(!If(b,g+40|0)){break a}if(!LC(g+40|0)){break a}if(!c){i=1;break a}if(!Qb(b,4)){break a}Fv(a);o=g,q=Ev(),x[o+24>>2]=q;c=g+24|0;Dv($g(a)+28|0,c);fr(c);j=x[$g(a)+28>>2];c=fj(b);if(c&1){break a}h=c-4|0;Rc(b,h);c=pe(b);c=pe(b)<<8|c<<16|pe(b);if(!c){break a}x[114414]=0;P(295,j|0,c|0);d=x[114414];x[114414]=0;i=1;if((d|0)==1){a=S(75016)|0;if((ib|0)==(ca(75016)|0)){Y(a|0)|0;_();i=0;break a}Q(a|0);p()}Rc(b,4);b=KC(b);k=Cb(x[j>>2]);d=hb-32|0;hb=d;v[d+24|0]=y[b|0];v[d+25|0]=y[b+1|0];v[d+26|0]=y[b+2|0];v[d+27|0]=y[b+3|0];f=Wq(d+8|0);h=b+h|0;x[f+12>>2]=h-4;x[f+8>>2]=b;bj(f,y[h-1|0]);b:{if(!c){break b}h=c;while(1){if(!bj(f,1)){b=1;x[d+4>>2]=1;while(1){e=bj(f,2);b=e+b|0;x[d+4>>2]=b;if((e|0)==3){continue}break}xc(d+4|0,c);b=0;e=x[d+4>>2];if(e){while(1){c=c-1|0;o=k+c|0,q=bj(f,8),v[o|0]=q;b=b+1|0;if((e|0)!=(b|0)){continue}break}}if(!c){break b}}b=bj(f,2);x[d+4>>2]=b+2;c:{if((b|0)==3){d:{if(!bj(f,1)){e=7;b=5;break d}e=y[gc(d+24|0,3)|0];b=x[d+4>>2]}l=bj(f,e);while(1){e=bj(f,3);b=e+b|0;x[d+4>>2]=b;if((e|0)==7){continue}break}break c}l=bj(f,y[gc(d+24|0,b)|0])}xc(d+4|0,c);e=0;m=x[d+4>>2];if(m){while(1){b=0;n=c+l|0;if(h>>>0>n>>>0){b=y[k+n|0]}c=c-1|0;v[k+c|0]=b;e=e+1|0;if((m|0)!=(e|0)){continue}break}}if(c){continue}break}}hb=d+32|0;b=g+8|0;ej(b,j);c=g+16|0;zv(c,b);b=Ho(g+24|0,c,0);Ud($g(a)+12|0,b);Ab(b)}hb=g+48|0;return i|0}function GU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-32|0;hb=f;Lc(c);a:{if(!Qb(c,3)){break a}while(1){d=f+24|0;Fq(d,c);i=ed(d);h=rf(d);if(A[a+12>>2]<=y[d|0]){break a}g=Df(a,y[d|0],b);d=y[i|0];b:{if(d>>>0<=126){if(!(d|y[h|0])){v[g|0]=254;break b}v[g|0]=d+1;if(y[h|0]==255){break b}v[g+2|0]=1;v[g+4|0]=y[h|0];break b}c:{switch(d-127|0){case 1:v[g+1|0]=y[h|0]+1;break b;case 0:break b;default:break c}}e=v[h|0];v[f+23|0]=e;h=0;d=d&127;if(d>>>0<=23){h=y[d+23328|0]}d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{j=y[i|0];switch((j&127)-2|0){case 21:break h;case 18:break i;case 17:break j;case 16:case 20:break k;case 15:break l;case 2:break m;case 1:break n;case 0:case 8:case 9:break o;default:break e}}if((e|0)>=0){break g}d=0-e&15;break f}v[f+16|0]=64;e=y[rc(f+23|0,f+16|0)|0];if(y[g+2|0]>1){break e}v[g+4|0]=e;v[g+2|0]=1;break b}d=3;if((e|0)>=0){break d}d=0-e&127;break f}if(!e){break b}d=0-e|-16;if((e|0)<0){break f}d=e<<4|15;break f}if(!e){break b}d=(e|0)>=0;if(!d){e=0-e&15;v[f+23|0]=e;j=y[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;v[f+23|0]=e;break d}d=e&15|-48;break f}d=e&15|-64;break f}d=164;if((e|0)==100){break f}x[f+16>>2]=e- -64;x[f+12>>2]=0;x[f+8>>2]=128;e=x[dl(f+16|0,f+12|0,f+8|0)>>2];if(!y[g+3|0]){break e}p:{switch(y[g+2|0]){case 0:case 2:break p;default:break b}}v[g+2|0]=2;v[g+4|0]=(e&254)>>>1;break b}d=e<<4}e=d;v[f+23|0]=e}d=h;if(!d){break b}}v[g+5|0]=e;v[g+3|0]=d}if(Qb(c,3)){continue}break}}hb=f+32|0}function Fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){f=(d<<2)+a|0;i=y[f+4|0];j=gc(h,d),k=i+1|0,v[j|0]=k;f=f+6|0;f=y[f|0]|y[f+1|0]<<8;j=fd(g,d),k=f+1|0,w[j>>1]=k;d=d+1|0;if((d|0)!=120){continue}break}break a}g=b+236|0;while(1){h=((d<<2)+a|0)+6|0;h=y[h|0]|y[h+1|0]<<8;j=fd(g,d+12|0),k=h+1|0,w[j>>1]=k;d=d+1|0;if((d|0)!=96){continue}break}}Sz(a+484|0,b+48|0,0);Sz(a+590|0,b+68|0,0);Sz(a+696|0,b+88|0,5);d=a+806|0;x[b>>2]=y[d|0]|y[d+1|0]<<8;d=a+808|0;g=y[d|0];b:{if(v[d|0]<0){v[b+34|0]=g-127;break b}if(!(!(v[a|0]&1)|g>>>0>16)){v[b+31|0]=y[d|0]+1;break b}if(!y[d|0]|y[d|0]>16){break b}v[b+31|0]=y[d|0]+1}if(y[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=a+809|0;if(v[d|0]>=0){w[b+28>>1]=y[d|0]+1}d=a+810|0;if(v[d|0]<0){break c}}v[b+30|0]=y[d|0]+1}v[b+33|0]=y[a+811|0]}if((c|0)==32){v[e+15|0]=y[a+812|0];v[e+14|0]=128;j=b,k=y[rc(e+15|0,e+14|0)|0]>>>1|0,x[j+4>>2]=k}c=a+813|0;if((y[c|0]|y[c+1|0]<<8)>>>0<=256){x[b+8>>2]=y[c|0]|y[c+1|0]<<8;v[b+15|0]=y[b+15|0]|1}v[b+16|0]=y[a+815|0];v[b+26|0]=y[a+816|0];v[b+27|0]=y[a+817|0];v[b+17|0]=y[a+818|0];v[b+18|0]=y[a+819|0];c=a+820|0;w[e+12>>1]=y[c|0]|y[c+1|0]<<8;w[e+10>>1]=100;j=b,k=y[Cf(e+12|0,e+10|0)|0],v[j+20|0]=k;c=a+822|0;w[e+8>>1]=y[c|0]|y[c+1|0]<<8;w[e+6>>1]=256;j=b,k=z[Cf(e+8|0,e+6|0)>>1]>>>2|0,v[j+19|0]=k;c=a+824|0;ev(b,y[c|0]&127,y[c|0]>>>7|0);a=a+825|0;dv(b,y[a|0]&127,y[a|0]>>>7|0);hb=e+16|0}function Wda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-48|0;hb=d;e=JN(d+32|0,1<<x[b+12>>2]);if(Og(a)){while(1){g=C[ll(a,c)>>3];IN(vc(e,c),g);c=c+1|0;if(Og(a)>>>0>c>>>0){continue}break}}x[114414]=0;P(1208,b|0,e|0);c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}h=d,i=bc(e),x[h>>2]=i;h=d,i=dc(e),x[h+24>>2]=i;b:{if(Hb(d,d+24|0)){while(1){c=x[d>>2];x[114414]=0;g=+ha(1209,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break b}IN(c,Zo(g));of(d);if(Hb(d,d+24|0)){continue}break}}x[114414]=0;P(1210,b|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;W(1211,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}if(rd(e)>>>0>3){c=1;while(1){Zy(vc(e,c),2);Zy(vc(e,(rd(e)>>>1|0)+c|0),0);c=c+1|0;if(c>>>0<rd(e)>>>1>>>0){continue}break}}x[114414]=0;P(1208,b|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}h=d,i=bc(e),x[h+24>>2]=i;h=d,i=dc(e),x[h+16>>2]=i;if(Hb(d+24|0,d+16|0)){while(1){c=x[d+24>>2];x[114414]=0;P(1212,d|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break b}f=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=f;f=x[d+12>>2];x[c+8>>2]=x[d+8>>2];x[c+12>>2]=f;c=d+24|0;of(c);if(Hb(c,d+16|0)){continue}break}}x[114414]=0;P(1210,b|0,e|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}x[114414]=0;W(1211,e|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}if(Og(a)){c=0;while(1){g=C[vc(e,c)>>3];h=ll(a,c),j=g,C[h>>3]=j;c=c+1|0;if(Og(a)>>>0>c>>>0){continue}break}}Mp(e);hb=d+48|0;return}}a=N()|0;Mp(e);Q(a|0);p()}function yL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=hb-16|0;hb=c;d=D(b,896)+a|0;a:{if(x[d+1075072>>2]&134218752){break a}if(!wj(d+1074984|0)){break a}h=x[(D(b,896)+a|0)+1075640>>2];if(y[h+15|0]&2){break a}d=Pl(a,b,2,1);if((d-1&255)>>>0>249){break a}g=x[(D(d,160)+a|0)+906140>>2];if(!g){break a}f=D(b,896)+a|0;d=y[f+1075794|0];b:{if(y[f+1075796|0]==1){v[c+8|0]=64;e=y[rc(f+1075798|0,c+8|0)|0];break b}e=255;if(y[f+1075797|0]!=13){break b}v[c+8|0]=64;e=y[rc((D(b,896)+a|0)+1075799|0,c+8|0)|0]}f=e;e=c+8|0;j=a+1074312|0;Kb(e,j,2);if(Ib(e)){if(d){if(Zd(d)){d=y[gc(h+108|0,d-1|0)|0]}Ql(a,b,d&255,z[(D(b,896)+a|0)+1075672>>1]);break a}if((f|0)==255){break a}mb[x[x[g>>2]+76>>2]](g,39,f,b);break a}k=x[h+4>>2];if(d){l=y[h+35|0]?k<<2:x[(D(b,896)+a|0)+1075672>>2];i=w[(D(b,896)+a|0)+1075772>>1];e=c+8|0;Kb(e,j,28);m=c,n=(Ib(e)?i<<2:i)+l|0,x[m+4>>2]=n;_d(c+4|0,0,256);e=a;if(Zd(d)){a=y[gc(h+108|0,d-1|0)|0]}else{a=d}Ql(e,b,a&255,z[c+4>>1])}a=y[h+35|0];i=c+8|0;Kb(i,j,101);e=(a|0)==1;a=(f|0)!=255;if(!Ib(i)){d=Zd(d)}if(((d?e:a)|0)!=1){break a}c:{switch(y[h+36|0]){case 1:if((f|0)!=255){RJ(g,f<<1);break a}RJ(g,k<<1);break a;case 0:break c;default:break a}}if((f|0)!=255){v[c+8|0]=127;v[c+4|0]=f<<1;n=g,o=7,p=y[rc(c+8|0,c+4|0)|0],q=b,m=x[x[g>>2]+76>>2],mb[m](n|0,o|0,p|0,q|0);break a}x[c+8>>2]=127;x[c+4>>2]=k<<1;q=g,p=7,o=y[Mb(c+8|0,c+4|0)|0],n=b,m=x[x[g>>2]+76>>2],mb[m](q|0,p|0,o|0,n|0)}hb=c+16|0}function pga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;t=x[a+16>>2];i=x[a+44>>2];x[b+28>>2]=i;m=x[a+48>>2];x[b+32>>2]=m;n=x[a+52>>2];x[b+36>>2]=n;h=x[a+56>>2];x[b+40>>2]=h;o=x[a+40>>2];p=x[a+36>>2];e=x[a+4>>2];f=e;g=x[a>>2];x[b+16>>2]=g;x[b+20>>2]=e;e=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=e;a:{if(!d){e=o>>12;k=p>>12;break a}while(1){g=x[b+16>>2];g=((((x[b+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+t|0;x[b>>2]=w[g>>1];x[b+4>>2]=w[g+2>>1];e=0;k=1;while(1){g=(e<<2)+b|0;h=x[g>>2];l=x[a+60>>2];q=(b+24|0)+(e<<3)|0;f=x[q+4>>2];j=Xb(f,-16777216,16776704);i=x[a+64>>2];r=Xb(x[q+8>>2],-16777216,16776704);e=x[a+68>>2];m=e>>31;x[q+8>>2]=f;n=x[a+72>>2];s=h<<8;f=s;f=yna(l,l>>31,f,f>>31);h=lb;l=f;f=yna(i,i>>31,j,j>>31);i=l+f|0;j=lb+h|0;j=f>>>0>i>>>0?j+1|0:j;f=yna(e,m,r,r>>31);h=f+i|0;e=lb+j|0;e=f>>>0>h>>>0?e+1|0:e;l=g;f=h+8388608|0;g=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;x[l>>2]=(g|0)/256;x[q+4>>2]=g-(n&s);g=k&1;k=0;e=1;if(g){continue}break}g=x[a+32>>2];p=x[a+28>>2]+p|0;k=p>>12;x[c>>2]=x[c>>2]+D(k,x[b>>2]);o=g+o|0;e=o>>12;x[c+4>>2]=x[c+4>>2]+D(e,x[b+4>>2]);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}h=x[b+40>>2];n=x[b+36>>2];m=x[b+32>>2];i=x[b+28>>2];g=x[b+16>>2];f=x[b+20>>2]}x[a>>2]=g;x[a+4>>2]=f;x[a+40>>2]=o;x[a+20>>2]=k;x[a+36>>2]=p;x[a+56>>2]=h;x[a+52>>2]=n;x[a+48>>2]=m;x[a+44>>2]=i;x[a+24>>2]=e;hb=b+48|0}function efa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;g=hb-16|0;hb=g;j=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];e=x[a+44>>2];q=x[a+16>>2];i=x[a+4>>2];o=i;f=x[a>>2];x[g+8>>2]=f;x[g+12>>2]=i;i=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=i;a:{if(!d){m=k>>12;i=l>>12;break a}r=b+24|0;while(1){f=(x[g+12>>2]<<1)+q|0;s=w[f-6>>1];b=(((x[g+8>>2]>>>16|0)+4&131064)<<1)+r|0;t=w[b>>1];u=w[f-4>>1];v=w[b+2>>1];y=w[f-2>>1];z=w[b+4>>1];A=w[f>>1];B=w[b+6>>1];C=w[f+2>>1];E=w[b+8>>1];F=w[f+4>>1];G=w[b+10>>1];H=w[f+6>>1];I=w[b+12>>1];J=w[f+8>>1];p=w[b+14>>1];f=x[a+60>>2];b=e;h=Xb(e,-16777216,16776704);e=x[a+64>>2];n=Xb(j,-16777216,16776704);o=x[a+72>>2];m=x[a+32>>2];i=x[c>>2];e=yna(e,e>>31,h,h>>31);j=lb;h=e;e=x[a+68>>2];e=yna(e,e>>31,n,n>>31);n=h+e|0;h=lb+j|0;h=e>>>0>n>>>0?h+1|0:h;p=(((((D(F,G)+D(C,E)|0)+D(H,I)|0)+D(p,J)|0)/2|0)+((((D(u,v)+D(s,t)|0)+D(y,z)|0)+D(A,B)|0)/2|0)|0)/16384<<8;e=p;e=yna(f,f>>31,e,e>>31);j=e+n|0;f=lb+h|0;f=e>>>0>j>>>0?f+1|0:f;h=i;l=x[a+28>>2]+l|0;i=l>>12;e=j+8388608|0;e=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;f=(e|0)/256|0;x[c>>2]=h+D(i,f);k=k+m|0;m=k>>12;x[c+4>>2]=x[c+4>>2]+D(f,m);e=e-(o&p)|0;c=c+8|0;Tb(g+8|0,g);j=b;d=d-1|0;if(d){continue}break}f=x[g+8>>2];o=x[g+12>>2]}x[a>>2]=f;x[a+4>>2]=o;x[a+40>>2]=k;x[a+20>>2]=i;x[a+36>>2]=l;x[a+48>>2]=j;x[a+44>>2]=e;x[a+24>>2]=m;hb=g+16|0}function qga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;t=x[a+16>>2];i=x[a+44>>2];x[b+28>>2]=i;m=x[a+48>>2];x[b+32>>2]=m;n=x[a+52>>2];x[b+36>>2]=n;h=x[a+56>>2];x[b+40>>2]=h;o=x[a+40>>2];p=x[a+36>>2];e=x[a+4>>2];f=e;g=x[a>>2];x[b+16>>2]=g;x[b+20>>2]=e;e=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=e;a:{if(!d){e=o>>12;k=p>>12;break a}while(1){g=x[b+16>>2];g=(((x[b+20>>2]&2147483647)<<1|g>>>31)&-2)+t|0;x[b>>2]=v[g|0]<<8;x[b+4>>2]=v[g+1|0]<<8;e=0;k=1;while(1){g=(e<<2)+b|0;h=x[g>>2];l=x[a+60>>2];q=(b+24|0)+(e<<3)|0;f=x[q+4>>2];j=Xb(f,-16777216,16776704);i=x[a+64>>2];r=Xb(x[q+8>>2],-16777216,16776704);e=x[a+68>>2];m=e>>31;x[q+8>>2]=f;n=x[a+72>>2];s=h<<8;f=s;f=yna(l,l>>31,f,f>>31);h=lb;l=f;f=yna(i,i>>31,j,j>>31);i=l+f|0;j=lb+h|0;j=f>>>0>i>>>0?j+1|0:j;f=yna(e,m,r,r>>31);h=f+i|0;e=lb+j|0;e=f>>>0>h>>>0?e+1|0:e;l=g;f=h+8388608|0;g=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;x[l>>2]=(g|0)/256;x[q+4>>2]=g-(n&s);g=k&1;k=0;e=1;if(g){continue}break}g=x[a+32>>2];p=x[a+28>>2]+p|0;k=p>>12;x[c>>2]=x[c>>2]+D(k,x[b>>2]);o=g+o|0;e=o>>12;x[c+4>>2]=x[c+4>>2]+D(e,x[b+4>>2]);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}h=x[b+40>>2];n=x[b+36>>2];m=x[b+32>>2];i=x[b+28>>2];g=x[b+16>>2];f=x[b+20>>2]}x[a>>2]=g;x[a+4>>2]=f;x[a+40>>2]=o;x[a+20>>2]=k;x[a+36>>2]=p;x[a+56>>2]=h;x[a+52>>2]=n;x[a+48>>2]=m;x[a+44>>2]=i;x[a+24>>2]=e;hb=b+48|0}function v3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=hb-176|0;hb=e;d=Ub(e+8|0,7480);x[114414]=0;b=d+12|0;O(118,b|0,6945)|0;c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}x[114414]=0;b=d+24|0;O(118,b|0,7310)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;b=d+36|0;O(118,b|0,6937)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;b=d+48|0;O(118,b|0,4448)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;b=d+60|0;O(118,b|0,6922)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;b=d+72|0;O(118,b|0,4514)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;b=d+84|0;O(118,b|0,2106)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;b=d+96|0;O(118,b|0,7848)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;b=d+108|0;O(118,b|0,7253)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;b=d+120|0;O(118,b|0,8039)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;b=d+132|0;O(118,b|0,1958)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;b=d+144|0;O(118,b|0,3559)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;x[e+172>>2]=13;x[e+168>>2]=d;b=x[e+172>>2];x[e>>2]=x[e+168>>2];x[e+4>>2]=b;O(2209,a|0,e|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){b=d+156|0;while(1){b=xb(b-12|0);if((d|0)!=(b|0)){continue}break}hb=e+176|0;return}b=d+156|0}a=N()|0;while(1){b=xb(b-12|0);if((d|0)!=(b|0)){continue}break}Q(a|0);p()}function ffa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=hb-16|0;hb=g;j=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];e=x[a+44>>2];q=x[a+16>>2];i=x[a+4>>2];o=i;f=x[a>>2];x[g+8>>2]=f;x[g+12>>2]=i;i=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=i;a:{if(!d){m=k>>12;i=l>>12;break a}r=b+24|0;while(1){f=x[g+12>>2]+q|0;s=v[f-3|0];b=(((x[g+8>>2]>>>16|0)+4&131064)<<1)+r|0;t=w[b>>1];u=v[f-2|0];y=w[b+2>>1];z=v[f-1|0];A=w[b+4>>1];B=v[f|0];C=w[b+6>>1];E=v[f+1|0];F=w[b+8>>1];G=v[f+2|0];H=w[b+10>>1];I=v[f+3|0];J=w[b+12>>1];K=v[f+4|0];p=w[b+14>>1];f=x[a+60>>2];b=e;h=Xb(e,-16777216,16776704);e=x[a+64>>2];n=Xb(j,-16777216,16776704);o=x[a+72>>2];m=x[a+32>>2];i=x[c>>2];e=yna(e,e>>31,h,h>>31);j=lb;h=e;e=x[a+68>>2];e=yna(e,e>>31,n,n>>31);n=h+e|0;h=lb+j|0;h=e>>>0>n>>>0?h+1|0:h;p=((((D(G,H)+D(E,F)|0)+D(I,J)|0)+D(p,K)<<8>>1)+(((D(u,y)+D(s,t)|0)+D(z,A)|0)+D(B,C)<<8>>1)|0)/16384<<8;e=p;e=yna(f,f>>31,e,e>>31);j=e+n|0;f=lb+h|0;f=e>>>0>j>>>0?f+1|0:f;h=i;l=x[a+28>>2]+l|0;i=l>>12;e=j+8388608|0;e=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;f=(e|0)/256|0;x[c>>2]=h+D(i,f);k=k+m|0;m=k>>12;x[c+4>>2]=x[c+4>>2]+D(f,m);e=e-(o&p)|0;c=c+8|0;Tb(g+8|0,g);j=b;d=d-1|0;if(d){continue}break}f=x[g+8>>2];o=x[g+12>>2]}x[a>>2]=f;x[a+4>>2]=o;x[a+40>>2]=k;x[a+20>>2]=i;x[a+36>>2]=l;x[a+48>>2]=j;x[a+44>>2]=e;x[a+24>>2]=m;hb=g+16|0}function J_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=hb-16|0;hb=k;l=Aw(g);g=ew(g);wg(k,g);a:{b:{if(Wc(k)){x[114414]=0;Z(2523,l|0,a|0,c|0,d|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[114414]=0;j=O(2535,l|0,h<<24>>24)|0;h=x[114414];x[114414]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[114414]=0;h=O(2535,l|0,48)|0;i=x[114414];x[114414]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;h=v[j+1|0];x[114414]=0;h=O(2535,l|0,h|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;j=j+2|0}i=0;x[114414]=0;fk(j,c);h=x[114414];x[114414]=0;if((h|0)==1){break b}x[114414]=0;o=R(2520,g|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(c>>>0<=g>>>0){g=x[f>>2];x[114414]=0;Vo((j-a<<2)+d|0,g);g=x[114414];x[114414]=0;if((g|0)==1){break e}g=x[f>>2];break a}f:{if(!y[pc(k,h)|0]){break f}if(v[pc(k,h)|0]!=(i|0)){break f}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=o;h=(Bb(k)-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[114414]=0;n=O(2535,l|0,n|0)|0;m=x[114414];x[114414]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+4;x[m>>2]=n;g=g+1|0;i=i+1|0;continue}}break}}a=N()|0;xb(k);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;xb(k);hb=k+16|0}function EH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0;h=hb-16|0;hb=h;a:{b:{c:{f=a+8|0;d:{if(Fl(f)){g=Fl(f);break d}g=xs(f)}if(!((g|0)>(b|0)&(b|0)>=0)){b=ec(8);x[114414]=0;c=O(118,h|0,2427)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}if(c>>>0>=120){b=ec(8);x[114414]=0;c=O(118,h|0,7198)|0;a=x[114414];x[114414]=0;if((a|0)!=1){a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}a=N()|0;hc(b);break b}f=a+32|0;a=Jy(x[f>>2],65535);a=(a|0)==65535?255:a;w[h>>1]=a;a=x[f>>2]+D(a,896)|0;g=a+1074984|0;Hn(g,7,x[f>>2],65535,1024);c=c+1|0;v[a+1075808|0]=c;v[a+1075805|0]=c;w[a+1075792>>1]=0;Rl(g);Fp(x[f>>2],g,b+1|0,0,1,1);x[a+1075680>>2]=65536;ft(x[f>>2],g,c,0,1,1,65535);j=a+1075676|0,k=Cn(Py(e*128,-128,128)+128),x[j>>2]=k;j=a+1075672|0,k=Cn(Py(d*256,0,256)),x[j>>2]=k;a=x[f>>2]+1074466|0;g=a;c=(z[x[f>>2]+480212>>1]<<1)+a|0;b=c;e:{if((b|0)==(a|0)){break e}i=z[h>>1];while(1){if((i|0)==z[a>>1]){break e}a=a+2|0;if((b|0)!=(a|0)){continue}break}a=b}b=a;f:{if((a|0)==(c|0)){break f}a=b+2|0;if((c|0)==(a|0)){break f}while(1){i=z[a>>1];if((i|0)!=z[h>>1]){w[b>>1]=i;b=b+2|0}a=a+2|0;if((c|0)!=(a|0)){continue}break}}a=Vy(g,b);w[x[f>>2]+480212>>1]=a;hb=h+16|0;return z[h>>1]}a=N()|0;hc(b)}Q(a|0)}p()}function cga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-48|0;hb=e;r=x[a+16>>2];h=x[a+44>>2];x[e+28>>2]=h;j=x[a+48>>2];x[e+32>>2]=j;l=x[a+52>>2];x[e+36>>2]=l;b=x[a+56>>2];x[e+40>>2]=b;s=x[a+24>>2];t=x[a+20>>2];f=x[a+4>>2];i=f;g=x[a>>2];x[e+16>>2]=g;x[e+20>>2]=f;f=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=f;if(d){while(1){g=x[e+16>>2];f=g>>>18|0;l=1;n=((((x[e+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;h=0;b=1;j=0;while(1){g=j<<1;i=w[g+n>>1];x[(j<<2)+e>>2]=i+((D(f,w[n+(g|4)>>1]-i|0)|0)/16384|0);g=b;b=0;j=1;if(g){continue}break}while(1){b=(h<<2)+e|0;i=x[b>>2];m=x[a+60>>2];o=(e+24|0)+(h<<3)|0;f=x[o+4>>2];k=Xb(f,-16777216,16776704);h=x[a+64>>2];p=Xb(x[o+8>>2],-16777216,16776704);g=x[a+68>>2];j=g>>31;x[o+8>>2]=f;n=x[a+72>>2];q=i<<8;f=q;f=yna(m,m>>31,f,f>>31);i=lb;m=f;f=yna(h,h>>31,k,k>>31);h=m+f|0;k=lb+i|0;k=f>>>0>h>>>0?k+1|0:k;f=yna(g,j,p,p>>31);i=f+h|0;g=lb+k|0;g=f>>>0>i>>>0?g+1|0:g;m=b;f=i+8388608|0;b=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[m>>2]=(b|0)/256;x[o+4>>2]=b-(n&q);h=1;b=l&1;l=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],s);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}l=x[e+36>>2];j=x[e+32>>2];h=x[e+28>>2];g=x[e+16>>2];i=x[e+20>>2];b=x[e+40>>2]}x[a>>2]=g;x[a+4>>2]=i;x[a+56>>2]=b;x[a+52>>2]=l;x[a+48>>2]=j;x[a+44>>2]=h;hb=e+48|0}function U_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=hb-16|0;hb=k;l=Hu(g);g=hw(g);wg(k,g);a:{b:{if(Wc(k)){x[114414]=0;Z(2503,l|0,a|0,c|0,d|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[114414]=0;j=O(22,l|0,h<<24>>24)|0;h=x[114414];x[114414]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+1;v[h|0]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[114414]=0;h=O(22,l|0,48)|0;i=x[114414];x[114414]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=v[j+1|0];x[114414]=0;h=O(22,l|0,h|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;j=j+2|0}i=0;x[114414]=0;fk(j,c);h=x[114414];x[114414]=0;if((h|0)==1){break b}x[114414]=0;o=R(2494,g|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(c>>>0<=g>>>0){g=x[f>>2];x[114414]=0;fk((j-a|0)+d|0,g);g=x[114414];x[114414]=0;if((g|0)==1){break e}g=x[f>>2];break a}f:{if(!y[pc(k,h)|0]){break f}if(v[pc(k,h)|0]!=(i|0)){break f}i=x[f>>2];x[f>>2]=i+1;v[i|0]=o;h=(Bb(k)-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[114414]=0;n=O(22,l|0,n|0)|0;m=x[114414];x[114414]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+1;v[m|0]=n;g=g+1|0;i=i+1|0;continue}}break}}a=N()|0;xb(k);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;xb(k);hb=k+16|0}function vba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=hb-48|0;hb=d;c=z[a+480190>>1];v[d+32|0]=0;BN(b,c+1|0,d+32|0);if(z[a+480192>>1]){h=Qq(d+32|0);c=a+484344|0;l=d,m=bc(c),x[l+24>>2]=m;l=d,m=dc(c),x[l+16>>2]=m;if(Hb(d+24|0,d+16|0)){while(1){a:{i=x[d+24>>2];if(!xh(i)){break a}c=z[a+480188>>1];x[114414]=0;v[d|0]=0;T(1437,h|0,c|0,d|0);c=x[114414];x[114414]=0;if((c|0)!=1){b:{l=d,m=bc(i),x[l+8>>2]=m;j=0;if(!x[i+12>>2]){break a}while(1){g=0;c:{if(!z[a+480188>>1]){break c}while(1){d:{c=x[d+8>>2];x[114414]=0;c=R(520,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break d}e:{if(!c){break e}c=y[x[d+8>>2]+1|0];if(!c){c=y[Bc(h,g)|0]}e=z[a+480192>>1];f=c&255;if(f){k=z[a+480192>>1];l=Bc(h,g),m=c,v[l|0]=m;c=f>>>0>k>>>0;e=c?e:f;c=c?1:f}else{c=1}if(c>>>0>e>>>0){break e}while(1){f=x[(((c&65535)<<2)+a|0)+900380>>2];f:{if(!f){break f}f=z[fd(f+236|0,y[x[d+8>>2]]-1|0)>>1];if(f>>>0>z[a+480190>>1]){break f}oe(d,b,f);he(d,1)}c=c+1|0;if((c&65535)>>>0<=e>>>0){continue}break}}Nj(d+8|0);g=g+1|0;if(g>>>0<z[a+480188>>1]){continue}break c}break}break b}j=j+1|0;if(j>>>0<A[i+12>>2]){continue}break}break a}}a=N()|0;$d(h);Q(a|0);p()}c=d+24|0;Zl(c);if(Hb(c,d+16|0)){continue}break}}c=z[a+480190>>1];g:{if(!c){e=0;break g}e=0;g=c;while(1){oe(d,b,c);if(!Ib(d)){e=Be((D(c,104)+a|0)+484380|0)+e|0}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}$d(h)}hb=d+48|0;return e&65535}function _ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-48|0;hb=e;i=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;l=e,m=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[l+28>>2]=m;f=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=f;a:{if(!f){break a}b=a+8|0;l=e,m=Sf(b,f),x[l+16>>2]=m;x[e+20>>2]=lb;l=e,m=Te(b,d),x[l+40>>2]=m;x[e+44>>2]=lb;tf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}j=x[a+24>>2];k=x[a+20>>2];f=x[a+4>>2];b=x[a>>2];x[e+8>>2]=b;x[e+12>>2]=f;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;g=a;if(d){while(1){f=x[e+36>>2]-1|0;x[e+36>>2]=f;a=x[e+8>>2];b=(((x[e+12>>2]&2147483647)<<1|a>>>31)&2147483646)<<1;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=b+i|0;x[e+40>>2]=a;x[e+44>>2]=0;b=x[e+32>>2];if((b|0)>0){while(1){a=x[e+40>>2];a=(x[e+44>>2]&2147483647)<<1|a>>>31;zj(x[e+24>>2],(w[(a<<1|2)+f>>1]+w[f+((a&2147483646)<<1)>>1]|0)/8<<16>>16);yj(x[e+24>>2],4);a=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(a){continue}break}}d=d-1|0;a=x[e+24>>2];Tb(a,a+8|0);b=x[e+24>>2];h=x[b+4>>2];if(h){a=x[e+40>>2];a=(x[e+44>>2]&2147483647)<<1|a>>>31;zj(b,(w[(a<<1|2)+f>>1]+w[f+((a&2147483646)<<1)>>1]|0)/8<<16>>16);yj(x[e+24>>2],h);b=x[e+24>>2];a=x[b>>2];x[b>>2]=a;x[b+4>>2]=0}a=Lp(b,x[e+28>>2]);x[c>>2]=x[c>>2]+D(a,k);x[c+4>>2]=x[c+4>>2]+D(a,j);c=c+8|0;Tb(e+8|0,e);if(d){continue}break}b=x[e+8>>2];f=x[e+12>>2]}x[g>>2]=b;x[g+4>>2]=f;hb=e+48|0}function Fea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb+-64|0;hb=c;w[c+62>>1]=b;d=Bj(a);b=hb-16|0;hb=b;e=c+48|0;x[e>>2]=0;x[e+4>>2]=0;x[b+12>>2]=0;Xc(e+8|0);if(d){Ln(e,d);DB(e,d)}hb=b+16|0;a:{b:{if(!d){break b}b=0;while(1){i=uc(e,b),j=b-f|0,w[i>>1]=j;x[114414]=0;g=O(1158,a|0,b|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}f=(z[g>>1]==z[c+62>>1])+f|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}if(!(f&65535)){break b}b=bc(a);d=dc(a);x[114414]=0;b=U(1159,b|0,d|0,c+62|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}x[c+32>>2]=b;b=td(c+40|0,c+32|0);i=c,j=dc(a),x[i+16>>2]=j;d=x[td(c+24|0,c+16|0)>>2];b=x[b>>2];x[114414]=0;U(1160,a|0,b|0,d|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}i=c,j=bc(a),x[i+32>>2]=j;i=c,j=dc(a),x[i+16>>2]=j;if(Hb(c+32|0,c+16|0)){while(1){b=z[x[c+32>>2]>>1];d=x[a+24>>2];x[114414]=0;d=O(392,d+484344|0,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break a}c:{if(!d){break c}b=Zb(x[a+24>>2]+484344|0,b);i=c,j=bc(b),x[i+8>>2]=j;i=c,j=dc(b),x[i>>2]=j;if(!Hb(c+8|0,c)){break c}while(1){b=x[c+8>>2];d:{if(y[b+3|0]!=12){break d}d=y[b+5|0];if(qc(e)>>>0<=d>>>0){break d}i=b,j=y[uc(e,y[b+5|0])|0],v[i+5|0]=j}b=c+8|0;Nj(b);if(Hb(b,c)){continue}break}}b=c+32|0;ge(b);if(Hb(b,c+16|0)){continue}break}}b=z[a+28>>1];if(qc(e)>>>0<=b>>>0){break b}i=a,j=z[uc(e,z[a+28>>1])>>1],w[i+28>>1]=j}qf(e);hb=c- -64|0;return}a=N()|0;qf(e);Q(a|0);p()}function YJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;c=hb-96|0;hb=c;b=Ho(c+80|0,Ed(c+72|0,b),0);x[114414]=0;d=R(296,b|0)|0;e=x[114414];x[114414]=0;a:{if((e|0)==1){break a}x[114414]=0;d=U(1736,b|0,c+32|0,d|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break a}b:{c:{if(!d|x[c+32>>2]!=542066252){break c}d=c+32|4;if(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24)){break c}x[c+28>>2]=y[c+40|0]|y[c+41|0]<<8|(y[c+42|0]<<16|y[c+43|0]<<24);x[114414]=0;x[c+20>>2]=1065353216;x[c+24>>2]=0;d=U(676,c+28|0,c+24|0,c+20|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break b}B[a+4220>>2]=B[d>>2];x[c+24>>2]=y[c+44|0]|y[c+45|0]<<8|(y[c+46|0]<<16|y[c+47|0]<<24);x[114414]=0;x[c+16>>2]=1065353216;x[c+20>>2]=0;d=U(676,c+24|0,c+20|0,c+16|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break b}B[a+4224>>2]=B[d>>2];x[c+20>>2]=y[c+48|0]|y[c+49|0]<<8|(y[c+50|0]<<16|y[c+51|0]<<24);x[114414]=0;x[c+12>>2]=1065353216;x[c+16>>2]=0;d=U(676,c+20|0,c+16|0,c+12|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break b}B[a+4228>>2]=B[d>>2];if((y[c+52|0]|y[c+53|0]<<8|(y[c+54|0]<<16|y[c+55|0]<<24))>>>0<=5){x[a+4232>>2]=y[c+52|0]|y[c+53|0]<<8|(y[c+54|0]<<16|y[c+55|0]<<24)}x[a+4236>>2]=y[c+56|0]|y[c+57|0]<<8|(y[c+58|0]<<16|y[c+59|0]<<24);v[a+4240|0]=y[c+60|0]!=0;v[a+4241|0]=y[c+61|0]!=0;v[a+4242|0]=y[c+62|0]!=0;v[a+4243|0]=y[c+63|0]!=0;v[a+4244|0]=y[c- -64|0]!=0;Is(a)}Ab(b);hb=c+96|0;return}}a=N()|0;Ab(b);Q(a|0);p()}function dga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-48|0;hb=e;r=x[a+16>>2];i=x[a+44>>2];x[e+28>>2]=i;j=x[a+48>>2];x[e+32>>2]=j;b=x[a+52>>2];x[e+36>>2]=b;l=x[a+56>>2];x[e+40>>2]=l;s=x[a+24>>2];t=x[a+20>>2];f=x[a+4>>2];h=f;g=x[a>>2];x[e+16>>2]=g;x[e+20>>2]=f;f=x[a+12>>2];x[e+8>>2]=x[a+8>>2];x[e+12>>2]=f;if(d){while(1){g=x[e+16>>2];f=g>>>10&4194048;h=(((x[e+20>>2]&2147483647)<<1|g>>>31)&-2)+r|0;j=0;l=1;b=1;i=0;while(1){g=v[h+i|0];x[(i<<2)+e>>2]=((D(f,v[h+(i|2)|0]-g|0)|0)/16384|0)+(g<<8);g=b;b=0;i=1;if(g){continue}break}while(1){b=(j<<2)+e|0;h=x[b>>2];m=x[a+60>>2];o=(e+24|0)+(j<<3)|0;f=x[o+4>>2];k=Xb(f,-16777216,16776704);n=x[a+64>>2];p=Xb(x[o+8>>2],-16777216,16776704);g=x[a+68>>2];i=g>>31;x[o+8>>2]=f;j=x[a+72>>2];q=h<<8;f=q;f=yna(m,m>>31,f,f>>31);h=lb;m=f;f=yna(n,n>>31,k,k>>31);n=m+f|0;k=lb+h|0;k=f>>>0>n>>>0?k+1|0:k;f=yna(g,i,p,p>>31);h=f+n|0;g=lb+k|0;g=f>>>0>h>>>0?g+1|0:g;m=b;f=h+8388608|0;b=((f>>>0<8388608?g+1|0:g)&16777215)<<8|f>>>24;x[m>>2]=(b|0)/256;x[o+4>>2]=b-(j&q);j=1;b=l&1;l=0;if(b){continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],s);c=c+8|0;Tb(e+16|0,e+8|0);d=d-1|0;if(d){continue}break}l=x[e+40>>2];j=x[e+32>>2];i=x[e+28>>2];g=x[e+16>>2];h=x[e+20>>2];b=x[e+36>>2]}x[a>>2]=g;x[a+4>>2]=h;x[a+56>>2]=l;x[a+52>>2]=b;x[a+48>>2]=j;x[a+44>>2]=i;hb=e+48|0}function I9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=E(0),k=E(0),l=0,m=0,n=0,o=E(0);i=hb-16|0;hb=i;a:{if(w[d>>1]>w[d+2>>1]){break a}if(!Lb(b)){break a}g=w[e>>1];if((g|0)<w[d>>1]){break a}h=w[d+2>>1];if((h|0)<(g|0)){break a}if((Lb(b)-1&65535)>>>0>(h-g&65535)>>>0|A[a+36>>2]>65535){break a}b:{if(!Lb(b)){break b}while(1){if(!(B[Pb(b,f)>>2]<E(0))){f=f+1|0;if(Lb(b)>>>0>f>>>0){continue}break b}break}f=0;break a}f=0;if(B[c>>2]<=E(0)){break a}w[a>>1]=1;w[a+28>>1]=z[d>>1];m=a,n=DK(Lb(b)),w[m+30>>1]=n;B[a+32>>2]=F(B[c>>2]);f=a+4|0;Il(f,(w[d+2>>1]-w[d>>1]|0)+1|0);c=bc(b);l=dc(b);m=i,n=bc(f),x[m+8>>2]=n;g=Gn(i+8|0,w[e>>1]-w[d>>1]|0);h=hb-16|0;hb=h;b=hb-32|0;hb=b;Ct(b+24|0,c,l);kl(b+16|0,x[b+24>>2],x[b+28>>2],At(g));m=b,n=Kx(c,x[b+16>>2]),x[m+8>>2]=n;m=b,n=uK(g,x[b+20>>2]),x[m>>2]=n;gd(h+8|0,b+8|0,b);hb=b+32|0;hb=h+16|0;b=w[e>>1];g=w[a+28>>1];c:{if((b|0)<=(g|0)){c=b;break c}while(1){b=b-1|0;j=B[Pb(f,w[a+30>>1]+(b-g|0)|0)>>2];k=B[a+32>>2];m=Pb(f,b-w[a+28>>1]|0),o=E(j/k),B[m>>2]=o;c=w[e>>1];g=w[a+28>>1];if((g|0)>=(b|0)){break c}if((c|0)!=-32768){continue}break}}b=w[a+30>>1]+c|0;d:{if((b|0)>w[d+2>>1]){break d}while(1){c=w[a+30>>1];if(w[e>>1]>(32767-c|0)){break d}j=B[a+32>>2];k=B[Pb(f,b-(c+w[a+28>>1]|0)|0)>>2];m=Pb(f,b-w[a+28>>1]|0),o=E(k*j),B[m>>2]=o;c=w[d+2>>1]>(b|0);b=b+1|0;if(c){continue}break}}mp(a);f=1}hb=i+16|0;return f|0}function DE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{c:{while(1){d:{c=x[a+12>>2];if(c>>>0>=d>>>0){break d}j=x[a+8>>2];if(j>>>0>=g>>>0){break d}b=2;f=y[c|0];e:{if(f<<24>>24>=0){w[j>>1]=f;b=c+1|0;break e}if(f>>>0<194){break b}if(f>>>0<=223){if((d-c|0)<2){break c}i=y[c+1|0];if((i&192)!=128){break a}w[j>>1]=i&63|f<<6&1984;b=c+2|0;break e}if(f>>>0<=239){if((d-c|0)<3){break c}k=y[c+2|0];i=y[c+1|0];f:{g:{if((f|0)!=237){if((f|0)!=224){break g}if((i&224)==160){break f}break a}if((i&224)==128){break f}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}w[j>>1]=k&63|((i&63)<<6|f<<12);b=c+3|0;break e}if(f>>>0>244){break b}b=1;if((d-c|0)<4){break a}k=y[c+3|0];i=y[c+2|0];c=y[c+1|0];h:{i:{switch(f-240|0){case 0:if((c+112&255)>>>0>=48){break b}break h;case 4:if((c&240)!=128){break b}break h;default:break i}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-j|0)<4){break a}b=2;k=k&63;l=i<<6;f=f&7;if((k|(l&4032|(c<<12&258048|f<<18)))>>>0>1114111){break a}b=c<<2;w[j>>1]=(i>>>4&3|(b&192|f<<8|b&60))+16320|55296;x[a+8>>2]=j+2;w[j+2>>1]=k|l&960|56320;b=x[a+12>>2]+4|0}x[a+12>>2]=b;x[a+8>>2]=x[a+8>>2]+2;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return b|0}function Mla(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{b=y[a+3|0];switch(b-14|0){case 0:break j;case 19:break d;case 17:break e;case 9:break f;case 8:break g;case 6:case 7:break h;case 1:break i;default:break b}}k:{l:{b=y[a+5|0];if((b|0)!=240){if((b|0)==15){break l}if(b){break k}v[a+3|0]=11;break a}v[a+5|0]=239;break c}v[a+5|0]=254;break c}if(b>>>0>=16){v[a+5|0]=b|15;break c}v[a+5|0]=b|240;break c}v[c+15|0]=y[a+5|0]>>>4;v[c+14|0]=15;e=a,f=y[rc(c+15|0,c+14|0)|0]|32,v[e+5|0]=f;break c}b=y[a+5|0];if(b>>>0>=16){v[a+5|0]=b>>>4|240;break c}v[a+5|0]=b|224;break c}v[a+5|0]=((y[a+5|0]^-1)&254)>>>1;break c}v[a+5|0]=y[a+5|0]&15|128;break c}e=a,f=Vk(y[a+5|0]<<1),v[e+5|0]=f;break c}b=32;m:{n:{o:{p:{q:{r:{s:{t:{d=y[a+5|0];switch(d>>>4|0){case 3:break m;case 5:break n;case 14:break o;case 12:case 13:break p;case 11:break q;case 10:break r;case 8:break s;case 0:break c;default:break t}}v[a+3|0]=0;break c}b=64;break m}b=176;break m}b=224;break m}if(d){break c}v[a+3|0]=0;break c}u:{switch(d&15){case 0:v[a+5|0]=119;break c;case 1:v[a+5|0]=119;break c;case 2:v[a+5|0]=121;break c;case 3:break u;default:break c}}v[a+5|0]=123;break c}b=48}v[a+5|0]=d&15|b}b=y[a+3|0]}if(b>>>0>=36){v[a+3|0]=0;break a}v[a+3|0]=y[b+23664|0];if(y[a+2|0]|(b|0)!=12){break a}v[a+2|0]=1;v[a+3|0]=0;b=y[a+5|0];v[a+5|0]=0;v[a+4|0]=b}hb=c+16|0}function n7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),p=E(0),q=0,r=E(0);f=hb-16|0;hb=f;m=a+44|0;if(Bh(m)){j=Od(m,0);k=Od(m,1);h=ld(m,0);i=ld(m,1);r=B[a+4212>>2];x[f+12>>2]=d;if(d){e=x[a+4224>>2];while(1){g=x[a+4220>>2];a:{if(g>>>0>e>>>0){x[f+8>>2]=g-e;l=x[Mb(f+12|0,f+8|0)>>2];b:{if(!(r<E(1))){e=0;if(!l){break b}while(1){B[h>>2]=B[j>>2];B[i>>2]=B[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((l|0)!=(e|0)){continue}break}break b}e=x[a+4224>>2];g=l+e|0;if(e>>>0>=g>>>0){break b}p=E(E(1)/E(A[a+4220>>2]));while(1){o=E(E(e>>>0)*p);B[h>>2]=o*B[j>>2];B[i>>2]=o*B[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((g|0)!=(e|0)){continue}break}}g=x[f+12>>2]-l|0;x[f+12>>2]=g;e=l+x[a+4224>>2]|0;break a}x[f+4>>2]=x[a+4216>>2]-e;n=x[Mb(f+12|0,f+4|0)>>2];c:{d:{e:{if(!(r<E(1))){e=0;if(n){break e}break d}q=x[a+4216>>2];l=x[a+4224>>2];e=q-l|0;g=e-n|0;if(e>>>0<=g>>>0){break c}p=E(E(1)/E(A[a+4220>>2]));while(1){o=E(E(e>>>0)*p);B[h>>2]=o*B[j>>2];B[i>>2]=o*B[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e-1|0;if(g>>>0<e>>>0){continue}break}break c}while(1){x[h>>2]=0;x[i>>2]=0;i=i+4|0;h=h+4|0;e=e+1|0;if((n|0)!=(e|0)){continue}break}}e=n<<2;k=e+k|0;j=e+j|0;q=x[a+4216>>2];l=x[a+4224>>2]}g=x[f+12>>2]-n|0;x[f+12>>2]=g;e=l+n|0;e=e>>>0<q>>>0?e:0}x[a+4224>>2]=e;if(g){continue}break}}zi(a,b,c,ld(m,0),ld(m,1),d)}hb=f+16|0}function qka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=Qk(a);if(c>>>0<b>>>0){j=hb-32|0;hb=j;a:{b:{i=b-c|0;c:{if(i>>>0<=(x[yb(a)>>2]-x[a+4>>2]|0)/33>>>0){d=hb-16|0;hb=d;x[d>>2]=a;b=x[a+4>>2];x[d+4>>2]=b;x[d+8>>2]=b+D(i,33);d:{f=x[d+4>>2];c=x[d+8>>2];if((f|0)!=(c|0)){while(1){b=yb(a);x[114414]=0;P(739,b|0,f|0);b=x[114414];x[114414]=0;if((b|0)==1){break d}f=f+33|0;x[d+4>>2]=f;if((c|0)!=(f|0)){continue}break}}Jb(d);hb=d+16|0;break c}a=N()|0;Jb(d);Q(a|0);p()}d=yb(a);g=j+8|0;b=Qk(a)+i|0;h=hb-16|0;hb=h;x[h+12>>2]=b;e=hb-16|0;hb=e;yb(a);x[e+12>>2]=130150524;x[114414]=0;x[e+8>>2]=2147483647;f=O(35,e+12|0,e+8|0)|0;c=x[114414];x[114414]=0;e:{if((c|0)!=1){hb=e+16|0;c=x[f>>2];break e}S(0)|0;zb();p()}f:{if(b>>>0<=c>>>0){b=am(a);if(b>>>0<c>>>1>>>0){x[h+8>>2]=b<<1;c=x[_c(h+8|0,h+12|0)>>2]}hb=h+16|0;b=c;break f}Vc();p()}f=Qk(a);c=0;e=hb-16|0;hb=e;x[e+12>>2]=0;Qe(g+12|0,d);if(b){if(b>>>0>130150524){ve();p()}c=Vd(D(b,33),1);x[e+4>>2]=b;x[e>>2]=c;c=x[e>>2];d=x[e+4>>2]}else{d=0}x[g>>2]=c;b=D(f,33)+c|0;x[g+8>>2]=b;x[g+4>>2]=b;k=ic(g),l=D(d,33)+c|0,x[k>>2]=l;hb=e+16|0;x[114414]=0;P(737,g|0,i|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(738,a|0,g|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}PR(g)}hb=j+32|0;break a}a=N()|0;PR(g);Q(a|0);p()}return}if(b>>>0<c>>>0){b=x[a>>2]+D(b,33)|0;Qk(a);OR(a,b);am(a);Qk(a)}}function EE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;c=x[a+12>>2];a:{b:{while(1){if(c>>>0>=d>>>0){f=0;break a}f=2;c:{b=z[c>>1];d:{if(b>>>0<=127){f=1;c=x[a+8>>2];if((g-c|0)<=0){break a}x[a+8>>2]=c+1;v[c|0]=b;break d}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break d}if(b>>>0<=55295){c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break d}if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=z[c+2>>1];if((i&64512)!=56320){break c}if((g-x[a+8>>2]|0)<4){break a}f=b&960;if((i&1023|(b<<10&64512|f<<10))>>>0>1048575){break c}x[a+12>>2]=c+2;c=x[a+8>>2];x[a+8>>2]=c+1;j=c;c=(f>>>6|0)+1|0;v[j|0]=c>>>2|240;f=x[a+8>>2];x[a+8>>2]=f+1;v[f|0]=c<<4&48|b>>>2&15|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=i>>>6&15|b<<4&48|128;b=x[a+8>>2];x[a+8>>2]=b+1;v[b|0]=i&63|128;break d}if(b>>>0<57344){break a}c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}c=x[a+12>>2]+2|0;x[a+12>>2]=c;continue}break}f=2;break a}f=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return f|0}function nH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=E(0),n=0,o=0,p=0,q=0,r=0,s=E(0);e=(b<<2)+a|0;i=e+1068|0;l=c<<1&-4;q=i,r=Rd(a,l),x[q>>2]=r;h=e+1076|0;q=h,r=Rd(a,l),x[q>>2]=r;k=e+1084|0;e=Rd(a,c&-4);x[k>>2]=e;a:{i=x[i>>2];if(!i){break a}h=x[h>>2];if(!h|!e){break a}b:{if((c|0)<4){break b}p=c>>>2|0;m=E(c|0);j=E(E(1)/m);while(1){k=d<<2;g=+E(E(E(f<<2)*E(3.1415927410125732))*j);q=i+k|0,s=E(xe(g)),B[q>>2]=s;n=d|1;o=n<<2;q=i+o|0,s=E(-E(oi(g))),B[q>>2]=s;g=+E(E(E(n|0)*E(1.5707963705062866))*j);q=h+k|0,s=E(E(xe(g))*E(.5)),B[q>>2]=s;q=h+o|0,s=E(E(oi(g))*E(.5)),B[q>>2]=s;d=d+2|0;f=f+1|0;if((p|0)!=(f|0)){continue}break}if((c|0)<8){break b}d=c>>3;i=(d|0)<=1?1:d;j=E(E(1)/m);d=0;f=0;while(1){h=d|1;g=+E(E(E(h<<1)*E(3.1415927410125732))*j);q=e+(d<<2)|0,s=E(xe(g)),B[q>>2]=s;q=e+(h<<2)|0,s=E(-E(oi(g))),B[q>>2]=s;d=d+2|0;f=f+1|0;if((i|0)!=(f|0)){continue}break}}f=(b<<2)+a|0;d=Rd(a,l);x[f+1092>>2]=d;if(!d){break a}if((c|0)>=2){e=c>>>1|0;g=1/+(e|0);b=0;while(1){j=E(oi((+(b|0)*1.5707963705062866+.7853981852531433)*g));q=d+(b<<2)|0,s=E(oi(+E(j*j)*1.5707963705062866)),B[q>>2]=s;b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=Rd(a,c>>2&-2);x[f+1100>>2]=b;if(!b){break a}if((c|0)>=8){d=c>>>3|0;c=36-El(c)|0;a=0;while(1){q=b+(a<<1)|0,r=Cl(a)>>>c<<2,w[q>>1]=r;a=a+1|0;if((d|0)!=(a|0)){continue}break}}return 1}fc(a,3);return 0}function mna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;h=hb-144|0;hb=h;x[114414]=0;k=R(440,a|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){a:{if(k){e=h+8|0;o=e|4;q=e|6;r=e|5;j=e|2;l=e|3;while(1){x[114414]=0;O(471,a|0,h+8|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break a}e=h+8|0;e=y[e|0]|y[e+1|0]<<8;b:{if(!e){break b}e=(e<<8|e>>>8)&65535;if(e>>>0>z[c+480192>>1]){break b}e=x[((e<<2)+c|0)+900380>>2];if(!e){break b}x[114414]=0;e=O(339,e|0,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break a}c:{if(!y[l|0]){break c}if(v[j|0]&1){v[e+12|0]=y[e+12|0]|1}if(y[j|0]&2){v[e+12|0]=y[e+12|0]|4}if(!(y[j|0]&4)){break c}v[e+12|0]=y[e+12|0]|2}f=y[l|0];x[114414]=0;v[h+4|0]=f;v[h+7|0]=31;f=O(409,h+4|0,h+7|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break a}f=y[f|0];x[114414]=0;i=f+1&255;P(472,e|0,i|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}v[e+13|0]=y[r|0];v[e+14|0]=y[q|0];f=y[o|0];v[e+15|0]=f;v[e+16|0]=f;f=0;if(!i){break b}while(1){m=(h+8|0)+(f<<2)|0;g=m+8|0;g=y[g|0]|y[g+1|0]<<8;s=Pb(e,f),t=g<<8|g>>>8,w[s>>1]=t;g=m+10|0;g=y[g|0]|y[g+1|0]<<8;g=g<<8|g>>>8;w[h+4>>1]=d?(g&65535)+128>>>2|0:g;sg(h+4|0,64);g=y[h+4|0];s=Pb(e,f),t=g,v[s+2|0]=t;f=f+1|0;if((i|0)!=(f|0)){continue}break}}n=n+1|0;if((n&65535)>>>0<k>>>0){continue}break}}Ab(a);hb=h+144|0;return}}b=N()|0;Ab(a);Q(b|0);p()}function _y(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{h=255;b:{c:{g=a+58|0;d=b;b=y[gc(g,d)|0];if((b|0)==255){break c}if(v[gc(g,d)|0]>=0){break b}e=a+22|0;b=b&127;if(z[fd(e,b)>>1]!=65535){if((d|0)!=z[fd(e,b)>>1]){break c}}j=fd(e,b),k=d,w[j>>1]=k;j=gc(g,d),k=b,v[j|0]=k;break b}i=a+4|0;f=a+22|0;b=0;e=255;d:{while(1){if(z[fd(f,b)>>1]==65535){break d}if(!(y[gc(i,b)|0]&32)){h=v[gc(g,z[fd(f,b)>>1])|0]<0?b:h;e=b}b=b+1|0;if((b|0)!=18){continue}break}if((e&255)!=255){b=(h&255)==255?e:h;e=b&255;j=gc(g,z[fd(f,e)>>1]),k=255,v[j|0]=k;j=fd(f,e),k=d,w[j>>1]=k;j=gc(g,d),k=b,v[j|0]=k}b=Jk(a,d);break b}j=fd(f,b),k=d,w[j>>1]=k;j=gc(g,d),k=b,v[j|0]=k}g=b&255;if((g|0)==255){break a}b=0;if(Aj(a)){break a}e=Oi(a+314|0,g);d=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[e+8|0]=d;v[e+9|0]=d>>>8;v[e+10|0]=d>>>16;v[e+11|0]=d>>>24;d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=f;v[e+1|0]=f>>>8;v[e+2|0]=f>>>16;v[e+3|0]=f>>>24;v[e+4|0]=d;v[e+5|0]=d>>>8;v[e+6|0]=d>>>16;v[e+7|0]=d>>>24;f=VN(g);h=f+3|0;d=1;while(1){e=d;d=d?f:h;ph(x[a>>2],d|32,y[gc(c,b)|0]);ph(x[a>>2],d|64,y[gc(c,b|2)|0]);ph(x[a>>2],d|96,y[gc(c,b|4)|0]);ph(x[a>>2],d|128,y[gc(c,b|6)|0]);ph(x[a>>2],d|224,y[gc(c,b|8)|0]);d=0;b=1;if(e){continue}break}ph(x[a>>2],tt(g)|192,y[gc(c,10)|0])}}function Afa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=hb-32|0;hb=f;e=x[a+12>>2];g=e;a:{b:{c:{h=x[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&h>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&h>>>0>2147483648|g>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];k=b;e=x[a>>2];x[f+24>>2]=e;x[f+28>>2]=b;x[f+16>>2]=h;x[f+20>>2]=g;e:{if(!d){b=i>>12;g=j>>12;break e}while(1){b=x[f+24>>2];h=((((x[f+28>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+m|0;b=(b>>>16&65520)+l|0;k=w[b+14>>1];n=w[b+12>>1];o=w[b+10>>1];p=w[b+8>>1];q=w[b+6>>1];r=w[b+4>>1];s=w[b+2>>1];t=w[b>>1];g=0;b=1;while(1){e=g<<1;x[(f+8|0)+(g<<2)>>2]=(((((((D(w[(e|-8)+h>>1],s)+D(w[(e|-12)+h>>1],t)|0)+D(w[(e|-4)+h>>1],r)|0)+D(w[e+h>>1],q)|0)+D(w[(e|4)+h>>1],p)|0)+D(w[(e|8)+h>>1],o)|0)+D(w[(e|12)+h>>1],n)|0)+D(w[(e|16)+h>>1],k)|0)/32768;e=b;b=0;g=1;if(e){continue}break}b=x[a+32>>2];j=x[a+28>>2]+j|0;g=j>>12;x[c>>2]=x[c>>2]+D(g,x[f+8>>2]);i=b+i|0;b=i>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[f+12>>2]);c=c+8|0;Tb(f+24|0,f+16|0);d=d-1|0;if(d){continue}break}e=x[f+24>>2];k=x[f+28>>2]}x[a>>2]=e;x[a+4>>2]=k;x[a+40>>2]=i;x[a+20>>2]=g;x[a+36>>2]=j;x[a+24>>2]=b;hb=f+32|0}function iV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-32|0;hb=d;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1397771593){Ad(b,32);zh(d,1,a+4|0);c=d+16|0;Ic(c,d);x[114414]=0;O(335,b+43|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}xb(d+16|0);w[b+30>>1]=y[a+19|0]<<2;sg(b+30|0,256);w[b+32>>1]=y[a+17|0];sg(b+32|0,64);c=a+47|0;w[b+28>>1]=(y[c|0]&127)<<2;sg(b+28|0,256);if(v[c|0]<0){w[b+34>>1]=z[b+34>>1]|32}c=a+18|0;if(y[c|0]&16){w[b+34>>1]=z[b+34>>1]|2}if(y[c|0]&32){w[b+34>>1]=z[b+34>>1]|8}if(y[c|0]&64){w[b+34>>1]=z[b+34>>1]|4}if(v[c|0]<0){w[b+34>>1]=z[b+34>>1]|16}c=a+60|0;c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+24>>2]=c?c>>>0<=256?256:c:8363;c=a+48|0;x[b>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+52|0;x[b+4>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+56|0;x[b+8>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a- -64|0;x[b+12>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+68|0;x[b+16>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);Dn(b);v[b+38|0]=y[(y[a+79|0]&7)+32960|0];v[b+41|0]=y[a+76|0];v[b+40|0]=y[a+77|0]&127;v[b+39|0]=y[a+78|0];c=512;e=a+46|0;b:{if(y[e|0]!=64){c=16384;if(y[e|0]!=128){break b}}w[b+34>>1]=z[b+34>>1]|c}a=a+72|0;c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24)}hb=d+32|0;return c|0}a=N()|0;xb(d+16|0);Q(a|0);p()}function $ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-48|0;hb=e;i=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;l=e,m=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[l+28>>2]=m;f=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=f;a:{if(!f){break a}b=a+8|0;l=e,m=Sf(b,f),x[l+16>>2]=m;x[e+20>>2]=lb;l=e,m=Te(b,d),x[l+40>>2]=m;x[e+44>>2]=lb;tf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}j=x[a+24>>2];k=x[a+20>>2];f=x[a+4>>2];b=x[a>>2];x[e+8>>2]=b;x[e+12>>2]=f;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;g=a;if(d){while(1){f=x[e+36>>2]-1|0;x[e+36>>2]=f;a=x[e+8>>2];b=((x[e+12>>2]&2147483647)<<1|a>>>31)&-2;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=b+i|0;x[e+40>>2]=a;x[e+44>>2]=0;b=x[e+32>>2];if((b|0)>0){while(1){a=x[e+40>>2];a=(x[e+44>>2]&2147483647)<<1|a>>>31;zj(x[e+24>>2],v[(a|1)+f|0]+v[f+(a&-2)|0]<<5);yj(x[e+24>>2],4);a=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(a){continue}break}}d=d-1|0;a=x[e+24>>2];Tb(a,a+8|0);b=x[e+24>>2];h=x[b+4>>2];if(h){a=x[e+40>>2];a=(x[e+44>>2]&2147483647)<<1|a>>>31;zj(b,v[(a|1)+f|0]+v[f+(a&-2)|0]<<5);yj(x[e+24>>2],h);b=x[e+24>>2];a=x[b>>2];x[b>>2]=a;x[b+4>>2]=0}a=Lp(b,x[e+28>>2]);x[c>>2]=x[c>>2]+D(a,k);x[c+4>>2]=x[c+4>>2]+D(a,j);c=c+8|0;Tb(e+8|0,e);if(d){continue}break}b=x[e+8>>2];f=x[e+12>>2]}x[g>>2]=b;x[g+4>>2]=f;hb=e+48|0}function pja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=hb-32|0;hb=h;x[h+28>>2]=d;a:{if(y[a+8|0]){d=a+12|0;n=h,o=wc(d)-c|0,x[n+24>>2]=o;f=h+24|0;a=x[Mb(f,h+28|0)>>2];n=h,o=bc(d),x[n+24>>2]=o;f=Fe(f,c);n=h,o=bc(d),x[n+8>>2]=o;n=h,o=Fe(h+8|0,c),x[n+16>>2]=o;NQ(f,Fe(h+16|0,a),b);break a}f=hb-32|0;hb=f;x[f+28>>2]=d;b:{c:{if(y[a+24|0]){if(!d){break b}k=a+40|0;break c}l=mb[x[x[a>>2]+44>>2]](a,b,c,d)|0;break b}while(1){g=0;i=hb-16|0;hb=i;j=a+40|0;e=a+232|0;m=c-(c&4095)|0;d:{e:{while(1){d=x[$e(e,g)>>2];if(y[Oi(j,d)+8|0]){if(x[Oi(j,d)>>2]==(m|0)){break e}}g=g+1|0;if((g|0)!=16){continue}break}d=x[$e(e,15)>>2];bq(e,e+60|0,e- -64|0);n=$e(e,0),o=d,x[n>>2]=o;d=x[$e(e,0)>>2];e=Oi(j,d);x[e>>2]=m;Wz(i+8|0,a,d);n=e,o=mb[x[x[a>>2]+44>>2]](a,x[i+8>>2],m,4096)|0,x[n+4>>2]=o;v[e+8|0]=1;break d}j=x[$e(e,g)>>2];g=g<<2;bq(e,g+e|0,(e+g|0)+4|0);n=$e(e,0),o=j,x[n>>2]=o}hb=i+16|0;g=c-x[Oi(k,d)>>2]|0;x[f+8>>2]=4096-g;n=f,o=x[Mb(f+8|0,f+28|0)>>2],x[n+24>>2]=o;if(g>>>0<A[Oi(k,d)+4>>2]){e=x[Oi(k,d)+4>>2]-g|0}else{e=0}x[f+20>>2]=e;e=x[Mb(f+24|0,f+20|0)>>2];Wz(f+8|0,a,d);i=x[f+8>>2];Wz(f,a,d);Ke(g+i|0,e+(g+x[f>>2]|0)|0,b);d=x[f+28>>2];x[f+28>>2]=d-e;l=e+l|0;if(e>>>0<A[f+24>>2]){break b}c=c+e|0;b=b+e|0;if((d|0)!=(e|0)){continue}break}}hb=f+32|0;a=l}hb=h+32|0;return a|0}function Bfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=hb-32|0;hb=f;h=x[a+12>>2];e=h;a:{b:{c:{g=x[a+8>>2];d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&g>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&g>>>0>2147483647|(e|0)==-1){break d}break b}if((e|0)==1&g>>>0>2147483648|e>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];k=b;h=x[a>>2];x[f+24>>2]=h;x[f+28>>2]=b;x[f+16>>2]=g;x[f+20>>2]=e;e:{if(!d){b=i>>12;g=j>>12;break e}while(1){b=x[f+24>>2];e=(((x[f+28>>2]&2147483647)<<1|b>>>31)&-2)+m|0;b=(b>>>16&65520)+l|0;k=w[b+14>>1];n=w[b+12>>1];o=w[b+10>>1];p=w[b+8>>1];q=w[b+6>>1];r=w[b+4>>1];s=w[b+2>>1];t=w[b>>1];b=0;g=1;while(1){x[(f+8|0)+(b<<2)>>2]=(((((((D(v[(b|-4)+e|0],s)+D(v[(b|-6)+e|0],t)|0)+D(v[(b|-2)+e|0],r)|0)+D(v[b+e|0],q)|0)+D(v[(b|2)+e|0],p)|0)+D(v[(b|4)+e|0],o)|0)+D(v[(b|6)+e|0],n)|0)+D(v[(b|8)+e|0],k)<<8)/32768;h=g;g=0;b=1;if(h){continue}break}b=x[a+32>>2];j=x[a+28>>2]+j|0;g=j>>12;x[c>>2]=x[c>>2]+D(g,x[f+8>>2]);i=b+i|0;b=i>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[f+12>>2]);c=c+8|0;Tb(f+24|0,f+16|0);d=d-1|0;if(d){continue}break}h=x[f+24>>2];k=x[f+28>>2]}x[a>>2]=h;x[a+4>>2]=k;x[a+40>>2]=i;x[a+20>>2]=g;x[a+36>>2]=j;x[a+24>>2]=b;hb=f+32|0}function UZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=hb-496|0;hb=a;g=a+488|0;Dc(g,d);x[114414]=0;m=R(2510,g|0)|0;g=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Bb(f)){g=x[qj(f,0)>>2];x[114414]=0;h=O(2535,m|0,45)|0;i=x[114414];x[114414]=0;if((i|0)==1){break g}n=(g|0)==(h|0)}j=Wb(a+456|0);h=Cg(a+440|0);i=Cg(a+424|0);x[114414]=0;ja(2564,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,j|0,h|0,i|0,a+420|0);c=x[114414];x[114414]=0;if((c|0)==1){break f}x[a+4>>2]=2484;k=Pd(a+8|0,0,a+4|0);c=a+16|0;h:{if((Bb(f)|0)>x[a+420>>2]){g=Bb(f);l=x[a+420>>2];g=(((Bb(i)+(g-l<<1)|0)+Bb(h)|0)+x[a+420>>2]|0)+1|0;break h}g=((Bb(i)+Bb(h)|0)+x[a+420>>2]|0)+2|0}if(g>>>0<101){break e}we(k,sd(g<<2));c=x[k>>2];if(c){break e}x[114414]=0;V(2485);b=x[114414];x[114414]=0;if((b|0)==1){break d}p()}f=N()|0;break b}f=N()|0;break b}f=N()|0;break c}g=x[d+4>>2];l=Rb(f);o=Rb(f);f=Bb(f);x[114414]=0;oa(2565,c|0,a+4|0,a|0,g|0,l|0,(f<<2)+o|0,m|0,n|0,a+480|0,x[a+476>>2],x[a+472>>2],j|0,h|0,i|0,x[a+420>>2]);f=x[114414];x[114414]=0;if((f|0)!=1){x[114414]=0;b=ga(2539,b|0,c|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break a}}}f=N()|0;Jc(k)}Nc(i);Nc(h);xb(j)}Ob(a+488|0);Q(f|0);p()}Jc(k);Nc(i);Nc(h);xb(j);Ob(a+488|0);hb=a+496|0;return b|0}function ifa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;g=hb-16|0;hb=g;f=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];h=x[a+44>>2];p=x[a+16>>2];j=x[a+4>>2];l=j;e=x[a>>2];x[g+8>>2]=e;x[g+12>>2]=j;j=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=j;a:{if(!d){b=f;break a}q=b+24|0;while(1){e=(x[g+12>>2]<<1)+p|0;r=w[e-6>>1];b=(((x[g+8>>2]>>>16|0)+4&131064)<<1)+q|0;s=w[b>>1];t=w[e-4>>1];u=w[b+2>>1];v=w[e-2>>1];y=w[b+4>>1];z=w[e>>1];A=w[b+6>>1];B=w[e+2>>1];C=w[b+8>>1];E=w[e+4>>1];F=w[b+10>>1];G=w[e+6>>1];H=w[b+12>>1];I=w[e+8>>1];m=w[b+14>>1];e=x[a+60>>2];b=h;i=Xb(b,-16777216,16776704);h=x[a+64>>2];k=Xb(f,-16777216,16776704);l=x[a+72>>2];j=x[c>>2];f=yna(h,h>>31,i,i>>31);h=lb;i=f;f=x[a+68>>2];f=yna(f,f>>31,k,k>>31);k=i+f|0;i=lb+h|0;i=f>>>0>k>>>0?i+1|0:i;m=(((((D(E,F)+D(B,C)|0)+D(G,H)|0)+D(m,I)|0)/2|0)+((((D(t,u)+D(r,s)|0)+D(v,y)|0)+D(z,A)|0)/2|0)|0)/16384<<8;f=m;f=yna(e,e>>31,f,f>>31);h=f+k|0;e=lb+i|0;e=f>>>0>h>>>0?e+1|0:e;f=h+8388608|0;f=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;e=(f|0)/256|0;x[c>>2]=D(e,o)+j;x[c+4>>2]=x[c+4>>2]+D(e,n);h=f-(l&m)|0;c=c+8|0;Tb(g+8|0,g);f=b;d=d-1|0;if(d){continue}break}e=x[g+8>>2];l=x[g+12>>2]}x[a>>2]=e;x[a+4>>2]=l;x[a+48>>2]=b;x[a+44>>2]=h;hb=g+16|0}function laa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=hb-48|0;hb=f;x[f+32>>2]=b;b=x[a>>2];o=f,q=bc(a),x[o+8>>2]=q;b=b+D(Rs(f+32|0,f+8|0),6)|0;a:{b:{if(!c){break b}e=x[yb(a)>>2];h=x[a+4>>2];if((e-h|0)/6>>>0>=c>>>0){i=c;e=(h-b|0)/6|0;if(e>>>0<c>>>0){sA(a,c-e|0,d);i=e;if((b|0)==(h|0)){break b}}l=hb-16|0;hb=l;m=x[a+4>>2];g=D((m-(D(c,6)+b|0)|0)/6|0,6)+b|0;j=rq(l,a,(h-g|0)/6|0);c:{d:{if(g>>>0<h>>>0){k=x[j+4>>2];e=g;while(1){n=yb(a);x[114414]=0;T(1583,n|0,k|0,e|0);n=x[114414];x[114414]=0;if((n|0)==1){break d}k=k+6|0;x[j+4>>2]=k;e=e+6|0;if(h>>>0>e>>>0){continue}break}}Jb(j);e=m;if((b|0)!=(g|0)){g=g-b|0;e=D((g|0)/-6|0,6)+e|0;Bg(e,b,g)}On(m,e);hb=l+16|0;break c}a=N()|0;Jb(j);Q(a|0);p()}a=D(b>>>0<=d>>>0?A[a+4>>2]>d>>>0?c:0:0,6)+d|0;c=b;if(i){while(1){d=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[c|0]=d;v[c+1|0]=d>>>8;v[c+2|0]=d>>>16;v[c+3|0]=d>>>24;d=y[a+4|0]|y[a+5|0]<<8;v[c+4|0]=d;v[c+5|0]=d>>>8;c=c+6|0;i=i-1|0;if(i){continue}break}}break b}e=yb(a);e=$R(f+8|0,gA(a,hg(a)+c|0),(b-x[a>>2]|0)/6|0,e);x[114414]=0;T(682,e|0,c|0,d|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;b=U(1582,a|0,e|0,b|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break a}cu(e)}a=x[Fb(f+40|0,b)>>2];hb=f+48|0;return a|0}a=N()|0;cu(e);Q(a|0);p()}function eg(a,b,c,d){var e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;h=lq(a);g=x[a+480180>>2];if(!h){if(g&17408){a=((e&255)>>>0)/12|0;e=z[((e-D(a,12)&255)<<1)+26512>>1]<<4>>>a|0;break a}if(!d){x[f+12>>2]=8363;d=8363}if(!(!(y[a+480208|0]&16)&x[a+480180>>2]!=64)){if(!(!$b(a+1074312|0,7)&x[a+480180>>2]!=64)){a=((e&255)>>>0)/12|0;b=yna(x[((a<<2)+e<<6&960)+30400>>2]<<a,0,d,0);a=lb;c=a>>>21|0;e=jd((a&2097151)<<11|b>>>21,c);break a}a=((e&255)>>>0)/12|0;e=z[((e-D(a,12)&255)<<1)+26512>>1]<<5>>>a|0;break a}a=((e&255)>>>0)/12|0;xc(f+12|0,-1>>>a|0);e=jd(Bna(yna(z[((e-D(a,12)&255)<<1)+26512>>1],0,267616,0),lb,x[f+12>>2]<<a,0),lb);break a}if(g&20){d=e>>>0>12;if(x[a+480180>>2]==16){b=c<<4}else{b=$b(a+1074312|0,76)?c&-8:c}c=d?e:12;if(y[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;e=(a|0)<=1?1:a;break a}c=c-12|0;a=((c&255)>>>0)/12|0;d=((b|0)/16|0)+(c-D(a,12)<<3&248)|0;x[f+8>>2]=d+8;_d(f+8|0,0,103);c=b;b=b>>31;c=(c^b)-b&15;b=d+(b|1)|0;b=(b|0)<=-8?-8:b;e=D(c,z[((((b|0)>=95?95:b)<<1)+26992|0)+16>>1])+D(z[(x[f+8>>2]<<1)+26992>>1],16-c|0)<<1>>>a|0;break a}if(!(!(e>>>0<24|(c&255)>>>0>15)&e>>>0<108)){a=((e&255)>>>0)/12|0;e=z[(D((c&240)>>>4|0,12)+(e-D(a,12)&255)<<1)+26112>>1]<<5>>>a|0;break a}e=z[(b<<1)+25886>>1]<<2}hb=f+16|0;return e}function tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;r=x[a+16>>2];i=x[a+44>>2];x[b+28>>2]=i;k=x[a+48>>2];x[b+32>>2]=k;m=x[a+52>>2];x[b+36>>2]=m;h=x[a+56>>2];x[b+40>>2]=h;s=x[a+24>>2];t=x[a+20>>2];g=x[a+4>>2];e=g;f=x[a>>2];x[b+16>>2]=f;x[b+20>>2]=e;g=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=g;if(d){while(1){f=x[b+16>>2];f=((((x[b+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+r|0;x[b>>2]=w[f>>1];x[b+4>>2]=w[f+2>>1];i=0;k=1;while(1){f=(i<<2)+b|0;h=x[f>>2];l=x[a+60>>2];o=(b+24|0)+(i<<3)|0;e=x[o+4>>2];j=Xb(e,-16777216,16776704);n=x[a+64>>2];p=Xb(x[o+8>>2],-16777216,16776704);g=x[a+68>>2];i=g>>31;x[o+8>>2]=e;m=x[a+72>>2];q=h<<8;e=q;e=yna(l,l>>31,e,e>>31);h=lb;l=e;e=yna(n,n>>31,j,j>>31);n=l+e|0;j=lb+h|0;j=e>>>0>n>>>0?j+1|0:j;e=yna(g,i,p,p>>31);h=e+n|0;g=lb+j|0;g=e>>>0>h>>>0?g+1|0:g;l=f;e=h+8388608|0;f=((e>>>0<8388608?g+1|0:g)&16777215)<<8|e>>>24;x[l>>2]=(f|0)/256;x[o+4>>2]=f-(m&q);f=k&1;k=0;i=1;if(f){continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],s);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}h=x[b+40>>2];m=x[b+36>>2];k=x[b+32>>2];e=x[b+20>>2];i=x[b+28>>2];f=x[b+16>>2]}x[a>>2]=f;x[a+4>>2]=e;x[a+56>>2]=h;x[a+52>>2]=m;x[a+48>>2]=k;x[a+44>>2]=i;hb=b+48|0}function tH(a){var b=0,c=0,d=0;ee(a,x[a+20>>2]);if(x[a+24>>2]>0){while(1){ee(a,x[x[a+28>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<x[a+24>>2]){continue}break}}ee(a,x[a+28>>2]);if(!(!x[a+396>>2]|x[a+264>>2]<=0)){while(1){c=x[a+396>>2]+D(d,24)|0;b=x[c+16>>2];if(b){if(x[(x[a+124>>2]+D(y[c+13|0],2096)|0)+4>>2]>0){b=0;while(1){ee(a,x[x[c+16>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<x[(x[a+124>>2]+D(y[c+13|0],2096)|0)+4>>2]){continue}break}b=x[c+16>>2]}ee(a,b)}ee(a,x[c+20>>2]);d=d+1|0;if((d|0)<x[a+264>>2]){continue}break}}b=x[a+124>>2];if(b){if(x[a+120>>2]>0){c=0;while(1){b=x[a+124>>2]+D(c,2096)|0;ee(a,x[b+8>>2]);ee(a,x[b+28>>2]);ee(a,x[b+32>>2]);ee(a,x[b+2084>>2]);b=x[b+2088>>2];ee(a,b?b-4|0:0);c=c+1|0;if((c|0)<x[a+120>>2]){continue}break}b=x[a+124>>2]}ee(a,b)}ee(a,x[a+260>>2]);ee(a,x[a+396>>2]);b=x[a+404>>2];if(b){if(x[a+400>>2]>0){b=0;while(1){ee(a,x[(x[a+404>>2]+D(b,40)|0)+4>>2]);b=b+1|0;if((b|0)<x[a+400>>2]){continue}break}b=x[a+404>>2]}ee(a,b)}c=1;a:{if(x[a+4>>2]<=0){break a}b=0;while(1){d=(b<<2)+a|0;ee(a,x[d+800>>2]);ee(a,x[d+928>>2]);ee(a,x[d+996>>2]);if(b>>>0>14){break a}b=b+1|0;if((b|0)<x[a+4>>2]){continue}break}}b=0;while(1){b=(b<<2)+a|0;ee(a,x[b+1068>>2]);ee(a,x[b+1076>>2]);ee(a,x[b+1084>>2]);ee(a,x[b+1092>>2]);ee(a,x[b+1100>>2]);b=1;d=c&1;c=0;if(d){continue}break}}function YZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=hb-192|0;hb=a;g=a+184|0;Dc(g,d);x[114414]=0;m=R(21,g|0)|0;g=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Bb(f)){g=y[pc(f,0)|0];x[114414]=0;h=O(22,m|0,45)|0;i=x[114414];x[114414]=0;if((i|0)==1){break g}n=(g|0)==(h&255)}j=Wb(a+160|0);h=Wb(a+144|0);i=Wb(a+128|0);x[114414]=0;ja(2562,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,j|0,h|0,i|0,a+124|0);c=x[114414];x[114414]=0;if((c|0)==1){break f}x[a+4>>2]=2484;k=Pd(a+8|0,0,a+4|0);c=a+16|0;h:{if((Bb(f)|0)>x[a+124>>2]){g=Bb(f);l=x[a+124>>2];g=(((Bb(i)+(g-l<<1)|0)+Bb(h)|0)+x[a+124>>2]|0)+1|0;break h}g=((Bb(i)+Bb(h)|0)+x[a+124>>2]|0)+2|0}if(g>>>0<101){break e}we(k,sd(g));c=x[k>>2];if(c){break e}x[114414]=0;V(2485);b=x[114414];x[114414]=0;if((b|0)==1){break d}p()}f=N()|0;break b}f=N()|0;break b}f=N()|0;break c}g=x[d+4>>2];l=Rb(f);o=Rb(f);f=Bb(f);x[114414]=0;oa(2563,c|0,a+4|0,a|0,g|0,l|0,f+o|0,m|0,n|0,a+176|0,v[a+175|0],v[a+174|0],j|0,h|0,i|0,x[a+124>>2]);f=x[114414];x[114414]=0;if((f|0)!=1){x[114414]=0;b=ga(17,b|0,c|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break a}}}f=N()|0;Jc(k)}xb(i);xb(h);xb(j)}Ob(a+184|0);Q(f|0);p()}Jc(k);xb(i);xb(h);xb(j);Ob(a+184|0);hb=a+192|0;return b|0}function uga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=hb-48|0;hb=b;r=x[a+16>>2];i=x[a+44>>2];x[b+28>>2]=i;k=x[a+48>>2];x[b+32>>2]=k;m=x[a+52>>2];x[b+36>>2]=m;h=x[a+56>>2];x[b+40>>2]=h;s=x[a+24>>2];t=x[a+20>>2];g=x[a+4>>2];e=g;f=x[a>>2];x[b+16>>2]=f;x[b+20>>2]=e;g=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=g;if(d){while(1){f=x[b+16>>2];f=(((x[b+20>>2]&2147483647)<<1|f>>>31)&-2)+r|0;x[b>>2]=v[f|0]<<8;x[b+4>>2]=v[f+1|0]<<8;i=0;k=1;while(1){f=(i<<2)+b|0;h=x[f>>2];l=x[a+60>>2];o=(b+24|0)+(i<<3)|0;e=x[o+4>>2];j=Xb(e,-16777216,16776704);n=x[a+64>>2];p=Xb(x[o+8>>2],-16777216,16776704);g=x[a+68>>2];i=g>>31;x[o+8>>2]=e;m=x[a+72>>2];q=h<<8;e=q;e=yna(l,l>>31,e,e>>31);h=lb;l=e;e=yna(n,n>>31,j,j>>31);n=l+e|0;j=lb+h|0;j=e>>>0>n>>>0?j+1|0:j;e=yna(g,i,p,p>>31);h=e+n|0;g=lb+j|0;g=e>>>0>h>>>0?g+1|0:g;l=f;e=h+8388608|0;f=((e>>>0<8388608?g+1|0:g)&16777215)<<8|e>>>24;x[l>>2]=(f|0)/256;x[o+4>>2]=f-(m&q);f=k&1;k=0;i=1;if(f){continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],s);c=c+8|0;Tb(b+16|0,b+8|0);d=d-1|0;if(d){continue}break}h=x[b+40>>2];m=x[b+36>>2];k=x[b+32>>2];e=x[b+20>>2];i=x[b+28>>2];f=x[b+16>>2]}x[a>>2]=f;x[a+4>>2]=e;x[a+56>>2]=h;x[a+52>>2]=m;x[a+48>>2]=k;x[a+44>>2]=i;hb=b+48|0}function jfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;g=hb-16|0;hb=g;f=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];h=x[a+44>>2];p=x[a+16>>2];j=x[a+4>>2];l=j;e=x[a>>2];x[g+8>>2]=e;x[g+12>>2]=j;j=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=j;a:{if(!d){b=f;break a}q=b+24|0;while(1){e=x[g+12>>2]+p|0;r=v[e-3|0];b=(((x[g+8>>2]>>>16|0)+4&131064)<<1)+q|0;s=w[b>>1];t=v[e-2|0];u=w[b+2>>1];y=v[e-1|0];z=w[b+4>>1];A=v[e|0];B=w[b+6>>1];C=v[e+1|0];E=w[b+8>>1];F=v[e+2|0];G=w[b+10>>1];H=v[e+3|0];I=w[b+12>>1];J=v[e+4|0];m=w[b+14>>1];e=x[a+60>>2];b=h;i=Xb(b,-16777216,16776704);h=x[a+64>>2];k=Xb(f,-16777216,16776704);l=x[a+72>>2];j=x[c>>2];f=yna(h,h>>31,i,i>>31);h=lb;i=f;f=x[a+68>>2];f=yna(f,f>>31,k,k>>31);k=i+f|0;i=lb+h|0;i=f>>>0>k>>>0?i+1|0:i;m=((((D(F,G)+D(C,E)|0)+D(H,I)|0)+D(m,J)<<8>>1)+(((D(t,u)+D(r,s)|0)+D(y,z)|0)+D(A,B)<<8>>1)|0)/16384<<8;f=m;f=yna(e,e>>31,f,f>>31);h=f+k|0;e=lb+i|0;e=f>>>0>h>>>0?e+1|0:e;f=h+8388608|0;f=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;e=(f|0)/256|0;x[c>>2]=D(e,o)+j;x[c+4>>2]=x[c+4>>2]+D(e,n);h=f-(l&m)|0;c=c+8|0;Tb(g+8|0,g);f=b;d=d-1|0;if(d){continue}break}e=x[g+8>>2];l=x[g+12>>2]}x[a>>2]=e;x[a+4>>2]=l;x[a+48>>2]=b;x[a+44>>2]=h;hb=g+16|0}function b_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=hb-448|0;hb=a;x[a+432>>2]=c;x[a+440>>2]=b;x[a+20>>2]=2542;h=Pd(a+24|0,a+32|0,a+20|0);x[114414]=0;Dc(a+16|0,e);b=x[114414];x[114414]=0;a:{b:{c:{d:{if((b|0)!=1){x[114414]=0;i=R(2510,a+16|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}v[a+15|0]=0;b=x[e+4>>2];x[114414]=0;b=pa(2554,a+440|0,c|0,d|0,a+16|0,b|0,f|0,a+15|0,i|0,h|0,a+20|0,a+432|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break b}if(!b){break c}b=hb-16|0;hb=b;e:{if(re(g)){c=x[g>>2];x[b+12>>2]=0;ug(c,b+12|0);ae(g,0);break e}x[b+8>>2]=0;ug(g,b+8|0);Ce(g,0)}hb=b+16|0;if(!y[a+15|0]){break d}x[114414]=0;b=O(2535,i|0,45)|0;c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(109,g|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break d}break b}c=N()|0;break a}x[114414]=0;b=O(2535,i|0,48)|0;c=x[114414];x[114414]=0;if((c|0)==1){break b}c=x[h>>2];d=x[a+20>>2];e=d-4|0;while(1){if(!((b|0)!=x[c>>2]|c>>>0>=e>>>0)){c=c+4|0;continue}break}x[114414]=0;U(2560,g|0,c|0,d|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break c}break b}x[114414]=0;b=O(2515,a+440|0,a+432|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break b}if(b){x[f>>2]=x[f>>2]|2}b=x[a+440>>2];Ob(a+16|0);Jc(h);hb=a+448|0;return b|0}c=N()|0;Ob(a+16|0)}Jc(h);Q(c|0);p()}function f8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=hb+-64|0;hb=b;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[d+12>>2]=0;U(1793,a+8|0,d+12|0,d+8|0)|0;c=x[114414];x[114414]=0;a:{if((c|0)!=1){hb=d+16|0;break a}S(0)|0;zb();p()}x[114414]=0;d=a;P(1788,a|0,11);a=x[114414];x[114414]=0;b:{if((a|0)!=1){a=78896;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{while(1){g=Qg(44);if(g){x[114414]=0;c=O(118,b+32|0,x[a+4>>2])|0;e=x[114414];x[114414]=0;if((e|0)==1){break l}h=x[a>>2];x[114414]=0;P(1789,b+48|0,c|0);e=x[114414];x[114414]=0;if((e|0)==1){break k}x[114414]=0;e=O(118,b|0,x[a+8>>2])|0;f=x[114414];x[114414]=0;if((f|0)==1){break j}x[114414]=0;P(1789,b+16|0,e|0);f=x[114414];x[114414]=0;if((f|0)==1){break i}x[114414]=0;h=aa(1790,g|0,h|0,1,b+48|0,b+16|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break h}Gb(b+16|0);xb(e);Gb(b+48|0);xb(c);x[114414]=0;x[b+60>>2]=h;P(1791,d|0,b+60|0);c=x[114414];x[114414]=0;if((c|0)==1){break c}c=x[b+60>>2];v[c+40|0]=y[a+20|0];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;v[c+41|0]=y[c+41|0]&253|y[a+21|0]<<1}a=a+24|0;if((a|0)!=79160){continue}break}hb=b- -64|0;return d|0}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;break g}a=N()|0;Gb(b+16|0)}xb(e)}Gb(b+48|0)}xb(c)}_b(g);break b}a=N()|0;break b}a=N()|0}MJ(d);Q(a|0);p()}function Hk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-32|0;hb=e;j=Kp(a);g=Bj(j);d=g;c=zc(a);a:{if(d>>>0>c>>>0){f=hb-32|0;hb=f;b:{c=d-c|0;c:{if(c>>>0<=(x[yb(a)>>2]-x[a+4>>2]|0)/12>>>0){h=hb-16|0;hb=h;d:{d=sl(h,a,c);c=x[d+4>>2];k=x[d+8>>2];if((c|0)!=(k|0)){while(1){i=yb(a);x[114414]=0;P(1227,i|0,c|0);i=x[114414];x[114414]=0;if((i|0)==1){break d}c=c+12|0;x[d+4>>2]=c;if((c|0)!=(k|0)){continue}break}}Jb(d);hb=h+16|0;break c}a=N()|0;Jb(d);Q(a|0);p()}d=yb(a);d=ek(f+8|0,Rm(a,zc(a)+c|0),zc(a),d);x[114414]=0;P(1224,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(1225,a|0,d|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}tN(d)}hb=f+32|0;break a}a=N()|0;tN(d);Q(a|0);p()}if(d>>>0<c>>>0){d=x[a>>2]+D(d,12)|0;zc(a);vN(a,d);Ht(a)}}e:{if(!b){break e}d=a+12|0;pt(d);if(vd(d)>>>0>1023){break e}x[e+28>>2]=0;c=x[a+24>>2]+484344|0;l=e,m=bc(c),x[l+24>>2]=m;l=e,m=dc(c),x[l+16>>2]=m;if(Hb(e+24|0,e+16|0)){while(1){c=e+24|0;x[e+12>>2]=x[x[c>>2]+12>>2];l=e,m=x[_c(e+28|0,e+12|0)>>2],x[l+28>>2]=m;Zl(c);if(Hb(c,e+16|0)){continue}break}c=x[e+28>>2]}else{c=0}CN(d,c)}if(g){d=0;while(1){c=wd(a,d);f=Xy(a,z[uc(j,d)>>1]);f:{if(b){v[e+28|0]=0;BN(c,f,e+28|0);break f}Ez(c,f,0)}d=d+1|0;if((g|0)!=(d|0)){continue}break}}hb=e+32|0}function AE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{while(1){c:{i=x[a+12>>2];if(i>>>0>=d>>>0){break c}l=x[a+8>>2];if(l>>>0>=g>>>0){break c}f=v[i|0];c=f&255;d:{if((f|0)>=0){if(c>>>0<=1114111){f=1;break d}b=2;break a}b=2;if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-i|0)<2){break b}j=y[i+1|0];if((j&192)!=128){break a}f=2;c=j&63|c<<6&1984;break d}if(f>>>0<=4294967279){if((d-i|0)<3){break b}k=y[i+2|0];j=y[i+1|0];e:{f:{if((c|0)!=237){if((c|0)!=224){break f}if((j&224)==160){break e}break a}if((j&224)==128){break e}break a}if((j&192)!=128){break a}}if((k&192)!=128){break a}f=3;c=k&63|(c<<12&61440|(j&63)<<6);break d}if(f>>>0>4294967284){break a}if((d-i|0)<4){break b}k=y[i+3|0];m=y[i+2|0];j=y[i+1|0];g:{h:{switch(c-240|0){case 0:if((j+112&255)>>>0<48){break g}break a;case 4:if((j&240)==128){break g}break a;default:break h}}if((j&192)!=128){break a}}if((m&192)!=128|(k&192)!=128){break a}f=4;c=k&63|(m<<6&4032|(c<<18&1835008|(j&63)<<12));if(c>>>0>1114111){break a}}x[l>>2]=c;x[a+12>>2]=f+i;x[a+8>>2]=x[a+8>>2]+4;continue}break}b=d>>>0>i>>>0;break a}b=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return b|0}function kna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=hb-48|0;hb=g;x[g+32>>2]=b;b=x[a>>2];m=g,n=bc(a),x[m+8>>2]=n;b=b+(vq(g+32|0,g+8|0)<<1)|0;a:{b:{if(A[a+4>>2]<A[yb(a)>>2]){f=x[a+4>>2];if((f|0)!=(b|0)){break b}h=hb-16|0;hb=h;d=Yg(h,a,1);a=yb(a);e=x[d+4>>2];x[114414]=0;T(479,a|0,e|0,c|0);a=x[114414];x[114414]=0;c:{if((a|0)!=1){x[d+4>>2]=x[d+4>>2]+2;Jb(d);hb=h+16|0;break c}a=N()|0;Jb(d);Q(a|0);p()}break a}d=yb(a);d=zq(g+8|0,$i(a,qc(a)+1|0),b-x[a>>2]>>1,d);x[114414]=0;P(474,d|0,c|0);c=x[114414];x[114414]=0;d:{if((c|0)==1){break d}x[114414]=0;b=U(475,a|0,d|0,b|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break d}Cu(d);break a}a=N()|0;Cu(d);Q(a|0);p()}j=hb-16|0;hb=j;k=x[a+4>>2];h=(k-(b+2|0)|0)+b|0;e=Yg(j,a,f-h>>1);e:{f:{if(f>>>0>h>>>0){i=x[e+4>>2];d=h;while(1){l=yb(a);x[114414]=0;T(481,l|0,i|0,d|0);l=x[114414];x[114414]=0;if((l|0)==1){break f}i=i+2|0;x[e+4>>2]=i;d=d+2|0;if(f>>>0>d>>>0){continue}break}}Jb(e);e=k;f=hb-16|0;hb=f;d=h;if((d|0)!=(b|0)){while(1){x[f+12>>2]=d-2;e=e-2|0;SA(e,x[f+12>>2]);d=x[f+12>>2];if((d|0)!=(b|0)){continue}break}}hb=f+16|0;rg(k,e);hb=j+16|0;break e}a=N()|0;Jb(e);Q(a|0);p()}SA(b,((b>>>0<=c>>>0&A[a+4>>2]>c>>>0)<<1)+c|0)}a=x[Fb(g+40|0,b)>>2];hb=g+48|0;return a|0}function MF(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{c=x[a+4>>2];f:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break f}c=Zc(a)}switch(c-43|0){case 0:case 2:break e;default:break d}}f=(c|0)==45;g=!b;c=x[a+4>>2];g:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break g}c=Zc(a)}b=c-58|0;if(g|b>>>0>4294967285){break c}if(x[a+116>>2]<0){break b}x[a+4>>2]=x[a+4>>2]-1;break b}b=c-58|0}if(b>>>0<4294967286){break b}b=c-48|0;if(b>>>0<10){while(1){e=(D(e,10)+c|0)-48|0;d=(e|0)<214748364;c=x[a+4>>2];h:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break h}c=Zc(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}i:{if(b>>>0>=10){break i}while(1){b=yna(e,d,10,0);d=b+c|0;c=lb;e=d-48|0;d=(b>>>0>d>>>0?c+1|0:c)-(d>>>0<48)|0;b=x[a+4>>2];j:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;c=y[b|0];break j}c=Zc(a)}b=c-48|0;if(b>>>0>9){break i}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=x[a+4>>2];k:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;b=y[b|0];break k}b=Zc(a)}if(b-48>>>0<10){continue}break}}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){x[a+4>>2]=x[a+4>>2]-1}a=e;e=f?0-a|0:a;d=f?0-(((a|0)!=0)+d|0)|0:d;break a}d=-2147483648;if(x[a+116>>2]<0){break a}x[a+4>>2]=x[a+4>>2]-1;lb=-2147483648;return 0}lb=d;return e}function UQ(a,b){var c=0,d=0;a:{b:{c:{d:{if(Yd(a,12601)){break d}if(Yd(a,13273)){break d}if(Yd(a,9448)){break d}if(Yd(a,9535)){break d}if(!Yd(a,9953)){break c}}w[b+10>>1]=4;x[b>>2]=7880;break b}e:{f:{if(Yd(a,13268)){break f}if(Yd(a,9453)){break f}if(!Yd(a,12591)){break e}}v[b+12|0]=1;w[b+10>>1]=4;x[b>>2]=4610;return 1}g:{if(!Yd(a,9988)){if(!Yd(a,9993)){break g}}w[b+10>>1]=8;x[b>>2]=4374;break b}h:{if(!Yd(a,11202)){if(!Yd(a,11207)){break h}}x[b>>2]=12977;w[b+10>>1]=v[a+2|0]-48;break b}i:{if(!Yd(a,23928)){if(!Yd(a,23933)){break i}}x[b+4>>2]=1;x[b>>2]=12783;w[b+10>>1]=y[a|0]==56?8:4;return 1}if(!(cd(a,11570,3)|(y[a+3|0]-52&255)>>>0>4)){x[b>>2]=4728;a=v[a+3|0];w[b+8>>1]=1088;w[b+10>>1]=a-48;break b}j:{if(cd(a,9473,3)){if(cd(a,9592,3)){break j}}if((y[a+3|0]-52&255)>>>0>5){break j}v[b+15|0]=1;v[b+13|0]=1;x[b>>2]=4473;w[b+10>>1]=v[a+3|0]-48;return 1}k:{if((y[a|0]-49&255)>>>0>8){break k}if(!cd(a+1|0,9600,3)){v[b+14|0]=1;x[b>>2]=4776;w[b+10>>1]=v[a|0]-48;return 1}c=y[a+2|0]|y[a+3|0]<<8;if((c|0)!=18499&(c|0)!=20035|(y[a+1|0]-48&255)>>>0>9){break k}v[b+14|0]=1;x[b>>2]=4776;w[b+10>>1]=(v[a+1|0]+D(v[a|0],10)|0)-528;return 1}if(cd(a,9295,3)|(y[a+3|0]-52&255)>>>0>5){break a}x[b>>2]=4637;w[b+10>>1]=v[a+3|0]-48}d=1}return d}function DJ(a){var b=0,c=E(0),d=0,e=0,f=E(0),g=0,h=0,i=E(0),k=0,m=0,n=E(0);d=hb-16|0;hb=d;b=Ze(x[a+16>>2]);m=a,n=le(E(10),E(E(E(B[a+4208>>2]*E(120))+E(-60))*E(.05000000074505806))),B[m+4232>>2]=n;i=E(E(b>>>0)*E(.0010000000474974513));m=a,n=le(E(10),E(E(-1)/E(E(E(B[a+4212>>2]*E(499.989990234375))+E(.009999999776482582))*i))),B[m+4236>>2]=n;m=a,n=le(E(10),E(E(-1)/E(E(E(B[a+4216>>2]*E(2950))+E(50))*i))),B[m+4240>>2]=n;x[d+12>>2]=1325400064;c=E(le(E(10),E(E(E(B[a+4220>>2]*E(60))+E(-60))*E(.05000000074505806)))*E(2147483648));b=(q(c),j(2));f=E(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){e=b<<1;if(!e){f=E(Pw(E(-1))/E(0));break a}if((b|0)==2139095040){break b}if(!(e>>>0<4278190080&(b|0)>=0)){f=XG(c);break a}b=(q(E(c*E(8388608))),j(2))-192937984|0}e=b-1060306944|0;g=e>>>15&240;h=+(l(2,b-(e&-8388608)|0),r())*C[g+57664>>3]+-1;k=h*h;c=E((C[7241]*k+(C[7242]*h+C[7243]))*k+(+(e>>23)*C[7240]+C[g+57672>>3]+h))}f=c}B[d+8>>2]=E(f*E(96817624))+E(67108864);m=a,n=E(B[Hl(d+12|0,d+8|0)>>2]*E(4.656612873077393e-10)),B[m+4244>>2]=n;B[a+4248>>2]=E(E(-1)/E(E(B[a+4224>>2]*E(99))+E(1)))+E(1);c=E(E(E(B[a+4228>>2]*E(4))*i)+E(2));c:{if(E(F(c))<E(2147483648)){g=~~c;break c}g=-2147483648}x[a+4252>>2]=g;hb=d+16|0}function l8(a){a=a|0;var b=0,c=0,d=0,e=0,f=E(0),g=0,h=0;c=hb-32|0;hb=c;a:{b=x[a+20>>2];b:{if(!b){break b}x[b+148>>2]=-1;g=c,h=mb[x[x[a>>2]+40>>2]](a)|0,x[g+16>>2]=h;x[c+8>>2]=1073741822;e=x[be(c+16|0,c+8|0)>>2];b=e<<2;if(!b){break b}d=x[a+20>>2];x[114414]=0;P(464,d+4|0,b+4|0);b=x[114414];x[114414]=0;c:{d:{e:{f:{if((b|0)!=1){b=x[a+20>>2];x[114414]=0;P(672,c+8|0,b+4|0);b=x[114414];x[114414]=0;if((b|0)==1){break d}x[114414]=0;x[c>>2]=0;x[c+4>>2]=0;T(1775,c+16|0,c+8|0,c|0);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;O(1776,c+16|0,0)|0;b=x[114414];x[114414]=0;g:{if((b|0)==1){break g}d=x[x[a>>2]+176>>2];b=0;x[114414]=0;P(d|0,a|0,-1);d=x[114414];x[114414]=0;if((d|0)==1){break g}if((e|0)>0){while(1){d=x[x[a>>2]+48>>2];x[114414]=0;f=E(la(d|0,a|0,b|0));d=x[114414];x[114414]=0;if((d|0)==1){break e}x[114414]=0;B[c+8>>2]=f;O(1777,c+16|0,c+8|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=x[x[a>>2]+180>>2];x[114414]=0;W(b|0,a|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}b=S(75016)|0;break c}b=S(75016)|0;break c}b=S(75016)|0;break c}b=S(75016)|0;break c}b=S(75016)|0}if((ib|0)!=(ca(75016)|0)){break a}Y(b|0)|0;jt(x[a+20>>2]+4|0);_()}hb=c+32|0;return}Q(b|0);p()}function vla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{if(!Qb(b,9)){break a}h=a+484344|0;i=a+480280|0;while(1){Un(b,c+28|0);d=Gf(b);b:{e=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);c:{if((e|0)==1229999433|(e|0)==1397771593){break c}e=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);if((e|0)==1297110104|(e|0)==1297110099){break c}if(Qb(b,d)){break b}}ng(b,8);break a}Bd(c+8|0,b,d);d=i;d:{e:{f:{if((y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))==1481001027){while(1){x[114414]=0;e=R(391,c+8|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break f}v[d+8|0]=e;d=d+32|0;if((h|0)!=(d|0)){continue}break d}}if(y[c+28|0]!=70){break e}e=y[c+29|0];g=(e|0)==88;g:{if(!g){if((e-48&255)>>>0>9){break e}d=v[c+30|0];if((d|0)>47){break g}break e}d=v[c+30|0];if((d|0)<48){break e}}if(d>>>0>57){break e}f=v[c+31|0];if((f|0)<48|(f|0)>57){break e}d=(f+(g?-16:D(e,100)+48|0)|0)+D(d,10)&255;if(d>>>0>249){break d}x[114414]=0;P(644,c+8|0,(D(d,160)+a|0)+906300|0);d=x[114414];x[114414]=0;if((d|0)!=1){break d}}a=N()|0;Ab(c+8|0);Q(a|0);p()}if((y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))!=1430540109){break d}x[a+1074308>>2]=0;j=1}Ab(c+8|0);if(Qb(b,9)){continue}break}}hb=c+32|0;return j|0}function iy(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=DL(b,c);a:{if(!x[b+656>>2]|!(v[g|0]&1)){break a}f=x[g+4>>2];h=a+1074312|0;e=$b(h,31);d=Xu(x[b+656>>2],c);if(od(d)){break a}f=f+(e^1)|0;i=$b(h,31);e=y[d+12|0];b:{c:{if(!i){d:{if(!(e&2)){break d}e=z[Pb(d,y[d+14|0])>>1]+!(x[a+480180>>2]&1048580)|0;if(!(!(y[b+89|0]&8)|(!(y[d+12|0]&4)|y[d+14|0]!=y[d+16|0]))){j=$b(h,70)}if((f|0)!=(e|0)|j){break d}f=z[Pb(d,y[d+13|0])>>1]}if(!(!(y[d+12|0]&4)|y[b+89|0]&8)){if((z[Pb(d,y[d+16|0])>>1]+1|0)!=(f|0)){break b}f=z[Pb(d,y[d+15|0])>>1];if(!$b(h,93)|(c|0)!=1|y[b+89|0]&8){break b}v[g|0]=y[g|0]&254;break b}if(z[xj(d)>>1]>=f>>>0){break b}j=1;f=z[xj(d)>>1];break c}e:{f:{if(!(!(e&4)|y[b+669|0]&8)){if(x[g+8>>2]==-1){break f}if($b(h,97)){break f}e=y[d+12|0]}if(e&2){e=z[Pb(d,y[d+13|0])>>1];i=z[Pb(d,y[d+14|0])>>1]+1|0;break e}e=z[xj(d)>>1];j=f>>>0>e>>>0;i=e;break e}e=z[Pb(d,y[d+15|0])>>1];i=z[Pb(d,y[d+16|0])>>1]+1|0}f=f>>>0<i>>>0?f:e}if(!j|c){break b}if(!(!(x[a+480180>>2]&16777248)&(!(y[b+89|0]&8)|x[a+480180>>2]==16384))){x[b+88>>2]=x[b+88>>2]|4096}if(y[xj(d)+2|0]|!(z[b+808>>1]|x[a+480180>>2]&16777248)){break b}x[b+696>>2]=0;x[b+720>>2]=0;x[b+680>>2]=0;x[b+88>>2]=x[b+88>>2]|4096}k=g,l=$b(h,31)+f|0,x[k+4>>2]=l}}function eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-432|0;hb=e;Lc(b);cA(b,e+376|0,e+296|0,e+8|0);g=e+408|0;m=e,n=Vk(y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24)?y[e+427|0]+1|0:1),v[m+4|0]=n;h=y[rc(23856,e+4|0)|0];v[e+7|0]=h;w[e+4>>1]=4;a:{b:{if(!h){break b}g=e+392|0;j=e+291|0;while(1){c:{d=e+8|0;d=y[d|0]|y[d+1|0]<<8;f=(d<<8|d>>>8)<<16>>16;if(!((f|0)<0|y[j|0]>63)){if(d){d=f&65535;k=d>>>0<=1?1:d;d=0;while(1){f=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);d:{if(!Rc(b,(f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))+(d<<2)|0)){break d}if(!Rc(b,VA(b))){break d}e:{if(!c){f=pe(b);break e}f=Du(b)}w[e+2>>1]=f;m=e,n=z[aj(e+4|0,e+2|0)>>1],w[m+4>>1]=n}d=d+1|0;if((k|0)!=(d|0)){continue}break}}d=e+296|0;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);if((d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))>>>0>l>>>0){d=e+296|0;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);if(Rc(b,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24))){break c}}v[e+7|0]=i+1;break b}iC(a);break a}d=e+296|0;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);cA(b,e+376|0,d,e+8|0);l=f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24);i=i+1|0;if((i&255)>>>0<h>>>0){continue}break}}w[a>>1]=z[e+4>>1];v[a+2|0]=y[e+7|0]}hb=e+432|0}function Via(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=hb-16|0;hb=j;d=Og(b);a:{if(d>>>0<c>>>0){k=hb-32|0;hb=k;b:{c:{h=c-d|0;d:{if(h>>>0<=x[yb(b)>>2]-x[b+4>>2]>>3>>>0){g=hb-16|0;hb=g;e:{d=Yq(g,b,h);e=x[d+4>>2];f=x[d+8>>2];if((e|0)!=(f|0)){while(1){h=yb(b);x[114414]=0;P(897,h|0,e|0);h=x[114414];x[114414]=0;if((h|0)==1){break e}e=e+8|0;x[d+4>>2]=e;if((e|0)!=(f|0)){continue}break}}Jb(d);hb=g+16|0;break d}a=N()|0;Jb(d);Q(a|0);p()}i=yb(b);g=k+8|0;f=Og(b)+h|0;d=hb-16|0;hb=d;x[d+12>>2]=f;f:{e=sv(b);if(f>>>0<=e>>>0){f=dj(b);if(f>>>0<e>>>1>>>0){x[d+8>>2]=f<<1;e=x[_c(d+8|0,d+12|0)>>2]}hb=d+16|0;d=e;break f}Vc();p()}l=Og(b);e=0;f=hb-16|0;hb=f;x[f+12>>2]=0;Qe(g+12|0,i);if(d){UC(f,x[g+16>>2],d);e=x[f>>2];d=x[f+4>>2]}else{d=0}x[g>>2]=e;i=(l<<3)+e|0;x[g+8>>2]=i;x[g+4>>2]=i;m=ic(g),n=(d<<3)+e|0,x[m>>2]=n;hb=f+16|0;x[114414]=0;P(895,g|0,h|0);d=x[114414];x[114414]=0;if((d|0)==1){break c}x[114414]=0;P(896,b|0,g|0);d=x[114414];x[114414]=0;if((d|0)==1){break c}nQ(g)}hb=k+32|0;break b}a=N()|0;nQ(g);Q(a|0);p()}break a}if(c>>>0<d>>>0){d=x[b>>2]+(c<<3)|0;Og(b);oQ(b,d);dj(b);Og(b)}}c=Qb(a,c<<3);if(c){d=hb-16|0;hb=d;e=j+8|0;jc(e,x[b>>2],Og(b)<<3);hb=d+16|0;Dd(a,e)}hb=j+16|0;return c|0}function le(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,k=0;d=(q(b),j(2));c=TG(d);a:{b:{c:{d:{e=(q(a),j(2));e:{if(e-2139095040>>>0>=2164260864){if(c){break e}break c}if(!c){break d}}h=E(1);if((e|0)==1065353216){break b}c=d<<1;if(!c){break b}i=c>>>0<4278190081;c=e<<1;a=E(a+b);if(!(i&c>>>0<=4278190080)){break a}if((c|0)==2130706432){break b}a=c>>>0>2130706431^(d|0)>=0?E(0):E(b*b);break a}if(TG(e)){h=E(a*a);if((e|0)<0){h=(SG(d)|0)==1?E(-h):h}if((d|0)>=0){break b}a=Pw(E(E(1)/h));break a}if((e|0)<0){c=SG(d);if(!c){a=XG(a);break a}e=e&2147483647;i=((c|0)==1)<<16}if(e>>>0>8388607){break c}e=((q(E(a*E(8388608))),j(2))&2147483647)-192937984|0}d=e-1060306944|0;c=d>>>15&240;f=+(l(2,e-(d&-8388608)|0),r())*C[c+58280>>3]+-1;g=f*f;f=((C[7317]*f+C[7318])*(g*g)+((C[7319]*f+C[7320])*g+(C[7321]*f+(C[c+58288>>3]+ +(d>>23)))))*+b;o(+f);c=j(1)|0;j(0)|0;f:{c=c&2147450880;if((c|0)==1079967744|c>>>0<1079967744){break f}if(f>127.99999995700433){a=VG(i);break a}if(!(f<=-150)){break f}a=UG(i);break a}k=f;g=C[7276];f=g+f;g=k-(f-g);g=(C[7277]*g+C[7278])*(g*g)+(C[7279]*g+1);o(+f);j(1)|0;e=j(0)|0;d=i+e|0;i=d<<15;d=((e&31)<<3)+57952|0;c=x[d>>2];d=x[d+4>>2]+i|0;l(0,c|0);l(1,(c>>>0>c>>>0?d+1|0:d)|0);h=E(g*+n())}a=h}return a}function _L(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{b:{d=a+484360|0;if(qc(Vb(d))>>>0<=b>>>0){break b}if(Rp(Vb(d),b)){break b}while(1){b=b+1|0;c=b&65535;if(qc(Vb(d))>>>0<=c>>>0){break a}if(!Rp(Vb(d),b&65535)){continue}break}break a}c=b}if(qc(Vb(d))>>>0>c>>>0){d=a+1074312|0;g=a+1304360|0;c=a+1074984|0;while(1){v[c+819|0]=0;x[c+700>>2]=0;v[c+861|0]=0;v[c+827|0]=0;x[c+708>>2]=0;v[c+841|0]=0;x[c+804>>2]=0;v[c+839|0]=0;v[c+840|0]=0;f=e+8|0;Kb(f,d,23);if(Ib(f)){w[c+798>>1]=0;w[c+800>>1]=1}v[c+859|0]=0;c=c+896|0;if((g|0)!=(c|0)){continue}break}ZL(a);c:{if(!(b&65535)){b=0;while(1){Hn((D(b,896)+a|0)+1074984|0,7,a,b&65535,1024);b=b+1|0;if((b|0)!=256){continue}break}Hk(a+1304360|0,1);x[a+1074444>>2]=x[a+480200>>2];x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];x[a+480208>>2]=x[a+480208>>2]&-769;Ly(a+1074376|0);w[a+1074440>>1]=0;x[a+1074392>>2]=-2;b=a+1074428|0;x[b>>2]=0;x[b+4>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074376>>2]=0;x[a+1074380>>2]=0;break c}w[a+1074440>>1]=b;w[a+1074436>>1]=0;b=a+1074424|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074392>>2]=-2;x[a+1074432>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074380>>2]=0}x[a+480208>>2]=x[a+480208>>2]&-769}hb=e+16|0}function BY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=hb-16|0;hb=j;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!x[i>>2]){break a}i=i+4|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){k=x[b+4>>2];x[j+8>>2]=x[b>>2];x[j+12>>2]=k;m=1;l=hb-16|0;hb=l;x[l+12>>2]=x[a+8>>2];n=Hh(l+8|0,l+12|0);x[114414]=0;k=aa(2620,f|0,e|0,i-c>>2,g-f|0,b|0)|0;o=x[114414];x[114414]=0;d:{if((o|0)!=1){Ne(n);hb=l+16|0;break d}a=N()|0;Ne(n);Q(a|0);p()}e:{f:{g:{h:{switch(k+1|0){case 0:x[h>>2]=f;while(1){i:{if(x[e>>2]==(c|0)){break i}b=$v(f,x[c>>2],j+8|0,x[a+8>>2]);if((b|0)==-1){break i}f=b+x[h>>2]|0;x[h>>2]=f;c=c+4|0;continue}break};x[e>>2]=c;break g;case 1:break c;default:break h}}f=k+x[h>>2]|0;x[h>>2]=f;if((f|0)==(g|0)){break e}if((d|0)==(i|0)){c=x[e>>2];i=d;continue}i=$v(j+4|0,0,b,x[a+8>>2]);if((i|0)!=-1){break f}}m=2;break c}c=j+4|0;if(g-x[h>>2]>>>0<i>>>0){break c}while(1){if(i){f=y[c|0];k=x[h>>2];x[h>>2]=k+1;v[k|0]=f;i=i-1|0;c=c+1|0;continue}break}c=x[e>>2]+4|0;x[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!x[i>>2]){break b}i=i+4|0;continue}}c=x[e>>2]}m=(c|0)!=(d|0)}hb=j+16|0;return m|0}f=x[h>>2];continue}}function wna(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{e=b;if(e){if(!c){break j}if(!d){break i}e=G(d)-G(e)|0;if(e>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;jb=a-D(b,c)|0;kb=0;lb=0;return b}if(!a){break g}if(!d){break f}f=d-1|0;if(f&d){break f}jb=a;kb=e&f;a=e>>>xna(d)|0;lb=0;return a}f=c-1|0;if(!(f&c)){break e}j=(G(c)+33|0)-G(e)|0;h=0-j|0;break c}j=e+1|0;h=63-e|0;break c}jb=0;a=(e>>>0)/(d>>>0)|0;kb=e-D(a,d)|0;lb=0;return a}e=G(d)-G(e)|0;if(e>>>0<31){break d}break b}jb=a&f;kb=0;if((c|0)==1){break a}c=xna(c);d=c&31;if((c&63)>>>0>=32){e=0;a=b>>>d|0}else{e=b>>>d|0;a=((1<<d)-1&b)<<32-d|a>>>d}lb=e;return a}j=e+1|0;h=63-e|0}f=a;e=j&63;g=e&31;if((e&63)>>>0>=32){e=0;f=b>>>g|0}else{e=b>>>g|0;f=((1<<g)-1&b)<<32-g|f>>>g}h=h&63;g=h&31;if((h&63)>>>0>=32){i=a<<g;a=0}else{i=(1<<g)-1&a>>>32-g|b<<g;a=a<<g}b=i;if(j){h=d-1|0;k=c-1|0;h=(k|0)!=-1?h+1|0:h;g=k;while(1){e=e<<1|f>>>31;f=f<<1|b>>>31;k=e;l=h-(e+(f>>>0>g>>>0)|0)|0;m=l>>31;i=m;e=f;l=c&i;f=e-l|0;e=k-((d&i)+(e>>>0<l>>>0)|0)|0;i=b<<1|a>>>31;a=n|a<<1;b=i|o;k=m&1;n=k;j=j-1|0;if(j){continue}break}}jb=f;kb=e;i=b<<1|a>>>31;a=k|a<<1;lb=i|o;return a}jb=a;kb=b;a=0;b=0}lb=b;return a}function S9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=hb-160|0;hb=c;e=pl(c+56|0,a);x[114414]=0;d=O(658,c+40|0,35968)|0;a=x[114414];x[114414]=0;a:{b:{c:{d:{if((a|0)!=1){x[114414]=0;x[c+24>>2]=19469590;x[c+28>>2]=0;T(659,e|0,d|0,c+24|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}Gb(d);if(!(x[e>>2]&1073741824)){break c}break a}a=N()|0;break b}a=N()|0;Gb(d);break b}a=Ae(b);x[114414]=0;w[c+38>>1]=a;w[c+36>>1]=65535;d=O(658,c+24|0,6086)|0;a=x[114414];x[114414]=0;e:{if((a|0)!=1){x[114414]=0;a=U(1170,e|0,c+36|0,d|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break e}Gb(d);if((a|0)!=1){w[c+38>>1]=z[c+36>>1]}sg(c+38|0,z[x[19563]+10>>1]);f:{if(z[c+38>>1]<=Ae(b)>>>0){break f}x[114414]=0;P(362,b|0,z[c+38>>1]);a=x[114414];x[114414]=0;if((a|0)!=1){break f}a=N()|0;break b}a=0;w[c+22>>1]=0;if(!z[c+38>>1]){break a}g:{while(1){h:{a=Zb(b,a&65535);x[114414]=0;P(1610,c+8|0,c+22|0);d=x[114414];x[114414]=0;if((d|0)==1){break h}x[114414]=0;Z(1584,e|0,a|0,c+8|0,1611)|0;a=x[114414];x[114414]=0;if((a|0)==1){break g}Gb(c+8|0);a=z[c+22>>1]+1|0;w[c+22>>1]=a;if(z[c+38>>1]>(a&65535)>>>0){continue}break a}break}a=N()|0;break b}a=N()|0;Gb(c+8|0);break b}a=N()|0;break b}a=N()|0;Gb(d)}Hg(e);Q(a|0);p()}Hg(e);hb=c+160|0}function up(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;a:{b:{c:{d:{e:{f:{g:{h:{b=x[a+480180>>2];i:{if((b|0)<=2047){if((b|0)<=31){switch(b-1|0){case 2:case 4:case 5:case 6:break d;case 7:break g;case 0:case 1:case 3:break i;default:break e}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break b}break d}if((b|0)==256|(b|0)==512){break b}break d}d=1;if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break b}if((b|0)!=8192){break d}break b}if((b|0)==65536){break c}if((b|0)!=2097152){break d}break a}if((b|0)>67108863){break h}if((b|0)==4194304){break f}if((b|0)!=16777216){break d}}d=x[a+480180>>2];break a}if((b|0)==67108864|(b|0)==134217728){break a}if((b|0)!=536870912){break d}break a}d=4;if(z[a+480192>>1]){break a}a=a+484344|0;f=c,g=bc(a),x[f+8>>2]=g;f=c,g=dc(a),x[f>>2]=g;d=1;if(!Hb(c+8|0,c)){break a}while(1){a=x[c+8>>2];if(!(!xh(a)|x[a+12>>2]==64)){d=4;break a}a=c+8|0;Zl(a);if(Hb(a,c)){continue}break}break a}d=32;if(z[a+480188>>1]>16){break a}if(!z[a+480188>>1]){break b}b=0;while(1){e=(b<<5)+a|0;if(v[e+480281|0]&1|z[e+480286>>1]!=64){break a}b=b+1|0;if(b>>>0<z[a+480188>>1]){continue}break}break b}if((b|0)==16){break b}}d=32;break a}d=16777216;break a}d=2}hb=c+16|0;return d}function oV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=hb-1072|0;hb=f;e=ci(f+16|0);a=Cm(a,e);Ab(e);x[a+1060>>2]=0;x[a+1064>>2]=0;x[a+1056>>2]=c;e=a+1068|0;x[e>>2]=0;x[e+4>>2]=0;e=0;x[a+1076>>2]=0;v[a+1080|0]=d;a:{b:{if(Je(c)){h=a+1060|0;while(1){x[a+1060>>2]=0;x[a+1064>>2]=0;c:{if(!x[c>>2]){break c}while(1){x[114414]=0;d=O(226,b|0,2)|0;g=x[114414];x[114414]=0;d:{e:{f:{g:{if((g|0)!=1){if(!d){break c}x[114414]=0;d=R(321,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break g}if(!d){break d}x[114414]=0;T(307,f|0,b|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break f}d=Cm(f+16|0,f);Ud(a,d);sc(a+16|0,d+16|0,1040);Ab(d);Ab(f);x[a+1072>>2]=0;x[a+1076>>2]=0;g=Rq(x[a+1056>>2]);d=x[x[a+1056>>2]+20>>2];if(g>>>0>=2){x[114414]=0;P(322,a|0,d+(e<<1)|0);d=x[114414];x[114414]=0;if((d|0)!=1){break d}break e}x[114414]=0;P(323,a|0,d+e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}break d}d=N()|0;break a}d=N()|0;break a}d=N()|0;break a}d=S(75884)|0;if((ib|0)!=(ca(75884)|0)){break a}Y(d|0)|0;x[114414]=0;V(20);d=x[114414];x[114414]=0;if((d|0)==1){break b}}if(A[h>>2]<A[c>>2]){continue}break}}e=e+1|0;if(Je(x[a+1056>>2])>>>0>e>>>0){continue}break}}hb=f+1072|0;return a|0}d=N()|0}Ab(a);Q(d|0);p()}function Lfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=hb-16|0;hb=h;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];i=x[a+44>>2];o=x[a+16>>2];e=x[a+4>>2];b=x[a>>2];x[h+8>>2]=b;x[h+12>>2]=e;g=x[a+12>>2];x[h>>2]=x[a+8>>2];x[h+4>>2]=g;a:{if(!d){g=k>>12;j=l>>12;break a}while(1){b=(x[h+8>>2]>>>21&2040)+32976|0;m=w[b+2>>1];e=(x[h+12>>2]<<1)+o|0;p=w[e>>1];q=w[b>>1];r=w[e-2>>1];s=w[b+4>>1];t=w[e+2>>1];u=w[b+6>>1];n=w[e+4>>1];e=x[a+60>>2];b=i;i=Xb(b,-16777216,16776704);g=x[a+64>>2];j=Xb(f,-16777216,16776704);v=x[a+72>>2];y=x[a+32>>2];z=x[c>>2];f=yna(g,g>>31,i,i>>31);g=lb;i=(((D(m,p)+D(q,r)|0)+D(s,t)|0)+D(u,n)|0)/16384<<8;m=yna(e,e>>31,i,i>>31);e=m+f|0;f=lb+g|0;f=e>>>0<m>>>0?f+1|0:f;n=e;e=x[a+68>>2];g=yna(e,e>>31,j,j>>31);e=n+g|0;f=lb+f|0;f=e>>>0<g>>>0?f+1|0:f;l=x[a+28>>2]+l|0;j=l>>12;e=e+8388608|0;f=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;e=(f|0)/256|0;x[c>>2]=D(j,e)+z;k=k+y|0;g=k>>12;x[c+4>>2]=x[c+4>>2]+D(e,g);i=f-(i&v)|0;c=c+8|0;Tb(h+8|0,h);f=b;d=d-1|0;if(d){continue}break}b=x[h+8>>2];e=x[h+12>>2]}x[a>>2]=b;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=j;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=i;x[a+24>>2]=g;hb=h+16|0}function QR(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;d=y[a|0];a:{if(d>>>0>21){break a}v[a|0]=y[d+23728|0];b:{switch(d-8|0){case 0:v[b|0]=y[b|0]<<1;break a;case 4:v[b|0]=y[b|0]+1>>>1;break a;case 5:a=y[b|0];v[b|0]=D(a>>>4|0,10)+(a&15);break a;case 6:c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=y[b|0];switch((d>>>4|0)-1|0){case 11:case 12:case 13:break a;case 9:break e;case 8:break f;case 6:break g;case 5:break h;case 3:break i;case 1:break j;case 0:break k;case 14:break c;case 10:break d;default:break l}}v[a|0]=0;break a}v[a|0]=29;v[c+15|0]=y[b|0]&15;v[c+14|0]=14;e=b,f=y[rc(c+15|0,c+14|0)|0]<<4|15,v[e|0]=f;break a}v[a|0]=29;v[c+13|0]=y[b|0]&15;v[c+12|0]=14;e=b,f=y[rc(c+13|0,c+12|0)|0]|240,v[e|0]=f;break a}v[b|0]=d&15|48;break a}v[b|0]=d&15|176;break a}v[b|0]=d&15|64;break a}v[a|0]=15;v[b|0]=y[b|0]&15;break a}v[a|0]=24;v[b|0]=(y[b|0]<<3&120)+8&240;break a}v[a|0]=24;v[b|0]=(y[b|0]&15)+1>>>1;break a}v[a|0]=10;break a;case 8:a=y[b|0];if(a>>>0<=223){v[b|0]=a>>>0>63?-16:a<<2&240;break a}if(a>>>0<=239){v[b|0]=a<<2&48|15;break a}v[b|0]=a<<4|15;break a;case 9:break b;default:break a}}a=y[b|0];if(a>>>0<=223){v[b|0]=a>>>0>63?15:a>>>2|0;break a}if(a>>>0>239){break a}v[b|0]=a>>>2&3|240}hb=c+16|0}function Efa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-32|0;hb=e;i=x[a+12>>2];f=i;a:{b:{c:{g=x[a+8>>2];d:{if((f|0)<=1&g>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&g>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&g>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&g>>>0>2147483648|f>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}l=x[a+16>>2];m=x[a+24>>2];n=x[a+20>>2];j=x[a+4>>2];b=x[a>>2];x[e+24>>2]=b;x[e+28>>2]=j;x[e+16>>2]=g;x[e+20>>2]=f;g=a;if(d){while(1){a=x[e+24>>2];h=((((x[e+28>>2]&2147483647)<<1|a>>>31)&2147483646)<<1)+l|0;a=(a>>>16&65520)+i|0;o=w[a+14>>1];p=w[a+12>>1];q=w[a+10>>1];r=w[a+8>>1];s=w[a+6>>1];t=w[a+4>>1];f=w[a+2>>1];j=w[a>>1];k=0;b=1;while(1){a=k<<1;x[(e+8|0)+(k<<2)>>2]=(((((((D(w[(a|-8)+h>>1],f)+D(w[(a|-12)+h>>1],j)|0)+D(w[(a|-4)+h>>1],t)|0)+D(w[a+h>>1],s)|0)+D(w[(a|4)+h>>1],r)|0)+D(w[(a|8)+h>>1],q)|0)+D(w[(a|12)+h>>1],p)|0)+D(w[(a|16)+h>>1],o)|0)/32768;a=b;b=0;k=1;if(a){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],n);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],m);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}b=x[e+24>>2];j=x[e+28>>2]}x[g>>2]=b;x[g+4>>2]=j;hb=e+32|0}function Nga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=hb-16|0;hb=g;a:{if(y[d|0]){e=Ed(g+8|0,b);b=Mi(c,b);c=hb-16|0;hb=c;x[c+12>>2]=b;d=x[e+4>>2];b:{c:{if(!d){d=x[e>>2];break c}x[c+8>>2]=32-d;b=Mb(c+8|0,c+12|0);d=x[e>>2];b=x[b>>2];f=x[d>>2]&(-1<<x[e+4>>2]&-1>>>x[c+8>>2]-b);if(f){dd(a,d,xna(f));break b}f=x[c+12>>2];if((f|0)==(b|0)){sz(a,e,b);break b}b=f-b|0;x[c+12>>2]=b;d=d+4|0;x[e>>2]=d}if(b>>>0>=32){while(1){f=x[d>>2];if(f){dd(a,d,xna(f));break b}d=d+4|0;x[e>>2]=d;b=b-32|0;x[c+12>>2]=b;if(b>>>0>31){continue}break}}d:{if(!b){break d}e=x[d>>2]&-1>>>32-b;if(!e){break d}dd(a,d,xna(e));break b}dd(a,d,b)}break a}e=Ed(g,b);b=Mi(c,b);c=hb-16|0;hb=c;x[c+12>>2]=b;d=x[e+4>>2];e:{f:{if(!d){d=x[e>>2];break f}x[c+8>>2]=32-d;b=x[Mb(c+8|0,c+12|0)>>2];d=x[e>>2];f=-1<<x[e+4>>2]&-1>>>x[c+8>>2]-b&(x[d>>2]^-1);if(f){dd(a,d,xna(f));break e}f=x[c+12>>2];if((f|0)==(b|0)){sz(a,e,b);break e}b=f-b|0;x[c+12>>2]=b;d=d+4|0;x[e>>2]=d}if(b>>>0>=32){while(1){f=x[d>>2];if((f|0)!=-1){dd(a,d,xna(f^-1));break e}d=d+4|0;x[e>>2]=d;b=b-32|0;x[c+12>>2]=b;if(b>>>0>31){continue}break}}g:{if(!b){break g}e=(x[d>>2]^-1)&-1>>>32-b;if(!e){break g}dd(a,d,xna(e));break e}dd(a,d,b)}}hb=c+16|0;hb=g+16|0}function afa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-48|0;hb=e;h=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;k=e,l=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[k+28>>2]=l;f=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=f;a:{if(!f){break a}b=a+8|0;k=e,l=Sf(b,f),x[k+16>>2]=l;x[e+20>>2]=lb;k=e,l=Te(b,d),x[k+40>>2]=l;x[e+44>>2]=lb;tf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}i=x[a+24>>2];j=x[a+20>>2];f=x[a+4>>2];b=x[a>>2];x[e+8>>2]=b;x[e+12>>2]=f;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;g=a;if(d){while(1){f=x[e+36>>2]-1|0;x[e+36>>2]=f;a=x[e+8>>2];b=x[e+12>>2]<<1;if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=b+h|0;x[e+40>>2]=a;x[e+44>>2]=0;b=x[e+32>>2];if((b|0)>0){while(1){zj(x[e+24>>2],w[f+(x[e+44>>2]<<1)>>1]/4<<16>>16);yj(x[e+24>>2],4);a=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(a){continue}break}}d=d-1|0;a=x[e+24>>2];Tb(a,a+8|0);b=x[e+24>>2];a=x[b+4>>2];if(a){zj(b,w[f+(x[e+44>>2]<<1)>>1]/4<<16>>16);yj(x[e+24>>2],a);b=x[e+24>>2];a=x[b>>2];x[b>>2]=a;x[b+4>>2]=0}a=Lp(b,x[e+28>>2]);x[c>>2]=x[c>>2]+D(a,j);x[c+4>>2]=x[c+4>>2]+D(a,i);c=c+8|0;Tb(e+8|0,e);if(d){continue}break}b=x[e+8>>2];f=x[e+12>>2]}x[g>>2]=b;x[g+4>>2]=f;hb=e+48|0}function hma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;Ad(b,32);e=a+4|0;e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[b>>2]=e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24);e=a+10|0;e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);e=e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24);x[b+4>>2]=e;g=e;e=a+14|0;e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[b+8>>2]=g+(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24));if(!(d?0:c)){c=a+46|0;c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24)}x[b+24>>2]=c;c=y[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;e=y[d+1|0]<<8;if(!(y[d|0]|e)|(e|y[d|0])==12288){break a}e=c;c=y[d|0]|y[d+1|0]<<8;c=(e-(((c<<8|c>>>8)&65535)<<7)|0)+6144|0}xt(b,+(c|0)*.0006510416666666666);v[f+15|0]=y[a+9|0];v[f+14|0]=64;h=b,i=y[rc(f+15|0,f+14|0)|0]<<2,w[h+30>>1]=i;if(v[a+40|0]&1){w[b+34>>1]=z[b+34>>1]|64;x[b>>2]=x[b>>2]>>>1;x[b+4>>2]=x[b+4>>2]>>>1;x[b+8>>2]=x[b+8>>2]>>>1}d=a+41|0;a=x[b+4>>2];c=x[b+8>>2];if(y[d|0]>=9){c=c>>>1|0;x[b+8>>2]=c;a=a>>>1|0;x[b+4>>2]=a;w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1}b:{if(a+1>>>0<c>>>0){w[b+34>>1]=z[b+34>>1]|2;break b}x[b+4>>2]=0;x[b+8>>2]=0}hb=f+16|0}function wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=hb-48|0;hb=g;x[g+32>>2]=b;b=x[a>>2];n=g,o=bc(a),x[n+8>>2]=o;b=b+(vq(g+32|0,g+8|0)<<1)|0;a:{b:{e=Vy(c,d);c:{if((e|0)<=0){break c}f=x[yb(a)>>2];k=x[a+4>>2];if(f-k>>1>=(e|0)){x[g+8>>2]=d;i=k-b|0;f=i>>1;if((f|0)<(e|0)){x[g+8>>2]=c;x[g+8>>2]=x[g+8>>2]+(f<<1);j=x[g+8>>2];h=hb-16|0;hb=h;f=Yg(h,a,e-f|0);l=yb(a);m=x[f+4>>2];x[114414]=0;d=Z(1246,l|0,j|0,d|0,m|0)|0;j=x[114414];x[114414]=0;d:{if((j|0)!=1){x[f+4>>2]=d;Jb(f);hb=h+16|0;break d}break a}if((i|0)<=0){break c}}i=hb-16|0;hb=i;j=x[a+4>>2];e=(j-((e<<1)+b|0)|0)+b|0;f=Yg(i,a,k-e>>1);if(e>>>0<k>>>0){h=x[f+4>>2];d=e;while(1){l=yb(a);x[114414]=0;T(1247,l|0,h|0,d|0);l=x[114414];x[114414]=0;if((l|0)==1){break a}h=h+2|0;x[f+4>>2]=h;d=d+2|0;if(k>>>0>d>>>0){continue}break}}Jb(f);bq(b,e,j);hb=i+16|0;Ke(c,x[g+8>>2],b);break c}f=yb(a);e=to(g+8|0,$i(a,qc(a)+e|0),b-x[a>>2]>>1,f);x[114414]=0;T(1243,e|0,c|0,d|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;b=U(1244,a|0,e|0,b|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break b}wC(e)}a=x[Fb(g+40|0,b)>>2];hb=g+48|0;return a|0}a=N()|0;wC(e);Q(a|0);p()}a=N()|0;Jb(f);Q(a|0);p()}function Mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=hb-16|0;hb=h;j=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];g=x[a+4>>2];e=g;b=x[a>>2];x[h+8>>2]=b;x[h+12>>2]=e;g=x[a+12>>2];x[h>>2]=x[a+8>>2];x[h+4>>2]=g;a:{if(!d){m=k>>12;n=l>>12;break a}while(1){e=x[h+8>>2];b=x[h+12>>2]+p|0;q=v[b+2|0];r=v[b+1|0];s=v[b|0];t=v[b-1|0];g=x[a+60>>2];b=f;i=Xb(f,-16777216,16776704);f=x[a+64>>2];o=Xb(j,-16777216,16776704);u=x[a+72>>2];m=x[a+32>>2];n=x[c>>2];f=yna(f,f>>31,i,i>>31);j=lb;i=f;f=x[a+68>>2];f=yna(f,f>>31,o,o>>31);o=i+f|0;i=lb+j|0;i=f>>>0>o>>>0?i+1|0:i;e=(e>>>21&2040)+32976|0;j=(((D(s,w[e+2>>1])+D(w[e>>1],t)|0)+D(r,w[e+4>>1])|0)+D(q,w[e+6>>1])<<8)/16384<<8;e=j;e=yna(g,g>>31,e,e>>31);f=e+o|0;g=lb+i|0;g=e>>>0>f>>>0?g+1|0:g;i=n;l=x[a+28>>2]+l|0;n=l>>12;e=f+8388608|0;e=((e>>>0<8388608?g+1|0:g)&16777215)<<8|e>>>24;g=(e|0)/256|0;x[c>>2]=i+D(n,g);k=k+m|0;m=k>>12;x[c+4>>2]=x[c+4>>2]+D(g,m);f=e-(j&u)|0;c=c+8|0;Tb(h+8|0,h);j=b;d=d-1|0;if(d){continue}break}b=x[h+8>>2];e=x[h+12>>2]}x[a>>2]=b;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=n;x[a+36>>2]=l;x[a+48>>2]=j;x[a+44>>2]=f;x[a+24>>2]=m;hb=h+16|0}function Nd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb+-64|0;hb=d;x[a+480180>>2]=b;b=up(a);eM(d,b);e=x[d+12>>2];c=a+1074320|0;x[c>>2]=x[d+8>>2];x[c+4>>2]=e;c=x[d+4>>2];x[a+1074312>>2]=x[d>>2];x[a+1074316>>2]=c;Xs(a+8|0,b);c=z[a+480192>>1];if(c){b=1;while(1){e=(((b&65535)<<2)+a|0)+900380|0;f=x[e>>2];if(f){_b(_t(f));c=z[a+480192>>1]}x[e>>2]=0;b=b+1|0;if((b&65535)>>>0<=c>>>0){continue}break}}x[a+480184>>2]=0;x[a+480188>>2]=0;x[a+480236>>2]=65536;x[a+480228>>2]=48;x[a+480232>>2]=48;v[a+480268|0]=5;x[a+480260>>2]=16;x[a+480264>>2]=32767;x[a+480204>>2]=125e4;x[a+480208>>2]=0;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+1074304>>2]=0;x[a+1074308>>2]=0;w[a+480192>>1]=0;wy(a,4);e=hb+-64|0;hb=e;b=a+484344|0;Sx(b);f=jg(b);c=Tx(e+8|0,b);x[114414]=0;T(1602,b|0,f|0,c|0);b=x[114414];x[114414]=0;a:{if((b|0)!=1){Ck(c);hb=e- -64|0;break a}a=N()|0;Ck(c);Q(a|0);p()}fO(a+484360|0);He(a+1304400|0);He(a+1304412|0);He(a+1304424|0);c=a+1304436|0;d=Sb(d,0,64);b=nM(d);Db(c,b);Db(c+12|0,b+12|0);Db(c+24|0,b+24|0);Db(c+36|0,b+36|0);Db(c+48|0,b+48|0);x[c+60>>2]=x[b+60>>2];zy(b);JA(a+1304500|0);pt(a+480248|0);if(x[a+480180>>2]&738230281){x[a+480208>>2]=x[a+480208>>2]|8388608}hb=d- -64|0}function w3(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-80|0;hb=e;a:{b:{c:{if(vi(a)){gp(e+72|0);break c}c=e+32|0;kn(c,a);x[114414]=0;c=R(2204,c|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break b}x[e+72>>2]=c;Mf(e+32|0)}if(vi(a)){c=a+36|0}else{c=x[e+72>>2]}d=x[a+8>>2];d:{if((d|0)==-1){d=yu(c);e:{if(!xd(c)){break e}while(1){if(!(C[Tc(c,f)>>3]+h<=b)){d=Tc(c,f);break e}h=C[d>>3]+h;f=f+1|0;if(xd(c)>>>0>f>>>0){continue}break}}b=b-h;break d}d=Tc(c,d)}f=a+24|0;c=x[f>>2];g=z[d+12>>1];x[114414]=0;P(2208,c|0,g|0);c=x[114414];x[114414]=0;if((c|0)!=1){f:{g=x[f>>2];i=y[a+64|0];c=QI(PQ(e+32|0,b),y[d+16|0],z[d+12>>1],x[d+8>>2]);x[114414]=0;d=x[c+12>>2];x[e+16>>2]=x[c+8>>2];x[e+20>>2]=d;d=x[c+20>>2];x[e+24>>2]=x[c+16>>2];x[e+28>>2]=d;d=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=d;X(2159,e+56|0,g|0,(i?7:1)|0,e+8|0);c=x[114414];x[114414]=0;if((c|0)==1){break f}g=e+56|0;c=$g(g);d=v[c+26|0]&1;i=x[(d?c+8|0:c+12|0)>>2];d=z[(d?c+20|0:c+22|0)>>1];b=C[c>>3];_l(g);w[x[f>>2]+1074438>>1]=d;w[x[f>>2]+1074440>>1]=d;x[x[f>>2]+1074428>>2]=i;x[x[f>>2]+1074392>>2]=-2;b=b+h;C[a+16>>3]=b;sk(e+72|0);hb=e+80|0;return+b}}f=N()|0;sk(e+72|0);break a}f=N()|0;Mf(e+32|0)}Q(f|0);p()}function Dja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;Ad(b,0);f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a:{if(c&34){if(d){x[b+24>>2]=f;break a}g=b,h=gg(jh(+(f+1408|0)*.0006510416666666666)*8363),x[g+24>>2]=h;break a}v[b+37|0]=(c|0)==16?f:f^128;v[b+36|0]=y[a+4|0]}v[e+15|0]=y[a+5|0];v[e+14|0]=64;g=b,h=y[rc(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;d=a+6|0;if((y[d|0]|y[d+1|0]<<8)>>>0<=256){w[b+28>>1]=y[d|0]|y[d+1|0]<<8;w[b+34>>1]=z[b+34>>1]|32}d=a+8|0;x[b>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+12|0;x[b+4>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+16|0;x[b+8>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+20|0;if(y[d|0]&16){w[b+34>>1]=z[b+34>>1]|2}if(y[d|0]&32){w[b+34>>1]=z[b+34>>1]|4}if(v[d+1|0]&1){w[b+34>>1]=z[b+34>>1]|8}if(y[d+1|0]&2){w[b+34>>1]=z[b+34>>1]|16}v[b+38|0]=y[(y[a+22|0]&7)+32960|0];v[b+39|0]=y[a+23|0];v[b+40|0]=y[a+24|0];v[b+41|0]=y[a+25|0];if((c|0)==32){v[e+13|0]=y[a+26|0];v[e+12|0]=64;g=b,h=y[rc(e+13|0,e+12|0)|0],w[g+32>>1]=h}c=a+27|0;x[b+12>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);a=a+31|0;x[b+16>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);hb=e+16|0}function AF(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=hb-16|0;hb=l;a:{b:{c:{if((c|0)<=36){g=y[a|0];if(g){break c}f=a;break b}x[114240]=28;d=0;e=0;break a}f=a;d:{while(1){if(!kk(g<<24>>24)){break d}g=y[f+1|0];f=f+1|0;if(g){continue}break}break b}e:{g=y[f|0];switch(g-43|0){case 0:case 2:break e;default:break b}}j=(g|0)==45?-1:0;f=f+1|0}f:{if(!((c|16)!=16|y[f|0]!=48)){n=1;if((y[f+1|0]&223)==88){f=f+2|0;m=16;break f}f=f+1|0;m=c?c:8;break f}m=c?c:10}c=0;while(1){g:{g=-48;i=v[f|0];h:{if((i-48&255)>>>0<10){break h}g=-87;if((i-97&255)>>>0<26){break h}g=-55;if((i-65&255)>>>0>25){break g}}i=g+i|0;if((i|0)>=(m|0)){break g}Ve(l,m,0,0,0,k,h,0,0);g=1;i:{if(x[l+8>>2]|x[l+12>>2]){break i}o=yna(k,h,m,0);p=lb;if((p|0)==-1&(i^-1)>>>0<o>>>0){break i}h=p;k=i+o|0;h=k>>>0<i>>>0?h+1|0:h;n=1;g=c}f=f+1|0;c=g;continue}break}if(b){x[b>>2]=n?f:a}j:{k:{if(c){x[114240]=68;a=d&1;j=a?0:j;k=d;h=e;break k}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break j}a=d&1}if(!(a|j)){x[114240]=68;a=d;d=a-1|0;e=e-!a|0;break a}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break j}x[114240]=68;break a}a=j^k;d=a-j|0;b=j>>31;e=(b^h)-((a>>>0<j>>>0)+b|0)|0}hb=l+16|0;lb=e;return d}function Ffa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-32|0;hb=e;i=x[a+12>>2];f=i;a:{b:{c:{g=x[a+8>>2];d:{if((f|0)<=1&g>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&g>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&g>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&g>>>0>2147483648|f>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}k=x[a+16>>2];l=x[a+24>>2];m=x[a+20>>2];j=x[a+4>>2];b=x[a>>2];x[e+24>>2]=b;x[e+28>>2]=j;x[e+16>>2]=g;x[e+20>>2]=f;g=a;if(d){while(1){a=x[e+24>>2];h=(((x[e+28>>2]&2147483647)<<1|a>>>31)&-2)+k|0;a=(a>>>16&65520)+i|0;n=w[a+14>>1];o=w[a+12>>1];p=w[a+10>>1];q=w[a+8>>1];r=w[a+6>>1];s=w[a+4>>1];t=w[a+2>>1];f=w[a>>1];b=0;a=1;while(1){x[(e+8|0)+(b<<2)>>2]=(((((((D(v[(b|-4)+h|0],t)+D(v[(b|-6)+h|0],f)|0)+D(v[(b|-2)+h|0],s)|0)+D(v[b+h|0],r)|0)+D(v[(b|2)+h|0],q)|0)+D(v[(b|4)+h|0],p)|0)+D(v[(b|6)+h|0],o)|0)+D(v[(b|8)+h|0],n)<<8)/32768;j=a;a=0;b=1;if(j){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],m);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],l);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}b=x[e+24>>2];j=x[e+28>>2]}x[g>>2]=b;x[g+4>>2]=j;hb=e+32|0}function pia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(x[a+4>>2]!=x[yb(a)>>2]){c=hb-16|0;hb=c;x[c>>2]=a;d=x[a+4>>2];x[c+4>>2]=d;x[c+8>>2]=d+56;d=yb(a);a=x[c+4>>2];x[114414]=0;T(948,d|0,a|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+56;Jb(c);hb=c+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}h=hb-32|0;hb=h;j=yb(a);f=h+8|0;d=Lk(a)+1|0;e=hb-16|0;hb=e;x[e+12>>2]=d;g=hb-16|0;hb=g;yb(a);x[g+12>>2]=76695844;x[114414]=0;x[g+8>>2]=2147483647;i=O(35,g+12|0,g+8|0)|0;c=x[114414];x[114414]=0;b:{if((c|0)!=1){hb=g+16|0;c=x[i>>2];break b}S(0)|0;zb();p()}c:{if(c>>>0>=d>>>0){d=Kn(a);if(d>>>0<c>>>1>>>0){x[e+8>>2]=d<<1;c=x[_c(e+8|0,e+12|0)>>2]}hb=e+16|0;d=c;break c}Vc();p()}i=Lk(a);c=0;e=hb-16|0;hb=e;x[e+12>>2]=0;Qe(f+12|0,j);if(d){c=EP(d);x[e+4>>2]=d;x[e>>2]=c;c=x[e>>2];g=x[e+4>>2]}else{g=0}x[f>>2]=c;d=D(i,56)+c|0;x[f+8>>2]=d;x[f+4>>2]=d;k=ic(f),l=D(g,56)+c|0,x[k>>2]=l;hb=e+16|0;d=x[f+8>>2];x[114414]=0;T(948,j|0,d|0,b|0);b=x[114414];x[114414]=0;d:{e:{if((b|0)==1){break e}x[f+8>>2]=x[f+8>>2]+56;x[114414]=0;P(949,a|0,f|0);a=x[114414];x[114414]=0;if((a|0)==1){break e}LP(f);hb=h+32|0;break d}a=N()|0;LP(f);Q(a|0);p()}}function bfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-48|0;hb=e;h=x[a+16>>2];x[e+24>>2]=a+112;x[e+16>>2]=0;x[e+20>>2]=0;k=e,l=Of(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0),x[k+28>>2]=l;f=x[a+128>>2];x[e+36>>2]=0;x[e+32>>2]=f;a:{if(!f){break a}b=a+8|0;k=e,l=Sf(b,f),x[k+16>>2]=l;x[e+20>>2]=lb;k=e,l=Te(b,d),x[k+40>>2]=l;x[e+44>>2]=lb;tf(a,e+40|0);if(lb>>>0<=A[a+76>>2]){break a}x[e+36>>2]=d}i=x[a+24>>2];j=x[a+20>>2];f=x[a+4>>2];b=x[a>>2];x[e+8>>2]=b;x[e+12>>2]=f;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;g=a;if(d){while(1){f=x[e+36>>2]-1|0;x[e+36>>2]=f;b=x[e+8>>2];a=x[e+12>>2];if(!f){x[e+16>>2]=0;x[e+20>>2]=0}f=a+h|0;x[e+40>>2]=b;x[e+44>>2]=0;b=x[e+32>>2];if((b|0)>0){while(1){zj(x[e+24>>2],v[f+x[e+44>>2]|0]<<6);yj(x[e+24>>2],4);a=b>>>0>1;Tb(e+40|0,e+16|0);b=b-1|0;if(a){continue}break}}d=d-1|0;a=x[e+24>>2];Tb(a,a+8|0);b=x[e+24>>2];a=x[b+4>>2];if(a){zj(b,v[f+x[e+44>>2]|0]<<6);yj(x[e+24>>2],a);b=x[e+24>>2];a=x[b>>2];x[b>>2]=a;x[b+4>>2]=0}a=Lp(b,x[e+28>>2]);x[c>>2]=x[c>>2]+D(a,j);x[c+4>>2]=x[c+4>>2]+D(a,i);c=c+8|0;Tb(e+8|0,e);if(d){continue}break}b=x[e+8>>2];f=x[e+12>>2]}x[g>>2]=b;x[g+4>>2]=f;hb=e+48|0}function jca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0,q=0,r=0,s=0;i=hb-16|0;hb=i;r=i,s=D(x[a>>2],Je(a)),x[r+12>>2]=s;xc(i+12|0,c>>>3|0);c=Cb(b);k=C[e+8>>3];e=x[i+12>>2];if(e){while(1){f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);j=f&16711680;h=j>>>8|0;o=j<<24;m=f&-16777216;j=m>>>24|0;g=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);l(0,o|m<<8|(((g&255)<<24|f>>>8)&-16777216|((g&16777215)<<8|f>>>24)&16711680|(g>>>8&65280|g>>>24)));f=h|j|(f<<24|(f&65280)<<8);h=0;l(1,f|(h|h));k=I(F(+n()),k);c=c+8|0;e=e-1|0;if(e){continue}break}}c=k==0;a:{if(c){break a}e=x[i+12>>2];if(!e){break a}q=c?1:1/k;c=x[a+20>>2];while(1){g=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);m=g<<24|(g&65280)<<8;f=g&16711680;h=f>>>8|0;o=f<<24;f=g&-16777216;j=f>>>24|0;a=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);l(0,o|f<<8|(((a&255)<<24|g>>>8)&-16777216|((a&16777215)<<8|g>>>24)&16711680|(a>>>8&65280|a>>>24)));a=h|j|m;h=0;l(1,a|(h|h));p=Qd(Fg(+n()*q)*32768);b:{if(F(p)<2147483648){a=~~p;break b}a=-2147483648}r=c,s=Uc(a),w[r>>1]=s;b=b+8|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){C[d>>3]=k}hb=i+16|0;return x[i+12>>2]<<3}function bea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+808|0;d=a+16|0;while(1){x[d+16>>2]=0;x[d+20>>2]=0;x[d+36>>2]=0;v[d+42|0]=1;w[d+40>>1]=257;x[d+24>>2]=0;x[d+28>>2]=0;w[d+32>>1]=0;d=d+44|0;if((c|0)!=(d|0)){continue}break}d=a+3832|0;while(1){x[c>>2]=0;x[c+4>>2]=0;x[c+68>>2]=0;x[c+72>>2]=0;x[c+24>>2]=0;x[c+28>>2]=0;w[c+20>>1]=511;x[c+16>>2]=-1;w[c+14>>1]=1;w[c+6>>1]=0;w[c+8>>1]=0;w[c+10>>1]=0;w[c+12>>1]=0;v[c+73|0]=0;v[c+74|0]=0;v[c+75|0]=0;v[c+76|0]=0;v[c+77|0]=0;v[c+78|0]=0;v[c+79|0]=0;v[c+80|0]=0;c=c+84|0;if((d|0)!=(c|0)){continue}break}d=0;x[a+3832>>2]=0;x[a+3836>>2]=0;c=a+3837|0;v[c|0]=0;v[c+1|0]=0;v[c+2|0]=0;v[c+3|0]=0;v[c+4|0]=0;v[c+5|0]=0;v[c+6|0]=0;v[c+7|0]=0;while(1){Ue((D(d,84)+a|0)+808|0,a);d=d+1|0;if((d|0)!=36){continue}break}while(1){x[(D(e,44)+a|0)+32>>2]=a;e=e+1|0;if((e|0)!=18){continue}break}e=0;while(1){d=x[(e<<2)+25456>>2];c=(D(e,44)+a|0)+16|0;a:{if(!(!(1<<e&3591)|e>>>0>11)){f=c;c=D(d,84)+a|0;$N(f,c+808|0,c+1060|0,c+1312|0,c+1564|0);break a}f=c;c=D(d,84)+a|0;$N(f,c+808|0,c+1060|0,0,0)}e=e+1|0;if((e|0)!=18){continue}break}e=0;while(1){Bn((D(e,84)+a|0)+808|0);e=e+1|0;if((e|0)!=36){continue}break}_N(a,b);return a|0}function h_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=hb-160|0;hb=a;x[a+144>>2]=c;x[a+152>>2]=b;x[a+20>>2]=2542;b=Pd(a+24|0,a+32|0,a+20|0);x[114414]=0;Dc(a+16|0,e);h=x[114414];x[114414]=0;a:{b:{c:{d:{if((h|0)!=1){x[114414]=0;h=R(21,a+16|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break b}v[a+15|0]=0;e=x[e+4>>2];x[114414]=0;c=pa(2543,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break b}if(!c){break c}He(g);if(!y[a+15|0]){break d}x[114414]=0;c=O(22,h|0,45)|0;d=x[114414];x[114414]=0;if((d|0)==1){break b}x[114414]=0;P(107,g|0,c|0);c=x[114414];x[114414]=0;if((c|0)!=1){break d}break b}c=N()|0;break a}x[114414]=0;d=O(22,h|0,48)|0;c=x[114414];x[114414]=0;if((c|0)==1){break b}c=x[b>>2];e=x[a+20>>2];h=e-1|0;d=d&255;while(1){if(!((d|0)!=y[c|0]|c>>>0>=h>>>0)){c=c+1|0;continue}break}x[114414]=0;U(2552,g|0,c|0,e|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break c}break b}x[114414]=0;c=O(2486,a+152|0,a+144|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break b}if(c){x[f>>2]=x[f>>2]|2}c=x[a+152>>2];Ob(a+16|0);Jc(b);hb=a+160|0;return c|0}c=N()|0;Ob(a+16|0)}Jc(b);Q(c|0);p()}function F8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=hb-16|0;hb=h;if(!y[a+4242|0]){Gx(a);a:{if(!y[a+4240|0]){break a}e=$L(x[a+16>>2]);if(e==C[a+4288>>3]){break a}C[a+4288>>3]=e;Hs(a)}g=a+4256|0;b:{if(y[a+4244|0]){if(!(C[g>>3]<=1)){C[g>>3]=1}break b}i=(x[a+4232>>2]&-2)!=4;e=C[g>>3];c:{if(F(e)<2147483648){f=~~e;break c}f=-2147483648}if(!(i|(f|0)<=0)){Fx(a);e=C[a+4256>>3]}C[g>>3]=e-+(f|0)}e=0;d:{e:{switch(x[a+4232>>2]){case 0:e=oi(C[a+4256>>3]*6.283185307179586);break d;case 1:e=F(C[a+4256>>3]+-.5)*-4+1;break d;case 2:e=C[a+4256>>3];e=e+e+-1;break d;case 3:e=C[a+4256>>3]<.5?-1:1;break d;case 4:e=C[a+4272>>3];break d;case 5:break e;default:break d}}e=C[a+4256>>3];j=e*e*e*((e*6+-15)*e+10);e=C[a+4272>>3];e=j*(C[a+4280>>3]-e)+e}C[h+8>>3]=(y[a+4241|0]?-e:e)*+B[a+4220>>2]+ +B[a+4224>>2];kN(h+8|0,1);f=sj(a);f:{if(!f){break f}g=x[a+4236>>2];if(y[a+4243|0]){l=f,m=g>>>8&15|176|(g&127)<<8|Xt(C[h+8>>3]*127)<<16,k=x[x[f>>2]+68>>2],mb[k](l|0,m|0)|0;break f}if((g|0)<0){break f}mb[x[x[f>>2]+44>>2]](f,g,E(C[h+8>>3]))}C[a+4256>>3]=C[a+4256>>3]+C[a+4264>>3]*+(d>>>0)}f=a;a=a+44|0;zi(f,b,c,Od(a,0),Od(a,1),d);hb=h+16|0}function AY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;j=hb-16|0;hb=j;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!y[i|0]){break a}i=i+1|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}l=x[b+4>>2];x[j+8>>2]=x[b>>2];x[j+12>>2]=l;k=hb-16|0;hb=k;x[k+12>>2]=x[a+8>>2];m=Hh(k+8|0,k+12|0);x[114414]=0;l=EF(f,e,i-c|0,g-f>>2,b);n=x[114414];x[114414]=0;e:{if((n|0)!=1){Ne(m);hb=k+16|0;break e}a=N()|0;Ne(m);Q(a|0);p()}f:{g:{h:{i:{if((l|0)==-1){while(1){j:{x[h>>2]=f;if(x[e>>2]==(c|0)){break j}g=1;k:{l:{m:{b=FE(f,c,i-c|0,j+8|0,x[a+8>>2]);switch(b+2|0){case 2:break k;case 1:break m;case 0:break g;default:break l}}x[e>>2]=c;break i}g=b}c=c+g|0;f=x[h>>2]+4|0;continue}break}x[e>>2]=c;break d}f=x[h>>2]+(l<<2)|0;x[h>>2]=f;if((f|0)==(g|0)){break f}c=x[e>>2];if((d|0)==(i|0)){i=d;continue}if(!FE(f,c,1,b,x[a+8>>2])){break h}}a=2;break c}x[h>>2]=x[h>>2]+4;c=x[e>>2]+1|0;x[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!y[i|0]){break b}i=i+1|0;continue}}x[e>>2]=c;a=1;break c}c=x[e>>2]}a=(c|0)!=(d|0)}hb=j+16|0;return a|0}f=x[h>>2];continue}}function aI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0);e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;b=x[a+8>>2];x[e+28>>2]=e+36;x[e+24>>2]=e+40;c=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=c;x[e+16>>2]=a;x[e+20>>2]=e+44;c=x[e+20>>2];x[e>>2]=x[e+16>>2];x[e+4>>2]=c;a:{b:{switch(x[b+40>>2]){case 0:os(e,b);break a;case 2:os(e,yb(b));break a;case 3:i=ah(b);d=0;b=hb-80|0;hb=b;c=x[e>>2];h=x[c+4>>2];g=x[c+24>>2];x[b+40>>2]=x[c+20>>2];x[b+44>>2]=g;g=x[c+16>>2];x[b+32>>2]=x[c+12>>2];x[b+36>>2]=g;Nh(b- -64|0,b+32|0,h);c=Mc(b+48|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);h=x[x[e+12>>2]>>2];g=x[x[e+8>>2]>>2];f=x[b+76>>2];x[b+24>>2]=x[b+72>>2];x[b+28>>2]=f;f=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=f;x[b+8>>2]=x[c+8>>2];f=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=f;if(h){f=b+16|0;while(1){c=0;if(g){while(1){j=x[Rf(b,c,d)>>2];$e(i,c);k=In(f,c,d),l=E(E(j|0)*E(7.450580596923828e-9)),B[k>>2]=l;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:os(e,yb(b));break a;default:break b}}os(e,yb(b))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function S3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=hb-2144|0;hb=b;Sb(b+96|0,0,2048);a:{b:{c:{f=x[c+4>>2];if(!f){a=ec(8);x[114414]=0;b=O(118,b+80|0,6434)|0;c=x[114414];x[114414]=0;if((c|0)==1){break c}a=oc(a,b);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}c=N()|0;xb(b);break b}g=x[c>>2];d=x[c+12>>2];c=x[c+8>>2];x[b+72>>2]=c;x[b+76>>2]=d;e=x[b+76>>2];x[b+24>>2]=x[b+72>>2];x[b+28>>2]=e;x[b+68>>2]=f;x[b+64>>2]=g;e=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=e;h=FP(b+16|0);if(h){x[b+48>>2]=c;x[b+52>>2]=d;c=x[b+52>>2];x[b+8>>2]=x[b+48>>2];x[b+12>>2]=c;x[b+44>>2]=f;x[b+40>>2]=g;c=x[b+44>>2];x[b>>2]=x[b+40>>2];x[b+4>>2]=c;c=AP(b)}else{c=0}x[b+56>>2]=c;x[b+60>>2]=0;d=0;c=2048;while(1){if(c){e=mb[f|0](g,(b+96|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}a=Ws(a,$l(b+32|0,Cb(b+96|0),d),h?b+56|0:0);if(a+1>>>0>=3){a=ec(8);x[114414]=0;b=O(118,b+80|0,4262)|0;c=x[114414];x[114414]=0;if((c|0)!=1){a=oc(a,b);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}c=N()|0;xb(b);break b}c=N()|0;hc(a);break b}hb=b+2144|0;return a|0}c=N()|0;hc(a)}Q(c|0)}p()}function nX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(tg(a,x[b+8>>2],e)){Pv(b,c,d);return}a:{if(tg(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;if(x[b+44>>2]!=4){f=a+16|0;h=f+(x[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}w[b+52>>1]=0;Ov(f,b,c,c,1,e);if(y[b+54|0]){break d}e:{if(!y[b+53|0]){break e}if(y[b+52|0]){d=1;if(x[b+24>>2]==1){break c}g=1;if(y[a+8|0]&2){break e}break c}g=1;if(!(v[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}x[b+44>>2]=a;if(d&1){break a}}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}g=x[a+12>>2];h=a+16|0;pr(h,b,c,d,e);f=a+24|0;g=h+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=x[a+8>>2];if(!(!(a&2)&x[b+36>>2]!=1)){while(1){if(y[b+54|0]){break a}pr(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(y[b+54|0]|x[b+36>>2]==1){break a}pr(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(y[b+54|0]|x[b+36>>2]==1&x[b+24>>2]==1){break a}pr(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function mp(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=E(0),h=E(0),i=0,j=0,k=0,l=E(0);c=x[a+36>>2];if(!c){Di(a+16|0);return}a:{b:{c:{switch(z[a>>1]){case 3:d=a+16|0;if(c>>>0>=1001){Di(d);return}Il(d,c);c=w[a+28>>1];e=a+4|0;Lb(e);b=1;g=Jl(a,c+1<<16>>16);c=w[a+28>>1];Lb(e);g=le(E(g/Jl(a,c)),E(E(1)/E(x[a+36>>2]+1>>>0)));if(!x[a+36>>2]){break b}while(1){h=le(g,E(b>>>0));k=Pb(d,b-1|0),l=h,B[k>>2]=l;b=b+1|0;if(b>>>0<=A[a+36>>2]){continue}break};break b;case 1:d=a+16|0;e=z[a+30>>1];if(e>>>0>1e3/(c>>>0)>>>0){Di(d);return}Il(d,D(c,e));c=w[a+28>>1];Lb(a+4|0);b=z[a+30>>1];if((c|0)>=0){c=(c>>>0)%(b>>>0)|0}else{c=b+(((c^-1)>>>0)%(b>>>0)^-1)|0}if(!e){break b}while(1){b=z[a+30>>1];f=c+i<<16>>16;d:{if((f|0)>=0){b=(f>>>0)%(b>>>0)|0;break d}b=b+(((f^-1)>>>0)%(b>>>0)^-1)|0}f=1;j=b<<16>>16;g=le(E(Jl(a,b+1<<16>>16)/Jl(a,j)),E(E(1)/E(x[a+36>>2]+1>>>0)));b=1;if(x[a+36>>2]){while(1){h=le(g,E((b&65535)>>>0));k=Pb(d,(D(x[a+36>>2],j)+f|0)-1|0),l=h,B[k>>2]=l;b=b+1|0;f=b&65535;if(f>>>0<=A[a+36>>2]){continue}break}}i=i+1|0;if(e>>>0>(i&65535)>>>0){continue}break};break b;case 0:break a;default:break c}}Di(a+16|0);x[a+36>>2]=0}return}Di(a+16|0)}function kn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-80|0;hb=c;g=sx(a);e=b+24|0;a:{b:{if(Vh(x[e>>2]+484360|0)){if(Vh(x[e>>2]+484360|0)){a=0;while(1){f=x[e>>2];b=QI(QQ(c+40|0,1),a&255,0,0);x[114414]=0;d=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=d;d=x[b+20>>2];x[c+16>>2]=x[b+16>>2];x[c+20>>2]=d;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;X(2159,c- -64|0,f|0,0,c|0);b=x[114414];x[114414]=0;c:{d:{if((b|0)!=1){b=c- -64|0;i=c,j=bc(b),x[i+32>>2]=j;i=c,j=dc(b),x[i+24>>2]=j;if(Hb(c+32|0,c+24|0)){break d}break c}b=N()|0;break b}while(1){e:{b=x[c+32>>2];f=z[b+24>>1];h=C[b>>3];d=x[b+16>>2];b=c+40|0;x[b+16>>2]=a;x[b+12>>2]=f;x[b+8>>2]=d;C[b>>3]=h;x[114414]=0;P(2160,g|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break e}b=c+32|0;Ao(b);if(Hb(b,c+24|0)){continue}break c}break}b=N()|0;_l(c- -64|0);break b}_l(c- -64|0);a=a+1|0;if(Vh(x[e>>2]+484360|0)>>>0>a>>>0){continue}break}}hb=c+80|0;return}a=ec(8);x[114414]=0;c=O(118,c+40|0,3534)|0;b=x[114414];x[114414]=0;if((b|0)!=1){a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break b}b=N()|0;hc(a)}Mf(g);Q(b|0)}p()}function Iba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=hb-16|0;hb=h;i=hb-16|0;hb=i;while(1){f=hb-32|0;hb=f;b=vO(f);d=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);c=(g<<5)+a|0;e=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=e;v[c+1|0]=e>>>8;v[c+2|0]=e>>>16;v[c+3|0]=e>>>24;v[c+4|0]=d;v[c+5|0]=d>>>8;v[c+6|0]=d>>>16;v[c+7|0]=d>>>24;d=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);e=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[c+24|0]=e;v[c+25|0]=e>>>8;v[c+26|0]=e>>>16;v[c+27|0]=e>>>24;v[c+28|0]=d;v[c+29|0]=d>>>8;v[c+30|0]=d>>>16;v[c+31|0]=d>>>24;d=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);e=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[c+16|0]=e;v[c+17|0]=e>>>8;v[c+18|0]=e>>>16;v[c+19|0]=e>>>24;v[c+20|0]=d;v[c+21|0]=d>>>8;v[c+22|0]=d>>>16;v[c+23|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[c+8|0]=b;v[c+9|0]=b>>>8;v[c+10|0]=b>>>16;v[c+11|0]=b>>>24;v[c+12|0]=d;v[c+13|0]=d>>>8;v[c+14|0]=d>>>16;v[c+15|0]=d>>>24;hb=f+32|0;g=g+1|0;if((g|0)!=4e3){continue}break}hb=i+16|0;hb=h+16|0}function W3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{c=w[b>>1];b=hb-32|0;hb=b;x[114414]=0;O(15,b+24|0,a|0)|0;d=x[114414];x[114414]=0;b:{c:{d:{if((d|0)!=1){e:{if(!y[b+24|0]){break e}d=x[x[a>>2]-12>>2];h=x[(d+a|0)+4>>2];x[114414]=0;Dc(b+16|0,a+d|0);d=x[114414];x[114414]=0;f:{g:{h:{if((d|0)!=1){x[114414]=0;d=R(2359,b+16|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break h}Ob(b+16|0);e=el(b+8|0,a);f=x[x[a>>2]-12>>2];x[114414]=0;f=a+f|0;i=R(16,f|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break g}e=x[e>>2];x[114414]=0;j=d;d=c&65535;g=c;c=h&74;c=aa(2360,j|0,e|0,f|0,i|0,((c|0)==64?d:(c|0)==8?d:g)|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break g}x[b+16>>2]=c;if(!cl(b+16|0)){break e}c=x[x[a>>2]-12>>2];x[114414]=0;P(18,a+c|0,5);c=x[114414];x[114414]=0;if((c|0)!=1){break e}c=S(0)|0;break f}c=S(0)|0;break f}c=S(0)|0;Ob(b+16|0);break f}c=S(0)|0}Kf(b+24|0);break d}Kf(b+24|0);break c}c=S(0)|0}Y(c|0)|0;c=x[x[a>>2]-12>>2];x[114414]=0;W(19,a+c|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}_()}hb=b+32|0;break a}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}}function sc(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){Xa(a|0,b|0,c|0);return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if(!(a&3)){c=a;break b}if(!c){c=a;break b}c=a;while(1){v[c|0]=y[b|0];b=b+1|0;c=c+1|0;if(!(c&3)){break b}if(c>>>0<e>>>0){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+-64|0;if(f>>>0<c>>>0){break c}while(1){x[c>>2]=x[b>>2];x[c+4>>2]=x[b+4>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=x[b+12>>2];x[c+16>>2]=x[b+16>>2];x[c+20>>2]=x[b+20>>2];x[c+24>>2]=x[b+24>>2];x[c+28>>2]=x[b+28>>2];x[c+32>>2]=x[b+32>>2];x[c+36>>2]=x[b+36>>2];x[c+40>>2]=x[b+40>>2];x[c+44>>2]=x[b+44>>2];x[c+48>>2]=x[b+48>>2];x[c+52>>2]=x[b+52>>2];x[c+56>>2]=x[b+56>>2];x[c+60>>2]=x[b+60>>2];b=b- -64|0;c=c- -64|0;if(f>>>0>=c>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){x[c>>2]=x[b>>2];b=b+4|0;c=c+4|0;if(d>>>0>c>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e-4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){v[c|0]=y[b|0];v[c+1|0]=y[b+1|0];v[c+2|0]=y[b+2|0];v[c+3|0]=y[b+3|0];b=b+4|0;c=c+4|0;if(d>>>0>=c>>>0){continue}break}}if(c>>>0<e>>>0){while(1){v[c|0]=y[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function Q7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=E(0),q=0,r=0,s=0,t=E(0);a:{if(!x[a+4272>>2]){break a}i=a+44|0;if(!Bh(i)){break a}k=Od(i,0);l=Od(i,1);m=ld(i,0);n=ld(i,1);if(d){j=a+4256|0;f=x[a+4268>>2];o=d;while(1){e=B[l>>2];g=B[k>>2];s=Pb(j,f<<1),t=g,B[s>>2]=t;s=Pb(j,x[a+4268>>2]<<1|1),t=e,B[s>>2]=t;e=E(F(zJ(E(E(E(F(g))+E(F(e)))*E(536870912)),31,5)));g=B[a+4276>>2];e=E(e*E(4.656612873077393e-10));e=E(E(B[(g>e?4240:4236)+a>>2]*E(g-e))+e);B[a+4276>>2]=e;p=E(B[a+4232>>2]*E(4.656612873077393e-10));g=B[a+4244>>2];e=E(E(E(B[a+4248>>2]*E(2147483648))*E(g-E(I(e,g))))+E(2147483392));b:{if(e<E(4294967296)&e>=E(0)){f=~~e>>>0;break b}f=0}h=f<<5;q=h;r=h|-2147483648;h=f>>>0<67108864;e=E(p*E((h?q:r)>>>(h?31:32-(f>>>26|0)|0)>>>0));f=x[a+4272>>2];f=(((f+(x[a+4252>>2]+(x[a+4268>>2]<<12)|0)|0)-1|0)/4096|0)%(f|0)<<1;s=m,t=E(e*B[Pb(j,f)>>2]),B[s>>2]=t;s=n,t=E(e*B[Pb(j,f|1)>>2]),B[s>>2]=t;h=x[a+4268>>2];f=h-1|0;x[a+4268>>2]=f;if(!h){f=x[a+4272>>2]+f|0;x[a+4268>>2]=f}n=n+4|0;m=m+4|0;l=l+4|0;k=k+4|0;o=o-1|0;if(o){continue}break}}zi(a,b,c,ld(i,0),ld(i,1),d)}}function xl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;x[a+4>>2]=0;nj(e+8|0,a,1);if(y[e+8|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=x[x[a>>2]-12>>2];x[114414]=0;b=x[(a+b|0)+24>>2];d=x[114414];x[114414]=0;if((d|0)==1){break c}x[114414]=0;b=R(2354,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break c}if(ne(b,-1)){break b}x[a+4>>2]=x[a+4>>2]+1;if(!ne(b,c)){continue}break}d=0;break a}if(x[a+4>>2]>=(b|0)){break a}while(1){d:{d=x[x[a>>2]-12>>2];x[114414]=0;d=x[(a+d|0)+24>>2];f=x[114414];x[114414]=0;if((f|0)==1){break d}x[114414]=0;f=R(2354,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break d}if(ne(f,-1)){break b}x[a+4>>2]=x[a+4>>2]+1;d=0;if(ne(f,c)){break a}if(x[a+4>>2]<(b|0)){continue}break a}break}}Y(S(0)|0)|0;mj(x[x[a>>2]-12>>2]+a|0,1);b=x[x[a>>2]-12>>2];x[114414]=0;b=x[(a+b|0)+20>>2];c=x[114414];x[114414]=0;e:{f:{g:{if((c|0)!=1){if(!(b&1)){break g}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break e}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)==1){break f}Q(a|0);p()}_();d=1;break a}S(0)|0;zb()}p()}d=2}Jg(x[x[a>>2]-12>>2]+a|0,d)}hb=e+16|0;return a|0}function Lia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=hb+-64|0;hb=e;o=e,q=uf(a)>>>5|0,w[o+32>>1]=q;w[e+16>>1]=3999;o=c,q=z[Cf(e+32|0,e+16|0)>>1],w[o+480190>>1]=q;Ez(b,z[c+480190>>1],0);a:{if(z[c+480190>>1]){h=e+62|0;l=e+58|0;m=e+56|0;i=e+52|0;n=e+60|0;j=1;k=1;while(1){f=Zp(c,k&65535);d=e+32|0;Pt(a,d);Ad(f,0);_n(e,2,d);d=e+16|0;Ic(d,e);x[114414]=0;O(334,((j<<5)+c|0)+946304|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}d=e+16|0;xb(d);w[f+32>>1]=64;x[f+24>>2]=8287;g=y[n|0]|y[n+1|0]<<8;w[e+16>>1]=g<<8|g>>>8;w[e>>1]=64;o=f,q=z[Cf(d,e)>>1]<<2,w[o+30>>1]=q;d=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);x[f>>2]=d<<24|(d&65280)<<8|(d>>>8&65280|(d&-33554432)>>>24);d=y[m|0]|y[m+1|0]<<8;g=y[l|0]|y[l+1|0]<<8;g=(g<<8|g>>>8)&65535;b:{if(g>>>0<2){break b}d=(d<<8|d>>>8)&65535;g=d+g<<1;if(g>>>0>A[f>>2]){break b}x[f+16>>2]=g;x[f+12>>2]=d<<1;w[f+34>>1]=z[f+34>>1]|8}f=y[h|0]|y[h+1|0]<<8?(y[h|0]|y[h+1|0]<<8)==512:1;d=e+16|0;oe(d,b,j-1|0);he(d,f);k=k+1|0;j=k&65535;if(j>>>0<=z[c+480190>>1]){continue}break}}hb=e- -64|0;return}a=N()|0;xb(e+16|0);Q(a|0);p()}function _8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=sf(a);if(c>>>0<b>>>0){i=hb-32|0;hb=i;a:{b:{g=b-c|0;c:{if(g>>>0<=x[yb(a)>>2]-x[a+4>>2]>>11>>>0){d=hb-16|0;hb=d;x[d>>2]=a;b=x[a+4>>2];x[d+4>>2]=b;x[d+8>>2]=b+(g<<11);d:{b=x[d+4>>2];h=x[d+8>>2];if((b|0)!=(h|0)){while(1){c=yb(a);x[114414]=0;P(1684,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break d}b=b+2048|0;x[d+4>>2]=b;if((b|0)!=(h|0)){continue}break}}Jb(d);hb=d+16|0;break c}a=N()|0;Jb(d);Q(a|0);p()}j=yb(a);d=i+8|0;c=sf(a)+g|0;e=hb-16|0;hb=e;x[e+12>>2]=c;f=hb-16|0;hb=f;yb(a);x[f+12>>2]=2097151;x[114414]=0;x[f+8>>2]=2147483647;h=O(35,f+12|0,f+8|0)|0;b=x[114414];x[114414]=0;e:{if((b|0)!=1){hb=f+16|0;b=x[h>>2];break e}S(0)|0;zb();p()}f:{if(b>>>0>=c>>>0){c=uk(a);if(c>>>0<b>>>1>>>0){x[e+8>>2]=c<<1;b=x[_c(e+8|0,e+12|0)>>2]}hb=e+16|0;break f}Vc();p()}c=gK(d,b,sf(a),j);x[114414]=0;P(1682,c|0,g|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(1678,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}Ls(c)}hb=i+32|0;break a}a=N()|0;Ls(c);Q(a|0);p()}return}if(b>>>0<c>>>0){c=x[a>>2]+(b<<11)|0;sf(a);eK(a,c);hK(a)}}function Aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{e=b&63;if(Qk(c)>>>0>e>>>0){e=TR(c,e);g=hb-16|0;hb=g;v[a+12|0]=0;MR(a);f=hb-32|0;hb=f;b:{c:{if(vd(a)>>>0<15){if(wk(a)>>>0<15){break c}c=yb(a);c=po(f+8|0,15,Lb(a),c);x[114414]=0;P(333,a|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}_i(c)}hb=f+32|0;break b}Vc();p()}f=0-y[e+1|0]|0;while(1){c=e+(h<<1)|0;d=y[c+1|0];if(d){v[g+7|0]=64;f=d+(f<<16>>16)|0;d=eq(g+8|0,f&65535,y[rc(c+2|0,g+7|0)|0]);d:{if(A[a+4>>2]<A[yb(a)>>2]){KR(a,d);break d}i=hb-32|0;hb=i;j=yb(a);c=po(i+8|0,ze(a,Lb(a)+1|0),Lb(a),j);k=x[c+8>>2];x[114414]=0;T(741,j|0,k|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}x[c+8>>2]=x[c+8>>2]+4;x[114414]=0;P(333,a|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}_i(c);hb=i+32|0}h=h+1|0;if((h|0)!=15){continue}}break}c=y[e+32|0];v[a+14|0]=c>>>4;v[a+13|0]=c&15;c=y[e+31|0];e=c&15;v[a+15|0]=e;v[a+16|0]=e;if(c&16){v[a+12|0]=y[a+12|0]|4}if(c&32){v[a+12|0]=y[a+12|0]|2}hb=g+16|0}e:{if(b<<24>>24>=0){c=y[a+12|0]&-2;a=a+12|0;break e}b=od(a);c=y[a+12|0]&-2|b^1;a=a+12|0}v[a|0]=c;return}a=N()|0;_i(c);Q(a|0);p()}function cB(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{if((y[a|0]-16&255)>>>0<241){break a}b=a+1954|0;d=a+1698|0;while(1){if(v[d|0]<=-2){break a}d=d+1|0;if((b|0)!=(d|0)){continue}break}if(y[a+14|0]){break a}d=0;while(1){b:{e=(d<<4)+a|0;b=e+418|0;if(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24)){break b}b=e+422|0;if(y[(D(d,13)+a|0)+942|0]|(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))>>>0>1048575){break b}c=D(d,11)+a|0;g=c+1346|0;if(y[g|0]>15|y[c+1351|0]>3|y[c+1356|0]>3){break b}c:{if(!(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))){break c}c=e+430|0;if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))>>>0>1048574){break c}if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))>>>0>(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))>>>0){break b}e=e+426|0;if((y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))>>>0>(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))>>>0){break b}}d:{e:{if(f&1|(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))){break e}if(cd(g,23389,11)){break e}f=0;break d}f=1}h=d>>>0>30;d=d+1|0;if((d|0)==32){break b}if(!y[(D(d,13)+a|0)+14|0]){continue}}break}f=f&h}return f&1}function lH(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=E(0),o=0,q=0;a:{if(y[b+21|0]){o=1;j=x[e>>2];l=x[f>>2];b:{if((h|0)>0){q=D(d,g);m=x[b>>2];while(1){if(x[a+1396>>2]<=9){pk(a)}g=x[a+1392>>2];k=w[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=y[k+x[b+8>>2]|0];x[a+1392>>2]=i>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:k;break c}g=Dl(a,b)}if((g|0)>=x[b+2092>>2]?y[b+23|0]:0){break a}if((g|0)<0){if(!y[a+1376|0]){o=0;if(x[a+1384>>2]){break b}}fc(a,21);return 0}k=D(d,l);m=((m+k|0)+j|0)>(q|0)?(q-k|0)+j|0:m;k=D(g,x[b>>2]);d:{if(y[b+22|0]){g=0;n=E(0);if((m|0)<=0){break d}while(1){n=E(B[x[b+28>>2]+(g+k<<2)>>2]+n);i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=B[i>>2]+n}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}break d}g=0;if((m|0)<=0){break d}while(1){i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=B[i>>2]+B[x[b+28>>2]+(g+k<<2)>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}}h=h-m|0;if((h|0)>0){continue}break}}x[e>>2]=j;x[f>>2]=l}return o}fc(a,21);return 0}ea(3764,9049,1887,2880);p()}function bga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=hb-16|0;hb=h;g=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];i=x[a+44>>2];q=x[a+16>>2];e=x[a+4>>2];f=e;b=x[a>>2];x[h+8>>2]=b;x[h+12>>2]=e;e=x[a+12>>2];x[h>>2]=x[a+8>>2];x[h+4>>2]=e;a:{if(!d){m=k>>12;n=l>>12;break a}while(1){f=x[h+8>>2];b=x[h+12>>2]+q|0;r=v[b+1|0];p=v[b|0];e=x[a+60>>2];b=i;j=Xb(i,-16777216,16776704);i=x[a+64>>2];o=Xb(g,-16777216,16776704);s=x[a+72>>2];m=x[a+32>>2];n=x[c>>2];g=yna(i,i>>31,j,j>>31);i=lb;j=g;g=x[a+68>>2];g=yna(g,g>>31,o,o>>31);o=j+g|0;j=lb+i|0;j=g>>>0>o>>>0?j+1|0:j;i=((D(r-p|0,f>>>10&4194048)|0)/16384|0)+(p<<8)<<8;f=i;f=yna(e,e>>31,f,f>>31);g=f+o|0;e=lb+j|0;e=g>>>0<f>>>0?e+1|0:e;j=n;l=x[a+28>>2]+l|0;n=l>>12;f=g+8388608|0;f=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;e=(f|0)/256|0;x[c>>2]=j+D(n,e);k=k+m|0;m=k>>12;x[c+4>>2]=x[c+4>>2]+D(e,m);i=f-(i&s)|0;c=c+8|0;Tb(h+8|0,h);g=b;d=d-1|0;if(d){continue}break}b=x[h+8>>2];f=x[h+12>>2]}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=k;x[a+20>>2]=n;x[a+36>>2]=l;x[a+48>>2]=g;x[a+44>>2]=i;x[a+24>>2]=m;hb=h+16|0}
function sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0;j=hb-16|0;hb=j;x[j+12>>2]=c>>>4;x[j+8>>2]=x[a>>2];d=x[Mb(j+12|0,j+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);m=f<<24|(f&65280)<<8;g=f&16711680;h=g>>>8|0;i=g<<24;e=f&-16777216;g=e>>>24|0;i=i|e<<8;e=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);l(0,i|(((e&255)<<24|f>>>8)&-16777216|((e&16777215)<<8|f>>>24)&16711680|(e>>>8&65280|e>>>24)));e=g|h|m;h=0;l(1,e|(h|h));k=Qd(Fg(+n())*32768);a:{if(F(k)<2147483648){e=~~k;break a}e=-2147483648}o=a,p=Uc(e),w[o>>1]=p;f=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);m=f<<24|(f&65280)<<8;g=f&16711680;h=g>>>8|0;i=g<<24;e=f&-16777216;g=e>>>24|0;i=i|e<<8;e=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);l(0,i|(((e&255)<<24|f>>>8)&-16777216|((e&16777215)<<8|f>>>24)&16711680|(e>>>8&65280|e>>>24)));e=g|h|m;h=0;l(1,e|(h|h));k=Qd(Fg(+n())*32768);b:{if(F(k)<2147483648){e=~~k;break b}e=-2147483648}o=a,p=Uc(e),w[o+2>>1]=p;a=a+4|0;c=c+16|0;b=b-1|0;if(b){continue}break}}hb=j+16|0;return d<<4}function kfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-32|0;hb=e;i=x[a+40>>2];j=x[a+36>>2];k=x[a+16>>2];g=x[a+4>>2];f=x[a>>2];x[e+24>>2]=f;x[e+28>>2]=g;h=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=h;a:{if(!d){b=i>>12;h=j>>12;break a}l=b+24|0;while(1){b=x[e+24>>2];g=((((x[e+28>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;m=w[b+14>>1];n=w[b+12>>1];o=w[b+10>>1];p=w[b+8>>1];q=w[b+6>>1];r=w[b+4>>1];s=w[b+2>>1];t=w[b>>1];h=0;b=1;while(1){f=h<<1;x[(e+8|0)+(h<<2)>>2]=(((((D(w[(f|8)+g>>1],o)+D(w[(f|4)+g>>1],p)|0)+D(w[(f|12)+g>>1],n)|0)+D(w[(f|16)+g>>1],m)|0)/2|0)+((((D(w[(f|-8)+g>>1],s)+D(w[(f|-12)+g>>1],t)|0)+D(w[(f|-4)+g>>1],r)|0)+D(w[g+f>>1],q)|0)/2|0)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=x[a+32>>2];j=x[a+28>>2]+j|0;h=j>>12;x[c>>2]=x[c>>2]+D(h,x[e+8>>2]);i=b+i|0;b=i>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[e+12>>2]);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}f=x[e+24>>2];g=x[e+28>>2]}x[a>>2]=f;x[a+4>>2]=g;x[a+40>>2]=i;x[a+20>>2]=h;x[a+36>>2]=j;x[a+24>>2]=b;hb=e+32|0}function Cfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=hb-16|0;hb=f;e=x[a+12>>2];g=e;a:{b:{c:{h=x[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&h>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&h>>>0>2147483648|g>>>0>1){break b}}k=b+196648|0;break a}k=b+131112|0;break a}k=b+262184|0}m=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];l=b;e=x[a>>2];x[f+8>>2]=e;x[f+12>>2]=b;x[f>>2]=h;x[f+4>>2]=g;e:{if(!d){b=i>>12;h=j>>12;break e}while(1){g=x[a+32>>2];b=x[f+8>>2];j=x[a+28>>2]+j|0;h=j>>12;e=(x[f+12>>2]<<1)+m|0;b=(b>>>16&65520)+k|0;e=(((((((D(w[e-4>>1],w[b+2>>1])+D(w[e-6>>1],w[b>>1])|0)+D(w[e-2>>1],w[b+4>>1])|0)+D(w[e>>1],w[b+6>>1])|0)+D(w[e+2>>1],w[b+8>>1])|0)+D(w[e+4>>1],w[b+10>>1])|0)+D(w[e+6>>1],w[b+12>>1])|0)+D(w[e+8>>1],w[b+14>>1])|0)/32768|0;x[c>>2]=x[c>>2]+D(h,e);i=g+i|0;b=i>>12;x[c+4>>2]=x[c+4>>2]+D(e,b);c=c+8|0;Tb(f+8|0,f);d=d-1|0;if(d){continue}break}e=x[f+8>>2];l=x[f+12>>2]}x[a>>2]=e;x[a+4>>2]=l;x[a+40>>2]=i;x[a+20>>2]=h;x[a+36>>2]=j;x[a+24>>2]=b;hb=f+16|0}function aga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=hb-16|0;hb=h;g=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];i=x[a+44>>2];q=x[a+16>>2];e=x[a+4>>2];f=e;b=x[a>>2];x[h+8>>2]=b;x[h+12>>2]=e;e=x[a+12>>2];x[h>>2]=x[a+8>>2];x[h+4>>2]=e;a:{if(!d){m=k>>12;n=l>>12;break a}while(1){f=x[h+8>>2];b=(x[h+12>>2]<<1)+q|0;r=w[b+2>>1];p=w[b>>1];e=x[a+60>>2];b=i;j=Xb(i,-16777216,16776704);i=x[a+64>>2];o=Xb(g,-16777216,16776704);s=x[a+72>>2];m=x[a+32>>2];n=x[c>>2];g=yna(i,i>>31,j,j>>31);i=lb;j=g;g=x[a+68>>2];g=yna(g,g>>31,o,o>>31);o=j+g|0;j=lb+i|0;j=g>>>0>o>>>0?j+1|0:j;i=p+((D(r-p|0,f>>>18|0)|0)/16384|0)<<8;f=i;f=yna(e,e>>31,f,f>>31);g=f+o|0;e=lb+j|0;e=g>>>0<f>>>0?e+1|0:e;j=n;l=x[a+28>>2]+l|0;n=l>>12;f=g+8388608|0;f=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;e=(f|0)/256|0;x[c>>2]=j+D(n,e);k=k+m|0;m=k>>12;x[c+4>>2]=x[c+4>>2]+D(e,m);i=f-(i&s)|0;c=c+8|0;Tb(h+8|0,h);g=b;d=d-1|0;if(d){continue}break}b=x[h+8>>2];f=x[h+12>>2]}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=k;x[a+20>>2]=n;x[a+36>>2]=l;x[a+48>>2]=g;x[a+44>>2]=i;x[a+24>>2]=m;hb=h+16|0}function YH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0);e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=b;x[e+36>>2]=d;b=x[a+8>>2];x[e+28>>2]=e+36;x[e+24>>2]=e+40;c=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=c;x[e+16>>2]=a;x[e+20>>2]=e+44;c=x[e+20>>2];x[e>>2]=x[e+16>>2];x[e+4>>2]=c;a:{b:{switch(x[b+40>>2]){case 0:ns(e,b);break a;case 2:ns(e,yb(b));break a;case 3:i=ah(b);d=0;b=hb-80|0;hb=b;c=x[e>>2];g=x[c+4>>2];x[b+40>>2]=x[c+20>>2];h=x[c+16>>2];x[b+32>>2]=x[c+12>>2];x[b+36>>2]=h;ep(b- -64|0,b+32|0,g);c=Mc(b+48|0,x[x[e+4>>2]>>2],x[x[e+8>>2]>>2],x[x[e+12>>2]>>2]);g=x[x[e+12>>2]>>2];h=x[x[e+8>>2]>>2];x[b+24>>2]=x[b+72>>2];f=x[b+68>>2];x[b+16>>2]=x[b+64>>2];x[b+20>>2]=f;x[b+8>>2]=x[c+8>>2];f=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=f;if(g){f=b+16|0;while(1){c=0;if(h){while(1){j=x[Rf(b,c,d)>>2];$e(i,c);k=Rf(f,c,d),l=E(E(j|0)*E(7.450580596923828e-9)),B[k>>2]=l;c=c+1|0;if((h|0)!=(c|0)){continue}break}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}hb=b+80|0;break a;case 1:ns(e,yb(b));break a;default:break b}}ns(e,yb(b))}x[a+4>>2]=x[a+4>>2]+x[e+36>>2];hb=e+48|0}function maa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=hb+-64|0;hb=e;g=qn(a);a:{if(b-1025>>>0<4294966272){break a}f=x[a+12>>2];if((f|0)==(b|0)){break a}if(c){c=x[g+8>>2];if(A[c+40>>2]<b>>>0|A[c+36>>2]>b>>>0){break a}f=x[a+12>>2]}c=D(zk(a),b>>>0>f>>>0?b-f|0:f-b|0);b:{c:{if(A[a+12>>2]<b>>>0){d:{if(d){d=dc(a);break d}d=bc(a)}x[e+48>>2]=d;d=td(e+56|0,e+48|0);f=e+40|0;Zh(f);d=x[d>>2];x[114414]=0;Z(1580,a|0,d|0,c|0,f|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}a=S(75016)|0;break c}if(d){i=e,j=dc(a),x[i+48>>2]=j;i=e,j=VK(e+48|0,0-c|0),x[i+40>>2]=j;c=td(e+32|0,e+40|0);i=e,j=dc(a),x[i+16>>2]=j;d=x[td(e+24|0,e+16|0)>>2];c=x[c>>2];x[114414]=0;U(1581,a|0,c|0,d|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}a=S(75016)|0;break c}i=e,j=bc(a),x[i+40>>2]=j;d=td(e+8|0,e+40|0);i=e,j=bc(a),x[i+16>>2]=j;i=e,j=VK(e+16|0,c),x[i+48>>2]=j;c=x[td(e,e+48|0)>>2];d=x[d>>2];x[114414]=0;U(1581,a|0,d|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}a=S(75016)|0}if((ib|0)==(ca(75016)|0)){Y(a|0)|0;_();break a}Q(a|0);p()}x[a+12>>2]=b;h=1}hb=e- -64|0;return h|0}function Vd(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if(BD(b)){f=b>>>0<=4?4:b;b=a?a:1;a:{while(1){i=hb-16|0;hb=i;x[i+12>>2]=0;b:{c:{if((f|0)==8){a=sd(b);break c}if(f&3|f>>>0<4){break b}a=f>>>2|0;if(a-1&a|b>>>0>-64-f>>>0){break b}c=16;a=f>>>0<=16?16:f;d=a>>>0<=16?16:a;d:{if(!(d-1&d)){a=d;break d}while(1){a=c;c=a<<1;if(a>>>0<d>>>0){continue}break}}e:{if(b>>>0>=-64-a>>>0){x[114240]=48;c=0;break e}j=b>>>0<11?16:b+11&-8;e=sd((j+a|0)+12|0);c=0;if(!e){break e}c=e-8|0;f:{if(!(e&a-1)){a=c;break f}h=e-4|0;d=x[h>>2];g=a;a=((a+e|0)-1&0-a)-8|0;a=(a-c>>>0<=15?g:0)+a|0;g=a-c|0;e=(d&-8)-g|0;if(!(d&3)){c=x[c>>2];x[a+4>>2]=e;x[a>>2]=c+g;break f}x[a+4>>2]=e|x[a+4>>2]&1|2;d=a+e|0;x[d+4>>2]=x[d+4>>2]|1;x[h>>2]=g|x[h>>2]&1|2;d=c+g|0;x[d+4>>2]=x[d+4>>2]|1;_r(c,g)}d=x[a+4>>2];g:{if(!(d&3)){break g}c=d&-8;if(c>>>0<=j+16>>>0){break g}x[a+4>>2]=j|d&1|2;h=a+j|0;d=c-j|0;x[h+4>>2]=d|3;c=a+c|0;x[c+4>>2]=x[c+4>>2]|1;_r(h,d)}c=a+8|0}a=c}if(!a){break b}x[i+12>>2]=a}hb=i+16|0;a=x[i+12>>2];if(a){break a}a=x[115731];if(a){mb[a|0]();continue}break}da(Yj(ec(4))|0,75016,26);p()}return a}return Me(a)}function yma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-2608|0;hb=f;a=Cm(f+8|0,a);x[a+1056>>2]=0;x[a+1060>>2]=0;Sb(a+1064|0,0,1536);x[114414]=0;W(529,a|0);d=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)!=1){if((w[a+1064>>1]|w[a+1066>>1])>=0){if(!c){break d}while(1){x[114414]=0;j=O(228,a|0,1)|0;d=x[114414];x[114414]=0;if((d|0)==1){break f}d=0;while(1){x[114414]=0;e=O(228,a|0,1)|0;k=x[114414];x[114414]=0;if((k|0)==1){break g}d=w[(a+D(d,6)|0)+(e?1066:1064)>>1];h:{if((d|0)>255){break h}e=a+D(d,6)|0;g=y[e+1068|0];if(w[e+1064>>1]<0){break h}if(w[e+1066>>1]>=0){continue}}break}g=(j?-1:0)^g;i=(i&255)+(g&255)|0;v[b+h|0]=i;h=h+1|0;if((h|0)!=(c|0)){continue}break}break d}x[114414]=0;d=R(530,a|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break c}}b=S(75884)|0;break e}b=S(75884)|0;break e}b=S(75884)|0}if((ib|0)!=(ca(75884)|0)){break a}Y(b|0)|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)==1){break b}}x[114414]=0;d=R(530,a|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break c}b=N()|0;break a}Ab(a);hb=f+2608|0;return d|0}b=N()|0}Ab(a);Q(b|0);p()}function ZQ(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;g=z[c>>1];a:{if(y[d|0]<=4){while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Oe(a,f+15|0)){break a}d=y[f+15|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Oe(a,f+14|0)){break a}d=y[f+14|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!Oe(a,f+13|0)){break a}d=y[f+13|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break a}}while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Oe(a,f+12|0)){break a}d=y[f+12|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!Oe(a,f+11|0)){break a}d=y[f+11|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break}}hb=f+16|0}function Pfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;g=hb-16|0;hb=g;f=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];h=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];i=b;e=x[a>>2];x[g+8>>2]=e;x[g+12>>2]=b;b=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=b;a:{if(!d){b=f;break a}while(1){b=(x[g+8>>2]>>>21&2040)+32976|0;j=w[b+2>>1];e=(x[g+12>>2]<<1)+n|0;o=w[e>>1];p=w[b>>1];q=w[e-2>>1];r=w[b+4>>1];s=w[e+2>>1];t=w[b+6>>1];u=w[e+4>>1];e=x[a+60>>2];b=h;h=Xb(b,-16777216,16776704);i=x[a+64>>2];k=Xb(f,-16777216,16776704);v=x[a+72>>2];y=x[c>>2];f=yna(i,i>>31,h,h>>31);i=lb;h=(((D(j,o)+D(p,q)|0)+D(r,s)|0)+D(t,u)|0)/16384<<8;j=yna(e,e>>31,h,h>>31);e=j+f|0;f=lb+i|0;f=e>>>0<j>>>0?f+1|0:f;j=e;e=x[a+68>>2];i=yna(e,e>>31,k,k>>31);e=j+i|0;f=lb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;e=(f|0)/256|0;x[c>>2]=D(e,m)+y;x[c+4>>2]=x[c+4>>2]+D(e,l);h=f-(h&v)|0;c=c+8|0;Tb(g+8|0,g);f=b;d=d-1|0;if(d){continue}break}e=x[g+8>>2];i=x[g+12>>2]}x[a>>2]=e;x[a+4>>2]=i;x[a+48>>2]=b;x[a+44>>2]=h;hb=g+16|0}function Ep(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=a+1074312|0;d=$b(e,96);x[b+660>>2]=(d?0:x[b+660>>2])+c;a:{if(!(y[b+88|0]&2)|(!(x[a+480180>>2]&18)|A[b+84>>2]>c>>>0)){break a}d=x[b+84>>2];if(!d){break a}f=c;c=x[b+80>>2];c=((f-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(x[b+88>>2]&1&x[a+480180>>2]==16384)|0;b:{if(Af(b+810|0)){d=x[b+656>>2];if(d){d=z[fd(d+236|0,y[b+810|0]-1|0)>>1];if(!d|d>>>0>z[a+480190>>1]){break b}}if(y[a+480210|0]&32){d=c;c=x[b+660>>2];x[b+660>>2]=d+c}x[b>>2]=0;x[b+4>>2]=c;if((!(y[b+88|0]&2)|A[b+84>>2]>c>>>0)&A[b+76>>2]>c>>>0){break b}if(!(!$b(e,57)&x[a+480180>>2]!=16)){x[b+700>>2]=0;x[b+88>>2]=x[b+88>>2]|2097152;return}if(!(x[a+480180>>2]&1048581)){if($b(e,27)){if(y[a+480208|0]&4){c=x[b+76>>2];x[b>>2]=0;x[b+4>>2]=c;return}x[b>>2]=0;x[b+4>>2]=0;return}c=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=c;if(!(y[a+480208|0]&4)){break b}a=x[b+76>>2];if(a>>>0<5){break b}x[b>>2]=0;x[b+4>>2]=a-2;return}if(!(y[b+88|0]&2)|x[a+480180>>2]!=1){break b}a=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=a;return}if(!(x[a+480180>>2]&268582928)|A[b+76>>2]<=c>>>0){break b}x[b>>2]=0;x[b+4>>2]=c}}function Dfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-16|0;hb=g;h=x[a+12>>2];f=h;a:{b:{c:{e=x[a+8>>2];d:{if((f|0)<=1&e>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&e>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&e>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&e>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];k=x[a+4>>2];b=x[a>>2];x[g+8>>2]=b;x[g+12>>2]=k;x[g>>2]=e;x[g+4>>2]=f;e:{if(!d){e=i>>12;f=j>>12;break e}while(1){k=x[a+32>>2];b=x[g+8>>2];j=x[a+28>>2]+j|0;f=j>>12;e=x[g+12>>2]+l|0;b=(b>>>16&65520)+h|0;b=(((((((D(v[e-2|0],w[b+2>>1])+D(v[e-3|0],w[b>>1])|0)+D(v[e-1|0],w[b+4>>1])|0)+D(v[e|0],w[b+6>>1])|0)+D(v[e+1|0],w[b+8>>1])|0)+D(v[e+2|0],w[b+10>>1])|0)+D(v[e+3|0],w[b+12>>1])|0)+D(v[e+4|0],w[b+14>>1])<<8)/32768|0;x[c>>2]=x[c>>2]+D(f,b);i=k+i|0;e=i>>12;x[c+4>>2]=x[c+4>>2]+D(b,e);c=c+8|0;Tb(g+8|0,g);d=d-1|0;if(d){continue}break}b=x[g+8>>2];k=x[g+12>>2]}x[a>>2]=b;x[a+4>>2]=k;x[a+40>>2]=i;x[a+20>>2]=f;x[a+36>>2]=j;x[a+24>>2]=e;hb=g+16|0}function cE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;q=a;i=hb-1040|0;hb=i;r=x[114240];a:{b:{c:{a=i+16|0;l=z[((b>>>0<=153?b:0)<<1)+73872>>1]+71949|0;c=x[x[114284]+20>>2];if(c){j=x[c+4>>2];c=x[c>>2];e=x[c>>2]+1794895138|0;h=tl(x[c+8>>2],e);g=tl(x[c+12>>2],e);d=tl(x[c+16>>2],e);d:{if(j>>>2>>>0<=h>>>0){break d}k=j-(h<<2)|0;if((d|g)&3|(k>>>0<=g>>>0|d>>>0>=k>>>0)){break d}s=d>>>2|0;t=g>>>2|0;g=0;while(1){k=h>>>1|0;m=k+g|0;n=m<<1;d=c+(n+t<<2)|0;o=tl(x[d>>2],e);d=tl(x[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|y[c+(d+o|0)|0]){break d}d=pj(l,c+d|0);if(!d){g=c+(s+n<<2)|0;h=tl(x[g>>2],e);e=tl(x[g+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break d}f=y[c+(e+h|0)|0]?0:c+e|0;break d}if((h|0)==1){break d}d=(d|0)<0;h=d?k:h-k|0;g=d?g:m;continue}}}f=f?f:l;c=wf(f);e:{if(c>>>0>=1024){sc(a,f,1023);v[a+1023|0]=0;f=68;break e}sc(a,f,c+1|0);f=0}switch(f+1|0){case 1:break a;case 0:break c;default:break b}}f=x[114240]}a=17386;if((f|0)==28){break a}ra();p()}if(!y[a|0]){x[i>>2]=b;a=i+16|0;mw(a,1024,8876,i)}x[114240]=r;Ub(q,a);hb=i+1040|0}function q3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{g=x[b>>2];b=x[b+4>>2];c=hb-32|0;hb=c;x[114414]=0;O(15,c+24|0,a|0)|0;d=x[114414];x[114414]=0;b:{c:{d:{if((d|0)!=1){e:{if(!y[c+24|0]){break e}d=x[x[a>>2]-12>>2];x[114414]=0;Dc(c+16|0,a+d|0);d=x[114414];x[114414]=0;f:{g:{h:{if((d|0)!=1){x[114414]=0;d=R(2359,c+16|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break h}Ob(c+16|0);e=el(c+8|0,a);f=x[x[a>>2]-12>>2];x[114414]=0;f=a+f|0;h=R(16,f|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break g}e=x[e>>2];x[114414]=0;b=za(2362,d|0,e|0,f|0,h|0,g|0,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break g}x[c+16>>2]=b;if(!cl(c+16|0)){break e}b=x[x[a>>2]-12>>2];x[114414]=0;P(18,a+b|0,5);b=x[114414];x[114414]=0;if((b|0)!=1){break e}b=S(0)|0;break f}b=S(0)|0;break f}b=S(0)|0;Ob(c+16|0);break f}b=S(0)|0}Kf(c+24|0);break d}Kf(c+24|0);break c}b=S(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[114414]=0;W(19,a+b|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}_()}hb=c+32|0;break a}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}}function lfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-32|0;hb=e;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];g=x[a+4>>2];f=g;j=x[a>>2];x[e+24>>2]=j;x[e+28>>2]=f;g=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=g;a:{if(!d){b=h>>12;g=i>>12;break a}l=b+24|0;while(1){b=x[e+24>>2];f=(((x[e+28>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;m=w[b+14>>1];n=w[b+12>>1];o=w[b+10>>1];p=w[b+8>>1];q=w[b+6>>1];r=w[b+4>>1];s=w[b+2>>1];t=w[b>>1];b=0;g=1;while(1){x[(e+8|0)+(b<<2)>>2]=((((D(v[(b|4)+f|0],o)+D(v[(b|2)+f|0],p)|0)+D(v[(b|6)+f|0],n)|0)+D(v[(b|8)+f|0],m)<<8>>1)+(((D(v[(b|-4)+f|0],s)+D(v[(b|-6)+f|0],t)|0)+D(v[(b|-2)+f|0],r)|0)+D(v[b+f|0],q)<<8>>1)|0)/16384;j=g;g=0;b=1;if(j){continue}break}b=x[a+32>>2];i=x[a+28>>2]+i|0;g=i>>12;x[c>>2]=x[c>>2]+D(g,x[e+8>>2]);h=b+h|0;b=h>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[e+12>>2]);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}j=x[e+24>>2];f=x[e+28>>2]}x[a>>2]=j;x[a+4>>2]=f;x[a+40>>2]=h;x[a+20>>2]=g;x[a+36>>2]=i;x[a+24>>2]=b;hb=e+32|0}function Qfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=hb-16|0;hb=g;e=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];h=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];j=b;f=x[a>>2];x[g+8>>2]=f;x[g+12>>2]=b;b=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=b;a:{if(!d){b=e;break a}while(1){j=x[g+8>>2];b=x[g+12>>2]+n|0;o=v[b+2|0];p=v[b+1|0];q=v[b|0];r=v[b-1|0];f=x[a+60>>2];b=h;i=Xb(b,-16777216,16776704);h=x[a+64>>2];k=Xb(e,-16777216,16776704);s=x[a+72>>2];t=x[c>>2];e=yna(h,h>>31,i,i>>31);h=lb;i=e;e=x[a+68>>2];e=yna(e,e>>31,k,k>>31);k=i+e|0;i=lb+h|0;i=e>>>0>k>>>0?i+1|0:i;e=(j>>>21&2040)+32976|0;h=(((D(w[e+2>>1],q)+D(w[e>>1],r)|0)+D(w[e+4>>1],p)|0)+D(o,w[e+6>>1])<<8)/16384<<8;e=h;e=yna(f,f>>31,e,e>>31);j=e+k|0;f=lb+i|0;f=e>>>0>j>>>0?f+1|0:f;e=j+8388608|0;e=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;f=(e|0)/256|0;x[c>>2]=D(f,m)+t;x[c+4>>2]=x[c+4>>2]+D(f,l);h=e-(h&s)|0;c=c+8|0;Tb(g+8|0,g);e=b;d=d-1|0;if(d){continue}break}f=x[g+8>>2];j=x[g+12>>2]}x[a>>2]=f;x[a+4>>2]=j;x[a+48>>2]=b;x[a+44>>2]=h;hb=g+16|0}function l4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{c=x[b>>2];b=hb-32|0;hb=b;x[114414]=0;O(15,b+24|0,a|0)|0;d=x[114414];x[114414]=0;b:{c:{d:{if((d|0)!=1){e:{if(!y[b+24|0]){break e}d=x[x[a>>2]-12>>2];x[114414]=0;Dc(b+16|0,a+d|0);d=x[114414];x[114414]=0;f:{g:{h:{if((d|0)!=1){x[114414]=0;d=R(2359,b+16|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break h}Ob(b+16|0);e=el(b+8|0,a);f=x[x[a>>2]-12>>2];x[114414]=0;f=a+f|0;g=R(16,f|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break g}e=x[e>>2];x[114414]=0;c=aa(2360,d|0,e|0,f|0,g|0,c|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break g}x[b+16>>2]=c;if(!cl(b+16|0)){break e}c=x[x[a>>2]-12>>2];x[114414]=0;P(18,a+c|0,5);c=x[114414];x[114414]=0;if((c|0)!=1){break e}c=S(0)|0;break f}c=S(0)|0;break f}c=S(0)|0;Ob(b+16|0);break f}c=S(0)|0}Kf(b+24|0);break d}Kf(b+24|0);break c}c=S(0)|0}Y(c|0)|0;c=x[x[a>>2]-12>>2];x[114414]=0;W(19,a+c|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}_()}hb=b+32|0;break a}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}}function kH(a,b,c,d,e){var f=E(0),g=0,h=E(0),i=0,j=E(0),k=E(0);if(!(a&3)){if((a|0)>=4){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>>2|0;while(1){b=d-4|0;h=B[b>>2];j=B[d>>2];k=B[c>>2];B[c>>2]=j+k;g=c-4|0;f=B[g>>2];B[g>>2]=B[b>>2]+f;j=E(k-j);f=E(f-h);B[d>>2]=E(B[e>>2]*j)-E(B[e+4>>2]*f);B[b>>2]=E(B[e+4>>2]*j)+E(B[e>>2]*f);b=d-12|0;j=B[b>>2];g=c-8|0;f=B[g>>2];i=g;g=d-8|0;k=B[g>>2];B[i>>2]=k+f;i=c-12|0;h=B[i>>2];B[i>>2]=B[b>>2]+h;f=E(f-k);h=E(h-j);B[g>>2]=E(B[e+32>>2]*f)-E(B[e+36>>2]*h);B[b>>2]=E(B[e+36>>2]*f)+E(B[e+32>>2]*h);b=d-20|0;j=B[b>>2];g=c-16|0;f=B[g>>2];i=g;g=d-16|0;k=B[g>>2];B[i>>2]=k+f;i=c-20|0;h=B[i>>2];B[i>>2]=B[b>>2]+h;f=E(f-k);h=E(h-j);B[g>>2]=E(B[e+64>>2]*f)-E(B[e+68>>2]*h);B[b>>2]=E(B[e+68>>2]*f)+E(B[e+64>>2]*h);b=d-28|0;j=B[b>>2];g=c-24|0;f=B[g>>2];i=g;g=d-24|0;k=B[g>>2];B[i>>2]=k+f;i=c-28|0;h=B[i>>2];B[i>>2]=B[b>>2]+h;f=E(f-k);h=E(h-j);B[g>>2]=E(B[e+96>>2]*f)-E(B[e+100>>2]*h);B[b>>2]=E(B[e+100>>2]*f)+E(B[e+96>>2]*h);d=d-32|0;c=c-32|0;e=e+128|0;b=a>>>0>1;a=a-1|0;if(b){continue}break}}return}ea(11790,9049,2423,5182);p()}function Pz(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-32|0;hb=g;OQ(a,b);h=hb-16|0;hb=h;Ad(c,1);a=b+22|0;a=y[a|0]|y[a+1|0]<<8;x[c>>2]=((a<<8|a>>>8)&65535)<<1;v[c+37|0]=y[b+24|0]<<4;v[h+15|0]=y[b+25|0];v[h+14|0]=64;l=c,m=y[rc(h+15|0,h+14|0)|0]<<2,w[l+30>>1]=m;a=b+26|0;a=y[a|0]|y[a+1|0]<<8;f=(a<<8|a>>>8)&65535;a=f<<1;i=x[c>>2];j=f;f=b+28|0;f=y[f|0]|y[f+1|0]<<8;k=(f<<8|f>>>8)&65535;f=k<<1;a=k>>>0>=2?a+f>>>0<=i>>>0?a:i>>>0<j+f>>>0?a:j:a;a:{b:{switch(i|0){case 2:x[c>>2]=0;break a;case 0:break a;default:break b}}x[c+4>>2]=a;f=a+f|0;x[c+8>>2]=f;if(a>>>0>=i>>>0){a=i-1|0;x[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){x[c+4>>2]=0;x[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|f>>>0>=i>>>0|(!e|a))){x[c+8>>2]=0;break a}if(a>>>0>=f>>>0){break a}w[c+34>>1]=z[c+34>>1]|2}hb=h+16|0;lm(g,3,b);c=g+16|0;Ic(c,g);a=0;x[114414]=0;O(334,d|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){xb(g+16|0);e=d;while(1){if((y[e|0]-1&255)>>>0<=30){v[e|0]=32}a=a+1|0;e=d+a|0;if((a|0)!=32){continue}break}a=Qz(b);hb=g+32|0;return a}a=N()|0;xb(g+16|0);Q(a|0);p()}function g3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{f=C[b>>3];b=hb-32|0;hb=b;x[114414]=0;O(15,b+24|0,a|0)|0;c=x[114414];x[114414]=0;b:{c:{d:{if((c|0)!=1){e:{if(!y[b+24|0]){break e}c=x[x[a>>2]-12>>2];x[114414]=0;Dc(b+16|0,a+c|0);c=x[114414];x[114414]=0;f:{g:{h:{if((c|0)!=1){x[114414]=0;c=R(2359,b+16|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break h}Ob(b+16|0);d=el(b+8|0,a);e=x[x[a>>2]-12>>2];x[114414]=0;e=a+e|0;g=R(16,e|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break g}d=x[d>>2];x[114414]=0;c=Qa(2363,c|0,d|0,e|0,g|0,+f)|0;d=x[114414];x[114414]=0;if((d|0)==1){break g}x[b+16>>2]=c;if(!cl(b+16|0)){break e}c=x[x[a>>2]-12>>2];x[114414]=0;P(18,a+c|0,5);c=x[114414];x[114414]=0;if((c|0)!=1){break e}c=S(0)|0;break f}c=S(0)|0;break f}c=S(0)|0;Ob(b+16|0);break f}c=S(0)|0}Kf(b+24|0);break d}Kf(b+24|0);break c}c=S(0)|0}Y(c|0)|0;c=x[x[a>>2]-12>>2];x[114414]=0;W(19,a+c|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}_()}hb=b+32|0;break a}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}}function zO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0;if(Dj(a)){f=y[(Zd(y[a+819|0])?a+819|0:a+821|0)|0];if(!(!$b(d+1074312|0,34)|(!f|f>>>0>120))){f=y[gc(x[a+656>>2]+108|0,f-1|0)|0]}d=a;j=E(E(b*E(16))*E(x[a+704>>2]));e=x[x[a+656>>2]+44>>2];c=(c+f|0)-61<<16>>16;a:{b:{a=x[a+876>>2]+x[a+768>>2]|0;if(a){h=x[e+36>>2];if(h){break b}}b=Jl(e,a+c<<16>>16);break a}g=h+1|0;c:{if((a|0)>=0){f=a;a=(a|0)/(g|0)|0;f=f-D(g,a)|0;break c}f=h-((a^-1)%(g|0)|0)|0;a=((a+1|0)/(g|0)|0)-1|0}k=w[e+28>>1];i=e+4|0;Lb(i);b=E(1);c=a+c<<16>>16;d:{if((c|0)<(k|0)){break d}if((c|0)>(z[e+28>>1]+Lb(i)|0)-1<<16>>16){break d}if(!f){b=B[Pb(i,c-w[e+28>>1]|0)>>2];break a}a=z[e>>1];e:{if((a|0)==3){a=e+16|0;if(Lb(a)){b=B[Pb(a,f-1|0)>>2];break e}a=z[e>>1]}f:{if((a&65535)!=1){break f}a=e+16|0;if(!Lb(a)){break f}g=z[e+30>>1];if((c|0)>=0){g=(c>>>0)%(g>>>0)|0}else{g=g+(((c^-1)>>>0)%(g>>>0)^-1)|0}b=B[Pb(a,(D(g<<16>>16,h)+f|0)-1|0)>>2];break e}b=le(E(Jl(e,c+1<<16>>16)/Jl(e,c)),E(E(f|0)/E(g|0)))}b=E(B[Pb(i,c-w[e+28>>1]|0)>>2]*b)}}l=d,m=Li(E(j*b)),x[l+700>>2]=m}}function _x(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;f=a+2|0;if(!(y[f|0]==255|!y[f|0])){x[e+12>>2]=y[f|0]+1;x[e+8>>2]=10;Mg(b,x[be(e+12|0,e+8|0)>>2]);f=y[a+3|0];v[b+15|0]=f;v[b+16|0]=f;v[b+13|0]=y[a+4|0];v[b+14|0]=y[a+5|0];g=511;a:{b:{switch(c-1|0){case 1:d=4096;g=128;break a;case 0:break b;default:break a}}d=32768;g=1024}if(Lb(b)){i=g>>>1|d;d=0;while(1){h=(d<<2)+a|0;c=h+6|0;c=y[c|0]|y[c+1|0]<<8;j=Pb(b,d),k=c>>>4|0,w[j>>1]=k;c:{d:{if(!d){f=0;c=0;break d}c=d-1|0;if(z[Pb(b,d)>>1]>=z[Pb(b,c)>>1]){break c}f=d;c=z[Pb(b,c)>>1]+1|0}j=Pb(b,f),k=c,w[j>>1]=k}c=h+8|0;x[e+12>>2]=(((y[c|0]|y[c+1|0]<<8)<<16>>16)+i|0)/(g|0);x[e+8>>2]=0;x[e+4>>2]=64;c=x[dl(e+12|0,e+8|0,e+4|0)>>2];j=Pb(b,d),k=c,v[j+2|0]=k;d=d+1|0;if(Lb(b)>>>0>d>>>0){continue}break}}v[b+12|0]=y[b+12|0]&254|v[a|0]&1;if(y[a|0]&2){c=y[b+15|0];c=(Lb(b)>>>0>=c>>>0)<<2|y[b+12|0]&-5}else{c=y[b+12|0]&-5}v[b+12|0]=c;e:{f:{if(y[a|0]&4){c=y[b+13|0];if(c>>>0<=y[b+14|0]){break f}}a=y[b+12|0]&-3;break e}a=Lb(b);a=y[b+12|0]&-3|(a>>>0>=c>>>0)<<1}v[b+12|0]=a}hb=e+16|0}function Gq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=hb-16|0;hb=g;a:{if(!b){break a}if(c){d=Ed(g+8|0,a);c=hb-16|0;hb=c;x[c+12>>2]=b;a=x[d+4>>2];b:{if(!a){a=x[d>>2];break b}x[c+8>>2]=32-a;b=Mb(c+8|0,c+12|0);a=x[d>>2];b=x[b>>2];x[a>>2]=x[a>>2]|-1<<x[d+4>>2]&-1>>>x[c+8>>2]-b;b=x[c+12>>2]-b|0;x[c+12>>2]=b;a=a+4|0;x[d>>2]=a}x[c+4>>2]=-1;f=b>>>5|0;e=f;if(e){while(1){x[a>>2]=x[c+4>>2];a=a+4|0;e=e-1|0;if(e){continue}break}}a=x[c+12>>2];b=b&-32;e=a-b|0;x[c+12>>2]=e;if((a|0)!=(b|0)){a=x[d>>2]+(f<<2)|0;x[d>>2]=a;x[a>>2]=x[a>>2]|-1>>>32-e}hb=c+16|0;break a}d=Ed(g,a);c=hb-16|0;hb=c;x[c+12>>2]=b;a=x[d+4>>2];c:{if(!a){a=x[d>>2];break c}x[c+8>>2]=32-a;b=Mb(c+8|0,c+12|0);a=x[d>>2];b=x[b>>2];x[a>>2]=x[a>>2]&(-1<<x[d+4>>2]&-1>>>x[c+8>>2]-b^-1);b=x[c+12>>2]-b|0;x[c+12>>2]=b;a=a+4|0;x[d>>2]=a}x[c+4>>2]=0;f=b>>>5|0;e=f;if(e){h=x[c+4>>2];while(1){x[a>>2]=h;a=a+4|0;e=e-1|0;if(e){continue}break}}a=x[c+12>>2];b=b&-32;e=a-b|0;x[c+12>>2]=e;if((a|0)!=(b|0)){a=x[d>>2]+(f<<2)|0;x[d>>2]=a;x[a>>2]=x[a>>2]&(-1>>>32-e^-1)}hb=c+16|0}hb=g+16|0}function UL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{b:{switch(x[a+480224>>2]-1|0){default:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2]<<1;c=yna(c,c>>31,5e4,0);f=lb;b=x[_c(d+12|0,d+8|0)>>2];c=Cc(zna(c,f,b,b>>31),lb);break a;case 0:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2];c=yna(c,c>>31,1e4,0);f=lb;b=x[_c(d+12|0,d+8|0)>>2];c=Cc(zna(c,f,b,b>>31),lb);break a;case 1:break b}}e=+A[a+24620>>2]*60/(+A[b+44>>2]*1e-4*(+(yna(x[b+32>>2],0,x[b+40>>2],0)>>>0)+ +(lb>>>0)*4294967296));c:{d:{c=a+484344|0;if(!kg(c,z[b+60>>1])){break d}if(!(od(Zb(c,z[b+60>>1])+24|0)^1)){break d}c=TL(Zb(c,z[b+60>>1]));break c}c=a+480248|0}if(!od(c)){e=e*5.960464477539063e-8*+A[Pb(c,A[b+48>>2]%(Lb(c)>>>0)|0)>>2]}e:{if(F(e)<2147483648){c=~~e;break e}c=-2147483648}e=e-+(c>>>0)+C[b+8>>3];C[b+8>>3]=e;if(!(e<1)){C[b+8>>3]=e+-1;c=c+1|0;break a}if(C[a+1074384>>3]>-1){break a}C[b+8>>3]=e+1;c=c-1|0}b=yna(x[a+480244>>2],0,c,0);a=lb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=jd((a&65535)<<16|b>>>16,a>>>16|0);hb=d+16|0;return(a?a:1)|0}function vz(a,b){a=a|0;b=b|0;a:{b:{switch((y[a+3|0]|64)+-64|0){case 0:v[a+3|0]=y[a+5|0]?42:0;return;case 1:v[a+3|0]=16;return;case 2:v[a+3|0]=12;return;case 3:v[a+3|0]=14;if(b){break a}b=a;a=y[a+5|0];v[b+5|0]=D(a>>>4|0,10)+(a&15);return;case 4:v[a+3|0]=11;return;case 5:v[a+3|0]=3;return;case 6:v[a+3|0]=2;return;case 7:v[a+3|0]=4;return;case 8:v[a+3|0]=5;return;case 9:v[a+3|0]=18;return;case 10:v[a+3|0]=1;return;case 11:v[a+3|0]=7;return;case 12:v[a+3|0]=6;return;case 13:v[a+3|0]=21;return;case 14:v[a+3|0]=22;return;case 15:v[a+3|0]=10;return;case 16:v[a+3|0]=29;return;case 17:v[a+3|0]=15;return;case 18:v[a+3|0]=8;return;case 19:v[a+3|0]=20;return;case 20:v[a+3|0]=17;return;case 21:v[a+3|0]=26;return;case 22:v[a+3|0]=23;return;case 23:v[a+3|0]=24;return;case 24:v[a+3|0]=9;return;case 25:v[a+3|0]=27;return;case 26:v[a+3|0]=31;return;case 28:v[a+3|0]=b?32:31;return;case 29:v[a+3|0]=33;return;case 27:v[a+3|0]=34;return;case 50:v[a+3|0]=b?25:0;return;case 51:v[a+3|0]=b?30:0;return;default:break b}}v[a+3|0]=0}}function Fd(a){var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;x[c+12>>2]=0;x[c+8>>2]=2611;b=x[c+12>>2];x[c>>2]=x[c+8>>2];x[c+4>>2]=b;d=x[c+4>>2];b=c+16|0;x[b+4>>2]=x[c>>2];x[b+8>>2]=d;x[b>>2]=a;d=hb-16|0;hb=d;if(x[a>>2]!=-1){a:{b=Fb(d,qS(d+8|0,b));while(1){if(x[a>>2]==1){continue}break}b:{c:{if(!x[a>>2]){Ue(a,1);x[114414]=0;e=x[114414];x[114414]=0;d:{if((e|0)==1){break d}x[114414]=0;W(2617,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break d}x[114414]=0;b=x[114414];x[114414]=0;if((b|0)==1){break d}x[a>>2]=-1;x[114414]=0;b=x[114414];x[114414]=0;if((b|0)==1){break d}x[114414]=0;b=x[114414];x[114414]=0;if((b|0)!=1){break a}}Y(S(0)|0)|0;x[114414]=0;c=x[114414];x[114414]=0;e:{if((c|0)==1){break e}Ue(a,0);x[114414]=0;a=x[114414];x[114414]=0;if((a|0)==1){break e}x[114414]=0;a=x[114414];x[114414]=0;if((a|0)==1){break e}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}}a=N()|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)==1){break c}Q(a|0);p()}break a}S(0)|0;zb()}p()}}hb=d+16|0;hb=c+32|0;return x[a+4>>2]-1|0}function cna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=hb-48|0;hb=e;a:{b:{if(x[a+8>>2]!=x[ic(a)>>2]){break b}i=a+8|0;j=a+4|0;f=x[a+4>>2];g=x[a>>2];if(f>>>0>g>>>0){k=x[i>>2];h=hb-16|0;hb=h;d=hb-16|0;hb=d;c=hb-16|0;hb=c;l=((f-g>>1)+1|0)/-2<<1;m=f+l|0;g=m;x[c+8>>2]=g;x[c+12>>2]=f;if((f|0)!=(k|0)){while(1){SA(g,x[c+12>>2]);g=g+2|0;x[c+8>>2]=g;n=x[c+12>>2]+2|0;x[c+12>>2]=n;if((k|0)!=(n|0)){continue}break}}gd(d+8|0,c+12|0,c+8|0);hb=c+16|0;o=d,q=rg(f,x[d+8>>2]),x[o+4>>2]=q;o=d,q=rg(m,x[d+12>>2]),x[o>>2]=q;gd(h+8|0,d+4|0,d);hb=d+16|0;hb=h+16|0;x[i>>2]=x[h+12>>2];x[j>>2]=x[j>>2]+l;break b}o=e,q=x[ic(a)>>2]-x[a>>2]|0,x[o+24>>2]=q;x[e+44>>2]=1;d=e+24|0;c=x[_c(d,e+44|0)>>2];c=zq(d,c,c>>>2|0,x[a+16>>2]);d=Fb(e+16|0,x[a+4>>2]);f=x[Fb(e+8|0,x[a+8>>2])>>2];d=x[d>>2];x[114414]=0;T(480,c|0,d|0,f|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}Yb(a,c);Yb(j,c+4|0);Yb(i,c+8|0);Yb(ic(a),ic(c));Cu(c)}PA(x[a+16>>2],x[a+8>>2],b);x[a+8>>2]=x[a+8>>2]+2;hb=e+48|0;return}a=N()|0;Cu(c);Q(a|0);p()}function Hha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=hb-144|0;hb=g;uz(a);a:{b:{if(!Yf(a,64)){break b}c:{d:{e:{if(!Nk(a,60)){break e}if(!rP(a,9903)){break e}b=15;break d}uz(a);if(!Yf(a,128)){break b}b=0;d=1;if(!Nk(a,124)){break d}e=31;if(rP(a,11212)){break c}}e=b;if(d){break a}}uz(a);b=0;while(1){c=0;d=hb-16|0;hb=d;if(oP(a,d+8|0)){c=d+8|0;c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24)}hb=d+16|0;if(c>>>0>131072){break a}b=b+1|0;if((b&65535)>>>0<e>>>0){continue}break}Yc(a,4);if(!Yf(a,2)){break b}d=0;c=hb-16|0;hb=c;b=hb-16|0;hb=b;f=b+8|0;hl(f,c+8|0);i=Eb(f);f=nd(a,ac(b,f));if((i|0)==(f|0)){Yc(a,Eb(b+8|0))}hb=b+16|0;hb=c+16|0;if((f|0)==(i|0)){b=c+8|0;b=y[b|0]|y[b+1|0]<<8;d=b<<8|b>>>8}if((d&65535)>>>0<178){break a}h=-1;b=D(e,30);if(!Yf(a,b)){break a}Yc(a,b);b=hb-16|0;hb=b;e=b+8|0;d=g+8|0;DQ(e,d);c=Eb(e);e=nd(a,ac(b,e));if((c|0)==(e|0)){Yc(a,Eb(b+8|0))}hb=b+16|0;a=(c|0)==(e|0);if(!a){EQ(d)}if(!a){break a}h=qP(g+8|0);break a}h=-1}hb=g+144|0;return h|0}function Hn(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(b&2){v[a+861|0]=0;x[a+708>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;v[a+819|0]=0;x[a+804>>2]=0;x[a+824>>2]=0;x[a+696>>2]=0;x[a+668>>2]=0;x[a+88>>2]=x[a+88>>2]|6144;if($b(c+1074312|0,23)){w[a+798>>1]=0;w[a+800>>1]=1}v[a+866|0]=0;v[a+859|0]=0;v[a+871|0]=255;x[a+660>>2]=0;v[a+872|0]=y[a+872|0]&248;Nt(a+810|0)}if(b&4){x[a+84>>2]=0;x[a+76>>2]=0;x[a+80>>2]=0;x[a+700>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;x[a>>2]=0;x[a+4>>2]=0;v[a+865|0]=0;v[a+858|0]=0;x[a+688>>2]=0;x[a+672>>2]=0;x[a+676>>2]=0;w[a+840>>1]=0;v[a+839|0]=0;w[a+856>>1]=32512;w[a+862>>1]=0;x[a+20>>2]=0;x[a+24>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+28>>2]=0;x[a+32>>2]=0;x[a+876>>2]=0;x[a+880>>2]=0;v[a+872|0]=y[a+872|0]&231}if(b&1){a:{if(d>>>0<=126){b=(d<<5)+c|0;c=x[b+480280>>2];x[a+88>>2]=c;x[a+692>>2]=z[b+480284>>1];x[a+760>>2]=z[b+480286>>1];if(!(c&1024)){break a}x[a+88>>2]=c&-1025|e;break a}x[a+760>>2]=64;x[a+692>>2]=128;x[a+88>>2]=0}w[a+796>>1]=0;v[a+817|0]=0;v[a+818|0]=0}}function Bw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;x[114414]=0;O(15,c+24|0,a|0)|0;d=x[114414];x[114414]=0;a:{b:{c:{if((d|0)!=1){d:{if(!y[c+24|0]){break d}d=x[x[a>>2]-12>>2];x[114414]=0;Dc(c+16|0,a+d|0);d=x[114414];x[114414]=0;e:{f:{g:{if((d|0)!=1){x[114414]=0;d=R(2359,c+16|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break g}Ob(c+16|0);e=el(c+8|0,a);f=x[x[a>>2]-12>>2];x[114414]=0;f=a+f|0;g=R(16,f|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break f}e=x[e>>2];x[114414]=0;b=aa(2361,d|0,e|0,f|0,g|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break f}x[c+16>>2]=b;if(!cl(c+16|0)){break d}b=x[x[a>>2]-12>>2];x[114414]=0;P(18,a+b|0,5);b=x[114414];x[114414]=0;if((b|0)!=1){break d}b=S(0)|0;break e}b=S(0)|0;break e}b=S(0)|0;Ob(c+16|0);break e}b=S(0)|0}Kf(c+24|0);break c}Kf(c+24|0);break b}b=S(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[114414]=0;W(19,a+b|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_()}hb=c+32|0;return}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function e0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;a=qw(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((Kr(b,c,0)|0)!=-1){while(1){f=Kr(b,c,e);x[114414]=0;X(164,d|0,b|0,e|0,f-e|0);f=x[114414];x[114414]=0;if((f|0)==1){break j}x[114414]=0;P(165,d+16|0,d|0);f=x[114414];x[114414]=0;if((f|0)==1){break i}x[114414]=0;P(166,a|0,d+16|0);f=x[114414];x[114414]=0;if((f|0)==1){break h}xb(d+16|0);xb(d);e=Kr(b,c,e)+Bb(c)|0;if((Kr(b,c,e)|0)!=-1){continue}break}}k:{if(od(a)){x[114414]=0;X(164,d+16|0,b|0,e|0,-1);c=x[114414];x[114414]=0;if((c|0)==1){break f}c=d+16|0;f=Bb(c);xb(c);if(!f){break k}}x[114414]=0;X(164,d|0,b|0,e|0,-1);b=x[114414];x[114414]=0;if((b|0)==1){break e}x[114414]=0;P(165,d+16|0,d|0);b=x[114414];x[114414]=0;if((b|0)==1){break d}x[114414]=0;P(166,a|0,d+16|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}xb(d+16|0);xb(d)}hb=d+32|0;return}e=N()|0;break a}e=N()|0;break g}e=N()|0;xb(d+16|0)}xb(d);break a}e=N()|0;break a}e=N()|0;break a}e=N()|0;break b}e=N()|0;xb(d+16|0)}xb(d)}vl(a);Q(e|0);p()}function Ic(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=x[b>>2];f=hb-48|0;hb=f;e=x[b+4>>2];d=y[b+8|0];e=e-(((d|0)==1|(d|0)==4)&(e|0)!=0)|0;b=Wb(a);b:{c:{d:{e:{f:{g:{h:{if((d-1&255)>>>0<=1){v[f+32|0]=0;a=Gl(c,c+e|0,f+32|0);x[114414]=0;U(116,b|0,c|0,a|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){break h}a=N()|0;break b}if((d-3&255)>>>0>1){break h}x[114414]=0;U(116,b|0,c|0,c+e|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break g}c=ud(b);d=jf(b);e=ud(b);a=hb-32|0;hb=a;x[a+16>>2]=d;x[a+24>>2]=c;x[a+8>>2]=e;if(Hb(a+24|0,a+16|0)){while(1){d=a+8|0;c=a+24|0;e=v[x[c>>2]];v[x[d>>2]]=e?e:32;bg(c);bg(d);if(Hb(c,a+16|0)){continue}break}}hb=a+32|0;x[114414]=0;c=O(117,f+16|0,b|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break f}x[114414]=0;d=O(118,f|0,13671)|0;a=x[114414];x[114414]=0;if((a|0)==1){break e}x[114414]=0;T(119,f+32|0,c|0,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}a=f+32|0;Db(b,a);xb(a);xb(d);xb(c)}hb=f+48|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break c}a=N()|0;xb(d)}xb(c)}xb(b);Q(a|0);p()}}function rga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=hb-16|0;hb=i;g=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];e=x[a+44>>2];n=x[a+16>>2];f=x[a+4>>2];b=x[a>>2];x[i+8>>2]=b;x[i+12>>2]=f;j=x[a+12>>2];x[i>>2]=x[a+8>>2];x[i+4>>2]=j;a:{if(!d){j=k>>12;h=l>>12;break a}while(1){h=w[(x[i+12>>2]<<1)+n>>1];f=x[a+60>>2];b=e;e=Xb(e,-16777216,16776704);j=x[a+64>>2];g=Xb(g,-16777216,16776704);o=x[a+72>>2];p=x[a+32>>2];q=x[c>>2];m=h<<8;h=m;f=yna(f,f>>31,h,h>>31);h=lb;j=yna(j,j>>31,e,e>>31);f=j+f|0;e=lb+h|0;e=f>>>0<j>>>0?e+1|0:e;h=f;f=x[a+68>>2];f=yna(f,f>>31,g,g>>31);g=h+f|0;e=lb+e|0;e=f>>>0>g>>>0?e+1|0:e;l=x[a+28>>2]+l|0;h=l>>12;g=g+8388608|0;e=((g>>>0<8388608?e+1|0:e)&16777215)<<8|g>>>24;g=(e|0)/256|0;x[c>>2]=D(h,g)+q;k=k+p|0;j=k>>12;x[c+4>>2]=x[c+4>>2]+D(g,j);e=e-(m&o)|0;c=c+8|0;Tb(i+8|0,i);g=b;d=d-1|0;if(d){continue}break}b=x[i+8>>2];f=x[i+12>>2]}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=k;x[a+20>>2]=h;x[a+36>>2]=l;x[a+48>>2]=g;x[a+44>>2]=e;x[a+24>>2]=j;hb=i+16|0}function Er(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;m=hb-16|0;hb=m;x[m+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break b}a=0;v[b|0]=0;b=x[e>>2];x[e>>2]=b+1;v[b|0]=46;if(!Bb(h)){break a}b=x[j>>2];if((b-i|0)>159){break a}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Bb(h)){break c}if(!y[b|0]){break b}a=0;b=x[j>>2];if((b-i|0)>159){break a}a=x[k>>2];x[j>>2]=b+4;x[b>>2]=a;a=0;x[k>>2]=0;break a}a=-1;f=cw(l,l+128|0,m+12|0)-l|0;if((f|0)>124){break a}g=y[(f>>2)+64928|0];d:{e:{a=f&-5;if((a|0)!=88){if((a|0)!=96){break e}b=x[e>>2];if((b|0)!=(d|0)){a=-1;if((y[b-1|0]&95)!=(y[c|0]&127)){break a}}x[e>>2]=b+1;v[b|0]=g;a=0;break a}v[c|0]=80;break d}a=g&95;if((a|0)!=y[c|0]){break d}v[c|0]=a|128;if(!y[b|0]){break d}v[b|0]=0;if(!Bb(h)){break d}a=x[j>>2];if((a-i|0)>159){break d}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b}a=x[e>>2];x[e>>2]=a+1;v[a|0]=g;a=0;if((f|0)>84){break a}x[k>>2]=x[k>>2]+1;break a}a=-1}hb=m+16|0;return a|0}function qx(a,b,c,d,e,f){var g=0,h=0,i=E(0),j=0;g=hb-96|0;hb=g;h=a+24|0;rp(x[h>>2]);v[x[h>>2]+1304512|0]=x[a+52>>2]!=0;x[g+92>>2]=f;x[g+88>>2]=e;x[g+84>>2]=d;x[g+80>>2]=c;c=g+80|0;c=DI(g+32|0,c,EI(c),b);d=x[a+32>>2];i=B[a+48>>2];e=x[c+12>>2];x[g+8>>2]=x[c+8>>2];x[g+12>>2]=e;e=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=e;c=hb-16|0;hb=c;e=x[g+12>>2];x[c+8>>2]=x[g+8>>2];x[c+12>>2]=e;e=x[g+4>>2];x[c>>2]=x[g>>2];x[c+4>>2]=e;e=ts(g+48|0);x[e+8>>2]=d;x[e+4>>2]=0;x[e>>2]=82896;d=x[c+4>>2];x[e+12>>2]=x[c>>2];x[e+16>>2]=d;d=x[c+12>>2];x[e+20>>2]=x[c+8>>2];x[e+24>>2]=d;B[e+28>>2]=i;x[e>>2]=82840;hb=c+16|0;d=0;a:{while(1){if(b){c=x[h>>2];x[g+24>>2]=b;x[g+28>>2]=0;x[114414]=0;x[g+16>>2]=134217727;x[g+20>>2]=0;f=O(2184,g+24|0,g+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break a}f=x[f>>2];x[114414]=0;c=U(2185,c|0,f|0,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break a}d=c+d|0;b=b-c|0;if(c){continue}}break}if(!(x[a+52>>2]!=1|d)){a=x[h>>2];x[a+480208>>2]=x[a+480208>>2]&-513}hb=g+96|0;return d}Q(N()|0);p()}function px(a,b,c,d,e,f){var g=0,h=0,i=E(0),j=0;g=hb-96|0;hb=g;h=a+24|0;rp(x[h>>2]);v[x[h>>2]+1304512|0]=x[a+52>>2]!=0;x[g+92>>2]=f;x[g+88>>2]=e;x[g+84>>2]=d;x[g+80>>2]=c;c=g+80|0;c=DI(g+32|0,c,EI(c),b);d=x[a+32>>2];i=B[a+48>>2];e=x[c+12>>2];x[g+8>>2]=x[c+8>>2];x[g+12>>2]=e;e=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=e;c=hb-16|0;hb=c;e=x[g+12>>2];x[c+8>>2]=x[g+8>>2];x[c+12>>2]=e;e=x[g+4>>2];x[c>>2]=x[g>>2];x[c+4>>2]=e;e=ts(g+48|0);x[e+8>>2]=d;x[e+4>>2]=0;x[e>>2]=82992;d=x[c+4>>2];x[e+12>>2]=x[c>>2];x[e+16>>2]=d;d=x[c+12>>2];x[e+20>>2]=x[c+8>>2];x[e+24>>2]=d;B[e+28>>2]=i;x[e>>2]=82944;hb=c+16|0;d=0;a:{while(1){if(b){c=x[h>>2];x[g+24>>2]=b;x[g+28>>2]=0;x[114414]=0;x[g+16>>2]=134217727;x[g+20>>2]=0;f=O(2184,g+24|0,g+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break a}f=x[f>>2];x[114414]=0;c=U(2185,c|0,f|0,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break a}d=c+d|0;b=b-c|0;if(c){continue}}break}if(!(x[a+52>>2]!=1|d)){a=x[h>>2];x[a+480208>>2]=x[a+480208>>2]&-513}hb=g+96|0;return d}Q(N()|0);p()}function jh(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=pi(a)&2047;c=pi(5551115123125783e-32);d=e-c|0;a:{if(d>>>0>=pi(512)-c>>>0){if((d|0)<0){return a+1}o(+a);c=j(1)|0;d=j(0)|0;b:{if(pi(1024)>>>0>e>>>0){break b}b=0;if(!d&(c|0)==-1048576){break a}if(pi(Infinity)>>>0<=e>>>0){return a+1}if((c|0)>0|(c|0)>=0){return hs(3105036184601418e216)}if(c>>>0<3230714880){break b}return hs(12882297539194267e-247)}c=c<<1|d>>>31;e=!(d<<1)&(c|0)==-2129002496|c>>>0<2165964800?e:0}b=C[6416];f=b+a;a=a-(f-b);b=a*a;g=b*b*(a*C[6421]+C[6420]);b=b*(a*C[6419]+C[6418]);a=a*C[6417];o(+f);j(1)|0;i=j(0)|0;d=i<<4&2032;a=g+(b+(a+C[d+51376>>3]));d=d+51384|0;h=x[d>>2];c=x[d+4>>2];d=h;h=0;d=d+h|0;c=(i<<13)+c|0;c=d>>>0<h>>>0?c+1|0:c;if(!e){c:{if(!(i&-2147483648)){l(0,d|0);l(1,c+-1048576|0);b=+n();a=b*a+b;a=a+a;break c}l(0,d|0);l(1,c+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){$G(aH()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);b=+n();b=b*a+b}return b}function Hla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;v[d+16|0]=44;x[d+8>>2]=-1;x[d+12>>2]=0;x[d>>2]=1042;x[d+4>>2]=2;f=hb-16|0;hb=f;c=hb-176|0;hb=c;e=lh(c+40|0);g=x[x[e>>2]-12>>2];x[114414]=0;h=$(121)|0;i=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{if((i|0)==1){break f}x[114414]=0;T(122,c+32|0,e+g|0,h|0);g=x[114414];x[114414]=0;if((g|0)==1){break f}Ob(c+32|0);x[114414]=0;P(147,e|0,d|0);g=x[114414];x[114414]=0;if((g|0)==1){break f}x[114414]=0;P(131,e|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;P(124,c|0,e|0);b=x[114414];x[114414]=0;if((b|0)==1){break f}x[114414]=0;T(139,c+16|0,c|0,d|0);b=x[114414];x[114414]=0;if((b|0)==1){break e}x[114414]=0;T(140,f|0,c+16|0,d|0);b=x[114414];x[114414]=0;if((b|0)==1){break d}xb(c+16|0);xb(c);Xd(e);hb=c+176|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;xb(c+16|0)}xb(c)}Xd(e);Q(a|0);p()}x[114414]=0;T(13,a|0,0,f|0);a=x[114414];x[114414]=0;g:{if((a|0)!=1){xb(f);hb=f+16|0;break g}a=N()|0;xb(f);Q(a|0);p()}hb=d+32|0}function sga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=hb-16|0;hb=i;g=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];e=x[a+44>>2];n=x[a+16>>2];f=x[a+4>>2];b=x[a>>2];x[i+8>>2]=b;x[i+12>>2]=f;j=x[a+12>>2];x[i>>2]=x[a+8>>2];x[i+4>>2]=j;a:{if(!d){j=k>>12;h=l>>12;break a}while(1){h=v[x[i+12>>2]+n|0];f=x[a+60>>2];b=e;e=Xb(e,-16777216,16776704);j=x[a+64>>2];g=Xb(g,-16777216,16776704);o=x[a+72>>2];p=x[a+32>>2];q=x[c>>2];m=h<<16;h=m;f=yna(f,f>>31,h,h>>31);h=lb;j=yna(j,j>>31,e,e>>31);f=j+f|0;e=lb+h|0;e=f>>>0<j>>>0?e+1|0:e;h=f;f=x[a+68>>2];f=yna(f,f>>31,g,g>>31);g=h+f|0;e=lb+e|0;e=f>>>0>g>>>0?e+1|0:e;l=x[a+28>>2]+l|0;h=l>>12;g=g+8388608|0;e=((g>>>0<8388608?e+1|0:e)&16777215)<<8|g>>>24;g=(e|0)/256|0;x[c>>2]=D(h,g)+q;k=k+p|0;j=k>>12;x[c+4>>2]=x[c+4>>2]+D(g,j);e=e-(m&o)|0;c=c+8|0;Tb(i+8|0,i);g=b;d=d-1|0;if(d){continue}break}b=x[i+8>>2];f=x[i+12>>2]}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=k;x[a+20>>2]=h;x[a+36>>2]=l;x[a+48>>2]=g;x[a+44>>2]=e;x[a+24>>2]=j;hb=i+16|0}function bp(a,b,c,d,e,f){var g=E(0),h=0,i=E(0),j=0,k=E(0),l=E(0);if((a|0)>=4){c=(c<<2)+b|0;d=c+(d<<2)|0;b=a>>>2|0;a=f<<2;while(1){f=d-4|0;i=B[f>>2];k=B[d>>2];l=B[c>>2];B[c>>2]=k+l;h=c-4|0;g=B[h>>2];B[h>>2]=B[f>>2]+g;k=E(l-k);g=E(g-i);B[d>>2]=E(B[e>>2]*k)-E(B[e+4>>2]*g);B[f>>2]=E(B[e+4>>2]*k)+E(B[e>>2]*g);f=d-12|0;k=B[f>>2];h=c-8|0;g=B[h>>2];j=h;h=d-8|0;l=B[h>>2];B[j>>2]=l+g;j=c-12|0;i=B[j>>2];B[j>>2]=B[f>>2]+i;e=a+e|0;g=E(g-l);i=E(i-k);B[h>>2]=E(B[e>>2]*g)-E(B[e+4>>2]*i);B[f>>2]=E(B[e+4>>2]*g)+E(B[e>>2]*i);f=d-20|0;k=B[f>>2];h=c-16|0;g=B[h>>2];j=h;h=d-16|0;l=B[h>>2];B[j>>2]=l+g;j=c-20|0;i=B[j>>2];B[j>>2]=B[f>>2]+i;e=a+e|0;g=E(g-l);i=E(i-k);B[h>>2]=E(B[e>>2]*g)-E(B[e+4>>2]*i);B[f>>2]=E(B[e+4>>2]*g)+E(B[e>>2]*i);f=d-28|0;k=B[f>>2];h=c-24|0;g=B[h>>2];j=h;h=d-24|0;l=B[h>>2];B[j>>2]=l+g;j=c-28|0;i=B[j>>2];B[j>>2]=B[f>>2]+i;e=a+e|0;g=E(g-l);i=E(i-k);B[h>>2]=E(B[e>>2]*g)-E(B[e+4>>2]*i);B[f>>2]=E(B[e+4>>2]*g)+E(B[e>>2]*i);e=a+e|0;d=d-32|0;c=c-32|0;f=b>>>0>1;b=b-1|0;if(f){continue}break}}}function Wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;OP(a);g=yb(a);d=Fb(f+16|0,x[a+4>>2]);h=Fb(f+8|0,x[a>>2]);e=Fb(f,x[b+4>>2]);d=x[d>>2];e=x[e>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[h>>2];x[c+40>>2]=d;x[c+24>>2]=e;x[c+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(969,c+40|0,c+32|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!e){break d}x[114414]=0;d=R(972,c+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}e=xz(c+40|0);x[114414]=0;T(970,g|0,d|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}DP(c+40|0);DP(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(971,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;d=x[c+24>>2];break a}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb()}p()}x[f+24>>2]=d;x[b+4>>2]=x[f+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Lk(a);Kn(a);Kn(a);hb=f+32|0}function Gr(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;m=hb-16|0;hb=m;v[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break b}a=0;v[b|0]=0;b=x[e>>2];x[e>>2]=b+1;v[b|0]=46;if(!Bb(h)){break a}b=x[j>>2];if((b-i|0)>159){break a}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Bb(h)){break c}if(!y[b|0]){break b}a=0;b=x[j>>2];if((b-i|0)>159){break a}a=x[k>>2];x[j>>2]=b+4;x[b>>2]=a;a=0;x[k>>2]=0;break a}a=-1;f=Gl(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=y[f+64928|0];d:{e:{switch((f&-2)-22|0){case 2:b=x[e>>2];if((b|0)!=(d|0)&(y[b-1|0]&95)!=(y[c|0]&127)){break a}x[e>>2]=b+1;v[b|0]=g;a=0;break a;case 0:v[c|0]=80;break d;default:break e}}a=g&95;if((a|0)!=y[c|0]){break d}v[c|0]=a|128;if(!y[b|0]){break d}v[b|0]=0;if(!Bb(h)){break d}a=x[j>>2];if((a-i|0)>159){break d}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b}a=x[e>>2];x[e>>2]=a+1;v[a|0]=g;a=0;if((f|0)>21){break a}x[k>>2]=x[k>>2]+1;break a}a=-1}hb=m+16|0;return a|0}function paa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;ig(a);g=yb(a);d=Fb(f+16|0,x[a+4>>2]);h=Fb(f+8|0,x[a>>2]);e=Fb(f,x[b+4>>2]);d=x[d>>2];e=x[e>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[h>>2];x[c+40>>2]=d;x[c+24>>2]=e;x[c+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(1576,c+40|0,c+32|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!e){break d}x[114414]=0;d=R(1578,c+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}e=Xk(c+40|0);x[114414]=0;T(1574,g|0,d|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}vh(c+40|0);vh(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(1577,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;d=x[c+24>>2];break a}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb()}p()}x[f+24>>2]=d;x[b+4>>2]=x[f+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Yk(a,xd(a));hb=f+32|0}function iha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;mi(a);g=yb(a);d=Fb(f+16|0,x[a+4>>2]);h=Fb(f+8|0,x[a>>2]);e=Fb(f,x[b+4>>2]);d=x[d>>2];e=x[e>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[h>>2];x[c+40>>2]=d;x[c+24>>2]=e;x[c+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(1007,c+40|0,c+32|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!e){break d}x[114414]=0;d=R(1011,c+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}e=Mm(c+40|0);x[114414]=0;T(1008,g|0,d|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}ij(c+40|0);ij(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(1009,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;d=x[c+24>>2];break a}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb()}p()}x[f+24>>2]=d;x[b+4>>2]=x[f+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Nm(a,zc(a));hb=f+32|0}function eea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;wm(a);g=yb(a);d=Fb(f+16|0,x[a+4>>2]);h=Fb(f+8|0,x[a>>2]);e=Fb(f,x[b+4>>2]);d=x[d>>2];e=x[e>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[h>>2];x[c+40>>2]=d;x[c+24>>2]=e;x[c+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(1187,c+40|0,c+32|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!e){break d}x[114414]=0;d=R(1189,c+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}e=$q(c+40|0);x[114414]=0;T(1166,g|0,d|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}_q(c+40|0);_q(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(1188,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;d=x[c+24>>2];break a}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb()}p()}x[f+24>>2]=d;x[b+4>>2]=x[f+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];ar(a,ue(a));hb=f+32|0}function Gda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;mi(a);g=yb(a);d=Fb(f+16|0,x[a+4>>2]);h=Fb(f+8|0,x[a>>2]);e=Fb(f,x[b+4>>2]);d=x[d>>2];e=x[e>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[h>>2];x[c+40>>2]=d;x[c+24>>2]=e;x[c+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(1228,c+40|0,c+32|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!e){break d}x[114414]=0;d=R(1231,c+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}e=Mm(c+40|0);x[114414]=0;T(1229,g|0,d|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}ij(c+40|0);ij(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(1230,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;d=x[c+24>>2];break a}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb()}p()}x[f+24>>2]=d;x[b+4>>2]=x[f+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Nm(a,zc(a));hb=f+32|0}function f9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;Ye(a);g=yb(a);d=Fb(f+16|0,x[a+4>>2]);h=Fb(f+8|0,x[a>>2]);e=Fb(f,x[b+4>>2]);d=x[d>>2];e=x[e>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[h>>2];x[c+40>>2]=d;x[c+24>>2]=e;x[c+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(1667,c+40|0,c+32|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!e){break d}x[114414]=0;d=R(1669,c+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}e=Vx(c+40|0);x[114414]=0;T(1665,g|0,d|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}Jp(c+40|0);Jp(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(1668,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;d=x[c+24>>2];break a}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb()}p()}x[f+24>>2]=d;x[b+4>>2]=x[f+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];vk(a,Lb(a));hb=f+32|0}function QM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=hb-16|0;hb=g;e=D(b,896)+a|0;a:{if(c){f=g+8|0;Kb(f,a+1074312|0,90);if(!Ib(f)){v[(D(b,896)+a|0)+1075815|0]=c}v[(D(b,896)+a|0)+1075816|0]=c;break a}c=y[e+1075816|0]}e=e+1074984|0;f=c&255;i=0-f|0;h=d?h:!(x[a+480180>>2]&204473357);LM(a,b,i,h);b:{c:{if(x[a+480180>>2]!=16777216){break c}j=x[(D(b,896)+a|0)+1075640>>2];if(!j|!x[j+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){KM(a,e,240-f|0);break b}if(!(b>>>0<224|d)){JM(e,224-f|0);break b}IM(e,i);break b}if(x[a+480180>>2]==268435456){x[(D(b,896)+a|0)+1075692>>2]=65535}if((c&255)>>>0>223&h){d:{d=f&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}FM(a,e,d);break b}if(x[a+480180>>2]==524288){break d}NM(a,e,d);break b}if(x[a+480180>>2]!=524288){break b}}e:{if(!(v[(D(b,896)+a|0)+1075856|0]&1)){break e}if(x[a+1074416>>2]==1){b=g+8|0;Kb(b,a+1074312|0,6);if(Ib(b)){break e}}if(x[a+480180>>2]&32832){break e}if(!(x[a+480208>>2]&2)|x[a+480180>>2]!=8){break b}}GM(a,e,f<<2)}hb=g+16|0}function O9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;RL(a);g=yb(a);d=Fb(f+16|0,x[a+4>>2]);h=Fb(f+8|0,x[a>>2]);e=Fb(f,x[b+4>>2]);d=x[d>>2];e=x[e>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[h>>2];x[c+40>>2]=d;x[c+24>>2]=e;x[c+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(1613,c+40|0,c+32|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!e){break d}x[114414]=0;d=R(1616,c+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}e=Px(c+40|0);x[114414]=0;T(1614,g|0,d|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}FK(c+40|0);FK(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(1615,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;d=x[c+24>>2];break a}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb()}p()}x[f+24>>2]=d;x[b+4>>2]=x[f+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];HK(a,jg(a));hb=f+32|0}function OG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=a;d=hb-208|0;hb=d;x[d+8>>2]=1;x[d+12>>2]=0;h=b<<2;a:{if(!h){break a}x[d+16>>2]=4;x[d+20>>2]=4;b=4;e=4;f=2;while(1){a=b;b=(e+4|0)+b|0;x[(d+16|0)+(f<<2)>>2]=b;f=f+1|0;e=a;if(b>>>0<h>>>0){continue}break}a=(g+h|0)-4|0;b:{if(a>>>0<=g>>>0){f=0;b=1;a=0;break b}f=1;b=1;while(1){c:{if((f&3)==3){Nw(g,c,b,d+16|0);es(d+8|0,2);b=b+2|0;break c}e=b-1|0;d:{if(A[(d+16|0)+(e<<2)>>2]>=a-g>>>0){ds(g,c,d+8|0,b,0,d+16|0);break d}Nw(g,c,b,d+16|0)}if((b|0)==1){cs(d+8|0,1);b=0;break c}cs(d+8|0,e);b=1}e=x[d+8>>2];f=e|1;x[d+8>>2]=f;g=g+4|0;if(a>>>0>g>>>0){continue}break}f=e>>>0>1;a=x[d+12>>2]!=0}ds(g,c,d+8|0,b,0,d+16|0);if(!(a|((b|0)!=1|f))){break a}while(1){e:{if((b|0)<=1){e=d+8|0;a=RG(e);es(e,a);f=x[d+8>>2];a=a+b|0;break e}e=d+8|0;cs(e,2);x[d+8>>2]=x[d+8>>2]^7;es(e,1);i=g-4|0;h=d+16|0;a=b-2|0;ds(i-x[h+(a<<2)>>2]|0,c,e,b-1|0,1,h);cs(e,1);f=x[d+8>>2]|1;x[d+8>>2]=f;ds(i,c,e,a,1,h)}b=a;g=g-4|0;if(x[d+12>>2]|(f|0)!=1|(b|0)!=1){continue}break}}hb=d+208|0}function rma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;ig(a);g=yb(a);d=Fb(f+16|0,x[a+4>>2]);h=Fb(f+8|0,x[a>>2]);e=Fb(f,x[b+4>>2]);d=x[d>>2];e=x[e>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[h>>2];x[c+40>>2]=d;x[c+24>>2]=e;x[c+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(536,c+40|0,c+32|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!e){break d}x[114414]=0;d=R(539,c+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}e=Xk(c+40|0);x[114414]=0;T(537,g|0,d|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}vh(c+40|0);vh(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(538,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;d=x[c+24>>2];break a}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb()}p()}x[f+24>>2]=d;x[b+4>>2]=x[f+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Yk(a,xd(a));hb=f+32|0}function kka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;ig(a);g=yb(a);d=Fb(f+16|0,x[a+4>>2]);h=Fb(f+8|0,x[a>>2]);e=Fb(f,x[b+4>>2]);d=x[d>>2];e=x[e>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[h>>2];x[c+40>>2]=d;x[c+24>>2]=e;x[c+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(746,c+40|0,c+32|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!e){break d}x[114414]=0;d=R(748,c+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}e=Xk(c+40|0);x[114414]=0;T(744,g|0,d|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}vh(c+40|0);vh(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(747,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;d=x[c+24>>2];break a}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb()}p()}x[f+24>>2]=d;x[b+4>>2]=x[f+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Yk(a,xd(a));hb=f+32|0}function Yla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;ml(a);g=yb(a);d=Fb(f+16|0,x[a+4>>2]);h=Fb(f+8|0,x[a>>2]);e=Fb(f,x[b+4>>2]);d=x[d>>2];e=x[e>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[h>>2];x[c+40>>2]=d;x[c+24>>2]=e;x[c+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(582,c+40|0,c+32|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!e){break d}x[114414]=0;d=R(585,c+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}e=lu(c+40|0);x[114414]=0;T(583,g|0,d|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}mq(c+40|0);mq(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(584,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;d=x[c+24>>2];break a}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb()}p()}x[f+24>>2]=d;x[b+4>>2]=x[f+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Jo(a,rd(a));hb=f+32|0}function Saa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;f=Wb(e+16|0);a:{b:{c:{if(c>>>0<=63){break c}x[114414]=0;c=R(305,b|0)|0;d=x[114414];x[114414]=0;d:{if((d|0)!=1){x[e+12>>2]=c;if((c|0)>0){break d}x[114414]=0;O(118,a|0,17386)|0;a=x[114414];x[114414]=0;if((a|0)!=1){break b}}break a}x[114414]=0;c=R(296,b|0)|0;d=x[114414];x[114414]=0;e:{if((d|0)==1){break e}x[114414]=0;c=R(836,c|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}x[114414]=0;x[e+8>>2]=c;c=O(414,e+12|0,e+8|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}c=x[c>>2];x[114414]=0;P(108,f|0,c|0);c=x[114414];x[114414]=0;if((c|0)!=1){break c}}break a}f:{while(1){g:{x[114414]=0;c=R(403,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break g}if(!c){break f}x[114414]=0;U(1544,f|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=x[114414];x[114414]=0;if((c|0)!=1){continue}}break}break a}x[114414]=0;O(304,b|0,4)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}Jd(a,f)}xb(f);hb=e+32|0;return}a=N()|0;xb(f);Q(a|0);p()}function $ma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;ig(a);g=yb(a);d=Fb(f+16|0,x[a+4>>2]);h=Fb(f+8|0,x[a>>2]);e=Fb(f,x[b+4>>2]);d=x[d>>2];e=x[e>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[h>>2];x[c+40>>2]=d;x[c+24>>2]=e;x[c+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(490,c+40|0,c+32|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!e){break d}x[114414]=0;d=R(492,c+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}e=Xk(c+40|0);x[114414]=0;T(488,g|0,d|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}vh(c+40|0);vh(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(491,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;d=x[c+24>>2];break a}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb()}p()}x[f+24>>2]=d;x[b+4>>2]=x[f+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Yk(a,xd(a));hb=f+32|0}function $la(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;ig(a);g=yb(a);d=Fb(f+16|0,x[a+4>>2]);h=Fb(f+8|0,x[a>>2]);e=Fb(f,x[b+4>>2]);d=x[d>>2];e=x[e>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[h>>2];x[c+40>>2]=d;x[c+24>>2]=e;x[c+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(576,c+40|0,c+32|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!e){break d}x[114414]=0;d=R(578,c+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}e=Xk(c+40|0);x[114414]=0;T(574,g|0,d|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}vh(c+40|0);vh(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(577,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;d=x[c+24>>2];break a}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb()}p()}x[f+24>>2]=d;x[b+4>>2]=x[f+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Yk(a,xd(a));hb=f+32|0}function $ha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;ig(a);g=yb(a);d=Fb(f+16|0,x[a+4>>2]);h=Fb(f+8|0,x[a>>2]);e=Fb(f,x[b+4>>2]);d=x[d>>2];e=x[e>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[h>>2];x[c+40>>2]=d;x[c+24>>2]=e;x[c+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(958,c+40|0,c+32|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!e){break d}x[114414]=0;d=R(960,c+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}e=Xk(c+40|0);x[114414]=0;T(956,g|0,d|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}vh(c+40|0);vh(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(959,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;d=x[c+24>>2];break a}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb()}p()}x[f+24>>2]=d;x[b+4>>2]=x[f+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Yk(a,xd(a));hb=f+32|0}function r_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;mi(a);g=yb(a);d=Fb(f+16|0,x[a+4>>2]);h=Fb(f+8|0,x[a>>2]);e=Fb(f,x[b+4>>2]);d=x[d>>2];e=x[e>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[h>>2];x[c+40>>2]=d;x[c+24>>2]=e;x[c+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(171,c+40|0,c+32|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!e){break d}x[114414]=0;d=R(173,c+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}e=Mm(c+40|0);x[114414]=0;T(169,g|0,d|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}ij(c+40|0);ij(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(172,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;d=x[c+24>>2];break a}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb()}p()}x[f+24>>2]=d;x[b+4>>2]=x[f+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Nm(a,zc(a));hb=f+32|0}function UV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;wm(a);g=yb(a);d=Fb(f+16|0,x[a+4>>2]);h=Fb(f+8|0,x[a>>2]);e=Fb(f,x[b+4>>2]);d=x[d>>2];e=x[e>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[h>>2];x[c+40>>2]=d;x[c+24>>2]=e;x[c+16>>2]=e;a:{b:{c:{d:{while(1){e:{x[114414]=0;e=O(242,c+40|0,c+32|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break e}if(!e){break d}x[114414]=0;d=R(245,c+24|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}e=$q(c+40|0);x[114414]=0;T(243,g|0,d|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}_q(c+40|0);_q(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(244,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;d=x[c+24>>2];break a}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb()}p()}x[f+24>>2]=d;x[b+4>>2]=x[f+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];ar(a,ue(a));hb=f+32|0}function SL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=hb-560|0;hb=f;w[f+558>>1]=b;a:{b:{if((b-256&65535)>>>0<65281){break b}b=((b<<2)+a|0)+900380|0;d=x[b>>2];c:{if(d){b=wO(f,c);c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;c=y[b+11|0]|y[b+12|0]<<8|(y[b+13|0]<<16|y[b+14|0]<<24);e=y[b+7|0]|y[b+8|0]<<8|(y[b+9|0]<<16|y[b+10|0]<<24);v[d+7|0]=e;v[d+8|0]=e>>>8;v[d+9|0]=e>>>16;v[d+10|0]=e>>>24;v[d+11|0]=c;v[d+12|0]=c>>>8;v[d+13|0]=c>>>16;v[d+14|0]=c>>>24;v[d+15|0]=y[b+15|0];c=x[b+44>>2];x[d+40>>2]=x[b+40>>2];x[d+44>>2]=c;c=x[b+36>>2];x[d+32>>2]=x[b+32>>2];x[d+36>>2]=c;c=x[b+28>>2];x[d+24>>2]=x[b+24>>2];x[d+28>>2]=c;c=x[b+20>>2];x[d+16>>2]=x[b+16>>2];x[d+20>>2]=c;qy(d+48|0,b+48|0);qy(d+68|0,b+68|0);qy(d+88|0,b+88|0);sc(d+108|0,b+108|0,448);_t(b);break c}e=Qg(556);if(!e){d=0;x[b>>2]=0;break b}x[114414]=0;d=O(1448,e|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[b>>2]=d}g=a,h=z[aj(a+480192|0,f+558|0)>>1],w[g+480192>>1]=h}hb=f+560|0;return d|0}a=N()|0;_b(e);Q(a|0);p()}function wI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;a:{b:{c:{d:{e:{f:{g:{if(vi(a)){gp(d+24|0);break g}c=d+8|0;kn(c,a);x[114414]=0;c=R(2204,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break f}x[d+24>>2]=c;Mf(d+8|0)}if(vi(a)){c=a+36|0}else{c=x[d+24>>2]}if((b|0)==-1){f=4194304;e=0;break d}if((b|0)>=0){e=b;if((xd(c)|0)>(b|0)){break d}}b=ec(8);x[114414]=0;c=O(118,d+8|0,6906)|0;a=x[114414];x[114414]=0;if((a|0)==1){break e}a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break c}a=N()|0;Mf(d+8|0);break b}a=N()|0;hc(b);break c}x[a+8>>2]=b;b=a+24|0;g=x[b>>2];x[g+480208>>2]=x[g+480208>>2]&-4194305|f;b=x[b>>2];f=y[Tc(c,e)+16|0];x[114414]=0;P(444,b+484360|0,f|0);b=x[114414];x[114414]=0;h:{if((b|0)==1){break h}b=x[Tc(c,e)+12>>2];c=x[Tc(c,e)+8>>2];x[114414]=0;+ka(2058,a|0,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)==1){break h}x[a+16>>2]=0;x[a+20>>2]=0;sk(d+24|0);hb=d+32|0;return}a=N()|0}sk(d+24|0)}Q(a|0)}p()}function RM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;e=D(b,896)+a|0;a:{if(c){f=g+8|0;Kb(f,a+1074312|0,90);if(!Ib(f)){v[(D(b,896)+a|0)+1075816|0]=c}v[(D(b,896)+a|0)+1075815|0]=c;break a}c=y[e+1075815|0]}e=e+1074984|0;f=c&255;h=d?h:!(x[a+480180>>2]&204473357);LM(a,b,f,h);b:{c:{if(x[a+480180>>2]!=16777216){break c}i=x[(D(b,896)+a|0)+1075640>>2];if(!i|!x[i+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){KM(a,e,f-240|0);break b}if(!(b>>>0<224|d)){JM(e,f-224|0);break b}IM(e,f);break b}if(x[a+480180>>2]==268435456){x[(D(b,896)+a|0)+1075692>>2]=1}if((c&255)>>>0>223&h){d:{d=f&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}HM(a,e,d);break b}if(x[a+480180>>2]==524288){break d}MM(a,e,d);break b}if(x[a+480180>>2]!=524288){break b}}e:{if(!(v[(D(b,896)+a|0)+1075856|0]&1)){break e}if(x[a+1074416>>2]==1){b=g+8|0;Kb(b,a+1074312|0,6);if(Ib(b)){break e}}if(x[a+480180>>2]&32832){break e}if(!(x[a+480208>>2]&2)|x[a+480180>>2]!=8){break b}}GM(a,e,0-(f<<2)|0)}hb=g+16|0}function Jw(a,b,c,d){var e=0,f=0,g=0,h=0;g=hb-32|0;hb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=c<<4|b>>>28;c=d<<4|c>>>28;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){f=c+1073741824|0;e=e+1|0;f=e?f:f+1|0;break a}f=c+1073741824|0;if(a|(b|0)!=134217728){break a}a=e&1;e=a+e|0;f=a>>>0>e>>>0?f+1|0:f;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){a=d<<4|c>>>28;e=c<<4|b>>>28;f=a&524287|2146959360;break a}e=0;f=2146435072;if(h>>>0>1140785151){break a}f=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;gf(g+16|0,a,b,c,e,h-15233|0);Al(g,a,b,c,e,15361-h|0);b=x[g+8>>2];e=b<<4;b=x[g+12>>2]<<4|b>>>28;c=x[g>>2];f=x[g+4>>2];h=f;e=f>>>28|e;f=b;a=h&268435455;b=c|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){e=e+1|0;f=e?f:f+1|0;break a}if(b|(a|0)!=134217728){break a}a=e;e=e+(e&1)|0;f=a>>>0>e>>>0?f+1|0:f}hb=g+32|0;l(0,e|0);l(1,d&-2147483648|f);return+n()}function g$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-32|0;hb=g;x[g+24>>2]=b;a:{b:{if(!(x[d+4>>2]&1)){x[g>>2]=-1;b=mb[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}Dc(g,d);x[114414]=0;b=R(2510,g|0)|0;a=x[114414];x[114414]=0;d:{e:{f:{g:{if((a|0)!=1){Ob(g);Dc(g,d);x[114414]=0;a=R(2511,g|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break g}Ob(g);x[114414]=0;P(2512,g|0,a|0);d=x[114414];x[114414]=0;if((d|0)==1){b=N()|0;break d}x[114414]=0;P(2513,g|12,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break f}x[114414]=0;d=g+24|0;a=qa(2514,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[114414];x[114414]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+24>>2];while(1){d=Nc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Ob(g);break d}b=N()|0;Ob(g);break d}b=N()|0;Nc(g);break d}b=N()|0;while(1){d=Nc(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}hb=g+32|0;return b|0}function Fj(a){a=a|0;var b=0;a:{b:{switch(y[a+3|0]){case 0:if(!y[a+5|0]){break a}v[a+3|0]=1;return;case 1:v[a+3|0]=2;return;case 2:v[a+3|0]=3;return;case 3:v[a+3|0]=4;return;case 4:v[a+3|0]=5;return;case 5:v[a+3|0]=6;return;case 6:v[a+3|0]=7;return;case 7:v[a+3|0]=8;return;case 8:v[a+3|0]=9;return;case 9:v[a+3|0]=10;return;case 10:v[a+3|0]=11;return;case 11:v[a+3|0]=12;return;case 12:v[a+3|0]=13;return;case 13:v[a+3|0]=14;b=a;a=y[a+5|0];v[b+5|0]=D(a>>>4|0,10)+(a&15);return;case 14:v[a+3|0]=19;return;case 15:if(y[a+5|0]<=31){v[a+3|0]=16;return}v[a+3|0]=17;return;case 16:v[a+3|0]=23;return;case 17:v[a+3|0]=24;return;case 20:v[a+3|0]=25;return;case 21:v[a+3|0]=30;return;case 25:v[a+3|0]=29;return;case 27:v[a+3|0]=15;return;case 29:v[a+3|0]=18;return;case 32:v[a+3|0]=42;return;case 33:v[a+3|0]=28;return;case 34:v[a+3|0]=27;return;case 35:v[a+3|0]=31;return;case 36:v[a+3|0]=32;return;case 37:v[a+3|0]=32;return;case 38:v[a+3|0]=34;return;default:break b}}v[a+3|0]=0}}function A$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-32|0;hb=g;x[g+24>>2]=b;a:{b:{if(!(x[d+4>>2]&1)){x[g>>2]=-1;b=mb[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}Dc(g,d);x[114414]=0;b=R(21,g|0)|0;a=x[114414];x[114414]=0;d:{e:{f:{g:{if((a|0)!=1){Ob(g);Dc(g,d);x[114414]=0;a=R(2480,g|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break g}Ob(g);x[114414]=0;P(2481,g|0,a|0);d=x[114414];x[114414]=0;if((d|0)==1){b=N()|0;break d}x[114414]=0;P(2482,g|12,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break f}x[114414]=0;d=g+24|0;a=qa(2483,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[114414];x[114414]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+24>>2];while(1){d=xb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Ob(g);break d}b=N()|0;Ob(g);break d}b=N()|0;xb(g);break d}b=N()|0;while(1){d=xb(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}hb=g+32|0;return b|0}function uaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;Ad(c,0);d=a+36|0;w[e+14>>1]=y[d|0]|y[d+1|0]<<8;w[e+12>>1]=32767;f=c,g=(z[Cf(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,w[f+28>>1]=g;d=a+38|0;w[e+10>>1]=y[d|0]|y[d+1|0]<<8;w[e+8>>1]=32767;f=c,g=(z[Cf(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,w[f+30>>1]=g;w[c+32>>1]=64;d=a+44|0;x[c>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+48|0;x[c+4>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+52|0;x[c+8>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+56|0;x[c+24>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=b+166|0;if(y[d|0]<=4){v[c+38|0]=y[y[d|0]+35850|0]}v[c+39|0]=y[b+167|0];d=b+171|0;v[c+41|0]=(y[d|0]|y[d+1|0]<<8)>>>4;b=b+169|0;b=(y[b|0]|y[b+1|0]<<8)>>>2|0;v[c+40|0]=b;if(y[c+41|0]|b&255){v[c+39|0]=y[c+39|0]^-1}a=a+40|0;if(y[a|0]&4){w[c+34>>1]=z[c+34>>1]|1}if(y[a|0]&8){w[c+34>>1]=z[c+34>>1]|2}if(y[a|0]&16){w[c+34>>1]=z[c+34>>1]|4}if(y[a|0]&32){w[c+34>>1]=z[c+34>>1]|32}hb=e+16|0}function cca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;x[a>>2]=b;c=hb-16|0;hb=c;e=c+8|0;d=b+1074376|0;f=sc(Me(229984),d,602);h=f+608|0;b=0;while(1){g=D(b,896);Bp(g+h|0,(d+g|0)+608|0);b=b+1|0;if((b|0)!=256){continue}break}d=hb-16|0;hb=d;x[114414]=0;x[d+12>>2]=f;b=U(1384,e|0,d+12|0,d+8|0)|0;e=x[114414];x[114414]=0;a:{b:{if((e|0)!=1){hb=d+16|0;break b}break a}hb=c+16|0;x[a+4>>2]=x[b>>2];c=hb-16|0;hb=c;e=c+8|0;d=hb-16|0;hb=d;x[114414]=0;b=a+8|0;R(1385,b+4|0)|0;f=x[114414];x[114414]=0;c:{if((f|0)==1){break a}x[114414]=0;x[d+12>>2]=0;U(1386,b+8|0,d+12|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break a}i=b,j=mc(b),x[i>>2]=j;hb=d+16|0;break c}d=b;hb=c+16|0;c=hb-16|0;hb=c;b=a+20|0;x[b>>2]=0;x[b+4>>2]=0;x[114414]=0;x[c+12>>2]=0;U(1379,b+8|0,c+12|0,c+8|0)|0;e=x[114414];x[114414]=0;d:{if((e|0)!=1){hb=c+16|0;break d}break a}x[114414]=0;W(1344,a|0);c=x[114414];x[114414]=0;if((c|0)!=1){return a|0}c=N()|0;$M(b);zM(d);dg(a+4|0);Q(c|0);p()}S(0)|0;zb();p()}function nW(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb+-64|0;hb=c;a=hd(a);x[114414]=0;b=$(196)|0;d=x[114414];x[114414]=0;a:{b:{if((d|0)==1){break b}c:{d:{if(!b){break d}x[114414]=0;d=O(2,c+32|0,5084)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}x[114414]=0;b=$(196)|0;e=x[114414];x[114414]=0;e:{f:{g:{h:{if((e|0)==1){break h}x[114414]=0;x[c+12>>2]=b;P(202,c+16|0,c+12|0);b=x[114414];x[114414]=0;if((b|0)==1){break h}x[114414]=0;T(3,c+48|0,d|0,c+16|0);b=x[114414];x[114414]=0;if((b|0)==1){break g}b=c+48|0;Db(a,b);xb(b);xb(c+16|0);xb(d);x[114414]=0;b=$(198)|0;d=x[114414];x[114414]=0;if((d|0)==1){break b}if(!b){break e}x[114414]=0;O(203,a|0,13276)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break e}break b}b=N()|0;break f}b=N()|0;xb(c+16|0)}xb(d);break a}x[114414]=0;b=$(197)|0;d=x[114414];x[114414]=0;if((d|0)==1){break b}if(!b){break d}x[114414]=0;O(203,a|0,12745)|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}}hb=c- -64|0;return}b=N()|0;break a}b=N()|0}xb(a);Q(b|0);p()}function Vj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-80|0;hb=c;d=x[a+28>>2];Sn(x[x[d>>2]-12>>2]+d|0,0);if(!Cd(a,4)){Lv(a)}a:{if(!x[a+4>>2]){break a}if(Cd(a,6)){break a}if(Cd(a,7)){break a}g=x[a+28>>2];f=c- -64|0;e=x[a+84>>2];h=D(x[a+20>>2],x[a+4>>2]);d=h+x[a+80>>2]|0;e=h>>>0>d>>>0?e+1|0:e;f=Ug(f,d,e);d=x[f+12>>2];x[c+24>>2]=x[f+8>>2];x[c+28>>2]=d;d=x[f+4>>2];x[c+16>>2]=x[f>>2];x[c+20>>2]=d;lj(g,c+16|0)}b:{if(!Cd(a,5)){break b}i=a+44|0;h=rd(i);if(!h){break b}g=a+32|0;while(1){c:{e=(x[a+96>>2]+j>>>0)%(h>>>0)|0;if(A[vc(i,e)>>2]>=wc(g)>>>0){break c}f=Jm(c+48|0,Bc(g,x[vc(i,e)>>2]),z[vc(i,e)+12>>1]);d=Nv(b,f);Gb(f);if(!d){break c}x[a+96>>2]=(e+1>>>0)%(h>>>0);if(x[vc(i,e)+4>>2]){f=x[a+28>>2];b=x[a+12>>2];d=x[a+8>>2];a=x[vc(i,e)+4>>2];g=d+a|0;b=Ug(c+32|0,g,a>>>0>g>>>0?b+1|0:b);a=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=a;a=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=a;lj(f,c)}j=vc(i,e);break b}j=j+1|0;if((h|0)!=(j|0)){continue}break}j=0}hb=c+80|0;return j}function rV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-80|0;hb=d;Lc(b);gr(a);a:{if(!ov(b,d+40|0)){break a}if(!GC(d+40|0)){break a}b:{if(!c){break b}c=d+40|4;f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);if(!Qb(b,(f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))-28|0)){break a}Fv(a);g=d,h=Ev(),x[g+24>>2]=h;e=d+24|0;Dv($g(a)+28|0,e);fr(e);f=x[$g(a)+28>>2];x[114414]=0;e=R(315,b|0)|0;b=x[114414];x[114414]=0;c:{if((b|0)==1){break c}c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);b=y[d+52|0]|y[d+53|0]<<8|(y[d+54|0]<<16|y[d+55|0]<<24);x[114414]=0;c=Z(316,e|0,(c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))-28|0,f|0,b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24))|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}e=0;if(!c){break a}c=d+8|0;ej(c,f);b=d+16|0;zv(b,c);b=Ho(d+24|0,b,0);Ud($g(a)+12|0,b);Ab(b);break b}b=ya(75016,76228)|0;a=ib;d:{if((ca(75016)|0)==(a|0)){break d}if((ca(76228)|0)==(a|0)){break d}Q(b|0);p()}Y(b|0)|0;_();e=0;break a}e=1}hb=d+80|0;return e|0}function qba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=hb-32|0;hb=d;b=hb-32|0;hb=b;B[b+16>>2]=2;w[b+22>>1]=12;x[b+12>>2]=15;c=Me(64);x[114414]=0;e=R(1440,c|0)|0;f=x[114414];x[114414]=0;a:{b:{c:{if((f|0)!=1){c=sy(b+8|0,e);e=x[c>>2];x[114414]=0;P(1441,e|0,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}a=x[c>>2];x[114414]=0;a=U(1442,a|0,b+22|0,b+16|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break c}d:{if(!a){ry(b+24|0);break d}a=x[c>>2];x[114414]=0;P(1443,a|0,b+12|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}iq(b+24|0,c)}Tf(c);hb=b+32|0;a=x[b+24>>2];break a}a=N()|0;_b(c);break b}a=N()|0;Tf(c)}Q(a|0);p()}x[d+24>>2]=a;a=0;e:{f:{g:{while(1){c=x[d+24>>2];x[114414]=0;w[d+22>>1]=a;b=O(2,d+8|0,(a<<2)+25872|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break g}x[114414]=0;T(1439,c|0,d+22|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break f}xb(b);a=a+1|0;if((a|0)!=12){continue}break}hb=d+32|0;return x[d+24>>2]}a=N()|0;break e}a=N()|0;xb(b)}Tf(d+24|0);Q(a|0);p()}function fga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=hb-16|0;hb=g;e=x[a+48>>2];m=x[a+24>>2];n=x[a+20>>2];h=x[a+44>>2];o=x[a+16>>2];b=x[a+4>>2];j=b;f=x[a>>2];x[g+8>>2]=f;x[g+12>>2]=b;b=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=b;a:{if(!d){b=e;break a}while(1){j=x[g+8>>2];b=x[g+12>>2]+o|0;p=v[b+1|0];l=v[b|0];f=x[a+60>>2];b=h;i=Xb(h,-16777216,16776704);h=x[a+64>>2];k=Xb(e,-16777216,16776704);q=x[a+72>>2];r=x[c>>2];e=yna(h,h>>31,i,i>>31);h=lb;i=e;e=x[a+68>>2];e=yna(e,e>>31,k,k>>31);k=i+e|0;i=lb+h|0;i=e>>>0>k>>>0?i+1|0:i;h=((D(p-l|0,j>>>10&4194048)|0)/16384|0)+(l<<8)<<8;e=h;e=yna(f,f>>31,e,e>>31);j=e+k|0;f=lb+i|0;f=e>>>0>j>>>0?f+1|0:f;e=j+8388608|0;e=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;f=(e|0)/256|0;x[c>>2]=D(f,n)+r;x[c+4>>2]=x[c+4>>2]+D(f,m);h=e-(h&q)|0;c=c+8|0;Tb(g+8|0,g);e=b;d=d-1|0;if(d){continue}break}f=x[g+8>>2];j=x[g+12>>2]}x[a>>2]=f;x[a+4>>2]=j;x[a+48>>2]=b;x[a+44>>2]=h;hb=g+16|0}function u6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-32|0;hb=f;m=f,n=Rn(b),x[m+16>>2]=n;d=hb-32|0;hb=d;e=b;c=Pe(a);g=mc(a);a:{if(c){while(1){b=c;c=b+16|0;if(nt(yb(a),e,c)){g=b;c=x[b>>2];if(c){continue}break a}if(!nt(yb(a),c,e)){break a}g=b+4|0;c=x[b+4>>2];if(c){continue}break a}}b=mc(a);g=b}x[d+28>>2]=b;b=x[g>>2];v[d+27|0]=0;if(!b){k=f+16|0;l=f+8|0;i=hb-16|0;hb=i;j=mc(a);b=Vd(40,4);h=Sk(i+8|0,j);c=hb-16|0;hb=c;x[114414]=0;x[c+12>>2]=b;e=d+8|0;b=U(1259,e|0,c+12|0,h|0)|0;h=x[114414];x[114414]=0;b:{if((h|0)!=1){hb=c+16|0;break b}S(0)|0;zb();p()}c=x[b>>2];x[114414]=0;c=R(1258,c+16|0)|0;h=x[114414];x[114414]=0;c:{d:{if((h|0)==1){break d}x[114414]=0;ba(2142,j|0,c|0,36692,k|0,l|0);c=x[114414];x[114414]=0;if((c|0)==1){break d}m=mc(b),n=1,v[m+4|0]=n;hb=i+16|0;break c}a=N()|0;oN(b);Q(a|0);p()}Tk(a,x[d+28>>2],g,x[e>>2]);b=ke(e);v[d+27|0]=1;oN(e)}a=f+24|0;Qi(a,Fb(d+8|0,b),d+27|0);hb=d+32|0;a=rh(a);hb=f+32|0;return a+12|0}function ZO(a,b,c){var d=0;d=y[a|0]&15;v[a|0]=y[d+24016|0];a:{b:{c:{switch(d|0){case 0:if(y[b|0]?c>>>0>=51:0){break b}v[a|0]=0;return;case 5:d=y[b|0];if(!((d&15)!=2&(d&240)!=32)){v[a|0]=20;v[b|0]=159;return}d:{if((d&15)!=12){if(c>>>0<51){break b}if((d&240)==192){break d}break b}if(c>>>0<51){break b}}v[a|0]=25;v[b|0]=0;return;case 7:if(c>>>0>51){break b}v[a|0]=0;return;case 10:a=y[b|0]&240;if(!a){break b}v[b|0]=a;return;case 11:v[b|0]=D(y[b|0]&15,17);return;case 12:v[b|0]=y[b|0]>>>2;return;case 13:a=y[b|0];v[b|0]=D(a>>>4|0,10)+(a&15);return;case 14:e:{switch((y[b|0]>>>4|0)-1|0){case 0:v[a|0]=2;break a;case 1:v[a|0]=3;break a;case 7:if(c>>>0<52){break b}v[a|0]=20;v[b|0]=y[b|0]&15|96;return;case 8:v[a|0]=15;v[b|0]=y[b|0]&15;return;case 9:v[a|0]=11;v[b|0]=y[b|0]<<4|15;return;case 10:v[a|0]=11;break a;case 11:case 12:break e;default:break b}}v[a|0]=20;return;case 15:break c;default:break b}}if(y[b|0]<48){break b}v[a|0]=17}return}v[b|0]=y[b|0]|240}function Vba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-32|0;hb=f;m=f,n=Rn(b),x[m+16>>2]=n;d=hb-32|0;hb=d;e=b;c=Pe(a);g=mc(a);a:{if(c){while(1){yb(a);b=c;c=b+16|0;if(Ft(e,c)){g=b;c=x[b>>2];if(c){continue}break a}yb(a);if(!Ft(c,e)){break a}g=b+4|0;c=x[b+4>>2];if(c){continue}break a}}b=mc(a);g=b}x[d+28>>2]=b;b=x[g>>2];v[d+27|0]=0;if(!b){k=f+16|0;l=f+8|0;i=hb-16|0;hb=i;j=mc(a);b=tM(j,1);h=Sk(i+8|0,j);c=hb-16|0;hb=c;x[114414]=0;x[c+12>>2]=b;e=d+8|0;b=U(1394,e|0,c+12|0,h|0)|0;h=x[114414];x[114414]=0;b:{if((h|0)!=1){hb=c+16|0;break b}S(0)|0;zb();p()}c=x[b>>2];x[114414]=0;c=R(1392,c+16|0)|0;h=x[114414];x[114414]=0;c:{d:{if((h|0)==1){break d}x[114414]=0;ba(1393,j|0,c|0,25776,k|0,l|0);c=x[114414];x[114414]=0;if((c|0)==1){break d}m=mc(b),n=1,v[m+4|0]=n;hb=i+16|0;break c}a=N()|0;qM(b);Q(a|0);p()}Tk(a,x[d+28>>2],g,x[e>>2]);b=ke(e);v[d+27|0]=1;qM(e)}a=f+24|0;Qi(a,Fb(d+8|0,b),d+27|0);hb=d+32|0;a=rh(a);hb=f+32|0;return a+8|0}function BE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;b=x[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=x[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=x[a+8>>2];if((g-f|0)<=0){break a}x[a+8>>2]=f+1;v[f|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}c=x[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if((f|0)<4){break b}x[a+8>>2]=c+1;v[c|0]=b>>>18|240;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>12&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}b=x[a+12>>2]+4|0;x[a+12>>2]=b;continue}break}c=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return c|0}function ega(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=hb-16|0;hb=g;e=x[a+48>>2];m=x[a+24>>2];n=x[a+20>>2];h=x[a+44>>2];o=x[a+16>>2];b=x[a+4>>2];j=b;f=x[a>>2];x[g+8>>2]=f;x[g+12>>2]=b;b=x[a+12>>2];x[g>>2]=x[a+8>>2];x[g+4>>2]=b;a:{if(!d){b=e;break a}while(1){j=x[g+8>>2];b=(x[g+12>>2]<<1)+o|0;p=w[b+2>>1];l=w[b>>1];f=x[a+60>>2];b=h;i=Xb(h,-16777216,16776704);h=x[a+64>>2];k=Xb(e,-16777216,16776704);q=x[a+72>>2];r=x[c>>2];e=yna(h,h>>31,i,i>>31);h=lb;i=e;e=x[a+68>>2];e=yna(e,e>>31,k,k>>31);k=i+e|0;i=lb+h|0;i=e>>>0>k>>>0?i+1|0:i;h=l+((D(p-l|0,j>>>18|0)|0)/16384|0)<<8;e=h;e=yna(f,f>>31,e,e>>31);j=e+k|0;f=lb+i|0;f=e>>>0>j>>>0?f+1|0:f;e=j+8388608|0;e=((e>>>0<8388608?f+1|0:f)&16777215)<<8|e>>>24;f=(e|0)/256|0;x[c>>2]=D(f,n)+r;x[c+4>>2]=x[c+4>>2]+D(f,m);h=e-(h&q)|0;c=c+8|0;Tb(g+8|0,g);e=b;d=d-1|0;if(d){continue}break}f=x[g+8>>2];j=x[g+12>>2]}x[a>>2]=f;x[a+4>>2]=j;x[a+48>>2]=b;x[a+44>>2]=h;hb=g+16|0}function Yba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-32|0;hb=f;m=f,n=Rn(b),x[m+16>>2]=n;d=hb-32|0;hb=d;e=b;c=Pe(a);g=mc(a);a:{if(c){while(1){yb(a);b=c;c=b+14|0;if(rM(e,c)){g=b;c=x[b>>2];if(c){continue}break a}yb(a);if(!rM(c,e)){break a}g=b+4|0;c=x[b+4>>2];if(c){continue}break a}}b=mc(a);g=b}x[d+28>>2]=b;b=x[g>>2];v[d+27|0]=0;if(!b){k=f+16|0;l=f+8|0;i=hb-16|0;hb=i;j=mc(a);b=hR(j);h=Sk(i+8|0,j);c=hb-16|0;hb=c;x[114414]=0;x[c+12>>2]=b;e=d+8|0;b=U(1391,e|0,c+12|0,h|0)|0;h=x[114414];x[114414]=0;b:{if((h|0)!=1){hb=c+16|0;break b}S(0)|0;zb();p()}c=x[b>>2];x[114414]=0;c=R(1388,c+14|0)|0;h=x[114414];x[114414]=0;c:{d:{if((h|0)==1){break d}x[114414]=0;ba(1390,j|0,c|0,25776,k|0,l|0);c=x[114414];x[114414]=0;if((c|0)==1){break d}m=mc(b),n=1,v[m+4|0]=n;hb=i+16|0;break c}a=N()|0;sM(b);Q(a|0);p()}Tk(a,x[d+28>>2],g,x[e>>2]);b=ke(e);v[d+27|0]=1;sM(e)}a=f+24|0;Qi(a,Fb(d+8|0,b),d+27|0);hb=d+32|0;a=au(a);hb=f+32|0;return a+4|0}function ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-32|0;hb=e;k=x[a+24>>2];l=x[a+20>>2];m=x[a+16>>2];g=x[a+4>>2];h=x[a>>2];x[e+24>>2]=h;x[e+28>>2]=g;i=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=i;i=a;if(d){n=b+24|0;while(1){a=x[e+24>>2];f=((((x[e+28>>2]&2147483647)<<1|a>>>31)&2147483646)<<1)+m|0;a=(((a>>>16|0)+4&131064)<<1)+n|0;o=w[a+14>>1];p=w[a+12>>1];q=w[a+10>>1];r=w[a+8>>1];s=w[a+6>>1];t=w[a+4>>1];g=w[a+2>>1];h=w[a>>1];j=0;b=1;while(1){a=j<<1;x[(e+8|0)+(j<<2)>>2]=(((((D(w[(a|8)+f>>1],q)+D(w[(a|4)+f>>1],r)|0)+D(w[(a|12)+f>>1],p)|0)+D(w[(a|16)+f>>1],o)|0)/2|0)+((((D(w[(a|-8)+f>>1],g)+D(w[(a|-12)+f>>1],h)|0)+D(w[(a|-4)+f>>1],t)|0)+D(w[a+f>>1],s)|0)/2|0)|0)/16384;a=b;b=0;j=1;if(a){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],k);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}h=x[e+24>>2];g=x[e+28>>2]}x[i>>2]=h;x[i+4>>2]=g;hb=e+32|0}function gs(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;a:{b:{d=pi(a)&2047;c=pi(5551115123125783e-32);f=d-c|0;if(f>>>0<pi(512)-c>>>0){f=d;break b}if((f|0)<0){return a+1}f=0;if(pi(1024)>>>0>d>>>0){break b}o(+a);c=j(1)|0;e=0;if(!(j(0)|0)&(c|0)==-1048576){break a}if(pi(Infinity)>>>0<=d>>>0){return a+1}if((c|0)<0){return hs(12882297539194267e-247)}return hs(3105036184601418e216)}b=C[6409];g=C[6408]*a+b;b=g-b;a=b*C[6411]+(b*C[6410]+a);b=a*a;k=b*b*(a*C[6415]+C[6414]);e=b*(a*C[6413]+C[6412]);o(+g);j(1)|0;i=j(0)|0;c=i<<4&2032;a=k+(e+(C[c+51376>>3]+a));c=c+51384|0;h=x[c>>2];d=x[c+4>>2];c=h;h=0;c=c+h|0;d=(i<<13)+d|0;d=c>>>0<h>>>0?d+1|0:d;if(!f){c:{if(!(i&-2147483648)){l(0,c|0);l(1,d-1058013184|0);b=+n();a=(b*a+b)*5486124068793689e288;break c}l(0,c|0);l(1,d+1071644672|0);b=+n();g=b*a;a=g+b;if(a<1){$G(aH()*22250738585072014e-324);e=a+1;a=e+(g+(b-a)+(a+(1-e)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,c|0);l(1,d|0);b=+n();e=b*a+b}return e}function BK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-32|0;hb=f;m=f,n=Rn(b),x[m+16>>2]=n;d=hb-32|0;hb=d;e=b;c=Pe(a);g=mc(a);a:{if(c){while(1){b=c;c=b+16|0;if(Ps(yb(a),e,c)){g=b;c=x[b>>2];if(c){continue}break a}if(!Ps(yb(a),c,e)){break a}g=b+4|0;c=x[b+4>>2];if(c){continue}break a}}b=mc(a);g=b}x[d+28>>2]=b;b=x[g>>2];v[d+27|0]=0;if(!b){k=f+16|0;l=f+8|0;h=hb-16|0;hb=h;j=mc(a);c=ZC(1);e=Sk(h+8|0,j);b=hb-16|0;hb=b;x[114414]=0;x[b+12>>2]=c;c=d+8|0;e=U(1653,c|0,b+12|0,e|0)|0;i=x[114414];x[114414]=0;b:{if((i|0)!=1){hb=b+16|0;break b}S(0)|0;zb();p()}b=x[e>>2];x[114414]=0;b=R(706,b+16|0)|0;i=x[114414];x[114414]=0;c:{d:{if((i|0)==1){break d}x[114414]=0;ba(1652,j|0,b|0,35980,k|0,l|0);b=x[114414];x[114414]=0;if((b|0)==1){break d}m=mc(e),n=1,v[m+4|0]=n;hb=h+16|0;break c}a=N()|0;tK(e);Q(a|0);p()}Tk(a,x[d+28>>2],g,x[c>>2]);b=ke(c);v[d+27|0]=1;tK(c)}a=f+24|0;Qi(a,Fb(d+8|0,b),d+27|0);hb=d+32|0;a=rh(a);hb=f+32|0;return a+4|0}function Vja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-32|0;hb=f;m=f,n=Rn(b),x[m+16>>2]=n;d=hb-32|0;hb=d;e=b;c=Pe(a);g=mc(a);a:{if(c){while(1){b=c;c=b+14|0;if(Qn(yb(a),e,c)){g=b;c=x[b>>2];if(c){continue}break a}if(!Qn(yb(a),c,e)){break a}g=b+4|0;c=x[b+4>>2];if(c){continue}break a}}b=mc(a);g=b}x[d+28>>2]=b;b=x[g>>2];v[d+27|0]=0;if(!b){k=f+16|0;l=f+8|0;i=hb-16|0;hb=i;j=mc(a);b=hR(j);h=Sk(i+8|0,j);c=hb-16|0;hb=c;x[114414]=0;x[c+12>>2]=b;e=d+8|0;b=U(809,e|0,c+12|0,h|0)|0;h=x[114414];x[114414]=0;b:{if((h|0)!=1){hb=c+16|0;break b}S(0)|0;zb();p()}c=x[b>>2];x[114414]=0;c=R(803,c+14|0)|0;h=x[114414];x[114414]=0;c:{d:{if((h|0)==1){break d}x[114414]=0;ba(808,j|0,c|0,23867,k|0,l|0);c=x[114414];x[114414]=0;if((c|0)==1){break d}m=mc(b),n=1,v[m+4|0]=n;hb=i+16|0;break c}a=N()|0;gR(b);Q(a|0);p()}Tk(a,x[d+28>>2],g,x[e>>2]);b=ke(e);v[d+27|0]=1;gR(e)}a=f+24|0;Qi(a,Fb(d+8|0,b),d+27|0);hb=d+32|0;a=au(a);hb=f+32|0;return a+2|0}function Ska(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-32|0;hb=f;m=f,n=Rn(b),x[m+16>>2]=n;d=hb-32|0;hb=d;e=b;c=Pe(a);g=mc(a);a:{if(c){while(1){b=c;c=b+16|0;if(Qn(yb(a),e,c)){g=b;c=x[b>>2];if(c){continue}break a}if(!Qn(yb(a),c,e)){break a}g=b+4|0;c=x[b+4>>2];if(c){continue}break a}}b=mc(a);g=b}x[d+28>>2]=b;b=x[g>>2];v[d+27|0]=0;if(!b){k=f+16|0;l=f+8|0;h=hb-16|0;hb=h;j=mc(a);c=ZC(1);e=Sk(h+8|0,j);b=hb-16|0;hb=b;x[114414]=0;x[b+12>>2]=c;c=d+8|0;e=U(705,c|0,b+12|0,e|0)|0;i=x[114414];x[114414]=0;b:{if((i|0)!=1){hb=b+16|0;break b}S(0)|0;zb();p()}b=x[e>>2];x[114414]=0;b=R(703,b+16|0)|0;i=x[114414];x[114414]=0;c:{d:{if((i|0)==1){break d}x[114414]=0;ba(704,j|0,b|0,23716,k|0,l|0);b=x[114414];x[114414]=0;if((b|0)==1){break d}m=mc(e),n=1,v[m+4|0]=n;hb=h+16|0;break c}a=N()|0;oS(e);Q(a|0);p()}Tk(a,x[d+28>>2],g,x[c>>2]);b=ke(c);v[d+27|0]=1;oS(c)}a=f+24|0;Qi(a,Fb(d+8|0,b),d+27|0);hb=d+32|0;a=rh(a);hb=f+32|0;return a+4|0}function jj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=hb-32|0;hb=i;x[i+16>>2]=c;x[i+24>>2]=b;b=i+8|0;Dc(b,d);x[114414]=0;j=R(2510,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){Ob(i+8|0);x[e>>2]=0;b=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(hh(i+24|0,i+16|0)){break b}c:{if((Pm(j,x[g>>2])|0)==37){b=g+4|0;if((h|0)==(b|0)){break b}k=0;c=Pm(j,x[b>>2]);d:{if(!((c|0)==69|(c&255)==48)){b=g;break d}if((g+8|0)==(h|0)){break b}k=c;c=Pm(j,x[g+8>>2])}l=i,m=mb[x[x[a>>2]+36>>2]](a,x[i+24>>2],x[i+16>>2],d,e,f,c,k)|0,x[l+24>>2]=m;g=b+8|0;break c}if(lk(j,1,x[g>>2])){while(1){e:{g=g+4|0;if((h|0)==(g|0)){g=h;break e}if(lk(j,1,x[g>>2])){continue}}break}while(1){if(hh(i+24|0,i+16|0)){break c}if(!lk(j,1,wl(i+24|0))){break c}Zm(i+24|0);continue}}if((al(j,wl(i+24|0))|0)==(al(j,x[g>>2])|0)){g=g+4|0;Zm(i+24|0);break c}x[e>>2]=4}b=x[e>>2];continue}break}x[e>>2]=4}if(hh(i+24|0,i+16|0)){x[e>>2]=x[e>>2]|2}hb=i+32|0;return x[i+24>>2]}a=N()|0;Ob(i+8|0);Q(a|0);p()}function Maa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-32|0;hb=f;e=hb-16|0;hb=e;c=a+33|0;x[b>>2]=y[c+206|0]|y[c+207|0]<<8;kL(c,b+48|0,y[c+192|0],y[c+200|0],y[c+194|0],y[c+195|0],y[c+196|0],0);kL(c,b+68|0,y[c+193|0],y[c+201|0],y[c+197|0],y[c+198|0],y[c+199|0],1);g=b+236|0;while(1){i=y[c+d|0];j=fd(g,d+12|0),k=i,w[j>>1]=k;d=d+1|0;if((d|0)!=96){continue}break}if(y[c+208|0]){v[b+31|0]=y[c+209|0]+1;d=1;g=y[b+31|0];a:{if(g){d=16;if(g>>>0<=16){break a}}v[b+31|0]=d}w[e+14>>1]=y[c+210|0]|y[c+211|0]<<8;w[e+12>>1]=127;j=b,k=y[Cf(e+14|0,e+12|0)|0]+1|0,v[j+30|0]=k}v[b+33|0]=y[c+212|0];hb=e+16|0;e=b+236|0;while(1){d=0;g=c+h|0;if(y[g|0]<(y[a+27|0]|y[a+28|0]<<8)>>>0){d=y[g|0]}j=fd(e,h+12|0),k=d,w[j>>1]=k;h=h+1|0;if((h|0)!=96){continue}break}lm(f,3,a+4|0);c=f+16|0;Ic(c,f);x[114414]=0;O(334,b+492|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){xb(f+16|0);if(!y[a+241|0]){v[b+30|0]=y[a+26|0]}hb=f+32|0;return}a=N()|0;xb(f+16|0);Q(a|0);p()}function zja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-16|0;hb=e;v[e+15|0]=8;w[e+12>>1]=0;x[e+8>>2]=0;if(d){k=D(c,d);c=0;while(1){if((k|0)>0){h=(j<<1)+b|0;m=h+(k<<1)|0;while(1){n=c;w[e+6>>1]=0;ZQ(a,e+14|0,e+12|0,e+15|0,e+6|0);a:{b:{g=y[e+15|0];if(!g){break b}c=z[e+12>>1];while(1){f=c<<1;c=f&254;w[e+12>>1]=c;f=(f&65534)>>>0>255;v[e+14|0]=f;if(!c){if(!Oe(a,e+5|0)){break b}c=y[e+5|0];f=c>>>7|0;v[e+14|0]=f;c=c<<1&254|1;w[e+12>>1]=c}i=z[e+6>>1]<<1|f;w[e+6>>1]=i;g=g-1|0;if(g&255){continue}break}break a}i=z[e+6>>1]}c=1;g=i&65535;c:{if(g>>>0<4){break c}f=15;while(1){c=f;l=c&255;if(g>>>l&1){break c}f=c-1|0;if(l>>>0>1){continue}break}}v[e+15|0]=(y[e+15|0]+c&254)>>>1;c=i&1;v[e+14|0]=c;f=c-1^(i&65534)>>>1;c=f+z[e+8>>1]|0;w[e+6>>1]=c;w[h>>1]=c;x[e+8>>2]=((f>>1)-(n<<16>>16)|0)+(c<<16>>16<<1);_d(e+8|0,-32768,32767);h=(d<<1)+h|0;if(m>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}hb=e+16|0}function Q0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;x[c+28>>2]=0;nj(c+24|0,a,0);a:{b:{c:{if(y[c+24|0]){d=x[x[a>>2]-12>>2];x[114414]=0;Dc(c+16|0,a+d|0);d=x[114414];x[114414]=0;d:{e:{f:{g:{h:{if((d|0)!=1){x[114414]=0;d=R(2347,c+16|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break h}e=_m(c+8|0,a);f=Xc(c);g=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[114414]=0;ga(2350,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break h}Ob(c+16|0);break f}b=S(0)|0;break g}b=S(0)|0;Ob(c+16|0)}Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;mj(x[x[a>>2]-12>>2]+a|0,b);b=x[x[a>>2]-12>>2];x[114414]=0;b=x[(a+b|0)+20>>2];d=x[114414];x[114414]=0;if((d|0)!=1){if(!(b&1)){break e}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)==1){break c}Q(a|0);p()}d=x[c+20>>2];x[b>>2]=d;break d}_()}Jg(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}hb=c+32|0;break a}S(0)|0;zb()}p()}return a|0}function Gfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;h=x[a+12>>2];f=h;a:{b:{c:{g=x[a+8>>2];d:{if((f|0)<=1&g>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&g>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&g>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&g>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];i=x[a+4>>2];b=x[a>>2];x[e+8>>2]=b;x[e+12>>2]=i;x[e>>2]=g;x[e+4>>2]=f;g=a;if(d){while(1){a=x[e+8>>2];b=(x[e+12>>2]<<1)+j|0;a=(a>>>16&65520)+h|0;a=(((((((D(w[b-4>>1],w[a+2>>1])+D(w[b-6>>1],w[a>>1])|0)+D(w[b-2>>1],w[a+4>>1])|0)+D(w[b>>1],w[a+6>>1])|0)+D(w[b+2>>1],w[a+8>>1])|0)+D(w[b+4>>1],w[a+10>>1])|0)+D(w[b+6>>1],w[a+12>>1])|0)+D(w[b+8>>1],w[a+14>>1])|0)/32768|0;x[c>>2]=x[c>>2]+D(a,l);x[c+4>>2]=x[c+4>>2]+D(a,k);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}b=x[e+8>>2];i=x[e+12>>2]}x[g>>2]=b;x[g+4>>2]=i;hb=e+16|0}function Hga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-48|0;hb=f;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;c=f+44|0;Un(b,c);a:{if(!KO(c)){break a}d=y[f+46|0];g=y[f+47|0];e=y[f+45|0];v[a+4|0]=1;h=e>>>3&3;c=(h|0)!=3;e=(e^-1)>>>1&3;g=g>>>0<192;w[a+2>>1]=z[(D(c,6)+24312|0)+(e<<1)>>1]<<g;i=D(D(y[e+(D(c,3)+24088|0)|0],z[((D(c,90)+24096|0)+D(e,30)|0)+(d>>>3&30)>>1]),1e3);d=d>>>1|0;d=D(((i>>>0)/z[(D(h,6)+24288|0)+(d&6)>>1]|0)+(d&1)|0,e?1:4);w[a>>1]=d;e=y[g+((c<<1)+24324|0)|0];if(e+8>>>0>(d&65535)>>>0){break a}c=hb-16|0;hb=c;x[c+12>>2]=e+4;x[c>>2]=36;d=x[Mb(c+12|0,c)>>2];if(!Qb(b,d)){d=uf(b)}Sq(c,f);lg(b,x[c>>2],d);Sq(c,f);Sb(x[c>>2]+d|0,0,36-d|0);cc(b,x[c+12>>2]);hb=c+16|0;b=2;if(e>>>0>2){while(1){if(y[b+f|0]){break a}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=e+f|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1868983881){b=1}else{b=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1735289176}v[a+5|0]=b}hb=f+48|0;return a|0}function kj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=hb-32|0;hb=i;x[i+16>>2]=c;x[i+24>>2]=b;b=i+8|0;Dc(b,d);x[114414]=0;j=R(21,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){Ob(i+8|0);x[e>>2]=0;b=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(Ag(i+24|0,i+16|0)){break b}c:{if((Qm(j,v[g|0])|0)==37){b=g+1|0;if((h|0)==(b|0)){break b}k=0;c=Qm(j,v[b|0]);d:{if(!((c|0)==69|(c&255)==48)){b=g;break d}if((g+2|0)==(h|0)){break b}k=c;c=Qm(j,v[g+2|0])}l=i,m=mb[x[x[a>>2]+36>>2]](a,x[i+24>>2],x[i+16>>2],d,e,f,c,k)|0,x[l+24>>2]=m;g=b+2|0;break c}if(zg(j,1,v[g|0])){while(1){e:{g=g+1|0;if((h|0)==(g|0)){g=h;break e}if(zg(j,1,v[g|0])){continue}}break}while(1){if(Ag(i+24|0,i+16|0)){break c}if(!zg(j,1,nk(i+24|0))){break c}yl(i+24|0);continue}}if((gw(j,nk(i+24|0))|0)==(gw(j,v[g|0])|0)){g=g+1|0;yl(i+24|0);break c}x[e>>2]=4}b=x[e>>2];continue}break}x[e>>2]=4}if(Ag(i+24|0,i+16|0)){x[e>>2]=x[e>>2]|2}hb=i+32|0;return x[i+24>>2]}a=N()|0;Ob(i+8|0);Q(a|0);p()}function i4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;i=c,j=OI(),x[i+24>>2]=j;f=c+24|0;MI(a+24|0,ke(f));ui(f);w[a+28>>1]=0;e=hL();g=hb-16|0;hb=g;d=Me(44);x[114414]=0;h=O(2165,d|0,e|0)|0;e=x[114414];x[114414]=0;a:{if((e|0)!=1){e=hb-16|0;hb=e;x[114414]=0;x[e+12>>2]=h;d=U(2169,g+8|0,e+12|0,e+8|0)|0;h=x[114414];x[114414]=0;b:{if((h|0)!=1){hb=e+16|0;break b}S(0)|0;zb();p()}hb=g+16|0;d=x[d>>2];break a}a=N()|0;_b(d);Q(a|0);p()}x[c+24>>2]=d;Vs(a+32|0,f);dg(f);i=c,j=NI(x[a>>2]),x[i+24>>2]=j;ZI(a+4|0,ke(f));pd(f);jn(x[a+24>>2],x[a+4>>2]);x[a+60>>2]=0;x[a+48>>2]=1065353216;x[a+52>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;v[a- -64|0]=0;i=c,j=Gj(b),x[i+24>>2]=j;i=c,j=Ti(b),x[i+16>>2]=j;c:{if(Si(f,c+16|0)){while(1){d=rh(c+24|0);b=Uf(c,d);x[114414]=0;X(2114,a|0,b|0,d+12|0,0);d=x[114414];x[114414]=0;if((d|0)==1){break c}xb(b);b=c+24|0;dq(b);if(Si(b,c+16|0)){continue}break}}hb=c+32|0;return}a=N()|0;xb(b);Q(a|0);p()}function wO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+14|0]=5;w[a+12>>1]=0;x[a+8>>2]=128;x[a>>2]=256;x[a+4>>2]=64;x[a+28>>2]=0;v[a+27|0]=60;x[a+40>>2]=0;x[a+44>>2]=0;v[a+33|0]=2;v[a+34|0]=0;v[a+35|0]=0;v[a+36|0]=2;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=255;v[a+26|0]=0;v[a+32|0]=0;d=jz(a+48|0);e=jz(a+68|0);f=jz(a+88|0);x[114414]=0;R(1150,a+492|0)|0;c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}x[114414]=0;R(1150,a+524|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;T(882,a|0,0,0);c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;T(883,a|0,0,0);c=x[114414];x[114414]=0;if((c|0)==1){break a}x[a+40>>2]=0;x[a+44>>2]=0;x[114414]=0;P(755,a|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}d=a+108|0;b=0;while(1){c=gc(d,b);b=b+1|0;v[c|0]=b;if(b>>>0<128){continue}break}return a|0}a=N()|0;Mn(f);Mn(e);Mn(d);Q(a|0);p()}function Hfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;h=x[a+12>>2];f=h;a:{b:{c:{g=x[a+8>>2];d:{if((f|0)<=1&g>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&g>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&g>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&g>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];i=x[a+4>>2];b=x[a>>2];x[e+8>>2]=b;x[e+12>>2]=i;x[e>>2]=g;x[e+4>>2]=f;g=a;if(d){while(1){a=x[e+8>>2];b=x[e+12>>2]+j|0;a=(a>>>16&65520)+h|0;a=(((((((D(v[b-2|0],w[a+2>>1])+D(v[b-3|0],w[a>>1])|0)+D(v[b-1|0],w[a+4>>1])|0)+D(v[b|0],w[a+6>>1])|0)+D(v[b+1|0],w[a+8>>1])|0)+D(v[b+2|0],w[a+10>>1])|0)+D(v[b+3|0],w[a+12>>1])|0)+D(v[b+4|0],w[a+14>>1])<<8)/32768|0;x[c>>2]=x[c>>2]+D(a,l);x[c+4>>2]=x[c+4>>2]+D(a,k);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}b=x[e+8>>2];i=x[e+12>>2]}x[g>>2]=b;x[g+4>>2]=i;hb=e+16|0}function ER(a){var b=0,c=0,d=0,e=0;c=hb-48|0;hb=c;b=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[c+8>>2]=(b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24))+788;x[c+12>>2]=0;b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[c+16>>2]=b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24);x[c+20>>2]=0;if(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24)){b=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);b=b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24)}else{b=52}x[c+24>>2]=b;x[c+28>>2]=0;a=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);x[c+44>>2]=4;x[c+40>>2]=c+8;b=x[c+44>>2];x[c>>2]=x[c+40>>2];x[c+4>>2]=b;x[c+32>>2]=(a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24))+80;x[c+36>>2]=0;e=hb-16|0;hb=e;a=x[c>>2];d=x[c>>2]+(x[c+4>>2]<<3)|0;a:{if((a|0)==(d|0)){break a}b=a+8|0;if((d|0)==(b|0)){break a}while(1){a=bv(a,b)?b:a;b=b+8|0;if((d|0)!=(b|0)){continue}break}}hb=e+16|0;hb=c+48|0;b=x[a>>2];c=b-52|0;lb=x[a+4>>2]-(b>>>0<52)|0;return c}function Gga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;h=Cb(b);a:{b:{c:{d:{while(1){b=c;if(!c){break d}c=b-1|0;if(!y[h+c|0]){continue}break}if((d|0)!=4){break b}c=0;while(1){e:{f:{g:{d=c+h|0;f=y[d|0];switch(f-10|0){case 0:break f;case 3:break g;default:break e}}e=e+1|0;break e}g=g+1|0}i=c?((f|0)==10&y[d-1|0]==13)+i|0:i;c=c+1|0;if((c|0)!=(b|0)){continue}break}break c}f=1;b=0;if((d|0)!=4){break a}}h:{if((e|0)==(g|0)){d=2;if((e|0)==(i|0)){break h}}if(e){d=0;if(!g){break h}}d=e?3:g?1:3}if(b){break b}b=0;f=1;e=0;break a}f=0;g=(d|0)==2;c=0;e=0;while(1){e=e+1|0;c=((g&y[c+h|0]==13)+c|0)+1|0;if(c>>>0<b>>>0){continue}break}}He(a);rr(a,e);if(!f){g=(d|0)==1?32:13;f=d&-3?13:32;d=(d|0)==2;c=0;while(1){i:{j:{k:{l:{e=v[c+h|0];switch(e-10|0){case 1:case 2:break i;case 0:break j;case 3:break k;default:break l}}if(e){break i}e=32;break i}c=c+d|0;e=g;break i}e=f}No(a,e);c=c+1|0;if(c>>>0<b>>>0){continue}break}}return 1}function zE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;a=c;a:{if((d-a|0)<3){break a}}while(1){b:{if(e>>>0<=h>>>0|a>>>0>=d>>>0){break b}b=v[a|0];g=b&255;c:{if((b|0)>=0){b=1;break c}if(b>>>0<4294967234){break b}if(b>>>0<=4294967263){if((y[a+1|0]&192)!=128|(d-a|0)<2){break b}b=2;break c}d:{e:{if(b>>>0<=4294967279){if((d-a|0)<3){break b}f=y[a+2|0];b=y[a+1|0];if((g|0)==237){break e}if((g|0)==224){if((b&224)==160){break d}break b}if((b&192)!=128){break b}break d}if((d-a|0)<4|b>>>0>4294967284){break b}i=y[a+3|0];j=y[a+2|0];f=y[a+1|0];f:{g:{switch(g-240|0){case 0:if((f+112&255)>>>0<48){break f}break b;case 4:if((f&240)==128){break f}break b;default:break g}}if((f&192)!=128){break b}}if((j&192)!=128|(i&192)!=128){break b}b=4;if((i&63|(j<<6&4032|(g<<18&1835008|(f&63)<<12)))>>>0>1114111){break b}break c}if((b&224)!=128){break b}}if((f&192)!=128){break b}b=3}h=h+1|0;a=a+b|0;continue}break}return a-c|0}function Zo(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;o(+a);e=j(1)|0;j(0)|0;b=e>>>16|0;o(+a);d=j(1)|0;e=j(0)|0;i=d-1072562176|0;if((i|0)==198911|i>>>0<198911){if(!e&(d|0)==1072693248){return 0}a=a+-1;c=a*134217728;c=a+c-c;h=C[6685];k=c*c*h;m=a+k;f=a*a;g=a*f;return m+(g*(g*(g*(g*C[6695]+(f*C[6694]+(a*C[6693]+C[6692])))+(f*C[6691]+(a*C[6690]+C[6689])))+(f*C[6688]+(a*C[6687]+C[6686])))+((a-c)*h*(a+c)+(k+(a-m))))}a:{if(b-32752>>>0<=4294934559){if(!(d&2147483647|e)){return bH(-1)/0}if(!e&(d|0)==2146435072){break a}if(!(!(b&32768)&(b&32752)!=32752)){a=a-a;return a/a}o(+(a*4503599627370496));d=j(1)|0;e=j(0)|0;d=d-54525952|0}b=d-1072037888|0;i=b;f=+(b>>20);b=(b>>>13&127)<<4;g=f*C[6678]+C[b+53576>>3];a=C[b+53568>>3];l(0,e-0|0);l(1,d-((i&-1048576)+(e>>>0<p>>>0)|0)|0);a=a*(+n()-C[b+55616>>3]-C[b+55624>>3]);h=g+a;c=a*a;a=h+(a*c*(c*(a*C[6684]+C[6683])+(a*C[6682]+C[6681]))+(c*C[6680]+(f*C[6679]+(a+(g-h)))))}return a}function OJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0);b=hb-32|0;hb=b;d=x[a+20>>2];a:{if(!d){break a}if(wc(d+4|0)>>>0<4){break a}d=b+8|0;ej(d,x[a+20>>2]+4|0);c=hb-16|0;hb=c;e=c+8|0;vK(e,ac(c,d));d=b+16|0;vv(d,e);x[d+12>>2]=0;x[d+8>>2]=0;hb=c+16|0;x[114414]=0;c=R(391,d|0)|0;e=x[114414];x[114414]=0;b:{if((e|0)!=1){if(c){break b}c=x[x[a>>2]+40>>2];x[114414]=0;c=R(c|0,a|0)|0;e=x[114414];x[114414]=0;c:{if((e|0)==1){break c}if(wc(x[a+20>>2]+4|0)-4>>>0<c<<2>>>0){break b}f=x[x[a>>2]+168>>2];e=0;x[114414]=0;P(f|0,a|0,-1);f=x[114414];x[114414]=0;if((f|0)==1){break c}if(c){while(1){x[114414]=0;g=E(wa(675,d|0));f=x[114414];x[114414]=0;if((f|0)==1){break c}f=x[x[a>>2]+44>>2];x[114414]=0;va(f|0,a|0,e|0,E(g));f=x[114414];x[114414]=0;if((f|0)==1){break c}e=e+1|0;if((c|0)!=(e|0)){continue}break}}c=x[x[a>>2]+172>>2];x[114414]=0;W(c|0,a|0);a=x[114414];x[114414]=0;if((a|0)!=1){break b}}}a=N()|0;Ab(d);Q(a|0);p()}Ab(d)}hb=b+32|0}function zea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-16|0;hb=f;x[f+12>>2]=b;a:{if(Dh(a)>>>0>=b>>>0){j=f,k=ue(a),x[j+8>>2]=k;b=x[a>>2];i=x[Mb(f+12|0,f+8|0)>>2];if(i){while(1){if((b|0)!=(c|0)){d=bc(c);g=dc(c);e=hb-16|0;hb=e;h=OA(d,g);b:{if(h>>>0<=Vf(b)>>>0){if(qc(b)>>>0<h>>>0){x[e+8>>2]=d;cO(e+8|0,qc(b));gz(d,x[e+8>>2],x[b>>2]);iO(b,x[e+8>>2],g,h-qc(b)|0);break b}ko(b,gz(d,g,x[b>>2]));break b}hO(b);Ln(b,$i(b,h));iO(b,d,g,h)}hb=e+16|0;gj(b+12|0,c+12|0);w[b+28>>1]=z[c+28>>1]}b=b+32|0;i=i-1|0;if(i){continue}break}}b=x[f+12>>2];d=x[f+8>>2];if(b>>>0>d>>>0){ez(a,b-d|0,c);break a}dO(a,x[a>>2]+(b<<5)|0);break a}if(x[a>>2]){ue(a);eO(a);yv(a);_g(yb(a),x[a>>2],Dh(a));j=yb(a),k=0,x[j>>2]=k;x[a>>2]=0;x[a+4>>2]=0}e=xm(a,b);d=hb-16|0;hb=d;if(aD(a)>>>0<e>>>0){Vc();p()}$C(d+8|0,yb(a),e);e=x[d+8>>2];x[a+4>>2]=e;x[a>>2]=e;g=x[d+12>>2];j=yb(a),k=e+(g<<5)|0,x[j>>2]=k;ar(a,0);hb=d+16|0;ez(a,b,c)}hb=f+16|0}function yja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;v[e+15|0]=4;w[e+12>>1]=0;x[e+8>>2]=0;if(d){k=D(c,d);m=(k|0)<=0;c=0;while(1){if(!m){h=b+j|0;n=k+h|0;while(1){o=c;v[e+7|0]=0;YQ(a,e+14|0,e+12|0,e+7|0);a:{b:{g=y[e+15|0];if(!g){break b}c=z[e+12>>1];while(1){f=c<<1;c=f&254;w[e+12>>1]=c;f=(f&65534)>>>0>255;v[e+14|0]=f;if(!c){if(!Oe(a,e+6|0)){break b}c=y[e+6|0];f=c>>>7|0;v[e+14|0]=f;c=c<<1&254|1;w[e+12>>1]=c}i=y[e+7|0]<<1|f;v[e+7|0]=i;g=g-1|0;if(g&255){continue}break}break a}i=y[e+7|0]}c=1;g=i&255;c:{if(g>>>0<4){break c}f=7;while(1){c=f;l=c&255;if(g>>>l&1){break c}f=c-1|0;if(l>>>0>1){continue}break}}v[e+15|0]=(y[e+15|0]+c&254)>>>1;c=i&1;v[e+14|0]=c;f=c-1^(i&254)>>>1;c=f+y[e+8|0]|0;v[e+7|0]=c;v[h|0]=c;x[e+8>>2]=((f>>1)-(o<<24>>24)|0)+(c<<24>>24<<1);_d(e+8|0,-128,127);h=d+h|0;if(n>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}hb=e+16|0}function qda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-32|0;hb=e;mi(a);g=yb(a);c=Fb(e+16|0,x[a+4>>2]);f=Fb(e+8|0,x[a>>2]);d=Fb(e,x[b+4>>2]);h=x[c>>2];d=x[d>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[f>>2];x[c+40>>2]=h;x[c+24>>2]=d;x[c+16>>2]=d;a:{b:{c:{d:{while(1){e:{x[114414]=0;d=O(1260,c+40|0,c+32|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break e}if(!d){break d}d=nN(c+24|0);f=Mm(c+40|0);x[114414]=0;T(1256,g|0,d|0,f|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}ij(c+40|0);ij(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(1261,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;c=x[c+24>>2];break a}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb()}p()}x[e+24>>2]=c;x[b+4>>2]=x[e+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Nm(a,zc(a));hb=e+32|0}function pfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-32|0;hb=e;j=x[a+24>>2];k=x[a+20>>2];l=x[a+16>>2];g=x[a+4>>2];h=x[a>>2];x[e+24>>2]=h;x[e+28>>2]=g;i=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=i;i=a;if(d){m=b+24|0;while(1){a=x[e+24>>2];f=(((x[e+28>>2]&2147483647)<<1|a>>>31)&-2)+l|0;a=(((a>>>16|0)+4&131064)<<1)+m|0;n=w[a+14>>1];o=w[a+12>>1];p=w[a+10>>1];q=w[a+8>>1];r=w[a+6>>1];s=w[a+4>>1];t=w[a+2>>1];g=w[a>>1];b=0;a=1;while(1){x[(e+8|0)+(b<<2)>>2]=((((D(v[(b|4)+f|0],p)+D(v[(b|2)+f|0],q)|0)+D(v[(b|6)+f|0],o)|0)+D(v[(b|8)+f|0],n)<<8>>1)+(((D(v[(b|-4)+f|0],t)+D(v[(b|-6)+f|0],g)|0)+D(v[(b|-2)+f|0],s)|0)+D(v[b+f|0],r)<<8>>1)|0)/16384;h=a;a=0;b=1;if(h){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],k);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],j);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}h=x[e+24>>2];g=x[e+28>>2]}x[i>>2]=h;x[i+4>>2]=g;hb=e+32|0}function m2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-32|0;hb=e;ml(a);g=yb(a);c=Fb(e+16|0,x[a+4>>2]);f=Fb(e+8|0,x[a>>2]);d=Fb(e,x[b+4>>2]);h=x[c>>2];d=x[d>>2];c=hb-48|0;hb=c;x[c+32>>2]=x[f>>2];x[c+40>>2]=h;x[c+24>>2]=d;x[c+16>>2]=d;a:{b:{c:{d:{while(1){e:{x[114414]=0;d=O(2236,c+40|0,c+32|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break e}if(!d){break d}d=hI(c+24|0);f=lu(c+40|0);x[114414]=0;T(2157,g|0,d|0,f|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}mq(c+40|0);mq(c+24|0);continue}break}Y(S(0)|0)|0;a=Mc(c,g,c+16|0,c+24|0);x[114414]=0;W(2237,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break c}hb=c+48|0;c=x[c+24>>2];break a}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb()}p()}x[e+24>>2]=c;x[b+4>>2]=x[e+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Jo(a,rd(a));hb=e+32|0}function sH(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=x[a+32>>2];b=x[a+1380>>2];a:{b:{if((b|0)==-1){f=1;b=-1;break b}d=x[a+1116>>2];c:{if((d|0)<=(b|0)){break c}while(1){e=y[(a+b|0)+1120|0];c=e+c|0;if((e|0)!=255){break c}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}if(A[a+40>>2]<c>>>0){fc(a,1);break a}b=(b|0)==(d|0)?-1:b}d:{while(1){if((b|0)!=-1){return 1}e=x[a+40>>2];if(e>>>0<=c+26>>>0){fc(a,1);break a}if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=(y[83488]|y[83489]<<8|(y[83490]<<16|y[83491]<<24))){fc(a,21);break a}if(y[c+4|0]){fc(a,21);break a}e:{if(f){if(!x[a+992>>2]|!(v[c+5|0]&1)){break e}fc(a,21);break a}if(v[c+5|0]&1){break e}fc(a,21);break a}g=c+27|0;d=y[c+26|0];c=g+d|0;if(e>>>0<c>>>0){break d}f=0;b=0;f:{if(!d){break f}while(1){h=y[b+g|0];c=h+c|0;if((h|0)!=255){break f}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}b=(b|0)==(d|0)?-1:b;if(c>>>0<=e>>>0){continue}break}fc(a,1);break a}fc(a,1)}return 0}function oha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;j=hb-112|0;hb=j;a:{b:{if(!Be(a)){break b}if(zc(b)>>>0<2){break b}f=tz(j+8|0,a);x[f+20>>2]=0;x[f>>2]=0;c:{d=zc(b);if(d){d:{while(1){c=wd(b,g);e=x[a>>2];i=x[c>>2];if(e>>>0<=i>>>0){break d}c=x[c+4>>2];if(c>>>0>e-i>>>0){break d}e=x[f>>2];if(e>>>0>268435456-c>>>0){break d}x[f>>2]=c+e;g=g+1|0;if((d|0)!=(g|0)){continue}break}g=d}if(!Sp(f)){break b}if(!g){break c}i=f+68|0;d=0;c=0;while(1){e=wd(b,d);k=x[f+20>>2];x[114414]=0;k=R(417,k|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}h=x[a+20>>2];x[114414]=0;h=R(417,h|0)|0;l=x[114414];x[114414]=0;if((l|0)==1){break a}sc(c+k|0,h+x[e>>2]|0,x[e+4>>2]);x[e>>2]=c;if(!(!d|d>>>0>9)){x[(i+(d<<2)|0)-4>>2]=c}c=x[e+4>>2]+c|0;d=d+1|0;if((g|0)!=(d|0)){continue}break}break c}if(Sp(f)){break c}break b}En(a);tz(a,f);x[a+4>>2]=0;x[a+8>>2]=x[a>>2];w[a+34>>1]=z[a+34>>1]|2}hb=j+112|0;return}S(0)|0;zb();p()}function cma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-80|0;hb=e;He(b);a:{b:{if(Qb(a,1)){c:{d:{e:{f:{g:{h:{while(1){x[114414]=0;d=U(570,a|0,e+16|0,64)|0;f=x[114414];x[114414]=0;if((f|0)==1){break e}x[e+8>>2]=d;d=Bb(b);x[114414]=0;x[e+4>>2]=c-d;d=O(35,e+8|0,e+4|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break h}d=x[d>>2];if(!d){break c}v[e+8|0]=0;f=e+16|0;h=f+d|0;g=e+8|0;d=Gl(f,h,g);i=e,j=jf(b),x[i+8>>2]=j;g=x[td(e,g)>>2];x[114414]=0;Z(571,b|0,g|0,f|0,d|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break g}x[114414]=0;O(304,a|0,d-(e+16|0)|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break f}if(d>>>0>=h>>>0){continue}break}x[114414]=0;O(304,a|0,1)|0;a=x[114414];x[114414]=0;if((a|0)!=1){break c}a=S(75016)|0;break d}a=S(75016)|0;break d}a=S(75016)|0;break d}a=S(75016)|0;break d}a=S(75016)|0}if((ib|0)!=(ca(75016)|0)){break b}Y(a|0)|0;_()}d=(Bb(b)|0)!=0}hb=e+80|0;break a}Q(a|0);p()}return d|0}function d7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{e=hb-16|0;hb=e;f=hd(a);b:{if(Bb(b)){while(1){c=x[qj(b,i)>>2];c:{if(c>>>0>=2097152){x[114414]=0;P(115,f|0,63);a=x[114414];x[114414]=0;if((a|0)!=1){break c}break b}d=0;d:{e:{while(1){h=c&63;v[(e+10|0)+d|0]=h;if(c>>>0<64){break e}c=c>>>6|0;d=d+1|0;if((d|0)!=6){continue}break}a=7;d=6;break d}if(d){a=d+1|0;if((a|0)!=2){break d}d=1;a=2;if((h|0)!=1){break d}a=y[e+10|0]|64}else{a=y[e+10|0]}x[114414]=0;P(115,f|0,a<<24>>24);a=x[114414];x[114414]=0;if((a|0)!=1){break c}break b}d=(-1<<a^-1)<<7-d;h=a+e|0;c=a;while(1){f:{if((a|0)==(c|0)){g=v[h+9|0];x[114414]=0;P(115,f|0,(d|g)<<24>>24);g=x[114414];x[114414]=0;if((g|0)==1){break b}c=c-1|0;break f}x[114414]=0;c=c-1|0;P(115,f|0,v[c+(e+10|0)|0]|-128);g=x[114414];x[114414]=0;if((g|0)==1){break b}}if(c){continue}break}}i=i+1|0;if(Bb(b)>>>0>i>>>0){continue}break}}hb=e+16|0;break a}a=N()|0;xb(f);Q(a|0);p()}}function S0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;x[c+28>>2]=0;d=c+24|0;nj(d,a,0);a:{b:{c:{if(y[d|0]){d=x[x[a>>2]-12>>2];x[114414]=0;Dc(c+16|0,a+d|0);d=x[114414];x[114414]=0;d:{e:{f:{if((d|0)!=1){x[114414]=0;d=R(2347,c+16|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break f}e=_m(c+8|0,a);f=Xc(c);g=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[114414]=0;ga(2348,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break f}Ob(c+16|0);break d}b=S(0)|0;break e}b=S(0)|0;Ob(c+16|0)}Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;mj(x[x[a>>2]-12>>2]+a|0,b);b=x[x[a>>2]-12>>2];x[114414]=0;b=x[(a+b|0)+20>>2];d=x[114414];x[114414]=0;g:{if((d|0)!=1){if(!(b&1)){break g}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)==1){break c}Q(a|0);p()}_()}Jg(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}hb=c+32|0;break a}S(0)|0;zb()}p()}return a|0}function P0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;x[c+28>>2]=0;d=c+24|0;nj(d,a,0);a:{b:{c:{if(y[d|0]){d=x[x[a>>2]-12>>2];x[114414]=0;Dc(c+16|0,a+d|0);d=x[114414];x[114414]=0;d:{e:{f:{if((d|0)!=1){x[114414]=0;d=R(2347,c+16|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break f}e=_m(c+8|0,a);f=Xc(c);g=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[114414]=0;ga(2351,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break f}Ob(c+16|0);break d}b=S(0)|0;break e}b=S(0)|0;Ob(c+16|0)}Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;mj(x[x[a>>2]-12>>2]+a|0,b);b=x[x[a>>2]-12>>2];x[114414]=0;b=x[(a+b|0)+20>>2];d=x[114414];x[114414]=0;g:{if((d|0)!=1){if(!(b&1)){break g}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)==1){break c}Q(a|0);p()}_()}Jg(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}hb=c+32|0;break a}S(0)|0;zb()}p()}return a|0}function N0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;x[c+28>>2]=0;d=c+24|0;nj(d,a,0);a:{b:{c:{if(y[d|0]){d=x[x[a>>2]-12>>2];x[114414]=0;Dc(c+16|0,a+d|0);d=x[114414];x[114414]=0;d:{e:{f:{if((d|0)!=1){x[114414]=0;d=R(2347,c+16|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break f}e=_m(c+8|0,a);f=Xc(c);g=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[114414]=0;ga(2352,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break f}Ob(c+16|0);break d}b=S(0)|0;break e}b=S(0)|0;Ob(c+16|0)}Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;mj(x[x[a>>2]-12>>2]+a|0,b);b=x[x[a>>2]-12>>2];x[114414]=0;b=x[(a+b|0)+20>>2];d=x[114414];x[114414]=0;g:{if((d|0)!=1){if(!(b&1)){break g}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)==1){break c}Q(a|0);p()}_()}Jg(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}hb=c+32|0;break a}S(0)|0;zb()}p()}return a|0}function M0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;x[c+28>>2]=0;d=c+24|0;nj(d,a,0);a:{b:{c:{if(y[d|0]){d=x[x[a>>2]-12>>2];x[114414]=0;Dc(c+16|0,a+d|0);d=x[114414];x[114414]=0;d:{e:{f:{if((d|0)!=1){x[114414]=0;d=R(2347,c+16|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break f}e=_m(c+8|0,a);f=Xc(c);g=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[114414]=0;ga(2353,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break f}Ob(c+16|0);break d}b=S(0)|0;break e}b=S(0)|0;Ob(c+16|0)}Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;mj(x[x[a>>2]-12>>2]+a|0,b);b=x[x[a>>2]-12>>2];x[114414]=0;b=x[(a+b|0)+20>>2];d=x[114414];x[114414]=0;g:{if((d|0)!=1){if(!(b&1)){break g}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break b}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)==1){break c}Q(a|0);p()}_()}Jg(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}hb=c+32|0;break a}S(0)|0;zb()}p()}return a|0}function CE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;a:{if((d-a|0)<3){break a}}while(1){b:{if(e>>>0<=g>>>0|a>>>0>=d>>>0){break b}b=y[a|0];f=a+1|0;c:{if(b<<24>>24>=0){break c}if(b>>>0<194){break b}if(b>>>0<=223){if((y[a+1|0]&192)!=128|(d-a|0)<2){break b}f=a+2|0;break c}d:{e:{if(b>>>0<=239){if((d-a|0)<3){break b}h=y[a+2|0];f=y[a+1|0];if((b|0)==237){break e}if((b|0)==224){if((f&224)==160){break d}break b}if((f&192)!=128){break b}break d}if((d-a|0)<4|b>>>0>244|e-g>>>0<2){break b}h=y[a+3|0];i=y[a+2|0];f=y[a+1|0];f:{g:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break f}break b;case 4:if((f&240)==128){break f}break b;default:break g}}if((f&192)!=128){break b}}if((i&192)!=128|(h&192)!=128|(h&63|(i<<6&4032|(b<<18&1835008|(f&63)<<12)))>>>0>1114111){break b}g=g+1|0;f=a+4|0;break c}if((f&224)!=128){break b}}if((h&192)!=128){break b}f=a+3|0}a=f;g=g+1|0;continue}break}return a-c|0}function WT(a,b){var c=0,d=0;d=y[a|0];if(d>>>0>=36){v[a|0]=0;return}c=y[d+23424|0];v[a|0]=c;a:{b:{c:{d:{e:{f:{g:{if(c>>>0<=22){switch(c-6|0){case 2:case 3:case 4:case 6:case 7:case 9:case 10:case 12:break a;case 11:break b;case 13:break c;case 0:case 1:case 5:break e;case 8:break f;default:break g}}if((c|0)==23){break d}if((c|0)!=31){break a}v[b|0]=(d<<5|y[b|0]>>>3)^128;return}if(y[b|0]|(c|0)!=1){break a}v[a|0]=0;return}a=y[b|0];v[b|0]=D(a>>>4|0,10)+(a&15);return}c=y[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}v[b|0]=a;return}a=y[b|0];if(a>>>0<=64){v[b|0]=a<<1;return}v[b|0]=128;return}h:{i:{j:{k:{c=y[b|0];switch((c&240)-48>>>4|0){case 4:break h;case 2:break i;case 1:break j;case 0:break k;default:break a}}v[a|0]=20;v[b|0]=159;return}v[a|0]=20;v[b|0]=192;return}if(c&14){break a}v[a|0]=21;v[b|0]=(y[b|0]!=80)<<6;return}v[a|0]=20;v[b|0]=y[b|0]&15|160;return}if(y[b|0]>31){break a}v[a|0]=16}}function B7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,p=0,q=E(0),r=E(0),s=E(0),t=0,u=0,v=0,w=0,z=0,A=E(0);f=hb-16|0;hb=f;a:{if(!x[a+4240>>2]){break a}g=a+44|0;if(!Bh(g)){break a}s=B[a+4220>>2];w=f,z=Od(g,0),x[w+8>>2]=z;w=f,z=Od(g,1),x[w+12>>2]=z;w=f,z=ld(g,0),x[w>>2]=z;w=f,z=ld(g,1),x[w+4>>2]=z;if(d){m=a+4208|0;j=d;while(1){h=0;i=1;k=0;while(1){n=(y[a+4264|0]?1-k|0:h)&255;t=x[((n<<2)+a|0)+4248>>2];u=x[a+4240>>2];v=x[a+4244>>2];o=h<<2;p=o+(f+8|0)|0;e=x[p>>2];x[p>>2]=e+4;l=B[e>>2];e=v-t|0;q=B[Pb(m,n+((e>>31&u)+e<<1)|0)>>2];r=E(E(B[a+4224>>2]*q)+E(l*B[a+4260>>2]));w=Pb(m,x[a+4244>>2]<<1|h),A=E(F(r))<E(10000000195414814e-40)?E(0):r,B[w>>2]=A;h=f+o|0;e=x[h>>2];x[h>>2]=e+4;B[e>>2]=l+E(E(q-l)*s);k=k+1|0;e=i;i=0;h=1;if(e){continue}break}i=x[a+4244>>2]+1|0;x[a+4244>>2]=(i|0)!=x[a+4240>>2]?i:0;j=j-1|0;if(j){continue}break}}zi(a,b,c,ld(g,0),ld(g,1),d)}hb=f+16|0}function Y8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=E(0),v=0,w=E(0);if(x[a+4220>>2]){f=a+44|0;i=Od(f,0);j=Od(f,1);k=ld(f,0);l=ld(f,1);if(d){h=a+4208|0;e=x[a+4224>>2];m=d;while(1){n=B[j>>2];o=B[i>>2];e=e-x[a+4228>>2]|0;e=(x[a+4220>>2]&e>>31)+e<<1;p=B[Pb(h,e)>>2];e=Pb(h,e|1);r=B[a+4248>>2];s=B[a+4256>>2];t=B[a+4252>>2];u=B[a+4244>>2];q=B[e>>2];g=E(E(E(E(n*r)+E(o*s))+E(p*t))+E(u*q));v=Pb(h,x[a+4224>>2]<<1),w=E(F(g))<E(10000000195414814e-40)?E(0):g,B[v>>2]=w;g=E(E(E(E(r*o)+E(s*n))+E(t*q))+E(u*p));v=Pb(h,x[a+4224>>2]<<1|1),w=E(F(g))<E(10000000195414814e-40)?E(0):g,B[v>>2]=w;e=x[a+4224>>2]+1|0;e=(e|0)!=x[a+4220>>2]?e:0;x[a+4224>>2]=e;B[k>>2]=E(p*B[a+4236>>2])+E(o*B[a+4240>>2]);B[l>>2]=E(q*B[a+4236>>2])+E(n*B[a+4240>>2]);l=l+4|0;k=k+4|0;j=j+4|0;i=i+4|0;m=m-1|0;if(m){continue}break}}zi(a,b,c,ld(f,0),ld(f,1),d)}}function kL(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;k=hb-16|0;hb=k;v[k+15|0]=c;v[k+14|0]=12;Mg(b,y[rc(k+15|0,k+14|0)|0]);if(Lb(b)){c=0;while(1){a:{b:{c:{switch(h|0){case 0:i=(c<<2)+a|0;j=i+96|0;j=y[j|0]|y[j+1|0]<<8;m=Pb(b,c),n=j,w[m>>1]=n;i=i+98|0;break b;case 1:break c;default:break a}}i=(c<<2)+a|0;j=i+144|0;j=y[j|0]|y[j+1|0]<<8;m=Pb(b,c),n=j,w[m>>1]=n;i=i+146|0}i=y[i|0];m=Pb(b,c),n=i,v[m+2|0]=n}d:{if(!c){break d}i=c-1|0;if(z[Pb(b,c)>>1]>=z[Pb(b,i)>>1]){break d}if(z[Pb(b,c)>>1]>255){break d}j=y[Pb(b,i)+1|0];l=Pb(b,c);w[l>>1]=z[l>>1]|j<<8;if(z[Pb(b,c)>>1]>=z[Pb(b,i)>>1]){break d}i=Pb(b,c);w[i>>1]=z[i>>1]+256}c=c+1|0;if(Lb(b)>>>0>c>>>0){continue}break}}v[b+12|0]=0;e:{if(!(d&1)){break e}if(od(b)){break e}v[b+12|0]=y[b+12|0]|1}if(e>>>0<=11){if(d&2){v[b+12|0]=y[b+12|0]|4}v[b+15|0]=e;v[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){v[b+12|0]=y[b+12|0]|2}v[b+14|0]=g;v[b+13|0]=f}hb=k+16|0}function WF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-32|0;hb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Bf(c+24|0,a+44|0)>>2];f=(e|0)>0?e:0;b:{while(1){if((d|0)!=(f|0)){g=Mr(x[a+32>>2]);if((g|0)==-1){break b}v[(c+24|0)+d|0]=g;d=d+1|0;continue}break}c:{if(y[a+53|0]){v[c+23|0]=y[c+24|0];break c}i=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];h=c+24|0;g=h+e|0;e:{switch(hG(x[a+36>>2],f,h,g,c+16|0,c+23|0,i,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=Mr(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}v[c+23|0]=y[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}e=e-1|0;if((Nr(Wg(v[e+(c+24|0)|0]),x[a+32>>2])|0)!=-1){continue}break b}}k=a,l=Wg(v[c+23|0]),x[k+48>>2]=l}d=Wg(v[c+23|0]);break a}d=-1}hb=c+32|0;return d}function Rfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-32|0;hb=e;i=x[a+40>>2];j=x[a+36>>2];k=x[a+16>>2];b=x[a+4>>2];g=b;f=x[a>>2];x[e+24>>2]=f;x[e+28>>2]=b;b=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=b;a:{if(!d){b=i>>12;h=j>>12;break a}while(1){b=x[e+24>>2];g=((((x[e+28>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(b>>>21&2040)+32976|0;l=w[b+6>>1];m=w[b+4>>1];n=w[b+2>>1];o=w[b>>1];h=0;b=1;while(1){f=h<<1;x[(e+8|0)+(h<<2)>>2]=(((D(w[f+g>>1],n)+D(w[(f|-4)+g>>1],o)|0)+D(w[(f|4)+g>>1],m)|0)+D(w[(f|8)+g>>1],l)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=x[a+32>>2];j=x[a+28>>2]+j|0;h=j>>12;x[c>>2]=x[c>>2]+D(h,x[e+8>>2]);i=b+i|0;b=i>>12;x[c+4>>2]=x[c+4>>2]+D(b,x[e+12>>2]);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}f=x[e+24>>2];g=x[e+28>>2]}x[a>>2]=f;x[a+4>>2]=g;x[a+40>>2]=i;x[a+20>>2]=h;x[a+36>>2]=j;x[a+24>>2]=b;hb=e+32|0}function vga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=hb-16|0;hb=h;e=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];g=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];i=b;f=x[a>>2];x[h+8>>2]=f;x[h+12>>2]=b;b=x[a+12>>2];x[h>>2]=x[a+8>>2];x[h+4>>2]=b;a:{if(!d){b=e;break a}while(1){j=w[(x[h+12>>2]<<1)+n>>1];f=x[a+60>>2];b=g;g=Xb(g,-16777216,16776704);i=x[a+64>>2];k=Xb(e,-16777216,16776704);o=x[a+72>>2];p=x[c>>2];j=j<<8;e=j;e=yna(f,f>>31,e,e>>31);q=lb;g=yna(i,i>>31,g,g>>31);f=g+e|0;e=lb+q|0;e=f>>>0<g>>>0?e+1|0:e;i=f;f=x[a+68>>2];g=yna(f,f>>31,k,k>>31);f=i+g|0;e=lb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;f=(e|0)/256|0;x[c>>2]=D(f,m)+p;x[c+4>>2]=x[c+4>>2]+D(f,l);g=e-(j&o)|0;c=c+8|0;Tb(h+8|0,h);e=b;d=d-1|0;if(d){continue}break}f=x[h+8>>2];i=x[h+12>>2]}x[a>>2]=f;x[a+4>>2]=i;x[a+48>>2]=b;x[a+44>>2]=g;hb=h+16|0}function lj(a,b){var c=0,d=0,e=0,f=0;c=hb+-64|0;hb=c;d=x[x[a>>2]-12>>2]+a|0;e=x[d+16>>2]&-3;Sn(d,e);nj(c+56|0,a,1);a:{b:{if(y[c+56|0]){d=x[x[a>>2]-12>>2];x[114414]=0;d=x[(a+d|0)+24>>2];f=x[114414];x[114414]=0;c:{d:{if((f|0)==1){break d}x[114414]=0;f=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=f;f=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=f;X(2357,c+40|0,d|0,c+8|0,8);b=x[114414];x[114414]=0;if((b|0)==1){break d}b=Ug(c+24|0,-1,-1);x[114414]=0;b=nS(c+40|0,b);d=x[114414];x[114414]=0;if((d|0)==1){break d}b=b?e|4:e;break c}Y(S(0)|0)|0;b=e|1;mj(x[x[a>>2]-12>>2]+a|0,b);e=x[x[a>>2]-12>>2];x[114414]=0;e=x[(a+e|0)+20>>2];d=x[114414];x[114414]=0;e:{if((d|0)!=1){if(!(e&1)){break e}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break a}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)==1){break b}Q(a|0);p()}_()}Jg(x[x[a>>2]-12>>2]+a|0,b)}hb=c- -64|0;return}S(0)|0;zb()}p()}function $ga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;x[g>>2]=c;x[g+8>>2]=b;if(Hb(g+8|0,g)){while(1){c=hb-16|0;hb=c;i=g+8|0;b=x[i>>2];if(!(y[b+3|0]!=4|y[b+5|0])){e=c+8|0;oe(e,d,z[d+14>>1]);he(e,0);v[b+3|0]=0}e=y[b+2|0];if(!(y[b+4|0]|(e|0)!=11)){f=c+8|0;oe(f,d,z[d+14>>1]);he(f,0);v[b+2|0]=0;e=0}a:{b:{c:{if(!y[b|0]){e=c+8|0;oe(e,d,z[d+14>>1]);h=Ib(e);e=y[b+2|0];f=y[b+3|0];if(!h){break c}if(!((e|0)==11|f)){v[b+5|0]=0;v[b+3|0]=4;break a}if((f|0)==4|e){break b}v[b+4|0]=0;v[b+2|0]=11;break b}f=y[b+3|0]}h=c+8|0;oe(h,d,z[d+14>>1]);he(h,(f|0)==4|(e|0)==11);f=y[b+3|0]}d:{if(!(!y[d+16|0]|f)){v[b+5|0]=125;v[b+3|0]=17;break d}e:{switch(f-16|0){case 1:break d;case 0:break e;default:break a}}if(y[b+5|0]){break a}v[b+5|0]=6;v[d+16|0]=1;break a}v[d+16|0]=0}w[d+14>>1]=(z[d+14>>1]+1>>>0)%z[d+12>>1];hb=c+16|0;Nj(i);if(Hb(i,g)){continue}break}}WO(a,d);hb=g+16|0}function wga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=hb-16|0;hb=h;e=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];g=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];i=b;f=x[a>>2];x[h+8>>2]=f;x[h+12>>2]=b;b=x[a+12>>2];x[h>>2]=x[a+8>>2];x[h+4>>2]=b;a:{if(!d){b=e;break a}while(1){j=v[x[h+12>>2]+n|0];f=x[a+60>>2];b=g;g=Xb(g,-16777216,16776704);i=x[a+64>>2];k=Xb(e,-16777216,16776704);o=x[a+72>>2];p=x[c>>2];j=j<<16;e=j;e=yna(f,f>>31,e,e>>31);q=lb;g=yna(i,i>>31,g,g>>31);f=g+e|0;e=lb+q|0;e=f>>>0<g>>>0?e+1|0:e;i=f;f=x[a+68>>2];g=yna(f,f>>31,k,k>>31);f=i+g|0;e=lb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=((f>>>0<8388608?e+1|0:e)&16777215)<<8|f>>>24;f=(e|0)/256|0;x[c>>2]=D(f,m)+p;x[c+4>>2]=x[c+4>>2]+D(f,l);g=e-(j&o)|0;c=c+8|0;Tb(h+8|0,h);e=b;d=d-1|0;if(d){continue}break}f=x[h+8>>2];i=x[h+12>>2]}x[a>>2]=f;x[a+4>>2]=i;x[a+48>>2]=b;x[a+44>>2]=g;hb=h+16|0}function V3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb+-64|0;hb=e;d=x[b+12>>2];x[e+24>>2]=x[b+8>>2];x[e+28>>2]=d;d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;i=FP(e+16|0);a:{if(i){h=hb-16|0;hb=h;g=e+40|0;d=hb-16|0;hb=d;f=hb-16|0;hb=f;x[d+4>>2]=1;j=d,k=Vd(324,4),x[j+8>>2]=k;hb=f+16|0;f=x[d+8>>2];x[114414]=0;O(2229,f|0,b|0)|0;b=x[114414];x[114414]=0;b:{if((b|0)!=1){b=Go(d);Fo(g,ic(b),b);mI(d);hb=d+16|0;break b}a=N()|0;mI(d);Q(a|0);p()}break a}h=hb-16|0;hb=h;g=e+32|0;d=hb-16|0;hb=d;f=hb-16|0;hb=f;x[d+4>>2]=1;j=d,k=EP(1),x[j+8>>2]=k;hb=f+16|0;f=x[d+8>>2];x[114414]=0;O(2230,f|0,b|0)|0;b=x[114414];x[114414]=0;c:{if((b|0)!=1){b=Go(d);Fo(g,ic(b),b);jI(d);hb=d+16|0;break c}a=N()|0;jI(d);Q(a|0);p()}}hb=h+16|0;b=e+48|0;QC(b,g);d=zm(e+56|0,b);g=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=g;RC(a,e+8|0,c);Ab(b);d:{if(!i){Ab(e+32|0);break d}Ab(e+40|0)}hb=e- -64|0}function W4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[114414]=0;W(2121,a|0);e=x[114414];x[114414]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}x[114414]=0;W(2074,b|0);e=x[114414];x[114414]=0;if((e|0)==1){break e}e=0;x[114414]=0;W(2122,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break e}a=Sb(c,0,d);if(!y[b|0]){break b}if(pj(b,3490)|(d|0)!=8){break d}x[a+4>>2]=2123;x[a>>2]=2124;break c}Y(S(0)|0)|0;x[114414]=0;X(2023,8100,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();return 0}if(pj(b,7131)|(d|0)!=64){break b}x[a+60>>2]=2125;x[a+56>>2]=2126;x[a+52>>2]=2127;x[a+48>>2]=2128;x[a+44>>2]=2129;x[a+40>>2]=2130;x[a+36>>2]=2131;x[a+32>>2]=2132;x[a+28>>2]=2133;x[a+24>>2]=2134;x[a+20>>2]=2135;x[a+16>>2]=2136;x[a+12>>2]=2137;x[a+8>>2]=2138;x[a+4>>2]=2139;x[a>>2]=2140}e=1}return e|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function TF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Bf(c+24|0,a+44|0)>>2];f=(e|0)>0?e:0;b:{while(1){if((d|0)!=(f|0)){g=Mr(x[a+32>>2]);if((g|0)==-1){break b}v[(c+24|0)+d|0]=g;d=d+1|0;continue}break}c:{if(y[a+53|0]){x[c+20>>2]=v[c+24|0];break c}i=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];h=c+24|0;g=h+e|0;e:{switch(hG(x[a+36>>2],f,h,g,c+16|0,c+20|0,i,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=Mr(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}x[c+20>>2]=v[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}e=e-1|0;if((Nr(v[e+(c+24|0)|0],x[a+32>>2])|0)!=-1){continue}break b}}x[a+48>>2]=x[c+20>>2]}d=x[c+20>>2];break a}d=-1}hb=c+32|0;return d}function LF(a,b,c,d){var e=0,f=0,g=0,h=0;g=hb-32|0;hb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;h=e;c=c&33554431;if(!(!e&(c|0)==16777216?!(a|b):!e&c>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(c^16777216|a|(b|h)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;gf(g+16|0,a,b,c,e,f-16129|0);Al(g,a,b,c,e,16257-f|0);a=x[g+8>>2];e=(x[g+12>>2]&33554431)<<7|a>>>25;c=x[g>>2]|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;f=x[g+4>>2];b=0;a=a&33554431;if(!(!b&(a|0)==16777216?!(c|f):!b&a>>>0<16777216)){e=e+1|0;break a}if(a^16777216|c|(b|f)){break a}e=(e&1)+e|0}hb=g+32|0;return l(2,d&-2147483648|e),r()}function yV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=hb-48|0;hb=b;c=-1;a:{if(!JC(a,b+8|0)){break a}c=0;if(!lL(b+8|0)){break a}g=wf(8966);if(g){l=x[a+12>>2];c=b+8|0;if(Nk(a,y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))){b:{if(!(y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24))){break b}while(1){if(!Yf(a,4)){break b}c:{if((y[c+4|0]|y[c+5|0]<<8)>>>0>=64){d=Lu(a);f=d&63;h=d<<24>>24;d:{if(!(d&64)){break d}e=6;while(1){d=Lu(a);f=(d&127)<<e|f;if(d<<24>>24>=0){break d}d=e>>>0<25;e=e+7|0;if(d){continue}break}}if((((h|0)<0?0-f|0:f)|0)<=0){break c}}e=0;f=1;while(1){d=Lu(a);if(d){h=mn(d<<24>>24);j=e>>>0>=g>>>0;d=j&f;f=!(f&1)|j?d:y[e+8966|0]==(h&255);e=e+1|0;continue}break}Yc(a,4);i=(e|0)==(g|0)?f?1:i:i}k=k+1|0;if(k>>>0<(y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24))>>>0){continue}break}}e=i&1}Nk(a,l)}c=e}a=c;hb=b+48|0;return a|0}function yW(){var a=0,b=0,c=0,d=0;c=hb-32|0;hb=c;a:{a=Ub(c+16|0,10486);if(!Bb(a)){break a}b:{if((Zf(a,10181)|0)!=-1){b=Zf(a,10181);x[114414]=0;X(200,c|0,a|0,b+1|0,-1);b=x[114414];x[114414]=0;if((b|0)==1){break b}Db(a,c);xb(c)}if((Zf(a,12743)|0)!=-1){b=Zf(a,12743);x[114414]=0;X(200,c|0,a|0,b+1|0,-1);b=x[114414];x[114414]=0;if((b|0)==1){break b}Db(a,c);xb(c)}if((Zf(a,9659)|0)!=-1){b=Zf(a,9659);x[114414]=0;X(200,c|0,a|0,0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}Db(a,c);xb(c)}if((Zf(a,9547)|0)!=-1){b=Zf(a,9547);x[114414]=0;X(200,c|0,a|0,0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}Db(a,c);xb(c)}if((Zf(a,9590)|0)!=-1){b=Zf(a,9590);x[114414]=0;X(200,c|0,a|0,0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}Db(a,c);xb(c)}x[114414]=0;b=R(201,a|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break a}}c=N()|0;xb(a);Q(c|0);p()}xb(a);hb=c+32|0;return b|0}function pca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-16|0;hb=g;l=g,m=D(x[a>>2],Je(a)),x[l+12>>2]=m;xc(g+12|0,c>>>2|0);c=Cb(b);f=x[e+4>>2];j=x[g+12>>2];if(j){while(1){e=Cb(y[c|0]);h=e|Cb(y[c+1|0])<<8|Cb(y[c+2|0])<<16|Cb(y[c+3|0])<<24;a:{b:{c:{if((h|0)>=0){e=h;break c}e=-2147483648;if((h|0)==-2147483648){break b}e=0-h|0}if(f>>>0>=e>>>0){break a}}f=e}c=c+4|0;j=j-1|0;if(j){continue}break}}d:{if(!f){break d}e=x[g+12>>2];if(!e){break d}h=f-1|0;j=f>>>1|0;c=x[a+20>>2];while(1){a=Cb(y[b|0]);a=a|Cb(y[b+1|0])<<8|Cb(y[b+2|0])<<16|Cb(y[b+3|0])<<24;i=a&-2147483648|a>>>1;k=j|a<<31;a=i;e:{if((a|0)>0|(a|0)>=0){a=Bna(k,a,f,0);i=lb;break e}i=Bna(h-k|0,0-((h>>>0<k>>>0)+a|0)|0,f,0);a=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}l=c,m=Cc(a,i)>>>16|0,w[l>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){x[d>>2]=f}hb=g+16|0;return x[g+12>>2]<<2}function oca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-16|0;hb=g;l=g,m=D(x[a>>2],Je(a)),x[l+12>>2]=m;xc(g+12|0,c>>>2|0);c=Cb(b);f=x[e+4>>2];j=x[g+12>>2];if(j){while(1){e=Cb(y[c+3|0]);h=e|Cb(y[c+2|0])<<8|Cb(y[c+1|0])<<16|Cb(y[c|0])<<24;a:{b:{c:{if((h|0)>=0){e=h;break c}e=-2147483648;if((h|0)==-2147483648){break b}e=0-h|0}if(f>>>0>=e>>>0){break a}}f=e}c=c+4|0;j=j-1|0;if(j){continue}break}}d:{if(!f){break d}e=x[g+12>>2];if(!e){break d}h=f-1|0;j=f>>>1|0;c=x[a+20>>2];while(1){a=Cb(y[b+3|0]);a=a|Cb(y[b+2|0])<<8|Cb(y[b+1|0])<<16|Cb(y[b|0])<<24;i=a&-2147483648|a>>>1;k=j|a<<31;a=i;e:{if((a|0)>0|(a|0)>=0){a=Bna(k,a,f,0);i=lb;break e}i=Bna(h-k|0,0-((h>>>0<k>>>0)+a|0)|0,f,0);a=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}l=c,m=Cc(a,i)>>>16|0,w[l>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){x[d>>2]=f}hb=g+16|0;return x[g+12>>2]<<2}function Dl(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;pk(a);a:{b:{c:{g=x[b+32>>2];d:{if(!g){e=x[b+2084>>2];if(e){break d}break b}f=x[b+4>>2];if((f|0)<9){break c}e=x[b+2084>>2];if(!e){break c}}h=x[a+1392>>2];j=Cl(h);d=x[b+2092>>2];if((d|0)>=2){while(1){f=d>>>1|0;i=f+c|0;g=j>>>0<A[(i<<2)+e>>2];c=g?c:i;d=g?f:d-f|0;if((d|0)>1){continue}break}}d=x[a+1396>>2];c=y[b+23|0]?c:x[x[b+2088>>2]+(c<<2)>>2];b=y[c+x[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}x[a+1392>>2]=h>>>b;b=d-b|0}x[a+1396>>2]=b;return c}if(y[b+23|0]){break a}if((f|0)>0){e=x[b+8>>2];while(1){f:{d=y[c+e|0];if((d|0)==255){break f}h=x[a+1392>>2];if(x[g+(c<<2)>>2]!=(h&(-1<<d^-1))){break f}e=x[a+1396>>2];if((e|0)>=(d|0)){x[a+1392>>2]=h>>>d;x[a+1396>>2]=e-y[x[b+8>>2]+c|0];return c}x[a+1396>>2]=0;break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}}fc(a,21);x[a+1396>>2]=0}return-1}ea(7258,9049,1705,1931);p()}function n_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;h=hb-416|0;hb=h;d=h+416|0;x[h+12>>2]=d;c=hb-144|0;hb=c;x[c+28>>2]=c+132;i=c+32|0;lF(a+8|0,i,c+28|0,e,f,g);x[c+16>>2]=0;x[c+20>>2]=0;x[c+12>>2]=i;e=h+16|0;i=mR(e,x[h+12>>2]);f=hb-16|0;hb=f;x[f+12>>2]=x[a+8>>2];g=Hh(f+8|0,f+12|0);x[114414]=0;a=kw(e,c+12|0,i,c+16|0);i=x[114414];x[114414]=0;a:{if((i|0)!=1){Ne(g);hb=f+16|0;break a}a=N()|0;Ne(g);Q(a|0);p()}if((a|0)==-1){Cr(8393);p()}x[h+12>>2]=e+(a<<2);hb=c+144|0;g=hb-16|0;hb=g;i=g+8|0;a=hb-32|0;hb=a;xw(a+24|0,e,x[h+12>>2]);h=a+16|0;j=x[a+28>>2];c=hb-16|0;hb=c;f=x[a+24>>2];x[c+4>>2]=f;x[c+8>>2]=b;while(1){if((f|0)!=(j|0)){iG(c+8|0,x[f>>2]);f=f+4|0;x[c+4>>2]=f;continue}break}ym(h,c+4|0,c+8|0);hb=c+16|0;k=a,l=ww(e,x[a+16>>2]),x[k+12>>2]=l;x[a+8>>2]=x[a+20>>2];gd(i,a+12|0,a+8|0);hb=a+32|0;hb=g+16|0;hb=d;return x[g+12>>2]}function Sfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-32|0;hb=e;i=x[a+40>>2];j=x[a+36>>2];k=x[a+16>>2];b=x[a+4>>2];g=b;h=x[a>>2];x[e+24>>2]=h;x[e+28>>2]=b;b=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=b;a:{if(!d){f=i>>12;b=j>>12;break a}while(1){b=x[e+24>>2];g=(((x[e+28>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(b>>>21&2040)+32976|0;l=w[b+6>>1];m=w[b+4>>1];n=w[b+2>>1];o=w[b>>1];f=0;b=1;while(1){x[(e+8|0)+(f<<2)>>2]=(((D(v[f+g|0],n)+D(v[(f|-2)+g|0],o)|0)+D(v[(f|2)+g|0],m)|0)+D(v[(f|4)+g|0],l)<<8)/16384;h=b;b=0;f=1;if(h){continue}break}h=x[a+32>>2];j=x[a+28>>2]+j|0;b=j>>12;x[c>>2]=x[c>>2]+D(b,x[e+8>>2]);i=h+i|0;f=i>>12;x[c+4>>2]=x[c+4>>2]+D(f,x[e+12>>2]);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}h=x[e+24>>2];g=x[e+28>>2]}x[a>>2]=h;x[a+4>>2]=g;x[a+40>>2]=i;x[a+20>>2]=b;x[a+36>>2]=j;x[a+24>>2]=f;hb=e+32|0}function Bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-16|0;hb=e;v[e+15|0]=8;v[e+14|0]=0;w[e+12>>1]=0;if(d){l=D(c,d);while(1){if((l|0)>0){h=(j<<1)+b|0;n=h+(l<<1)|0;while(1){w[e+10>>1]=0;ZQ(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{b:{g=y[e+15|0];if(!g){break b}c=z[e+12>>1];while(1){f=c<<1;c=f&254;w[e+12>>1]=c;f=(f&65534)>>>0>255;v[e+14|0]=f;if(!c){if(!Oe(a,e+9|0)){break b}c=y[e+9|0];f=c>>>7|0;v[e+14|0]=f;c=c<<1&254|1;w[e+12>>1]=c}i=z[e+10>>1]<<1|f;w[e+10>>1]=i;g=g-1|0;if(g&255){continue}break}break a}i=z[e+10>>1]}c=1;g=i&65535;c:{if(g>>>0<4){break c}f=15;while(1){c=f;m=c&255;if(g>>>m&1){break c}f=c-1|0;if(m>>>0>1){continue}break}}v[e+15|0]=(y[e+15|0]+c&254)>>>1;c=i&1;v[e+14|0]=c;k=(c-1^(i&65534)>>>1)+k|0;w[e+10>>1]=k;w[h>>1]=k;h=(d<<1)+h|0;if(n>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}hb=e+16|0}function Jy(a,b){var c=0,d=0,e=0,f=0,g=0;d=z[a+480188>>1];a:{if(d>>>0<=255){f=a+1304392|0;while(1){e=D(d,896)+a|0;c=e+1075060|0;b:{if(x[c>>2]){break b}if(!wj(e+1074984|0)){break a}if(x[c>>2]){break b}if(y[e+1075073|0]&24){break a}}if(y[e+1075073|0]&2){if(!zd(f)){break a}if(!WM(x[f>>2],d&65535)){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}g=8388608;if(b>>>0<=255){b=D(b,896)+a|0;if(!x[b+1075680>>2]){d=65535;if(x[b+1075060>>2]){break a}}g=x[b+1075672>>2]|x[b+1075664>>2]<<9}d=65535;b=z[a+480188>>1];if(b>>>0>255){break a}e=0;while(1){c=D(b,896)+a|0;if(!(x[c+1075680>>2]?0:x[c+1075060>>2])){f=(x[c+1075672>>2]|x[c+1075664>>2]<<9)>>>(x[c+1075072>>2]>>>1&1)|0;c:{d:{if(f>>>0<g>>>0){c=x[c+1075712>>2];break d}if((f|0)!=(g|0)){break c}c=x[c+1075712>>2];if(e>>>0>=c>>>0){break c}}g=f;d=b;e=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function CI(a,b,c,d){var e=0,f=0,g=0,h=0,i=E(0),j=0;e=hb-80|0;hb=e;h=a+24|0;rp(x[h>>2]);v[x[h>>2]+1304512|0]=x[a+52>>2]!=0;c=Mc(e+32|0,d,c,b);f=x[a+32>>2];i=B[a+48>>2];x[e+8>>2]=x[c+8>>2];d=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=d;c=hb-16|0;hb=c;x[c+8>>2]=x[e+8>>2];d=x[e+4>>2];x[c>>2]=x[e>>2];x[c+4>>2]=d;d=ts(e+48|0);x[d+8>>2]=f;x[d+4>>2]=0;x[d>>2]=83064;f=x[c+4>>2];x[d+12>>2]=x[c>>2];x[d+16>>2]=f;x[d+20>>2]=x[c+8>>2];B[d+24>>2]=i;x[d>>2]=83016;hb=c+16|0;c=0;a:{while(1){if(b){f=x[h>>2];x[e+24>>2]=b;x[e+28>>2]=0;x[114414]=0;x[e+16>>2]=134217727;x[e+20>>2]=0;g=O(2184,e+24|0,e+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break a}g=x[g>>2];x[114414]=0;f=U(2185,f|0,g|0,d|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}c=c+f|0;b=b-f|0;if(f){continue}}break}if(!(x[a+52>>2]!=1|c)){a=x[h>>2];x[a+480208>>2]=x[a+480208>>2]&-513}hb=e+80|0;return c}Q(N()|0);p()}function BI(a,b,c,d){var e=0,f=0,g=0,h=0,i=E(0),j=0;e=hb-80|0;hb=e;h=a+24|0;rp(x[h>>2]);v[x[h>>2]+1304512|0]=x[a+52>>2]!=0;c=Mc(e+32|0,d,c,b);f=x[a+32>>2];i=B[a+48>>2];x[e+8>>2]=x[c+8>>2];d=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=d;c=hb-16|0;hb=c;x[c+8>>2]=x[e+8>>2];d=x[e+4>>2];x[c>>2]=x[e>>2];x[c+4>>2]=d;d=ts(e+48|0);x[d+8>>2]=f;x[d+4>>2]=0;x[d>>2]=83136;f=x[c+4>>2];x[d+12>>2]=x[c>>2];x[d+16>>2]=f;x[d+20>>2]=x[c+8>>2];B[d+24>>2]=i;x[d>>2]=83088;hb=c+16|0;c=0;a:{while(1){if(b){f=x[h>>2];x[e+24>>2]=b;x[e+28>>2]=0;x[114414]=0;x[e+16>>2]=134217727;x[e+20>>2]=0;g=O(2184,e+24|0,e+16|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break a}g=x[g>>2];x[114414]=0;f=U(2185,f|0,g|0,d|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}c=c+f|0;b=b-f|0;if(f){continue}}break}if(!(x[a+52>>2]!=1|c)){a=x[h>>2];x[a+480208>>2]=x[a+480208>>2]&-513}hb=e+80|0;return c}Q(N()|0);p()}function ow(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a;a:{if(b&3){while(1){c=y[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}d=x[b>>2];b:{if((d^-1)&d-16843009&-2139062144){break b}while(1){c=d^1027423549;if((c^-1)&c-16843009&-2139062144){break b}d=x[b+4>>2];b=b+4|0;if(!(d-16843009&(d^-1)&-2139062144)){continue}break}}while(1){c=b;e=y[b|0];if(e){b=c+1|0;if((e|0)!=61){continue}}break}b=c}if((a|0)==(b|0)){return 0}e=b-a|0;c:{if(y[e+a|0]){break c}f=x[115199];if(!f){break c}d=x[f>>2];if(!d){break c}while(1){d:{b=a;h=0;g=e;c=0;e:{if(!e){break e}c=y[b|0];f:{if(!c){break f}while(1){g:{i=y[d|0];if(!i){break g}g=g-1|0;if(!g|(c|0)!=(i|0)){break g}d=d+1|0;c=y[b+1|0];b=b+1|0;if(c){continue}break f}break}h=c}c=(h&255)-y[d|0]|0}if(!c){b=x[f>>2]+e|0;if(y[b|0]==61){break d}}d=x[f+4>>2];f=f+4|0;if(d){continue}break c}break}j=b+1|0}return j}function B9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-32|0;hb=f;x[f+24>>2]=d;j=Vj(a,c);vf(f,x[a+28>>2]);d=x[f+12>>2];x[f+16>>2]=x[f+8>>2];x[f+20>>2]=d;a:{if(!j){if(Cd(a,5)){break a}}l=x[f+24>>2];d=hb-48|0;hb=d;h=x[a+28>>2];Wj(h,d+40|0);e=x[d+44>>2];if(!e&A[d+40>>2]>256|e){x[d+40>>2]=256;x[d+44>>2]=0}b:{c:{d:{e:{f:{if(x[d+40>>2]|x[d+44>>2]){while(1){zf(h,d+38|0);g=Wb(d+24|0);x[114414]=0;U(698,h|0,g|0,255)|0;e=x[114414];x[114414]=0;if((e|0)==1){break f}x[114414]=0;T(13,d+8|0,l|0,g|0);e=x[114414];x[114414]=0;if((e|0)==1){break e}x[114414]=0;e=O(1646,b|0,d+38|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break d}i=e;e=d+8|0;Db(i,e);xb(e);xb(g);e=x[d+44>>2];k=k+1|0;if(!e&k>>>0<A[d+40>>2]|e){continue}break}}hb=d+48|0;break b}a=N()|0;break c}a=N()|0;break c}a=N()|0;xb(d+8|0)}xb(g);Q(a|0);p()}}hj(a,j,c,f+16|0);hb=f+32|0}function rca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-16|0;hb=g;l=g,m=D(x[a>>2],Je(a)),x[l+12>>2]=m;xc(g+12|0,(c>>>0)/3|0);c=Cb(b);f=x[e+4>>2];j=x[g+12>>2];if(j){while(1){e=Cb(y[c|0]);h=Cb(y[c+1|0])<<16|e<<8|Cb(y[c+2|0])<<24;a:{b:{c:{if((h|0)>=0){e=h;break c}e=-2147483648;if((h|0)==-2147483648){break b}e=0-h|0}if(f>>>0>=e>>>0){break a}}f=e}c=c+3|0;j=j-1|0;if(j){continue}break}}d:{if(!f){break d}e=x[g+12>>2];if(!e){break d}h=f-1|0;j=f>>>1|0;c=x[a+20>>2];while(1){a=Cb(y[b|0]);a=Cb(y[b+1|0])<<16|a<<8|Cb(y[b+2|0])<<24;i=a&-2147483648|a>>>1;k=j|a<<31;a=i;e:{if((a|0)>0|(a|0)>=0){a=Bna(k,a,f,0);i=lb;break e}i=Bna(h-k|0,0-((h>>>0<k>>>0)+a|0)|0,f,0);a=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}l=c,m=Cc(a,i)>>>16|0,w[l>>1]=m;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){x[d>>2]=f}hb=g+16|0;return D(x[g+12>>2],3)|0}function qca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-16|0;hb=g;l=g,m=D(x[a>>2],Je(a)),x[l+12>>2]=m;xc(g+12|0,(c>>>0)/3|0);c=Cb(b);f=x[e+4>>2];j=x[g+12>>2];if(j){while(1){e=Cb(y[c+2|0]);h=Cb(y[c+1|0])<<16|e<<8|Cb(y[c|0])<<24;a:{b:{c:{if((h|0)>=0){e=h;break c}e=-2147483648;if((h|0)==-2147483648){break b}e=0-h|0}if(f>>>0>=e>>>0){break a}}f=e}c=c+3|0;j=j-1|0;if(j){continue}break}}d:{if(!f){break d}e=x[g+12>>2];if(!e){break d}h=f-1|0;j=f>>>1|0;c=x[a+20>>2];while(1){a=Cb(y[b+2|0]);a=Cb(y[b+1|0])<<16|a<<8|Cb(y[b|0])<<24;i=a&-2147483648|a>>>1;k=j|a<<31;a=i;e:{if((a|0)>0|(a|0)>=0){a=Bna(k,a,f,0);i=lb;break e}i=Bna(h-k|0,0-((h>>>0<k>>>0)+a|0)|0,f,0);a=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}l=c,m=Cc(a,i)>>>16|0,w[l>>1]=m;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){x[d>>2]=f}hb=g+16|0;return D(x[g+12>>2],3)|0}function i5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=hb-48|0;hb=c;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{c:{if((b|0)!=1){d=Wb(c+32|0);b=x[a+24>>2];x[114414]=0;P(2108,c+16|0,b|0);b=x[114414];x[114414]=0;d:{if((b|0)!=1){b=c+16|0;e=c,f=bc(b),x[e+8>>2]=f;e=c,f=dc(b),x[e>>2]=f;if(!Hb(c+8|0,c)){break b}while(1){e:{b=x[c+8>>2];x[114414]=0;O(1251,d|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break e}b=c+8|0;_j(b);e=c,f=dc(c+16|0),x[e>>2]=f;if(!Hb(b,c)){break b}x[114414]=0;O(2029,d|0,10156)|0;b=x[114414];x[114414]=0;if((b|0)!=1){continue}}break}b=S(0)|0;qd(c+16|0);break d}b=S(0)|0}xb(d);break c}b=S(0)|0}Y(b|0)|0;b=0;x[114414]=0;X(2023,3360,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)!=1){_();break a}a=N()|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}b=Ld(Rb(d));qd(c+16|0);xb(d)}hb=c+48|0;return b|0}function Q5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=hb-48|0;hb=c;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{c:{if((b|0)!=1){d=Wb(c+32|0);b=x[a+24>>2];x[114414]=0;P(2073,c+16|0,b|0);b=x[114414];x[114414]=0;d:{if((b|0)!=1){b=c+16|0;e=c,f=bc(b),x[e+8>>2]=f;e=c,f=dc(b),x[e>>2]=f;if(!Hb(c+8|0,c)){break b}while(1){e:{b=x[c+8>>2];x[114414]=0;O(1251,d|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break e}b=c+8|0;_j(b);e=c,f=dc(c+16|0),x[e>>2]=f;if(!Hb(b,c)){break b}x[114414]=0;O(2029,d|0,10156)|0;b=x[114414];x[114414]=0;if((b|0)!=1){continue}}break}b=S(0)|0;qd(c+16|0);break d}b=S(0)|0}xb(d);break c}b=S(0)|0}Y(b|0)|0;b=0;x[114414]=0;X(2023,2920,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)!=1){_();break a}a=N()|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}b=Ld(Rb(d));qd(c+16|0);xb(d)}hb=c+48|0;return b|0}function Aja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;v[e+15|0]=4;v[e+14|0]=0;w[e+12>>1]=0;if(d){l=D(c,d);n=(l|0)<=0;while(1){if(!n){h=b+j|0;o=l+h|0;while(1){v[e+11|0]=0;YQ(a,e+14|0,e+12|0,e+11|0);a:{b:{g=y[e+15|0];if(!g){break b}c=z[e+12>>1];while(1){f=c<<1;c=f&254;w[e+12>>1]=c;f=(f&65534)>>>0>255;v[e+14|0]=f;if(!c){if(!Oe(a,e+10|0)){break b}c=y[e+10|0];f=c>>>7|0;v[e+14|0]=f;c=c<<1&254|1;w[e+12>>1]=c}i=y[e+11|0]<<1|f;v[e+11|0]=i;g=g-1|0;if(g&255){continue}break}break a}i=y[e+11|0]}c=1;g=i&255;c:{if(g>>>0<4){break c}f=7;while(1){c=f;m=c&255;if(g>>>m&1){break c}f=c-1|0;if(m>>>0>1){continue}break}}v[e+15|0]=(y[e+15|0]+c&254)>>>1;c=i&1;v[e+14|0]=c;k=(c-1^(i&254)>>>1)+k|0;v[e+11|0]=k;v[h|0]=k;h=d+h|0;if(o>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}hb=e+16|0}function wH(a,b,c,d){var e=0,f=0,g=0,h=E(0),i=0,j=E(0),k=0,l=E(0),m=E(0),n=E(0),o=0;e=hb-96|0;hb=e;if((d|0)>0){while(1){B[e+48>>2]=-B[a>>2];B[e>>2]=B[a+68>>2];f=0;while(1){g=(e+48|0)+(f<<3)|0;i=(f<<4)+a|0;j=B[i+8>>2];h=B[i+4>>2];B[g+4>>2]=j+h;k=f<<1;B[(8-k<<2)+e>>2]=h-j;j=B[i+16>>2];h=B[i+12>>2];B[(7-k<<2)+e>>2]=j-h;B[g+8>>2]=-E(h+j);f=f+1|0;if((f|0)!=4){continue}break}vH(e+48|0);vH(e);B[e+4>>2]=-B[e+4>>2];B[e+12>>2]=-B[e+12>>2];B[e+20>>2]=-B[e+20>>2];B[e+28>>2]=-B[e+28>>2];i=0;while(1){f=i<<2;g=f+b|0;j=B[g>>2];k=g;h=B[f+45840>>2];l=B[f+(e+48|0)>>2];m=B[e+f>>2];g=f+36|0;n=B[g+45840>>2];B[k>>2]=E(h*l)-E(m*n);k=a+f|0;f=c+f|0;g=c+g|0;h=E(E(h*m)+E(n*l));B[k>>2]=E(j*B[f>>2])-E(B[g>>2]*h);B[(17-i<<2)+a>>2]=E(B[f>>2]*h)+E(j*B[g>>2]);i=i+1|0;if((i|0)!=9){continue}break}b=b+36|0;a=a+72|0;o=o+1|0;if((o|0)!=(d|0)){continue}break}}hb=e+96|0}function mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];i=x[a+4>>2];e=x[a>>2];x[f+8>>2]=e;x[f+12>>2]=i;j=x[a+12>>2];x[f>>2]=x[a+8>>2];x[f+4>>2]=j;a:{if(!d){b=g>>12;j=h>>12;break a}i=b+24|0;while(1){l=x[a+32>>2];b=x[f+8>>2];h=x[a+28>>2]+h|0;j=h>>12;e=(x[f+12>>2]<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+i|0;e=(((((D(w[e+4>>1],w[b+10>>1])+D(w[e+2>>1],w[b+8>>1])|0)+D(w[e+6>>1],w[b+12>>1])|0)+D(w[e+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[e-4>>1],w[b+2>>1])+D(w[e-6>>1],w[b>>1])|0)+D(w[e-2>>1],w[b+4>>1])|0)+D(w[e>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(j,e);g=g+l|0;b=g>>12;x[c+4>>2]=x[c+4>>2]+D(e,b);c=c+8|0;Tb(f+8|0,f);d=d-1|0;if(d){continue}break}e=x[f+8>>2];i=x[f+12>>2]}x[a>>2]=e;x[a+4>>2]=i;x[a+40>>2]=g;x[a+20>>2]=j;x[a+36>>2]=h;x[a+24>>2]=b;hb=f+16|0}function sp(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;a:{b:{switch(x[a+480224>>2]-1|0){default:b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2]<<1;d=yna(b,d,5e4,0);e=lb;b=x[_c(c+8|0,c)>>2];b=Cc(zna(d,e,b,b>>31),lb);x[a+1074404>>2]=b;break a;case 1:b=x[a+24620>>2];x[c+8>>2]=1;x[c+12>>2]=0;g=c,h=yna(x[a+1074420>>2],0,yna(x[a+1074408>>2],0,x[a+1074416>>2],0),lb),x[g>>2]=h;x[c+4>>2]=lb;d=hb-16|0;hb=d;e=c+8|0;f=bv(e,c);hb=d+16|0;d=yna(b,0,6e5,0);b=f?c:e;b=Bna(d,lb,x[b>>2],x[b+4>>2]);x[a+1074404>>2]=b;break a;case 0:break b}}b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2];d=yna(b,d,1e4,0);e=lb;b=x[_c(c+8|0,c)>>2];b=Cc(zna(d,e,b,b>>31),lb);x[a+1074404>>2]=b}d=a+1074404|0;a=x[a+480244>>2];b=yna(a,a>>31,b,b>>31);a=lb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Cc(zna(b,a,65536,0),lb);x[d>>2]=a?a:1;hb=c+16|0}function m8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0);c=hb-4112|0;hb=c;i=mb[x[x[a>>2]+112>>2]](a)|0;if(!i){mb[x[x[a>>2]+116>>2]](a)}x[c+12>>2]=0;f=hb-16|0;hb=f;h=a+44|0;if(sf(h)){while(1){e=sm(h,d);g=sm(h,d);x[f+12>>2]=0;g=(g+2048|0)-e>>2;if((g|0)>0){while(1){B[e>>2]=B[f+12>>2];e=e+4|0;j=g>>>0>1;g=g-1|0;if(j){continue}break}}d=d+1|0;if(sf(h)>>>0>d>>>0){continue}break}}hb=f+16|0;if(b){f=c+2064|0;while(1){x[c+8>>2]=b;xc(c+8|0,512);d=c+16|0;Xp(d);mb[x[x[a>>2]+60>>2]](a,d,f,x[c+8>>2]);e=0;d=0;if(x[c+8>>2]){while(1){e=(c+16|0)+(d<<2)|0;B[c+4>>2]=F(B[e>>2]);k=c,l=B[Ex(c+12|0,c+4|0)>>2],B[k+12>>2]=l;B[c+4>>2]=F(B[e+2048>>2]);k=c,l=B[Ex(c+12|0,c+4|0)>>2],B[k+12>>2]=l;e=x[c+8>>2];d=d+1|0;if(e>>>0>d>>>0){continue}break}}b=b-e|0;if(b){continue}break}}if(!i){mb[x[x[a>>2]+120>>2]](a)}hb=c+4112|0;return E(B[c+12>>2])}function eM(a,b){var c=0;c=hb-16|0;hb=c;a=Wq(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Nb(a,7,1);Nb(a,9,1);Nb(a,10,1);Nb(a,13,1);Nb(a,15,1);Nb(a,16,1);Nb(a,17,1);Nb(a,18,1);Nb(a,20,1);Nb(a,21,1);Nb(a,24,1);Nb(a,25,1);Nb(a,26,1);Nb(a,28,1);Nb(a,30,1);Nb(a,31,1);Nb(a,33,1);Nb(a,34,1);Nb(a,39,1);Nb(a,41,1);Nb(a,44,1);Nb(a,46,1);Nb(a,45,1);Nb(a,47,1);Nb(a,48,1);Nb(a,50,1);Nb(a,99,1);Nb(a,102,1);Nb(a,104,1);Nb(a,105,1);break a;case 1:vy(c,2);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;Ig(a,107);break a;case 3:vy(c,4);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;Ig(a,4);break a;case 2:break b;case 0:break c}}Nb(a,88,1);break a}vy(c,b);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b}hb=c+16|0}function Wr(a){a=a|0;var b=0,c=0,d=0;c=hb-16|0;hb=c;b=x[x[a>>2]-12>>2];x[114414]=0;b=x[(a+b|0)+24>>2];d=x[114414];x[114414]=0;a:{b:{c:{d:{e:{if((d|0)!=1){if(!b){break b}x[114414]=0;O(15,c+8|0,a|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break d}if(!y[c+8|0]){break e}b=x[x[a>>2]-12>>2];x[114414]=0;b=x[(a+b|0)+24>>2];d=x[114414];x[114414]=0;f:{if((d|0)==1){break f}x[114414]=0;b=R(2345,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break f}if((b|0)!=-1){break e}b=x[x[a>>2]-12>>2];x[114414]=0;P(18,a+b|0,1);b=x[114414];x[114414]=0;if((b|0)!=1){break e}}b=S(0)|0;Kf(c+8|0);break c}b=S(0)|0;break c}Kf(c+8|0);break b}b=S(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[114414]=0;W(19,a+b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}_()}hb=c+16|0;return a|0}a=N()|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function W6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=E(0),o=E(0),p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=E(0),v=E(0);i=hb-16|0;hb=i;j=a+44|0;if(Bh(j)){h=Od(j,0);x[i+8>>2]=h;k=Od(j,1);x[i+12>>2]=k;e=ld(j,0);x[i>>2]=e;f=ld(j,1);x[i+4>>2]=f;a:{if(B[a+4216>>2]!=E(.5)){if(!d){break a}h=d;while(1){f=0;k=1;while(1){f=f<<2;e=f+(i+8|0)|0;g=x[e>>2];x[e>>2]=g+4;e=a+f|0;m=e+4248|0;p=B[m>>2];l=B[g>>2];q=B[a+4228>>2];r=B[a+4224>>2];s=B[a+4220>>2];t=B[a+4236>>2];u=B[a+4232>>2];g=e+4240|0;n=B[g>>2];B[m>>2]=n;B[g>>2]=l;g=e+4264|0;v=B[g>>2];e=e+4256|0;o=B[e>>2];B[g>>2]=o;l=E(E(E(E(n*r)+E(s*l))+E(p*q))-E(E(v*t)+E(o*u)));B[e>>2]=l;f=f+i|0;e=x[f>>2];x[f>>2]=e+4;B[e>>2]=l;e=k;k=0;f=1;if(e){continue}break}h=h-1|0;if(h){continue}break}break a}g=h;h=d<<2;sc(e,g,h);sc(f,k,h)}zi(a,b,c,ld(j,0),ld(j,1),d)}hb=i+16|0}function d5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;x[114414]=0;W(2048,a|0);d=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}x[114414]=0;W(2074,b|0);d=x[114414];x[114414]=0;if((d|0)==1){break g}x[114414]=0;W(2074,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break g}d=x[a+24>>2];x[114414]=0;b=O(118,e+16|0,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break g}x[114414]=0;c=O(118,e|0,c|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break f}x[114414]=0;X(2114,d|0,b|0,c|0,1);d=x[114414];x[114414]=0;if((d|0)==1){break e}xb(c);xb(b);b=1;break b}d=S(0)|0;break c}d=S(0)|0;break d}d=S(0)|0;xb(c)}xb(b)}Y(d|0)|0;b=0;x[114414]=0;X(2023,2763,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_()}hb=e+32|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function R3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb+-64|0;hb=e;x[e+56>>2]=c;c=hp(a,e+56|0);h=AI(c+4|0);i=zI(c+24|0);j=yI(c+32|0);k=sx(c+36|0);x[c+56>>2]=3;l=oh(c+68|0);x[114414]=0;P(2195,c|0,d|0);a=x[114414];x[114414]=0;a:{b:{c:{d:{if((a|0)!=1){a=x[b>>2];f=x[b+4>>2];g=x[b+12>>2];b=x[b+8>>2];x[e+16>>2]=b;x[e+20>>2]=g;x[114414]=0;x[e+32>>2]=b;x[e+36>>2]=g;x[e+24>>2]=a;x[e+28>>2]=f;x[e+8>>2]=a;x[e+12>>2]=f;T(2192,e+40|0,e+8|0,0);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;T(2196,c|0,e+40|0,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}Ab(e+40|0);x[114414]=0;W(2197,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}pd(e+56|0);hb=e- -64|0;return c|0}a=N()|0;break a}a=N()|0;break a}a=N()|0;Ab(e+40|0);break a}a=N()|0}qd(l);Mf(k);dg(j);ui(i);pd(h);pd(c);pd(e+56|0);Q(a|0);p()}function j$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=hb-32|0;hb=h;a:{b:{c:{if((b|0)!=(c|0)){j=x[114240];x[114240]=0;g=hb-16|0;hb=g;ie();e=hb-16|0;hb=e;f=hb-16|0;hb=f;iw(f,b,h+28|0,2);k=x[f>>2];i=x[f+4>>2];b=x[f+12>>2];x[e+8>>2]=x[f+8>>2];x[e+12>>2]=b;x[e>>2]=k;x[e+4>>2]=i;hb=f+16|0;i=x[e>>2];f=x[e+4>>2];b=x[e+12>>2];x[g+8>>2]=x[e+8>>2];x[g+12>>2]=b;x[g>>2]=i;x[g+4>>2]=f;hb=e+16|0;f=x[g>>2];e=x[g+4>>2];b=x[g+12>>2];x[h+16>>2]=x[g+8>>2];x[h+20>>2]=b;x[h+8>>2]=f;x[h+12>>2]=e;hb=g+16|0;g=x[h+16>>2];i=x[h+20>>2];e=x[h+8>>2];f=x[h+12>>2];b=x[114240];if(!b){break c}if(x[h+28>>2]!=(c|0)){break b}l=e;m=f;n=g;o=i;if((b|0)!=68){break a}break b}x[d>>2]=4;break a}x[114240]=j;if(x[h+28>>2]==(c|0)){break a}}x[d>>2]=4;e=l;f=m;g=n;i=o}x[a>>2]=e;x[a+4>>2]=f;x[a+8>>2]=g;x[a+12>>2]=i;hb=h+32|0}function MQ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){f=c;c=v[a+b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;if((b|0)!=20){continue}break}a:{if(c>>>0>5){break a}while(1){d=D(g,30)+a|0;j=d+20|0;b=0;e=0;while(1){f=b;b=v[e+j|0];b=f+((b&255)!=0&(b|0)<32)|0;e=e+1|0;if((e|0)!=22){continue}break}c=b+c|0;if(y[d+44|0]|(c>>>0>48|y[d+45|0]>64)){break a}b=y[d+42|0]|y[d+43|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>32768){break a}b=y[d+42|0]|y[d+43|0]<<8;h=((b<<8|b>>>8)&65535)+h|0;i=y[d+45|0]|i;g=g+1|0;if((g|0)!=15){continue}break}if(!h|!(i&255)|y[a+470|0]>128|y[a+471|0]>220){break a}e=hb-16|0;hb=e;c=a+472|0;d=c+128|0;b:{if((c|0)==(d|0)){break b}b=c+1|0;if((d|0)==(b|0)){break b}while(1){c=y[c|0]<y[b|0]?b:c;b=b+1|0;if((d|0)!=(b|0)){continue}break}}hb=e+16|0;c=y[c|0];if(c>>>0>63|!(y[a+471|0]|(c|y[a+470|0]))){break a}k=1}return k}function ana(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Wb(a);h=Bb(b);x[114414]=0;P(482,f|0,h|0);a=x[114414];x[114414]=0;if((a|0)!=1){a:{if(h){while(1){a=d+1|0;e=y[pc(b,d)|0];b:{c:{if((a|0)==(h|0)|(e|0)!=37){break c}e=y[pc(b,a)|0];g=e-49|0;if((g&255)>>>0<=8){d=x[c+4>>2];e=x[c>>2];x[114414]=0;d=O(500,e|0,d|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}if(d>>>0<=g>>>0){d=a;break b}x[114414]=0;d=O(483,c|0,g|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){x[114414]=0;O(484,f|0,d|0)|0;e=x[114414];x[114414]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}x[114414]=0;U(485,f|0,1,37)|0;g=x[114414];x[114414]=0;d=a;if((g|0)==1){break a}}x[114414]=0;U(485,f|0,1,e<<24>>24)|0;a=x[114414];x[114414]=0;if((a|0)==1){break a}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}return}}a=N()|0;xb(f);Q(a|0);p()}function $8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{if((sf(a)|0)==(b|0)){if((sf(a+12|0)|0)==(c|0)){break b}}x[114414]=0;P(1675,a|0,b|0);d=x[114414];x[114414]=0;c:{d:{if((d|0)==1){break d}x[114414]=0;e=a+12|0;P(1675,e|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break d}x[114414]=0;f=a+24|0;P(1676,f|0,b|0);d=x[114414];x[114414]=0;if((d|0)==1){break d}x[114414]=0;g=a+36|0;P(1676,g|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break d}if(b){d=0;while(1){h=sm(a,d);i=Pb(f,d),j=h,x[i>>2]=j;d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break c}return 1}b=S(75016)|0;if((ib|0)!=(ca(75016)|0)){break a}Y(b|0)|0;pK(a);oK(a);b=a+12|0;pK(b);oK(b);b=a+24|0;nK(b);mK(b);a=a+36|0;nK(a);mK(a);_();return 0}a=0;while(1){b=sm(e,a);i=Pb(g,a),j=b,x[i>>2]=j;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}Q(b|0);p()}function XJ(a,b,c){var d=0;a:{b:{switch(b|0){case 0:GJ(a,c);return;case 1:b=0;a=Cg(a);d=Bb(c);x[114414]=0;P(110,a|0,d|0);d=x[114414];x[114414]=0;c:{if((d|0)!=1){d:{if(Bb(c)){while(1){d=y[pc(c,b)|0];x[114414]=0;P(109,a|0,(d<<24>>24<0?65533:d)|0);d=x[114414];x[114414]=0;if((d|0)==1){break d}b=b+1|0;if(Bb(c)>>>0>b>>>0){continue}break}}break c}}break a}return;case 2:b=0;a=Cg(a);d=Bb(c);x[114414]=0;P(110,a|0,d|0);d=x[114414];x[114414]=0;e:{if((d|0)!=1){f:{if(Bb(c)){while(1){d=y[pc(c,b)|0];x[114414]=0;P(109,a|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break f}b=b+1|0;if(Bb(c)>>>0>b>>>0){continue}break}}break e}}break a}return;case 3:jp(a,c,17600);return;case 4:jp(a,c,18624);return;case 5:jp(a,c,19648);return;case 6:jp(a,c,20672);return;case 7:jp(a,c,21696);return;default:break b}}Cg(a);return}b=N()|0;Nc(a);Q(b|0);p()}function nfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];i=x[a+4>>2];e=x[a>>2];x[f+8>>2]=e;x[f+12>>2]=i;j=x[a+12>>2];x[f>>2]=x[a+8>>2];x[f+4>>2]=j;a:{if(!d){b=g>>12;j=h>>12;break a}i=b+24|0;while(1){l=x[a+32>>2];b=x[f+8>>2];h=x[a+28>>2]+h|0;j=h>>12;e=x[f+12>>2]+k|0;b=(((b>>>16|0)+4&131064)<<1)+i|0;e=((((D(v[e+2|0],w[b+10>>1])+D(v[e+1|0],w[b+8>>1])|0)+D(v[e+3|0],w[b+12>>1])|0)+D(v[e+4|0],w[b+14>>1])<<8>>1)+(((D(v[e-2|0],w[b+2>>1])+D(v[e-3|0],w[b>>1])|0)+D(v[e-1|0],w[b+4>>1])|0)+D(v[e|0],w[b+6>>1])<<8>>1)|0)/16384|0;x[c>>2]=x[c>>2]+D(j,e);g=g+l|0;b=g>>12;x[c+4>>2]=x[c+4>>2]+D(e,b);c=c+8|0;Tb(f+8|0,f);d=d-1|0;if(d){continue}break}e=x[f+8>>2];i=x[f+12>>2]}x[a>>2]=e;x[a+4>>2]=i;x[a+40>>2]=g;x[a+20>>2]=j;x[a+36>>2]=h;x[a+24>>2]=b;hb=f+16|0}function GJ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;e=Cg(a);g=c,h=ud(b),x[g+8>>2]=h;g=c,h=jf(b),x[g>>2]=h;a:{b:{if(!Hb(c+8|0,c)){break b}a=0;while(1){b=y[x[c+8>>2]];c:{d:{if(!a){if(b<<24>>24>=0){a=0;x[114414]=0;P(109,e|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break c}break a}if((b&224)==192){d=b&31;a=1;break c}if((b&240)==224){d=b&15;a=2;break c}f=65533;if((b&248)!=240){break d}d=b&7;a=3;break c}if((b&192)!=128){x[114414]=0;P(109,e|0,65533);a=x[114414];x[114414]=0;if((a|0)==1){break a}d=b&63;a=-1;break c}f=b&63|d<<6;d=f;a=a-1|0;if(a){break c}}d=0;x[114414]=0;P(109,e|0,f|0);b=x[114414];x[114414]=0;a=0;if((b|0)==1){break a}}b=c+8|0;bg(b);if(Hb(b,c)){continue}break}if(!a){break b}x[114414]=0;P(109,e|0,65533);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break a}hb=c+16|0;return}a=N()|0;Nc(e);Q(a|0);p()}function Eja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;x[a>>2]=0;x[a+4>>2]=0;x[f+12>>2]=0;Xc(a+8|0);if(b){d=hb-16|0;hb=d;c=hb-16|0;hb=c;yb(a);x[c+12>>2]=214748364;x[114414]=0;x[c+8>>2]=2147483647;e=O(35,c+12|0,c+8|0)|0;g=x[114414];x[114414]=0;a:{if((g|0)!=1){hb=c+16|0;c=x[e>>2];break a}S(0)|0;zb();p()}if(b>>>0>c>>>0){Vc();p()}c=fR(yb(a),b);x[d+12>>2]=b;x[d+8>>2]=c;c=x[d+8>>2];x[a+4>>2]=c;x[a>>2]=c;e=x[d+12>>2];h=yb(a),i=c+D(e,20)|0,x[h>>2]=i;$p(a);$p(a);hb=d+16|0;d=hb-16|0;hb=d;x[d>>2]=a;c=x[a+4>>2];x[d+4>>2]=c;x[d+8>>2]=c+D(b,20);b:{c:{b=x[d+4>>2];c=x[d+8>>2];if((b|0)!=(c|0)){while(1){e=yb(a);x[114414]=0;P(853,e|0,b|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}b=b+20|0;x[d+4>>2]=b;if((b|0)!=(c|0)){continue}break}}Jb(d);hb=d+16|0;break b}a=N()|0;Jb(d);Q(a|0);p()}}hb=f+16|0;return a|0}function kx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-80|0;hb=c;d=x[a>>2];f=x[d+4>>2];e=x[d+24>>2];x[c+40>>2]=x[d+20>>2];x[c+44>>2]=e;e=x[d+16>>2];x[c+32>>2]=x[d+12>>2];x[c+36>>2]=e;Nh(c- -64|0,c+32|0,f);d=Mc(c+48|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);f=x[x[a+12>>2]>>2];e=x[x[a+8>>2]>>2];a=x[c+76>>2];x[c+24>>2]=x[c+72>>2];x[c+28>>2]=a;a=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=a;x[c+8>>2]=x[d+8>>2];a=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=a;if(f){i=c+16|0;j=b+4|0;while(1){a=0;if(e){while(1){h=C[kh(c,a,g)>>3];gc(b,a);h=Qd(Fg(+(Cj(Qd(h*134217728))-1024+((qs(j)^-2147483648)>>>21)|0)*7.450580596923828e-9)*32768);a:{if(F(h)<2147483648){d=~~h;break a}d=-2147483648}d=Uc(d);k=hn(i,a,g),l=d,w[k>>1]=l;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}hb=c+80|0}function Sda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=hd(a);h=Bb(b);x[114414]=0;P(74,f|0,h|0);a=x[114414];x[114414]=0;if((a|0)!=1){a:{if(h){while(1){a=d+1|0;e=y[pc(b,d)|0];b:{c:{if((a|0)==(h|0)|(e|0)!=37){break c}e=y[pc(b,a)|0];g=e-49|0;if((g&255)>>>0<=8){d=x[c+4>>2];e=x[c>>2];x[114414]=0;d=O(80,e|0,d|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}if(d>>>0<=g>>>0){d=a;break b}x[114414]=0;d=O(75,c|0,g|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){x[114414]=0;O(76,f|0,d|0)|0;e=x[114414];x[114414]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}x[114414]=0;U(77,f|0,1,37)|0;g=x[114414];x[114414]=0;d=a;if((g|0)==1){break a}}x[114414]=0;U(77,f|0,1,e<<24>>24)|0;a=x[114414];x[114414]=0;if((a|0)==1){break a}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}return}}a=N()|0;xb(f);Q(a|0);p()}function $Y(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=Lb(a);if(c>>>0<b>>>0){h=hb-32|0;hb=h;a:{b:{f=b-c|0;c:{if(f>>>0<=x[yb(a)>>2]-x[a+4>>2]>>2>>>0){VE(a,f);break c}g=rl(a);e=h+8|0;d=Lb(a)+f|0;b=hb-16|0;hb=b;x[b+12>>2]=d;d:{c=qE(a);if(d>>>0<=c>>>0){d=vd(a);if(d>>>0<c>>>1>>>0){x[b+8>>2]=d<<1;c=x[_c(b+8|0,b+12|0)>>2]}hb=b+16|0;b=c;break d}Vc();p()}i=Lb(a);c=0;d=hb-16|0;hb=d;x[d+12>>2]=0;Qe(e+12|0,g);if(b){pE(d,x[e+16>>2],b);c=x[d>>2];b=x[d+4>>2]}else{b=0}x[e>>2]=c;g=(i<<2)+c|0;x[e+8>>2]=g;x[e+4>>2]=g;j=ic(e),k=(b<<2)+c|0,x[j>>2]=k;hb=d+16|0;x[114414]=0;P(2614,e|0,f|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(2615,a|0,e|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}nE(e)}hb=h+32|0;break a}a=N()|0;nE(e);Q(a|0);p()}return}if(b>>>0<c>>>0){b=x[a>>2]+(b<<2)|0;Lb(a);oE(a,b);og(a)}}function v5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[114414]=0;W(2048,a|0);d=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){d=x[a+24>>2];x[114414]=0;P(2094,c|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break i}if(zc(c)>>>0<2147483647){break h}d=ec(8);x[114414]=0;b=O(2095,d|0,3641)|0;e=x[114414];x[114414]=0;if((e|0)==1){break g}x[114414]=0;T(2042,b|0,75356,231);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=S(0)|0;break f}b=S(0)|0;break e}b=S(0)|0;break e}j:{k:{if((b|0)>=0){if((zc(c)|0)>(b|0)){break k}}b=Ld(17386);break j}b=Ld(Rb(wd(c,b)))}qd(c);break d}b=S(0)|0;hc(d)}qd(c)}Y(b|0)|0;b=0;x[114414]=0;X(2023,7755,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break c}_()}hb=c+16|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break a}S(0)|0;zb()}p()}Q(a|0);p()}function u5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[114414]=0;W(2048,a|0);d=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){d=x[a+24>>2];x[114414]=0;P(2096,c|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break i}if(zc(c)>>>0<2147483647){break h}d=ec(8);x[114414]=0;b=O(2095,d|0,3641)|0;e=x[114414];x[114414]=0;if((e|0)==1){break g}x[114414]=0;T(2042,b|0,75356,231);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=S(0)|0;break f}b=S(0)|0;break e}b=S(0)|0;break e}j:{k:{if((b|0)>=0){if((zc(c)|0)>(b|0)){break k}}b=Ld(17386);break j}b=Ld(Rb(wd(c,b)))}qd(c);break d}b=S(0)|0;hc(d)}qd(c)}Y(b|0)|0;b=0;x[114414]=0;X(2023,7723,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break c}_()}hb=c+16|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break a}S(0)|0;zb()}p()}Q(a|0);p()}function t5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[114414]=0;W(2048,a|0);d=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){d=x[a+24>>2];x[114414]=0;P(2097,c|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break i}if(zc(c)>>>0<2147483647){break h}d=ec(8);x[114414]=0;b=O(2095,d|0,3641)|0;e=x[114414];x[114414]=0;if((e|0)==1){break g}x[114414]=0;T(2042,b|0,75356,231);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=S(0)|0;break f}b=S(0)|0;break e}b=S(0)|0;break e}j:{k:{if((b|0)>=0){if((zc(c)|0)>(b|0)){break k}}b=Ld(17386);break j}b=Ld(Rb(wd(c,b)))}qd(c);break d}b=S(0)|0;hc(d)}qd(c)}Y(b|0)|0;b=0;x[114414]=0;X(2023,7661,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break c}_()}hb=c+16|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break a}S(0)|0;zb()}p()}Q(a|0);p()}function s5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[114414]=0;W(2048,a|0);d=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){d=x[a+24>>2];x[114414]=0;P(2098,c|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break i}if(zc(c)>>>0<2147483647){break h}d=ec(8);x[114414]=0;b=O(2095,d|0,3641)|0;e=x[114414];x[114414]=0;if((e|0)==1){break g}x[114414]=0;T(2042,b|0,75356,231);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=S(0)|0;break f}b=S(0)|0;break e}b=S(0)|0;break e}j:{k:{if((b|0)>=0){if((zc(c)|0)>(b|0)){break k}}b=Ld(17386);break j}b=Ld(Rb(wd(c,b)))}qd(c);break d}b=S(0)|0;hc(d)}qd(c)}Y(b|0)|0;b=0;x[114414]=0;X(2023,7691,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break c}_()}hb=c+16|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break a}S(0)|0;zb()}p()}Q(a|0);p()}function r5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[114414]=0;W(2048,a|0);d=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){d=x[a+24>>2];x[114414]=0;P(2099,c|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break i}if(zc(c)>>>0<2147483647){break h}d=ec(8);x[114414]=0;b=O(2095,d|0,3641)|0;e=x[114414];x[114414]=0;if((e|0)==1){break g}x[114414]=0;T(2042,b|0,75356,231);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=S(0)|0;break f}b=S(0)|0;break e}b=S(0)|0;break e}j:{k:{if((b|0)>=0){if((zc(c)|0)>(b|0)){break k}}b=Ld(17386);break j}b=Ld(Rb(wd(c,b)))}qd(c);break d}b=S(0)|0;hc(d)}qd(c)}Y(b|0)|0;b=0;x[114414]=0;X(2023,7626,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break c}_()}hb=c+16|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break a}S(0)|0;zb()}p()}Q(a|0);p()}function q5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[114414]=0;W(2048,a|0);d=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)!=1){d=x[a+24>>2];x[114414]=0;P(2100,c|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break i}if(zc(c)>>>0<2147483647){break h}d=ec(8);x[114414]=0;b=O(2095,d|0,3641)|0;e=x[114414];x[114414]=0;if((e|0)==1){break g}x[114414]=0;T(2042,b|0,75356,231);b=x[114414];x[114414]=0;if((b|0)!=1){break b}b=S(0)|0;break f}b=S(0)|0;break e}b=S(0)|0;break e}j:{k:{if((b|0)>=0){if((zc(c)|0)>(b|0)){break k}}b=Ld(17386);break j}b=Ld(Rb(wd(c,b)))}qd(c);break d}b=S(0)|0;hc(d)}qd(c)}Y(b|0)|0;b=0;x[114414]=0;X(2023,7787,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break c}_()}hb=c+16|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break a}S(0)|0;zb()}p()}Q(a|0);p()}function $F(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;x[114414]=0;g=O(15,d+24|0,a|0)|0;e=x[114414];x[114414]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!y[g|0]){break e}e=el(d+8|0,a);f=x[x[a>>2]-12>>2];h=x[(f+a|0)+4>>2];x[114414]=0;f=a+f|0;i=R(16,f|0)|0;j=x[114414];x[114414]=0;if((j|0)==1){break d}e=x[e>>2];x[114414]=0;c=b+c|0;b=ga(17,e|0,b|0,((h&176)==32?c:b)|0,c|0,f|0,i|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break d}x[d+16>>2]=b;if(!cl(d+16|0)){break e}b=x[x[a>>2]-12>>2];x[114414]=0;P(18,a+b|0,5);b=x[114414];x[114414]=0;if((b|0)!=1){break e}break d}Kf(g);break b}b=S(0)|0;Kf(g);break c}b=S(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[114414]=0;W(19,a+b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}_()}hb=d+32|0;return a}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)==1){S(0)|0;zb();p()}Q(a|0);p()}function rla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-48|0;hb=e;i=e+24|0;g=hb-144|0;hb=g;f=lh(g+8|0);h=x[x[f>>2]-12>>2];x[114414]=0;j=$(121)|0;k=x[114414];x[114414]=0;a:{b:{if((k|0)==1){break b}x[114414]=0;T(122,g|0,f+h|0,j|0);h=x[114414];x[114414]=0;if((h|0)==1){break b}Ob(g);x[114414]=0;P(133,f|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(124,i|0,f|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}Xd(f);hb=g+144|0;break a}a=N()|0;Xd(f);Q(a|0);p()}x[114414]=0;T(645,e+36|0,e+8|0,d|0);c=x[114414];x[114414]=0;c:{d:{if((c|0)!=1){x[114414]=0;P(646,e|0,e+24|0);c=x[114414];x[114414]=0;if((c|0)==1){break d}x[114414]=0;T(477,a|0,b|0,e|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}lf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break c}c=N()|0;lf(e+24|0)}Q(c|0);p()}function hU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;Ad(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=yq(a+4|0,a);x[b+4>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=yq(a+8|0,a);x[b+8>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+15|0;x[b+24>>2]=(y[c|0]|y[c+1|0]<<8)<<1;if(!(y[c|0]|y[c+1|0]<<8)){x[b+24>>2]=16726}c=a+14|0;e=b,f=(D(yt(v[a+17|0],y[c|0]<<28>>24),x[b+24>>2])>>>0)/8363|0,x[e+24>>2]=f;v[d+15|0]=y[a+18|0];v[d+14|0]=127;e=b,f=(((y[rc(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[e+30>>1]=f;if(y[c|0]>=16){c=y[c|0];w[b+34>>1]=32;w[b+28>>1]=c&240}a=a+19|0;if(y[a|0]&4){w[b+34>>1]=z[b+34>>1]|1}a:{if(!(y[a|0]&8)|A[b+4>>2]>=A[b+8>>2]){break a}w[b+34>>1]=z[b+34>>1]|2;if(y[a|0]&16){w[b+34>>1]=z[b+34>>1]|4}if(!(y[a|0]&64)){break a}w[b+34>>1]=z[b+34>>1]|128}hb=d+16|0}function _aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=hb-16|0;hb=h;e=hb-32|0;hb=e;i=c;f=b;d=Pe(b);c=mc(b);a:{if(d){while(1){b=d;d=b+16|0;if(Uy(yb(f),i,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!Uy(yb(f),d,i)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break a}}b=mc(f);c=b}x[e+28>>2]=b;b=x[c>>2];v[e+27|0]=0;if(!b){j=hb-16|0;hb=j;l=mc(f);b=Vd(28,4);k=Sk(j+8|0,l);d=hb-16|0;hb=d;x[114414]=0;x[d+12>>2]=b;g=e+8|0;b=U(1541,g|0,d+12|0,k|0)|0;k=x[114414];x[114414]=0;b:{if((k|0)!=1){hb=d+16|0;break b}S(0)|0;zb();p()}d=x[b>>2]+16|0;x[114414]=0;T(1540,l|0,d|0,i|0);d=x[114414];x[114414]=0;c:{if((d|0)!=1){m=mc(b),n=1,v[m+4|0]=n;hb=j+16|0;break c}a=N()|0;nL(b);Q(a|0);p()}Tk(f,x[e+28>>2],c,x[g>>2]);b=ke(g);v[e+27|0]=1;nL(g)}c=h+8|0;Qi(c,Fb(e+8|0,b),e+27|0);hb=e+32|0;tO(a,c);hb=h+16|0}function $I(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=hb+-64|0;hb=j;x[j+60>>2]=e;e=x[a+4>>2];k=x[a>>2];a=x[a+8>>2];x[114414]=0;x[j+40>>2]=b;x[j+52>>2]=a;x[j+44>>2]=k;x[j+48>>2]=e;x[j+20>>2]=d?d:2031;a=O(2032,j+20|0,j+60|0)|0;b=x[114414];x[114414]=0;a:{b:{c:{d:{if((b|0)!=1){x[j+24>>2]=a;a=x[ip(j+32|0,j+24|0)>>2];x[114414]=0;b=x[j+52>>2];x[j+8>>2]=x[j+48>>2];x[j+12>>2]=b;b=x[j+44>>2];x[j>>2]=x[j+40>>2];x[j+4>>2]=b;c=+ua(2033,j|0,+c,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}pd(j+24|0);break b}a=S(0)|0;break c}a=S(0)|0;pd(j+24|0)}Y(a|0)|0;x[114414]=0;fa(2034,10636,d|0,x[j+60>>2],f|0,g|0,h|0,i|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();c=0}hb=j- -64|0;return+c}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function JP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=hb-48|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+44>>2]=0;yb(b);Id(a+8|0,c+44|0,c+40|0);if(x[b+4>>2]){Hq(a,x[b+4>>2]);Ej(c+32|0,b);Mk(c+24|0,b);b=x[c+36>>2];x[c+16>>2]=x[c+32>>2];x[c+20>>2]=b;b=x[c+28>>2];x[c+8>>2]=x[c+24>>2];x[c+12>>2]=b;b=hb-80|0;hb=b;g=x[a+4>>2];d=x[c+20>>2];h=d;f=x[c+16>>2];x[b+72>>2]=f;x[b+76>>2]=d;e=x[c+12>>2];i=e;d=x[c+8>>2];x[b+64>>2]=d;x[b+68>>2]=e;x[b+24>>2]=f;x[b+28>>2]=h;x[b+16>>2]=d;x[b+20>>2]=e;e=GP(b+24|0,b+16|0)+x[a+4>>2]|0;x[a+4>>2]=e;if(!((e-1^g-1)>>>0<32?g:0)){x[x[a>>2]+((e>>>0>=33?e-1>>>5|0:0)<<2)>>2]=0}x[b+48>>2]=d;x[b+52>>2]=i;x[b+56>>2]=f;x[b+60>>2]=h;f=b+40|0;oo(f,a,g);d=x[b+60>>2];x[b+8>>2]=x[b+56>>2];x[b+12>>2]=d;d=x[b+52>>2];x[b>>2]=x[b+48>>2];x[b+4>>2]=d;hQ(b+32|0,b+8|0,b,f);hb=b+80|0}hb=c+48|0;return a|0}function Mha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;Ad(c,2);v[d+16|0]=y[b+13|0];v[d|0]=64;e=d+16|0;g=c,h=y[rc(e,d)|0]<<2,w[g+30>>1]=h;f=b+14|0;x[c+24>>2]=(y[f|0]|y[f+1|0]<<8)<<1;Wk(d,2,b+1|0);Ic(e,d);x[114414]=0;O(335,c+43|0,e|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){xb(d+16|0);e=ad(a,8,1,0,2);a:{if((y[b|0]&3)!=1){break a}a=b+22|0;x[c>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a=b+26|0;x[c+4>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a=b+30|0;a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[c+8>>2]=a;if(a>>>0>A[c+4>>2]){x[c+8>>2]=a-1}if(y[b|0]&4){w[c+34>>1]=z[c+34>>1]|2}if(y[b|0]&8){w[c+34>>1]=z[c+34>>1]|4}if(!(y[b|0]&16)){break a}DA(e);pm(e,9);x[c>>2]=x[c>>2]>>>1;x[c+4>>2]=x[c+4>>2]>>>1;x[c+8>>2]=x[c+8>>2]>>>1}hb=d+32|0;return}a=N()|0;xb(d+16|0);Q(a|0);p()}function Lea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=hb-16|0;hb=h;e=hb-32|0;hb=e;i=c;f=b;d=Pe(b);c=mc(b);a:{if(d){while(1){b=d;d=b+14|0;if(xo(yb(f),i,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!xo(yb(f),d,i)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break a}}b=mc(f);c=b}x[e+28>>2]=b;b=x[c>>2];v[e+27|0]=0;if(!b){j=hb-16|0;hb=j;k=mc(f);d=ID(1);g=Sk(j+8|0,k);b=hb-16|0;hb=b;x[114414]=0;x[b+12>>2]=d;d=e+8|0;g=U(1156,d|0,b+12|0,g|0)|0;l=x[114414];x[114414]=0;b:{if((l|0)!=1){hb=b+16|0;break b}S(0)|0;zb();p()}b=x[g>>2]+14|0;x[114414]=0;T(1155,k|0,b|0,i|0);b=x[114414];x[114414]=0;c:{if((b|0)!=1){m=mc(g),n=1,v[m+4|0]=n;hb=j+16|0;break c}a=N()|0;rO(g);Q(a|0);p()}Tk(f,x[e+28>>2],c,x[d>>2]);b=ke(d);v[e+27|0]=1;rO(d)}c=h+8|0;Qi(c,Fb(e+8|0,b),e+27|0);hb=e+32|0;tO(a,c);hb=h+16|0}function zla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;d=Lb(b);a:{if(d>>>0<c>>>0){g=hb-32|0;hb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=x[yb(b)>>2]-x[b+4>>2]>>2>>>0){h=hb-16|0;hb=h;e:{d=je(h,b,e);e=x[d+4>>2];j=x[d+8>>2];if((e|0)!=(j|0)){while(1){i=yb(b);x[114414]=0;P(712,i|0,e|0);i=x[114414];x[114414]=0;if((i|0)==1){break e}e=e+4|0;x[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Jb(d);hb=h+16|0;break d}a=N()|0;Jb(d);Q(a|0);p()}d=yb(b);d=eu(g+8|0,ze(b,Lb(b)+e|0),Lb(b),d);x[114414]=0;P(710,d|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;P(711,b|0,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}eS(d)}hb=g+32|0;break b}a=N()|0;eS(d);Q(a|0);p()}break a}if(c>>>0<d>>>0){d=x[b>>2]+(c<<2)|0;Lb(b);fS(b,d);og(b)}}c=Qb(a,c<<2);if(c){d=f+8|0;kA(d,b);Dd(a,d)}hb=f+16|0;return c|0}function dka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;d=Lb(b);a:{if(d>>>0<c>>>0){g=hb-32|0;hb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=x[yb(b)>>2]-x[b+4>>2]>>2>>>0){h=hb-16|0;hb=h;e:{d=je(h,b,e);e=x[d+4>>2];j=x[d+8>>2];if((e|0)!=(j|0)){while(1){i=yb(b);x[114414]=0;P(801,i|0,e|0);i=x[114414];x[114414]=0;if((i|0)==1){break e}e=e+4|0;x[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Jb(d);hb=h+16|0;break d}a=N()|0;Jb(d);Q(a|0);p()}d=yb(b);d=eu(g+8|0,ze(b,Lb(b)+e|0),Lb(b),d);x[114414]=0;P(799,d|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;P(800,b|0,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}qR(d)}hb=g+32|0;break b}a=N()|0;qR(d);Q(a|0);p()}break a}if(c>>>0<d>>>0){d=x[b>>2]+(c<<2)|0;Lb(b);rR(b,d);og(b)}}c=Qb(a,c<<2);if(c){d=f+8|0;kA(d,b);Dd(a,d)}hb=f+16|0;return c|0}function Yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;d=qc(b);a:{if(d>>>0<c>>>0){g=hb-32|0;hb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=x[yb(b)>>2]-x[b+4>>2]>>1>>>0){h=hb-16|0;hb=h;e:{d=Yg(h,b,e);e=x[d+4>>2];j=x[d+8>>2];if((e|0)!=(j|0)){while(1){i=yb(b);x[114414]=0;P(807,i|0,e|0);i=x[114414];x[114414]=0;if((i|0)==1){break e}e=e+2|0;x[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Jb(d);hb=h+16|0;break d}a=N()|0;Jb(d);Q(a|0);p()}d=yb(b);d=zq(g+8|0,$i(b,qc(b)+e|0),qc(b),d);x[114414]=0;P(805,d|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;P(806,b|0,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}iR(d)}hb=g+32|0;break b}a=N()|0;iR(d);Q(a|0);p()}break a}if(c>>>0<d>>>0){d=x[b>>2]+(c<<1)|0;qc(b);jR(b,d);jo(b)}}c=Qb(a,c<<1);if(c){d=f+8|0;BB(d,b);Dd(a,d)}hb=f+16|0;return c|0}function A3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb+-64|0;hb=d;a:{b:{if((b|0)>=0){e=a+24|0;if(Bj(Vb(x[e>>2]+484360|0))>>>0>b>>>0){break b}}a=a+16|0;break a}g=z[uc(Vb(x[e>>2]+484360|0),b)>>1];c:{if(!go(x[e>>2]+484344|0,g)){break c}if((c|0)>=0){f=c;if((f|0)<x[Zb(x[e>>2]+484344|0,g)+12>>2]){break c}}a=a+16|0;break a}w[x[e>>2]+1074438>>1]=b;b=b&65535;_L(x[e>>2],b);x[x[e>>2]+1074428>>2]=f;x[x[e>>2]+1074392>>2]=-2;c=x[e>>2];e=y[a+64|0];v[d+30|0]=255;x[d+40>>2]=0;w[d+28>>1]=0;x[d+24>>2]=0;if(!((b|0)==65535|(f|0)==-1)){w[d+36>>1]=b;x[d+32>>2]=f;x[d+40>>2]=2}b=x[d+44>>2];x[d+16>>2]=x[d+40>>2];x[d+20>>2]=b;b=x[d+36>>2];x[d+8>>2]=x[d+32>>2];x[d+12>>2]=b;b=x[d+28>>2];x[d>>2]=x[d+24>>2];x[d+4>>2]=b;b=d+48|0;ht(b,c,e?7:1,d);h=a,i=C[$g(b)>>3],C[h+16>>3]=i;_l(b);a=a+16|0}hb=d- -64|0;return+C[a>>3]}function JU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;d=qc(b);a:{if(d>>>0<c>>>0){g=hb-32|0;hb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=x[yb(b)>>2]-x[b+4>>2]>>1>>>0){h=hb-16|0;hb=h;e:{d=Yg(h,b,e);e=x[d+4>>2];j=x[d+8>>2];if((e|0)!=(j|0)){while(1){i=yb(b);x[114414]=0;P(374,i|0,e|0);i=x[114414];x[114414]=0;if((i|0)==1){break e}e=e+2|0;x[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Jb(d);hb=h+16|0;break d}a=N()|0;Jb(d);Q(a|0);p()}d=yb(b);d=zq(g+8|0,$i(b,qc(b)+e|0),qc(b),d);x[114414]=0;P(372,d|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;P(373,b|0,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}AB(d)}hb=g+32|0;break b}a=N()|0;AB(d);Q(a|0);p()}break a}if(c>>>0<d>>>0){d=x[b>>2]+(c<<1)|0;qc(b);CB(b,d);jo(b)}}c=Qb(a,c<<1);if(c){d=f+8|0;BB(d,b);Dd(a,d)}hb=f+16|0;return c|0}function BM(a,b,c,d){var e=0,f=0;f=hb-16|0;hb=f;x[f+12>>2]=b;e=0;a:{if(!b){break a}if(x[a+480180>>2]&20){c=a+1074312|0;b=$b(c,73)?b&65535:b;if(y[a+480208|0]&16){a=$b(c,73)?14-((9983-b>>>0)/768|0)&31:((b>>>0)/768|0)+2|0;e=x[((b>>>0)%768<<2)+27200>>2]<<6>>>a|0;break a}e=229079296/((b?b:1)>>>0)|0;break a}e=227001280/(b>>>0)|0;if(lq(a)){break a}e=(b+c<<4)-133808|0;if(x[a+480180>>2]==64){break a}b=x[a+480180>>2];xc(f+12|0,16777215);if(b&17408){e=jd(Bna(yna(c?c:8363,0,3506176,0),lb,(x[f+12>>2]<<8)+d|0,0),lb);break a}if(y[a+480208|0]&16){if($b(a+1074312|0,7)){c=d>>31;b=d;a=x[f+12>>2];d=a>>>24|0;e=a<<8;b=b+e|0;a=c+d|0;e=((b>>>0<e>>>0?a+1|0:a)&15)<<28|b>>>4;break a}e=jd(Bna(yna(c?c:8363,0,7012352,0),lb,(x[f+12>>2]<<8)+d|0,0),lb);break a}e=jd(Bna(-1485242368,13,(x[f+12>>2]<<8)+d|0,0),lb)}hb=f+16|0;return e}function P3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=hb-32|0;hb=f;x[f+24>>2]=d;d=hp(a,f+24|0);g=AI(d+4|0);h=zI(d+24|0);i=yI(d+32|0);j=sx(d+36|0);x[d+56>>2]=3;k=oh(d+68|0);x[114414]=0;P(2195,d|0,e|0);a=x[114414];x[114414]=0;a:{b:{c:{d:{if((a|0)!=1){x[114414]=0;a=R(2201,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break d}x[114414]=0;T(2202,f|0,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;T(2203,f+8|0,f|0,0);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;T(2196,d|0,f+8|0,e|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}Ab(f+8|0);x[114414]=0;W(2197,d|0);a=x[114414];x[114414]=0;if((a|0)!=1){break a}}a=N()|0;break b}a=N()|0;break b}a=N()|0;Ab(f+8|0)}qd(k);Mf(j);dg(i);ui(h);pd(g);pd(d);pd(f+24|0);Q(a|0);p()}pd(f+24|0);hb=f+32|0;return d|0}function Laa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;Ad(b,4);w[b+30>>1]=y[a+12|0]<<2;sg(b+30|0,256);c=y[a+15|0];w[b+34>>1]=32;w[b+28>>1]=c;v[b+37|0]=y[a+13|0];v[b+36|0]=y[a+16|0];x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=a+4|0;e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=e;c=a+8|0;x[b+8>>2]=e+(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));a=a+14|0;if(y[a|0]&16){x[b>>2]=x[b>>2]>>>1;x[b+4>>2]=x[b+4>>2]>>>1;x[b+8>>2]=x[b+8>>2]>>>1}if(y[a|0]&32){x[b>>2]=x[b>>2]>>>1;x[b+4>>2]=x[b+4>>2]>>>1;x[b+8>>2]=x[b+8>>2]>>>1}a:{if(!(y[a|0]&3)|A[b+8>>2]<=A[b+4>>2]){break a}w[b+34>>1]=z[b+34>>1]|2;if(!(y[a|0]&2)){break a}w[b+34>>1]=z[b+34>>1]|4}a=Ub(d,17386);x[114414]=0;O(335,b+43|0,a|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){xb(a);hb=d+16|0;return}b=N()|0;xb(a);Q(b|0);p()}function X2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;e=oh(a);a=b+24|0;c=x[a>>2];x[114414]=0;c=R(2222,c+484344|0)|0;f=x[114414];x[114414]=0;a:{b:{c:{if((f|0)==1){break c}x[114414]=0;P(1545,e|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break c}d:{e:{f:{g:{while(1){c=x[a>>2];x[114414]=0;c=R(2222,c+484344|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}if(c>>>0<=g>>>0){break d}c=Zb(x[a>>2]+484344|0,g);x[114414]=0;P(2219,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)!=1){x[114414]=0;T(2213,d+16|0,b|0,d|0);c=x[114414];x[114414]=0;if((c|0)==1){break g}x[114414]=0;P(1547,e|0,d+16|0);c=x[114414];x[114414]=0;if((c|0)==1){break f}g=g+1|0;xb(d+16|0);xb(d);continue}break}a=N()|0;break a}a=N()|0;break e}a=N()|0;xb(d+16|0)}xb(d);break a}hb=d+32|0;return}a=N()|0;break a}a=N()|0}qd(e);Q(a|0);p()}function _ba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=Bo(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(1380,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+32;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}h=hb-32|0;hb=h;i=yb(a);e=xm(a,ue(a)+1|0);g=ue(a);d=hb-16|0;hb=d;x[d+12>>2]=0;c=h+8|0;Qe(c+12|0,i);if(e){f=tM(x[c+16>>2],e);x[d+4>>2]=e;x[d>>2]=f;f=x[d>>2];e=x[d+4>>2]}else{e=0}x[c>>2]=f;g=(g<<5)+f|0;x[c+8>>2]=g;x[c+4>>2]=g;j=ic(c),k=(e<<5)+f|0,x[j>>2]=k;hb=d+16|0;d=x[c+8>>2];x[114414]=0;T(1380,i|0,d|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+32;x[114414]=0;P(1381,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}uM(c);hb=h+32|0;break b}a=N()|0;uM(c);Q(a|0);p()}}function HM(a,b,c){var d=0,e=0;a:{if(x[a+480180>>2]==4){d=y[b+833|0];if(c){v[b+833|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(x[a+480180>>2]!=1048576){break a}if(c){v[b+833|0]=c;break a}c=y[b+833|0]}b:{if(!(v[b+872|0]&1)){break b}d=x[b+700>>2];if(!d|!(c&255)){break b}c:{if(!(y[a+480208|0]&16)){break c}d=x[b+700>>2];if(x[a+480180>>2]==4){break c}c=Dy(a,c&15);e=yna(c,c>>31,d,d>>31);c=lb;e=e+32768|0;c=e>>>0<32768?c+1|0:c;c=Cc(zna(e,c,65536,0),lb);x[b+700>>2]=c;if((c|0)!=(d|0)){break b}a=a+1074312|0;if(!(!$b(a,7)|x[b+700>>2]==2147483647)){x[b+700>>2]=x[b+700>>2]+1;return}if($b(a,7)){break b}a=x[b+700>>2];if((a|0)<2){break b}x[b+700>>2]=a-1;return}c=d-((c&255)<<2)|0;x[b+700>>2]=c;if((c|0)>0){break b}x[b+700>>2]=1;if(x[a+480180>>2]!=2){break b}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}}function ie(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;if(y[461028]){return x[115256]}c=hb-32|0;hb=c;a:{b:{while(1){e=(c+8|0)+(a<<2)|0;d=1<<a&2147483647;if(d|1){d=IF(a,d?9986:17386)}else{d=x[a<<2>>2]}x[e>>2]=d;if((d|0)==-1){break b}a=a+1|0;if((a|0)!=6){continue}break}if(!HF(0)){b=61704;if(!cd(c+8|0,61704,24)){break a}b=61728;if(!cd(c+8|0,61728,24)){break a}a=0;if(!y[460856]){while(1){f=(a<<2)+460808|0,g=IF(a,17386),x[f>>2]=g;a=a+1|0;if((a|0)!=6){continue}break}v[460856]=1;x[115208]=x[115202]}b=460808;if(!cd(c+8|0,460808,24)){break a}b=460832;if(!cd(c+8|0,460832,24)){break a}b=sd(24);if(!b){break b}}a=x[c+12>>2];x[b>>2]=x[c+8>>2];x[b+4>>2]=a;a=x[c+28>>2];x[b+16>>2]=x[c+24>>2];x[b+20>>2]=a;a=x[c+20>>2];x[b+8>>2]=x[c+16>>2];x[b+12>>2]=a;break a}b=0}hb=c+32|0;v[461028]=1;x[115256]=b;return b|0}function tU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c;c=0;if(Xf(a,e+8|0)){x[e+4>>2]=y[e+8|0];g=x[Mb(e+4|0,e+12|0)>>2];c=hb+-64|0;hb=c;d=c+40|0;bf(d,a,g);a=x[d>>2];x[114414]=0;d=R(421,d|0)|0;f=x[114414];x[114414]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114414]=0;d=R(422,d|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}x[114414]=0;X(423,c+8|0,3,d|0,a|0);d=x[114414];x[114414]=0;if((d|0)==1){break d}x[114414]=0;P(355,c+24|0,c+8|0);d=x[114414];x[114414]=0;if((d|0)==1){break d}x[114414]=0;P(425,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}x[114414]=0;O(426,c|0,c+24|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}xb(c+24|0);Hc(c+40|0);hb=c- -64|0;c=!g|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(c+24|0)}Hc(c+40|0);Q(a|0);p()}}hb=e+16|0;return c|0}function iaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-32|0;hb=g;c=zk(a);a:{if(!b){break a}c=D(b,c);b:{if(x[a+12>>2]!=(b|0)){break b}if((hg(a)|0)!=(c|0)){break b}c=hb-16|0;hb=c;d=bc(a);f=dc(a);Zh(c+8|0);a=hb-16|0;hb=a;x[a>>2]=f;x[a+8>>2]=d;f=Rs(a,a+8|0);h=hb-16|0;hb=h;x[h+8>>2]=d;if((f|0)>0){while(1){i=h+8|0;d=x[i>>2];e=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[d|0]=e;v[d+1|0]=e>>>8;v[d+2|0]=e>>>16;v[d+3|0]=e>>>24;e=y[c+12|0]|y[c+13|0]<<8;v[d+4|0]=e;v[d+5|0]=e>>>8;d=f>>>0>1;Nj(i);f=f-1|0;if(d){continue}break}}hb=h+16|0;hb=a+16|0;hb=c+16|0;break a}d=g+8|0;Zh(d);c=GS(g+16|0,c,d);QK(a);Wl(a,c);x[a>>2]=x[c>>2];x[a+4>>2]=x[c+4>>2];d=x[yb(c)>>2];j=yb(a),k=d,x[j>>2]=k;j=yb(c),k=0,x[j>>2]=k;x[c>>2]=0;x[c+4>>2]=0;bm(c);x[a+12>>2]=b}hb=g+32|0;return(b|0)!=0|0}function wi(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=hb-48|0;hb=f;d=a+24|0;g=x[x[d>>2]+24620>>2];a:{if(!((g|0)!=(b|0)|x[x[d>>2]+24624>>2]!=(c|0))){if(y[a+29|0]){break a}KL(x[d>>2],1);break a}e=f+8|0;sc(e,x[d>>2]+24604|0,40);h=x[e+32>>2];i=x[e+36>>2];x[f+28>>2]=c;x[f+24>>2]=b;Nl(e,h);An(e,i);ny(x[d>>2],e);if((b|0)==(g|0)){break a}b=x[d>>2];e=b+946300|0;c=b+906300|0;while(1){b=x[c>>2];b:{if(!b){break b}if(!(mb[x[x[b>>2]+112>>2]](b)|0)){break b}mb[x[x[b>>2]+104>>2]](b,0);mb[x[x[b>>2]+92>>2]](b);mb[x[x[b>>2]+120>>2]](b)}c=c+160|0;if((e|0)!=(c|0)){continue}break}b=x[d>>2];d=b+946300|0;c=b+906300|0;while(1){b=x[c>>2];c:{if(!b){break c}if(mb[x[x[b>>2]+112>>2]](b)|0){break c}mb[x[x[b>>2]+104>>2]](b,1);mb[x[x[b>>2]+116>>2]](b)}c=c+160|0;if((d|0)!=(c|0)){continue}break}}v[a+29|0]=1;hb=f+48|0}function wea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;c=hb+-64|0;hb=c;zf(a,c+62|0);a:{b:{c:{d:{e:{f:{g:{e=x[19563];if(z[c+62>>1]>z[e+12>>1]){f=x[b+12>>2];d=c+16|0;UA(d,12611);x[114414]=0;X(1168,c+32|0,d|0,c+62|0,e+12|0);d=x[114414];x[114414]=0;if((d|0)==1){break g}x[114414]=0;d=O(626,c+48|0,c+32|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break f}x[114414]=0;P(601,f|0,d|0);f=x[114414];x[114414]=0;if((f|0)==1){break e}xb(d);xb(c+32|0);Gb(c+16|0);w[c+62>>1]=z[e+12>>1]}mg(Ni(b,0),z[c+62>>1]);b=Ni(b,0);h=c,i=bc(b),x[h+16>>2]=i;h=c,i=dc(b),x[h+8>>2]=i;if(Hb(c+16|0,c+8|0)){break b}break a}b=N()|0;break c}b=N()|0;break d}b=N()|0;xb(d)}xb(c+32|0)}Gb(c+16|0);Q(b|0);p()}while(1){b=c+16|0;d=x[b>>2];zf(a,c+6|0);w[d>>1]=z[c+6>>1];ge(b);if(Hb(b,c+8|0)){continue}break}}hb=c- -64|0}function Uda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;b=C[a+8>>3];d=hb-32|0;hb=d;o(+C[a>>3]);a=j(1)|0;i=j(0)|0;o(+b);c=j(1)|0;f=j(0)|0;h=c&2147483647;c=a&2147483647;e=(h|0)==(c|0)&f>>>0>i>>>0|c>>>0<h>>>0;a=e?i:f;e=e?c:h;m=e;l(0,a|0);l(1,e|0);b=+n();e=e>>>20|0;a:{if((e|0)==2047){break a}p=f;f=(c|0)==(h|0)&f>>>0<i>>>0|c>>>0>h>>>0;l(0,(f?i:p)|0);c=f?c:h;l(1,c|0);g=+n();b:{if(!(a|m)){break b}a=c>>>20|0;if((a|0)==2047){break b}if((a-e|0)>=65){b=g+b;break a}c:{if(a>>>0>=1534){b=b*190109156629516e-225;g=g*190109156629516e-225;k=5.260135901548374e210;break c}k=1;if(e>>>0>572){break c}b=b*5.260135901548374e210;g=g*5.260135901548374e210;k=190109156629516e-225}YG(d+24|0,d+16|0,g);YG(d+8|0,d,b);b=k*M(C[d>>3]+C[d+16>>3]+C[d+8>>3]+C[d+24>>3]);break a}b=g}hb=d+32|0;return+b}function Zc(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=x[a+112>>2];d=x[a+116>>2];i=!!(b|d);e=b;f=x[a+4>>2];h=x[a+44>>2];b=f-h|0;g=b;c=b+x[a+120>>2]|0;b=x[a+124>>2]+(b>>31)|0;a:{b=c>>>0<g>>>0?b+1|0:b;if(!(((b|0)>=(d|0)&c>>>0>=e>>>0|(b|0)>(d|0))&i)){i=uw(a);if((i|0)>=0){break a}f=x[a+4>>2];h=x[a+44>>2]}x[a+112>>2]=-1;x[a+116>>2]=-1;x[a+104>>2]=f;g=c;c=h-f|0;d=g+c|0;b=(c>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=c>>>0>d>>>0?b+1|0:b;return-1}d=c+1|0;b=d?b:b+1|0;f=x[a+4>>2];h=x[a+8>>2];e=x[a+116>>2];g=e;c=x[a+112>>2];b:{if(!(e|c)){break b}e=c-d|0;c=g-(b+(c>>>0<d>>>0)|0)|0;j=h-f|0;g=j>>31;if((c|0)>=(g|0)&e>>>0>=j>>>0|(c|0)>(g|0)){break b}h=e+f|0}x[a+104>>2]=h;c=x[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){v[f-1|0]=i}return i}function gga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-32|0;hb=e;h=x[a+40>>2];i=x[a+36>>2];l=x[a+16>>2];b=x[a+4>>2];j=b;f=x[a>>2];x[e+24>>2]=f;x[e+28>>2]=b;b=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=b;a:{if(!d){g=h>>12;b=i>>12;break a}while(1){b=x[e+24>>2];m=b>>>18|0;j=((((x[e+28>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;g=0;b=1;while(1){k=g<<1;f=w[k+j>>1];x[(e+8|0)+(g<<2)>>2]=f+((D(w[(k|4)+j>>1]-f|0,m)|0)/16384|0);f=b;b=0;g=1;if(f){continue}break}f=x[a+32>>2];i=x[a+28>>2]+i|0;b=i>>12;x[c>>2]=x[c>>2]+D(b,x[e+8>>2]);h=f+h|0;g=h>>12;x[c+4>>2]=x[c+4>>2]+D(g,x[e+12>>2]);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}f=x[e+24>>2];j=x[e+28>>2]}x[a>>2]=f;x[a+4>>2]=j;x[a+40>>2]=h;x[a+20>>2]=b;x[a+36>>2]=i;x[a+24>>2]=g;hb=e+32|0}function k4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=_k(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(2162,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+24;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}h=hb-32|0;hb=h;i=yb(a);f=Zk(a,xd(a)+1|0);g=xd(a);d=hb-16|0;hb=d;x[d+12>>2]=0;c=h+8|0;Qe(c+12|0,i);if(f){vM(d,x[c+16>>2],f);e=x[d>>2];f=x[d+4>>2]}else{f=0}x[c>>2]=e;g=D(g,24)+e|0;x[c+8>>2]=g;x[c+4>>2]=g;j=ic(c),k=D(f,24)+e|0,x[j>>2]=k;hb=d+16|0;d=x[c+8>>2];x[114414]=0;T(2162,i|0,d|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+24;x[114414]=0;P(2163,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}fI(c);hb=h+32|0;break b}a=N()|0;fI(c);Q(a|0);p()}}function jk(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;v[k+15|0]=a;a:{b:{c:{if(x[d>>2]!=(c|0)){break c}l=43;m=a&255;if((m|0)!=y[j+24|0]){l=45;if(y[j+25|0]!=(m|0)){break c}}x[d>>2]=c+1;v[c|0]=l;break b}if(!(!Bb(g)|(a|0)!=(f|0))){a=0;b=x[i>>2];if((b-h|0)>159){break a}a=x[e>>2];x[i>>2]=b+4;x[b>>2]=a;break b}a=-1;f=Gl(j,j+26|0,k+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=x[d>>2];if((b|0)==(c|0)|(b-c|0)>2|y[b-1|0]!=48){break a}a=0;x[e>>2]=0;x[d>>2]=b+1;v[b|0]=y[f+64928|0];break a}a=x[d>>2];x[d>>2]=a+1;v[a|0]=y[f+64928|0];x[e>>2]=x[e>>2]+1;a=0;break a}a=0;x[e>>2]=0}hb=k+16|0;return a|0}function ik(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;k=hb-16|0;hb=k;x[k+12>>2]=a;a:{b:{c:{if(x[d>>2]!=(c|0)){break c}l=43;if(x[j+96>>2]!=(a|0)){l=45;if(x[j+100>>2]!=(a|0)){break c}}x[d>>2]=c+1;v[c|0]=l;break b}if(!(!Bb(g)|(a|0)!=(f|0))){a=0;b=x[i>>2];if((b-h|0)>159){break a}a=x[e>>2];x[i>>2]=b+4;x[b>>2]=a;break b}a=-1;g=cw(j,j+104|0,k+12|0)-j|0;if((g|0)>92){break a}f=g>>2;d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(g|0)<88){break d}b=x[d>>2];if((b|0)==(c|0)|(b-c|0)>2|y[b-1|0]!=48){break a}a=0;x[e>>2]=0;x[d>>2]=b+1;v[b|0]=y[f+64928|0];break a}a=x[d>>2];x[d>>2]=a+1;v[a|0]=y[f+64928|0];x[e>>2]=x[e>>2]+1;a=0;break a}a=0;x[e>>2]=0}hb=k+16|0;return a|0}function wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24);v[e+15|0]=y[a+4|0];v[e+14|0]=64;f=b,g=y[rc(e+15|0,e+14|0)|0]<<2,w[f+30>>1]=g;c=a+6|0;d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);a=a+10|0;a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);d=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);a=d+(a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24))|0;x[b+8>>2]=a;d=x[b+4>>2];c=x[b>>2];if(d>>>0>=c>>>0){d=c-1|0;x[b+4>>2]=d}if(a>>>0>c>>>0){x[b+8>>2]=c;a=c}a:{if(a>>>0<d>>>0){x[b+4>>2]=0;x[b+8>>2]=0;break a}if(a>>>0<=d>>>0){break a}x[b+68>>2]=d;w[b+34>>1]=z[b+34>>1]|2}hb=e+16|0}function vs(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-176|0;hb=d;e=lh(d+40|0);f=x[x[e>>2]-12>>2];x[114414]=0;g=$(121)|0;h=x[114414];x[114414]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}x[114414]=0;T(122,d+32|0,e+f|0,g|0);f=x[114414];x[114414]=0;if((f|0)==1){break e}Ob(d+32|0);x[114414]=0;P(141,e|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break e}x[114414]=0;P(132,e|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break e}x[114414]=0;P(124,d|0,e|0);b=x[114414];x[114414]=0;if((b|0)==1){break e}x[114414]=0;T(139,d+16|0,d|0,c|0);b=x[114414];x[114414]=0;if((b|0)==1){break d}x[114414]=0;T(140,a|0,d+16|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}xb(d+16|0);xb(d);Xd(e);hb=d+176|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;xb(d+16|0)}xb(d)}Xd(e);Q(c|0);p()}function rK(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;a:{if(Lb(a)>>>0>511){break a}if(!Jf(x[x[b>>2]-12>>2]+b|0)){break a}g=hb-16|0;hb=g;f=Me(64);x[114414]=0;h=R(1440,f|0)|0;e=x[114414];x[114414]=0;b:{c:{if((e|0)!=1){f=sy(g,h);e=x[f>>2];x[114414]=0;h=U(1663,e|0,b|0,c|0)|0;e=x[114414];x[114414]=0;d:{e:{if((e|0)!=1){if((h|0)==1){break e}ry(g+8|0);break d}a=N()|0;Tf(f);break c}iq(g+8|0,f)}Tf(f);hb=g+16|0;e=x[g+8>>2];break b}a=N()|0;_b(f)}Q(a|0);p()}x[d+8>>2]=e;f:{g:{if(!zd(d+8|0)){x[114414]=0;c=O(1661,b|0,c|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break g}x[d>>2]=c;sS(d+8|0,ke(d));Tf(d)}e=0;if(!zd(d+8|0)){break f}b=d+8|0;e=x[b>>2];x[114414]=0;P(1662,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)!=1){break f}}a=N()|0;Tf(d+8|0);Q(a|0);p()}Tf(d+8|0)}hb=d+16|0;return e}function hr(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;a=hd(a);a:{b:{c:{switch(b|0){case 0:x[114414]=0;b=O(2,d|0,11856)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}Db(a,b);xb(b);break b;case 1:x[114414]=0;b=O(2,d|0,11881)|0;c=x[114414];x[114414]=0;if((c|0)!=1){Db(a,b);xb(b);break b}break a;case 2:x[114414]=0;b=O(2,d|0,11829)|0;c=x[114414];x[114414]=0;if((c|0)!=1){Db(a,b);xb(b);break b}break a;case 3:x[114414]=0;b=O(2,d|0,11803)|0;c=x[114414];x[114414]=0;if((c|0)!=1){Db(a,b);xb(b);break b}break a;case 4:x[114414]=0;b=O(2,d|0,8842)|0;c=x[114414];x[114414]=0;if((c|0)!=1){Db(a,b);xb(b);break b}break a;case 5:break c;default:break b}}x[114414]=0;b=O(2,d|0,3460)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}Db(a,b);xb(b)}hb=d+16|0;return}b=N()|0;xb(a);Q(b|0);p()}function _o(a){var b=E(0),c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;e=(q(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=E(1);if(d>>>0<964689920){break a}b=Mh(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=E(-Mh(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=Lh(f+1.5707963267948966);break a}b=Lh(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=Mh(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=Lh(-4.71238898038469-+a);break a}b=Lh(+a+-4.71238898038469);break a}b=E(a-a);if(d>>>0>=2139095040){break a}b:{switch(Rw(a,c+8|0)&3){case 0:b=Mh(C[c+8>>3]);break a;case 1:b=Lh(-C[c+8>>3]);break a;case 2:b=E(-Mh(C[c+8>>3]));break a;default:break b}}b=Lh(C[c+8>>3])}a=b;hb=c+16|0;return a}function xv(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-48|0;hb=e;x[e+44>>2]=d;a:{f=x[b>>2];b:{if(!(mb[x[x[f>>2]+40>>2]](f,c,d)|0)){ci(a);break b}jl(e+24|0,b);x[114414]=0;b=R(236,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}d=x[x[b>>2]+24>>2];x[114414]=0;b=R(d|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}x[114414]=0;x[e+20>>2]=b-c;b=O(35,e+44|0,e+20|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}g=x[b>>2];b=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=b;b=hb-16|0;hb=b;d=e+8|0;f=jl(b+8|0,d);x[114414]=0;h=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=h;X(249,e+32|0,b|0,c|0,g|0);c=x[114414];x[114414]=0;c:{if((c|0)!=1){Ab(d);hb=b+16|0;break c}a=N()|0;Ab(d);Q(a|0);p()}b=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=b;RC(a,e,0)}hb=e+48|0;return}a=N()|0;Ab(e+24|0);Q(a|0);p()}function I7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=0,q=0,r=0,s=0;g=hb-16|0;hb=g;j=a+44|0;if(Bh(j)){r=g,s=Od(j,0),x[r+8>>2]=s;r=g,s=Od(j,1),x[r+12>>2]=s;r=g,s=ld(j,0),x[r>>2]=s;r=g,s=ld(j,1),x[r+4>>2]=s;if(d){p=y[a+4273|0];q=y[a+4272|0];k=d;while(1){e=0;l=1;while(1){h=e<<2;f=h+(g+8|0)|0;e=x[f>>2];x[f>>2]=e+4;f=a+h|0;m=f+4228|0;i=E(E(B[a+4236>>2]*B[m>>2])+E(B[a+4240>>2]*B[e>>2]));B[m>>2]=i;i=E(B[a+4260>>2]*zJ(E(i*E(1073741824)),q,p));e=f+4244|0;n=B[a+4264>>2];f=f+4252|0;o=B[f>>2];i=E(i-E(E(B[a+4268>>2]*B[e>>2])+E(n*o)));B[f>>2]=i;B[e>>2]=o+E(i*n);e=g+h|0;h=x[e>>2];x[e>>2]=h+4;B[h>>2]=i*E(9.313225746154785e-10);h=l;l=0;e=1;if(h){continue}break}k=k-1|0;if(k){continue}break}}zi(a,b,c,ld(j,0),ld(j,1),d)}hb=g+16|0}function wka(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;v[g+14|0]=d;v[g+15|0]=c;v[g+13|0]=e;v[g+12|0]=f;if((d-1&255)>>>0<=5){v[g+14|0]=d+15}QR(g+15|0,g+13|0);QR(g+14|0,g+12|0);a:{if(y[g+15|0]==10){v[g+13|0]=y[g+13|0]&15?-1:y[g+12|0];if(y[g+14|0]!=10){break a}v[g+14|0]=0;break a}if(y[g+14|0]!=10){break a}v[g+12|0]=y[g+12|0]&15?-1:0}if(b){v[a+2|0]=1;v[a+4|0]=b+2>>>2}Yx(g+15|0,g+13|0,g+14|0,g+12|0);c=y[g+15|0];b:{if(!c){break b}d=y[g+14|0];if(!d){v[g+14|0]=c;v[g+12|0]=y[g+13|0];break b}if((c|0)==(d|0)&(c|0)!=20){break b}if(!b){Xx(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);v[a+2|0]=y[g+15|0];v[a+4|0]=y[g+13|0];break b}if(rn(c)>>>0<=rn(y[g+14|0])>>>0){break b}wh(g+15|0,g+14|0);wh(g+13|0,g+12|0)}v[a+3|0]=y[g+14|0];v[a+5|0]=y[g+12|0];hb=g+16|0}function mca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=E(0),h=0,i=E(0),j=E(0),k=0,m=0;f=hb-16|0;hb=f;k=f,m=D(x[a>>2],Je(a)),x[k+12>>2]=m;xc(f+12|0,c>>>2|0);c=Cb(b);g=B[e+4>>2];e=x[f+12>>2];if(e){while(1){h=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);g=E(I(E(F((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()))),g));c=c+4|0;e=e-1|0;if(e){continue}break}}c=g==E(0);a:{if(c){break a}e=x[f+12>>2];if(!e){break a}j=c?E(1):E(E(1)/g);c=x[a+20>>2];while(1){a=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);i=de(E(nf(E((l(2,a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)),r())*j),E(-1))*E(32768)));b:{if(E(F(i))<E(2147483648)){a=~~i;break b}a=-2147483648}k=c,m=Uc(a),w[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){B[d>>2]=g}hb=f+16|0;return x[f+12>>2]<<2}function hx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-80|0;hb=c;d=x[a>>2];e=x[d+4>>2];x[c+40>>2]=x[d+20>>2];f=x[d+16>>2];x[c+32>>2]=x[d+12>>2];x[c+36>>2]=f;gn(c- -64|0,c+32|0,e);d=Mc(c+48|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);e=x[x[a+12>>2]>>2];f=x[x[a+8>>2]>>2];x[c+24>>2]=x[c+72>>2];a=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=a;x[c+8>>2]=x[d+8>>2];a=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=a;if(e){i=c+16|0;j=b+4|0;while(1){a=0;if(f){while(1){h=C[kh(c,a,g)>>3];gc(b,a);h=Qd(Fg(+(Cj(Qd(h*134217728))-1024+((qs(j)^-2147483648)>>>21)|0)*7.450580596923828e-9)*32768);a:{if(F(h)<2147483648){d=~~h;break a}d=-2147483648}d=Uc(d);k=fn(i,a,g),l=d,w[k>>1]=l;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}hb=c+80|0}function hga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-32|0;hb=e;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];b=x[a+4>>2];j=b;f=x[a>>2];x[e+24>>2]=f;x[e+28>>2]=b;b=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=b;a:{if(!d){g=h>>12;b=i>>12;break a}while(1){b=x[e+24>>2];l=b>>>10&4194048;j=(((x[e+28>>2]&2147483647)<<1|b>>>31)&-2)+k|0;g=0;b=1;while(1){f=v[g+j|0];x[(e+8|0)+(g<<2)>>2]=((D(v[(g|2)+j|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}f=x[a+32>>2];i=x[a+28>>2]+i|0;b=i>>12;x[c>>2]=x[c>>2]+D(b,x[e+8>>2]);h=f+h|0;g=h>>12;x[c+4>>2]=x[c+4>>2]+D(g,x[e+12>>2]);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}f=x[e+24>>2];j=x[e+28>>2]}x[a>>2]=f;x[a+4>>2]=j;x[a+40>>2]=h;x[a+20>>2]=b;x[a+36>>2]=i;x[a+24>>2]=g;hb=e+32|0}function EF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-1040|0;hb=g;h=x[b>>2];x[g+12>>2]=h;j=a?a:g+16|0;d=a?d:256;a:{b:{c:{if(!(!h|!d)){while(1){f=c>>>2|0;if(!(c>>>0>131|f>>>0>=d>>>0)){f=h;break b}k=kw(j,g+12|0,d>>>0>f>>>0?f:d,e);f=x[g+12>>2];if((k|0)==-1){d=0;i=-1;break c}l=(g+16|0)!=(j|0)?k:0;d=d-l|0;j=(l<<2)+j|0;c=f?(c+h|0)-f|0:0;i=i+k|0;if(!f){break c}h=f;if(d){continue}break c}}f=h}if(!f){break a}}if(!d|!c){break a}h=i;while(1){d:{i=Wo(j,f,c,e);e:{if(i+2>>>0<=2){f:{switch(i+1|0){case 1:x[g+12>>2]=0;break e;case 0:break a;default:break f}}x[e>>2]=0;break e}f=x[g+12>>2]+i|0;x[g+12>>2]=f;h=h+1|0;d=d-1|0;if(d){break d}}i=h;break a}j=j+4|0;c=c-i|0;i=h;if(c){continue}break}}if(a){x[b>>2]=x[g+12>>2]}hb=g+1040|0;return i|0}function vH(a){var b=E(0),c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),j=E(0),k=E(0),l=E(0),m=E(0),n=E(0),o=E(0);b=B[a+32>>2];c=B[a+8>>2];e=B[a+16>>2];f=E(E(b-c)+e);i=B[a>>2];j=B[a+24>>2];k=E(i-j);B[a+16>>2]=f+k;d=B[a+4>>2];g=B[a+20>>2];h=B[a+28>>2];l=E(E(d-E(g+h))*E(.8660253882408142));k=E(k-E(f*E(.5)));B[a+4>>2]=l+k;m=E(E(g+d)*E(.9848077297210693));f=E(B[a+12>>2]*E(.8660253882408142));n=E(E(h+d)*E(-.6427876353263855));o=E(E(m-f)+n);d=E(i+E(j*E(.5)));i=E(E(b+c)*E(.7660444378852844));b=E(E(e-b)*E(.1736481785774231));j=E(E(d-i)+b);B[a+12>>2]=o+j;B[a+20>>2]=j-o;B[a+28>>2]=k-l;g=E(E(g-h)*E(.3420201539993286));h=E(g-E(f+m));c=E(E(e+c)*E(.9396926164627075));b=E(E(d+c)-b);B[a+32>>2]=h+b;e=E(E(g+f)+n);c=E(E(d-c)+i);B[a+24>>2]=e+c;B[a+8>>2]=c-e;B[a>>2]=b-h}function lx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-80|0;hb=c;d=x[a>>2];f=x[d+4>>2];e=x[d+24>>2];x[c+40>>2]=x[d+20>>2];x[c+44>>2]=e;e=x[d+16>>2];x[c+32>>2]=x[d+12>>2];x[c+36>>2]=e;Nh(c- -64|0,c+32|0,f);d=Mc(c+48|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);f=x[x[a+12>>2]>>2];e=x[x[a+8>>2]>>2];a=x[c+76>>2];x[c+24>>2]=x[c+72>>2];x[c+28>>2]=a;a=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=a;x[c+8>>2]=x[d+8>>2];a=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=a;if(f){h=c+16|0;i=b+4|0;while(1){a=0;if(e){while(1){d=x[Rf(c,a,g)>>2];gc(b,a);d=(d+((qs(i)^-2147483648)>>>21|0)|0)-2147482624>>>12|0;d=d>>>0<=491520?491520:d;j=hn(h,a,g),k=(d|0)>=557055?557055:d,w[j>>1]=k;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}hb=c+80|0}function N9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a=hb-16|0;hb=a;x[b>>2]=0;x[b+4>>2]=0;x[a+12>>2]=0;d=yb(c);x[114414]=0;U(1617,b+8|0,a+12|0,d|0)|0;d=x[114414];x[114414]=0;a:{if((d|0)!=1){x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];d=x[yb(c)>>2];g=yb(b),h=d,x[g>>2]=h;g=yb(c),h=0,x[g>>2]=h;x[c>>2]=0;x[c+4>>2]=0;hb=a+16|0;break a}S(0)|0;zb();p()}x[b+20>>2]=x[c+20>>2];a=x[c+16>>2];x[b+12>>2]=x[c+12>>2];x[b+16>>2]=a;f=hb-16|0;hb=f;d=b+24|0;x[d>>2]=0;x[d+4>>2]=0;x[f+12>>2]=0;a=c+24|0;e=yb(a);x[114414]=0;U(1618,d+8|0,f+12|0,e|0)|0;e=x[114414];x[114414]=0;b:{if((e|0)!=1){x[d>>2]=x[a>>2];x[d+4>>2]=x[a+4>>2];e=x[yb(a)>>2];g=yb(d),h=e,x[g>>2]=h;g=yb(a),h=0,x[g>>2]=h;x[a>>2]=0;x[a+4>>2]=0;hb=f+16|0;break b}S(0)|0;zb();p()}Jd(b+36|0,c+36|0);x[b+48>>2]=x[c+48>>2]}function MG(a){var b=0,c=0,d=0,e=0;b=hb-16|0;hb=b;e=(q(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=Lh(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=E(-Mh(d+1.5707963267948966));break a}a=Mh(d+-1.5707963267948966);break a}a=Lh(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=Mh(d+4.71238898038469);break a}a=E(-Mh(d+-4.71238898038469));break a}a=Lh(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=E(a-a);break a}b:{switch(Rw(a,b+8|0)&3){case 0:a=Lh(C[b+8>>3]);break a;case 1:a=Mh(C[b+8>>3]);break a;case 2:a=Lh(-C[b+8>>3]);break a;default:break b}}a=E(-Mh(C[b+8>>3]))}hb=b+16|0;return a}function Ez(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-80|0;hb=d;a:{b:{e=x[a+4>>2];if(e>>>0<b>>>0){h=Do(d+72|0);f=b-e|0;b=Mt(a);if(!(f>>>0>b>>>0|e>>>0>b-f>>>0)){b=d+56|0;Mk(b,a);Ed(h,b);x[a+4>>2]=x[a+4>>2]+f;break b}Dz(a);b=Cz(d+56|0);e=x[a+4>>2];x[114414]=0;e=O(904,a|0,e+f|0)|0;g=x[114414];x[114414]=0;c:{if((g|0)==1){break c}x[114414]=0;P(905,b|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}x[b+4>>2]=x[a+4>>2]+f;Ej(d+40|0,a);Mk(d+32|0,a);e=d+24|0;Ej(e,b);x[114414]=0;g=x[d+44>>2];x[d+8>>2]=x[d+40>>2];x[d+12>>2]=g;g=x[d+36>>2];x[d>>2]=x[d+32>>2];x[d+4>>2]=g;X(906,d+48|0,d+8|0,d|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}Ed(h,d+48|0);Bz(a,b);ce(b);break b}a=N()|0;ce(b);Q(a|0);p()}x[a+4>>2]=b;break a}Gq(Ed(d+16|0,h),f,c)}hb=d+80|0}function kca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0;f=hb-16|0;hb=f;k=f,m=D(x[a>>2],Je(a)),x[k+12>>2]=m;xc(f+12|0,c>>>3|0);c=Cb(b);g=C[e+8>>3];e=x[f+12>>2];if(e){while(1){h=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);l(0,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));l(1,h|0);g=I(F(+n()),g);c=c+8|0;e=e-1|0;if(e){continue}break}}c=g==0;a:{if(c){break a}e=x[f+12>>2];if(!e){break a}j=c?1:1/g;c=x[a+20>>2];while(1){a=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);h=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);l(0,h|0);l(1,a|0);i=Qd(Fg(+n()*j)*32768);b:{if(F(i)<2147483648){a=~~i;break b}a=-2147483648}k=c,m=Uc(a),w[k>>1]=m;b=b+8|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){C[d>>3]=g}hb=f+16|0;return x[f+12>>2]<<3}function WZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=aF(c);b:{if(b){bk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;ak(k,a);break b}xr(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;eh(k,a)}hi(i,k);Nc(k);l=e,m=li(a),x[l>>2]=m;l=f,m=ki(a),x[l>>2]=m;wg(k,a);Db(g,k);xb(k);fh(k,a);hi(h,k);Nc(k);a=$j(a);break a}a=$E(c);c:{if(b){bk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;ak(k,a);break c}xr(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;eh(k,a)}hi(i,k);Nc(k);l=e,m=li(a),x[l>>2]=m;l=f,m=ki(a),x[l>>2]=m;wg(k,a);Db(g,k);xb(k);fh(k,a);hi(h,k);Nc(k);a=$j(a)}x[j>>2]=a;hb=k+16|0}function vn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=x[b+88>>2];d=c|2048;x[b+88>>2]=d;e=x[b+656>>2];if(!(!e|v[b+724|0]&1)){d=c|6144;x[b+88>>2]=d}a:{if(!x[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=x[b+104>>2];if(!c){break b}f=z[c+34>>1];if(f&2){x[b+88>>2]=(f&4?d|4:d&-135)|2;d=x[c>>2];x[b+76>>2]=d;f=x[c+4>>2];x[b+80>>2]=f;c=x[c+8>>2];x[b+84>>2]=c;if(c>>>0<d>>>0){x[b+76>>2]=c;g=c}else{g=d}d=x[b+4>>2];if(g>>>0>=d>>>0){break b}x[b>>2]=0;x[b+4>>2]=((d-f>>>0)%(c-f>>>0)|0)+f;break b}x[b+88>>2]=d&-135;x[b+76>>2]=x[c>>2]}if(!e){break a}if(!(!(y[e+60|0]&2|x[a+480180>>2]&1064964)|!x[e>>2])){x[b+88>>2]=x[b+88>>2]|4096}if(y[e+65|0]==255|x[b+732>>2]!=-1){break a}a=e+48|0;h=b,i=Up(a,x[b+728>>2],256,64),x[h+732>>2]=i;h=b,i=z[Pb(a,y[e+65|0])>>1],x[h+728>>2]=i}}function t3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;i=Wb(a);c=Wb(e+16|0);a:{b:{c:{d:{g=b+24|0;if(!z[x[g>>2]+480192>>1]){break d}a=0;f=1;while(1){b=x[g>>2];x[114414]=0;b=O(2211,b|0,f&65535)|0;d=x[114414];x[114414]=0;if((d|0)==1){break c}x[114414]=0;b=O(118,e|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break c}d=Wc(b);x[114414]=0;O(1251,c|0,b|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break b}x[114414]=0;O(2029,c|0,17363)|0;h=x[114414];x[114414]=0;if((h|0)==1){break b}a=d^1|a;xb(b);f=f+1|0;if(z[x[g>>2]+480192>>1]>=(f&65535)>>>0){continue}break}if(!(a&1)){break d}x[114414]=0;O(398,i|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){break d}a=N()|0;break a}xb(c);hb=e+32|0;return}a=N()|0;break a}a=N()|0;xb(b)}xb(c);xb(i);Q(a|0);p()}function s3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;i=Wb(a);c=Wb(e+16|0);a:{b:{c:{d:{g=b+24|0;if(!z[x[g>>2]+480190>>1]){break d}a=0;f=1;while(1){b=x[g>>2];x[114414]=0;b=O(2212,b|0,f&65535)|0;d=x[114414];x[114414]=0;if((d|0)==1){break c}x[114414]=0;b=O(118,e|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break c}d=Wc(b);x[114414]=0;O(1251,c|0,b|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break b}x[114414]=0;O(2029,c|0,17363)|0;h=x[114414];x[114414]=0;if((h|0)==1){break b}a=d^1|a;xb(b);f=f+1|0;if(z[x[g>>2]+480190>>1]>=(f&65535)>>>0){continue}break}if(!(a&1)){break d}x[114414]=0;O(398,i|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){break d}a=N()|0;break a}xb(c);hb=e+32|0;return}a=N()|0;break a}a=N()|0;xb(b)}xb(c);xb(i);Q(a|0);p()}function iv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-16|0;hb=f;v[f+15|0]=d;v[b+12|0]=y[b+12|0]&240|y[a|0]&15;g=a+1|0;d=f+15|0;Mg(b,y[rc(g,d)|0]);e=y[rc(a+2|0,d)|0];v[b+13|0]=e;j=b,k=Md(y[a+3|0],e,y[f+15|0]),v[j+14|0]=k;d=y[rc(a+4|0,d)|0];v[b+15|0]=d;j=b,k=Md(y[a+5|0],d,y[f+15|0]),v[j+16|0]=k;v[f+14|0]=25;if(y[rc(f+14|0,g)|0]){d=0;while(1){e=D(d,3)+a|0;h=Xb(y[e+6|0]+c<<24>>24,0,64);j=Pb(b,d),k=h,v[j+2|0]=k;e=e+7|0;e=y[e|0]|y[e+1|0]<<8;j=Pb(b,d),k=e,w[j>>1]=k;a:{if(!d){break a}e=d-1|0;if(z[Pb(b,d)>>1]>=z[Pb(b,e)>>1]){break a}if(z[Pb(b,d)>>1]>255){break a}h=y[Pb(b,e)+1|0];i=Pb(b,d);w[i>>1]=z[i>>1]|h<<8;if(z[Pb(b,d)>>1]>=z[Pb(b,e)>>1]){break a}e=Pb(b,d);w[e>>1]=z[e>>1]+256}v[f+14|0]=25;d=d+1|0;if(d>>>0<y[rc(f+14|0,g)|0]){continue}break}}hb=f+16|0}function Ula(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-32|0;hb=e;x[e+24>>2]=b;k=e,l=ud(a),x[k+8>>2]=l;f=qm(e+24|0,e+8|0);a:{b=Yi(c,d);b:{if(!b){k=e,l=ud(a),x[k+8>>2]=l;a=Fe(e+8|0,f);break b}if(!xx(a,c)){i=hb-16|0;hb=i;g=Bb(a);h=Fc(a);c:{if(b>>>0<=h-g>>>0){h=Rb(a);if((f|0)==(g|0)){break c}j=f+h|0;fl(b+j|0,j,g-f|0);break c}$k(a,h,(b+g|0)-h|0,g,f,0,b);h=x[a>>2]}b=b+g|0;Zg(a,b);v[i+15|0]=0;Wd(b+h|0,i+15|0);if((c|0)!=(d|0)){b=f+h|0;while(1){Wd(b,c);b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}k=i,l=ud(a),x[k+8>>2]=l;a=Fe(i+8|0,f);hb=i+16|0;break b}c=yi(e+8|0,c,d);d=ud(c);g=jf(c);x[114414]=0;a=aa(587,a|0,b|0,f|0,d|0,g|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}xb(c)}hb=e+32|0;return a|0}a=N()|0;xb(c);Q(a|0);p()}function Kf(a){var b=0,c=0;b=x[a+4>>2];c=x[x[b>>2]-12>>2];x[114414]=0;b=x[(b+c|0)+24>>2];c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=x[a+4>>2];c=x[x[b>>2]-12>>2];x[114414]=0;b=Jf(b+c|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}if(!b){break b}b=x[a+4>>2];if(!(x[(x[x[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(CG()){break b}b=x[a+4>>2];c=x[x[b>>2]-12>>2];x[114414]=0;b=x[(b+c|0)+24>>2];c=x[114414];x[114414]=0;c:{if((c|0)==1){break c}x[114414]=0;b=R(2345,b|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[114414]=0;P(18,a+b|0,1);a=x[114414];x[114414]=0;if((a|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)==1){break a}}return}S(0)|0;zb();p()}function Zaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-80|0;hb=c;e=JN(a,1<<b-1);x[e+12>>2]=b;a=1<<b;g=a>>>2|0;a:{if(b>>>0>=2){h=1/+(a>>>0);b=g;a=1;while(1){x[114414]=0;C[c+40>>3]=+(b>>>0)*-6.283185307179586*h;T(1542,c+48|0,35024,c+40|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}x[114414]=0;P(1212,c- -64|0,c+48|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}d=vc(e,a);f=x[c+76>>2];x[d+8>>2]=x[c+72>>2];x[d+12>>2]=f;f=x[c+68>>2];x[d>>2]=x[c+64>>2];x[d+4>>2]=f;a=a<<1;d=b>>>0<2;b=b>>>1|0;if(!d){continue}break}}a=Vl(c+24|0,1,0);x[114414]=0;b=x[a+12>>2];x[c+16>>2]=x[a+8>>2];x[c+20>>2]=b;b=x[a+4>>2];x[c+8>>2]=x[a>>2];x[c+12>>2]=b;X(1543,e|0,0,g|0,c+8|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}hb=c+80|0;return e|0}a=N()|0;Mp(e);Q(a|0);p()}function zaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;Ad(c,0);w[c+28>>1]=y[a+36|0]<<2;d=y[a+37|0];w[c+32>>1]=64;w[c+30>>1]=d<<2;d=a+40|0;x[c>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+44|0;x[c+4>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+48|0;x[c+8>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+52|0;x[c+24>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=b+151|0;if(y[d|0]<5){v[c+38|0]=y[y[d|0]+35850|0]}v[c+39|0]=y[b+152|0];d=b+156|0;v[c+41|0]=(y[d|0]|y[d+1|0]<<8)>>>4;b=b+154|0;b=(y[b|0]|y[b+1|0]<<8)>>>2|0;v[c+40|0]=b;if(y[c+41|0]|b&255){v[c+39|0]=y[c+39|0]^-1}a=a+38|0;if(y[a|0]&4){w[c+34>>1]=z[c+34>>1]|1}if(y[a|0]&8){w[c+34>>1]=z[c+34>>1]|2}if(y[a|0]&16){w[c+34>>1]=z[c+34>>1]|4}if(y[a|0]&32){w[c+34>>1]=z[c+34>>1]|32}}function eI(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-176|0;hb=d;e=lh(d+40|0);f=x[x[e>>2]-12>>2];x[114414]=0;g=$(121)|0;h=x[114414];x[114414]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}x[114414]=0;T(122,d+32|0,e+f|0,g|0);f=x[114414];x[114414]=0;if((f|0)==1){break e}Ob(d+32|0);x[114414]=0;P(146,e|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break e}x[114414]=0;P(129,e|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break e}x[114414]=0;P(124,d|0,e|0);b=x[114414];x[114414]=0;if((b|0)==1){break e}x[114414]=0;T(139,d+16|0,d|0,c|0);b=x[114414];x[114414]=0;if((b|0)==1){break d}x[114414]=0;T(140,a|0,d+16|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}xb(d+16|0);xb(d);Xd(e);hb=d+176|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;xb(d+16|0)}xb(d)}Xd(e);Q(c|0);p()}function _Z(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=fF(c);b:{if(b){bk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;ak(k,a);break b}xr(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;eh(k,a)}Db(i,k);xb(k);l=e,m=li(a),v[l|0]=m;l=f,m=ki(a),v[l|0]=m;wg(k,a);Db(g,k);xb(k);fh(k,a);Db(h,k);xb(k);a=$j(a);break a}a=eF(c);c:{if(b){bk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;ak(k,a);break c}xr(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;eh(k,a)}Db(i,k);xb(k);l=e,m=li(a),v[l|0]=m;l=f,m=ki(a),v[l|0]=m;wg(k,a);Db(g,k);xb(k);fh(k,a);Db(h,k);xb(k);a=$j(a)}x[j>>2]=a;hb=k+16|0}function kJ(a){var b=0,c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=E(0);c=Ze(x[a+16>>2]);g=E(E(B[a+4220>>2]*E(.9980000257492065))+E(.0010000000474974513));d=-9965.784284662086/+E(E(E(B[a+4216>>2]*E(2999.9990234375))+E(.0010000000474974513))*E(c>>>0));m=a,n=E(jh(d*+A[a+4288>>2])),B[m+4232>>2]=n;m=a+4236|0,n=E(jh(d*+A[a+4292>>2])),B[m>>2]=n;l=d*(1/+g+-1);c=0;h=a+4272|0;i=a+4232|0;while(1){j=x[(c<<2)+h>>2];e=c<<1&-4;f=jh(l*+(j+x[(e+h|0)+16>>2]>>>0));b=jh(d*+(j>>>0));g=B[e+i>>2];e=(c<<3)+i|0;f=f*.5;B[e+12>>2]=b*(.5-f);B[e+8>>2]=b*(f+.5);b=b*+g;b=(((b+1)*b+1)*b+1)*b+1;k=b*b+k;c=c+1|0;if((c|0)!=4){continue}break}d=jh(+jJ(B[a+4208>>2])*.16609640474436813);b=jh(+jJ(B[a+4212>>2])*.33219280948873625);B[a+4228>>2]=d*4*M(b)/M(k);B[a+4224>>2]=d*M(1-b)}function Wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-32|0;hb=e;j=x[a+24>>2];k=x[a+20>>2];l=x[a+16>>2];f=x[a+4>>2];b=x[a>>2];x[e+24>>2]=b;x[e+28>>2]=f;g=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=g;g=a;if(d){while(1){a=x[e+24>>2];h=((((x[e+28>>2]&2147483647)<<1|a>>>31)&2147483646)<<1)+l|0;a=(a>>>21&2040)+32976|0;m=w[a+6>>1];n=w[a+4>>1];o=w[a+2>>1];f=w[a>>1];i=0;b=1;while(1){a=i<<1;x[(e+8|0)+(i<<2)>>2]=(((D(w[a+h>>1],o)+D(w[(a|-4)+h>>1],f)|0)+D(w[(a|4)+h>>1],n)|0)+D(w[(a|8)+h>>1],m)|0)/16384;a=b;b=0;i=1;if(a){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],k);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],j);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}b=x[e+24>>2];f=x[e+28>>2]}x[g>>2]=b;x[g+4>>2]=f;hb=e+32|0}function XK(a){a=a|0;var b=0;a:{b:{c:{if(y[a+3|0]!=19){break c}v[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=y[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}v[a+3|0]=2;break a}v[a+3|0]=3;break a}v[a+5|0]=b&15|16;return}v[a+5|0]=b&3|48;return}v[a+5|0]=b&223^120;return}v[a+5|0]=b&15|176;return}v[a+5|0]=b&3|64;return}v[a+3|0]=15;v[a+5|0]=b&15;return}if(b&15){v[a+3|0]=11;v[a+5|0]=b<<4|15;return}break b}if(b&15){v[a+3|0]=11;break a}break b}if((b|0)!=192){break c}v[a|0]=254;break b}if((b|0)!=208){break c}v[a+3|0]=0}return}v[a+3|0]=0;return}v[a+5|0]=b|240}function F6(){var a=0,b=0,c=0,d=0,e=0;b=hb-48|0;hb=b;c=Wb(b+32|0);x[114414]=0;W(2028,b+16|0);a=x[114414];x[114414]=0;a:{b:{c:{d:{if((a|0)!=1){a=b+16|0;d=b,e=bc(a),x[d+8>>2]=e;d=b,e=dc(a),x[d>>2]=e;if(!Hb(b+8|0,b)){break c}while(1){e:{a=x[b+8>>2];x[114414]=0;O(1251,c|0,a|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break e}a=b+8|0;_j(a);d=b,e=dc(b+16|0),x[d>>2]=e;if(!Hb(a,b)){break c}x[114414]=0;O(2029,c|0,10156)|0;a=x[114414];x[114414]=0;if((a|0)!=1){continue}}break}a=S(0)|0;qd(b+16|0);break d}a=S(0)|0}xb(c);Y(a|0)|0;a=0;x[114414]=0;X(2023,3291,0,0,0);c=x[114414];x[114414]=0;if((c|0)==1){break a}_();break b}a=Ld(Rb(c));qd(b+16|0);xb(c)}hb=b+48|0;return a|0}b=N()|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)!=1){Q(b|0);p()}S(0)|0;zb();p()}function GM(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{if(!x[b+700>>2]){break a}f=x[a+480180>>2]==64?D(c,-20):c;b:{c:{if(!(!(y[a+480208|0]&16)|x[a+480180>>2]==4)){h=x[b+700>>2];c=f>>31;x[e+12>>2]=(c^f)-c>>>2;xc(e+12|0,255);c=x[b+700>>2];d=x[e+12>>2];if(!d){break b}g=b;d:{if((f|0)<0){d=Dy(a,d);break d}d=Cy(a,d)}d=yna(d,d>>31,c,c>>31);c=lb;d=d+32768|0;c=d>>>0<32768?c+1|0:c;c=Cc(zna(d,c,65536,0),lb);x[g+700>>2]=c;if((c|0)!=(h|0)){break b}g=$b(a+1074312|0,7);c=x[b+700>>2];if((g|0)==(f>>>31|0)){g=(c|0)==2147483647;c=x[b+700>>2];if(g){break b}c=c+1|0;break c}if((c|0)<2){break b}c=c-1|0;break c}c=f+x[b+700>>2]|0}x[b+700>>2]=c}if((c|0)>0){break a}x[b+700>>2]=1;if(x[a+480180>>2]!=2){break a}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}hb=e+16|0}function FR(a){var b=0,c=0,d=0;a:{if(cd(a,9970,3)){break a}b=a+3|0;if(y[b|0]<48|y[b|0]>51){break a}b=a+8|0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if((c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))>>>0<52){break a}b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if((b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24))>>>0>4294966507){break a}b=a+16|0;b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if((b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24))>>>0<52){break a}b=a+24|0;if(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24)){b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if((b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24))>>>0<52){break a}}a=a+32|0;a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);d=(a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24))>>>0<4294967216}return d}function f7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ai(a,b,c,d);x[a+4260>>2]=0;x[a>>2]=80448;c=a+4960|0;b=a+4504|0;d=b;while(1){d=yk(d)+24|0;if((d|0)!=(c|0)){continue}break}v[a+5046|0]=1;w[a+5044>>1]=0;x[a+4208>>2]=1063675494;x[a+4212>>2]=1065185444;x[a+4256>>2]=1059760811;d=a+4248|0;x[d>>2]=1065353216;x[d+4>>2]=1048525618;d=a+4240|0;x[d>>2]=1038174126;x[d+4>>2]=1065353216;d=a+4232|0;x[d>>2]=1047457519;x[d+4>>2]=1062836634;d=a+4224|0;x[d>>2]=1053079357;x[d+4>>2]=1059859440;d=a+4216|0;x[d>>2]=0;x[d+4>>2]=1032805417;x[114414]=0;U(1673,a+44|0,2,2)|0;d=x[114414];x[114414]=0;a:{if((d|0)!=1){x[114414]=0;W(1674,a|0);d=x[114414];x[114414]=0;if((d|0)!=1){break a}}d=N()|0;while(1){c=fg(c-24|0);if((b|0)!=(c|0)){continue}break}xf(a);Q(d|0);p()}return a|0}function vf(a,b){var c=0,d=0,e=0;d=hb-32|0;hb=d;a=Ug(a,-1,-1);nj(d+24|0,b,1);a:{b:{if(y[d+24|0]){c=x[x[b>>2]-12>>2];x[114414]=0;c=x[(b+c|0)+24>>2];e=x[114414];x[114414]=0;c:{d:{if((e|0)==1){break d}x[114414]=0;Ka(2356,d+8|0,c|0,0,0,1,8);c=x[114414];x[114414]=0;if((c|0)==1){break d}c=x[d+12>>2];x[a>>2]=x[d+8>>2];x[a+4>>2]=c;c=x[d+20>>2];x[a+8>>2]=x[d+16>>2];x[a+12>>2]=c;a=0;break c}Y(S(0)|0)|0;mj(x[x[b>>2]-12>>2]+b|0,1);a=x[x[b>>2]-12>>2];x[114414]=0;a=x[(a+b|0)+20>>2];c=x[114414];x[114414]=0;e:{if((c|0)!=1){if(!(a&1)){break e}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break a}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)==1){break b}Q(a|0);p()}_();a=1}Jg(x[x[b>>2]-12>>2]+b|0,a)}hb=d+32|0;return}S(0)|0;zb()}p()}function MN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=Ts(b);f=hb-16|0;hb=f;x[a>>2]=0;x[a+4>>2]=0;x[f+12>>2]=0;Xc(a+8|0);FN(a,2048);g=hb-16|0;hb=g;a:{b:{d=Yq(g,a,2048);e=x[d+4>>2];i=x[d+8>>2];if((e|0)!=(i|0)){while(1){h=yb(a);x[114414]=0;P(1215,h|0,e|0);h=x[114414];x[114414]=0;if((h|0)==1){break b}e=e+8|0;x[d+4>>2]=e;if((e|0)!=(i|0)){continue}break}}Jb(d);hb=g+16|0;break a}a=N()|0;Jb(d);Q(a|0);p()}hb=f+16|0;d=a;a=0;c:{while(1){c=1;if((a|0)!=1024){x[114414]=0;c=+(a-1024|0);k=+fb(1207,+(M(c*c*-9.5367431640625e-7+1)*b));e=x[114414];x[114414]=0;if((e|0)==1){break c}c=c*.0372006759294457;c=k*oi(c)/(c*j)}l=ll(d,a),m=c*.011841342921061943,C[l>>3]=m;a=a+1|0;if((a|0)!=2048){continue}break}return}a=N()|0;Pf(d);Q(a|0);p()}function Bg(a,b,c){var d=0,e=0;a:{if((a|0)==(b|0)){break a}e=a+c|0;if(b-e>>>0<=0-(c<<1)>>>0){return sc(a,b,c)}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){d=a;break b}if(!(a&3)){d=a;break c}d=a;while(1){if(!c){break a}v[d|0]=y[b|0];b=b+1|0;c=c-1|0;d=d+1|0;if(d&3){continue}break}break c}d:{if(d){break d}if(e&3){while(1){if(!c){break a}c=c-1|0;d=c+a|0;v[d|0]=y[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c-4|0;x[c+a>>2]=x[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c-1|0;v[c+a|0]=y[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){x[d>>2]=x[b>>2];b=b+4|0;d=d+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function tma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-32|0;hb=g;oT(a);yb(a);c=Fb(g+16|0,x[a+4>>2]);d=Fb(g+8|0,x[a>>2]);e=Fb(g,x[b+4>>2]);f=x[c>>2];i=x[e>>2];j=hb-16|0;hb=j;e=hb-32|0;hb=e;c=hb-32|0;hb=c;x[c+16>>2]=x[d>>2];x[c+24>>2]=f;x[c+8>>2]=i;d=hb-16|0;hb=d;h=x[c+24>>2];i=c+16|0;f=x[i>>2];k=x[c+8>>2]+D((h-f|0)/-48|0,48)|0;h=h-f|0;l=Bg(k,f,h);m=f;f=D((h|0)/48|0,48);x[d+12>>2]=m+f;x[d+8>>2]=f+l;gd(c,d+12|0,d+8|0);hb=d+16|0;d=x[c+8>>2];gd(e+24|0,i,Fb(c,D((k-d|0)/48|0,48)+d|0));hb=c+32|0;x[e+16>>2]=x[e+24>>2];x[e+8>>2]=x[e+28>>2];gd(j+8|0,e+16|0,e+8|0);hb=e+32|0;hb=j+16|0;x[g+24>>2]=x[j+12>>2];x[b+4>>2]=x[g+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Wi(a);cm(a);cm(a);hb=g+32|0}function nka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-32|0;hb=g;SR(a);yb(a);c=Fb(g+16|0,x[a+4>>2]);d=Fb(g+8|0,x[a>>2]);e=Fb(g,x[b+4>>2]);f=x[c>>2];i=x[e>>2];j=hb-16|0;hb=j;e=hb-32|0;hb=e;c=hb-32|0;hb=c;x[c+16>>2]=x[d>>2];x[c+24>>2]=f;x[c+8>>2]=i;d=hb-16|0;hb=d;h=x[c+24>>2];i=c+16|0;f=x[i>>2];k=x[c+8>>2]+D((h-f|0)/-33|0,33)|0;h=h-f|0;l=Bg(k,f,h);m=f;f=D((h|0)/33|0,33);x[d+12>>2]=m+f;x[d+8>>2]=f+l;gd(c,d+12|0,d+8|0);hb=d+16|0;d=x[c+8>>2];gd(e+24|0,i,Fb(c,D((k-d|0)/33|0,33)+d|0));hb=c+32|0;x[e+16>>2]=x[e+24>>2];x[e+8>>2]=x[e+28>>2];gd(j+8|0,e+16|0,e+8|0);hb=e+32|0;hb=j+16|0;x[g+24>>2]=x[j+12>>2];x[b+4>>2]=x[g+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Qk(a);am(a);am(a);hb=g+32|0}function fia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;Ad(b,0);zh(d,1,a);c=d+16|0;Ic(c,d);x[114414]=0;O(335,b+43|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){e=d+16|0;xb(e);c=a+48|0;x[b>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+52|0;x[b+4>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+56|0;x[b+8>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+62|0;x[b+24>>2]=y[c|0]|y[c+1|0]<<8;xt(b,+((y[a+60|0]^8)-120|0)*.005208333333333333);v[d+16|0]=y[a+61|0];v[d|0]=64;f=b,g=y[rc(e,d)|0]<<2,w[f+30>>1]=g;w[b+34>>1]=0;a=a+47|0;if(y[a|0]&4){w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1}if(y[a|0]&32){w[b+34>>1]=z[b+34>>1]|4}if(v[a|0]<0){w[b+34>>1]=z[b+34>>1]|2}hb=d+32|0;return}a=N()|0;xb(d+16|0);Q(a|0);p()}function W2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;g=oh(a);f=b+24|0;a=z[x[f>>2]+480192>>1];x[114414]=0;P(1545,g|0,a|0);c=x[114414];x[114414]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(z[x[f>>2]+480192>>1]){while(1){c=x[f>>2];x[114414]=0;c=O(2211,c|0,a&65535)|0;e=x[114414];x[114414]=0;if((e|0)==1){break e}x[114414]=0;c=O(118,d|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break e}x[114414]=0;T(2213,d+16|0,b|0,c|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;P(1547,g|0,d+16|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}xb(d+16|0);xb(c);a=a+1|0;if(z[x[f>>2]+480192>>1]>=(a&65535)>>>0){continue}break}}hb=d+32|0;return}a=N()|0;break a}a=N()|0;break b}a=N()|0;xb(d+16|0)}xb(c);break a}a=N()|0}qd(g);Q(a|0);p()}function V2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;g=oh(a);f=b+24|0;a=z[x[f>>2]+480190>>1];x[114414]=0;P(1545,g|0,a|0);c=x[114414];x[114414]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(z[x[f>>2]+480190>>1]){while(1){c=x[f>>2];x[114414]=0;c=O(2212,c|0,a&65535)|0;e=x[114414];x[114414]=0;if((e|0)==1){break e}x[114414]=0;c=O(118,d|0,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break e}x[114414]=0;T(2213,d+16|0,b|0,c|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;P(1547,g|0,d+16|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}xb(d+16|0);xb(c);a=a+1|0;if(z[x[f>>2]+480190>>1]>=(a&65535)>>>0){continue}break}}hb=d+32|0;return}a=N()|0;break a}a=N()|0;break b}a=N()|0;xb(d+16|0)}xb(c);break a}a=N()|0}qd(g);Q(a|0);p()}function vL(a,b){var c=E(0),d=E(0),e=E(0);a:{b:{c:{switch(b|0){case 0:qp(a,E(1));pp(a,E(3.725290298461914e-9));op(a,E(268435456));np(a,0);break b;case 1:qp(a,E(32));pp(a,E(4.656612873077393e-10));op(a,E(2147483648));np(a,0);break b;case 2:qp(a,E(2));pp(a,E(7.450580596923828e-9));op(a,E(134217728));np(a,1);break b;default:qp(a,E(1));pp(a,E(7.450580596923828e-9));op(a,E(134217728));np(a,1);hy(a,0);Nl(a,1);gy(a,1);d=E(256);c=E(128);e=E(128);b=0;break a;case 4:case 5:break c}}qp(a,E(.75));pp(a,E(7.450580596923828e-9));op(a,E(134217728));np(a,1);hy(a,0);b=(b|0)==4;Nl(a,b?2:3);gy(a,1);d=E(256);c=b?E(256):E(192);e=c;b=1;break a}hy(a,1);Nl(a,0);gy(a,0);d=E(128);e=E(100);c=E(256);b=4}B[a+16>>2]=c;B[a+20>>2]=e;B[a+24>>2]=d;x[a+28>>2]=b}function FG(a,b,c,d){a:{switch(b-9|0){case 0:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];return;case 6:b=x[c>>2];x[c>>2]=b+4;b=w[b>>1];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 7:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=z[b>>1];x[a+4>>2]=0;return;case 8:b=x[c>>2];x[c>>2]=b+4;b=v[b|0];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 9:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=y[b|0];x[a+4>>2]=0;return;case 16:b=x[c>>2]+7&-8;x[c>>2]=b+8;C[a>>3]=C[b>>3];return;case 17:mb[d|0](a,c);default:return;case 1:case 4:case 14:b=x[c>>2];x[c>>2]=b+4;b=x[b>>2];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];x[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=x[c>>2]+7&-8;x[c>>2]=b+8;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c}function sha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;x[a>>2]=0;x[a+4>>2]=0;Xc(a+8|0);if(b){c=hb-16|0;hb=c;d=hb-16|0;hb=d;x[d+12>>2]=477218588;x[114414]=0;x[d+8>>2]=2147483647;e=O(35,d+12|0,d+8|0)|0;f=x[114414];x[114414]=0;a:{if((f|0)!=1){hb=d+16|0;d=x[e>>2];break a}S(0)|0;zb();p()}if(b>>>0>d>>>0){Jv(3950);p()}d=D(b,9);e=Vd(d,1);x[c+12>>2]=b;x[c+8>>2]=e;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;g=yb(a),h=b+D(x[c+12>>2],9)|0,x[g>>2]=h;hb=c+16|0;c=hb-16|0;hb=c;x[c>>2]=a;b=x[a+4>>2];x[c+4>>2]=b;x[c+8>>2]=b+d;b=x[c+4>>2];d=x[c+8>>2];if((b|0)!=(d|0)){while(1){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;b=b+9|0;x[c+4>>2]=b;if((b|0)!=(d|0)){continue}break}}Jb(c);hb=c+16|0}return a|0}function mha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-32|0;hb=g;mi(a);yb(a);c=Fb(g+16|0,x[a+4>>2]);d=Fb(g+8|0,x[a>>2]);e=Fb(g,x[b+4>>2]);f=x[c>>2];i=x[e>>2];j=hb-16|0;hb=j;e=hb-32|0;hb=e;c=hb-32|0;hb=c;x[c+16>>2]=x[d>>2];x[c+24>>2]=f;x[c+8>>2]=i;d=hb-16|0;hb=d;h=x[c+24>>2];i=c+16|0;f=x[i>>2];k=x[c+8>>2]+D((h-f|0)/-12|0,12)|0;h=h-f|0;l=Bg(k,f,h);m=f;f=D((h|0)/12|0,12);x[d+12>>2]=m+f;x[d+8>>2]=f+l;gd(c,d+12|0,d+8|0);hb=d+16|0;d=x[c+8>>2];gd(e+24|0,i,Fb(c,D((k-d|0)/12|0,12)+d|0));hb=c+32|0;x[e+16>>2]=x[e+24>>2];x[e+8>>2]=x[e+28>>2];gd(j+8|0,e+16|0,e+8|0);hb=e+32|0;hb=j+16|0;x[g+24>>2]=x[j+12>>2];x[b+4>>2]=x[g+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Nm(a,zc(a));hb=g+32|0}function k2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-32|0;hb=g;ig(a);yb(a);c=Fb(g+16|0,x[a+4>>2]);d=Fb(g+8|0,x[a>>2]);e=Fb(g,x[b+4>>2]);f=x[c>>2];i=x[e>>2];j=hb-16|0;hb=j;e=hb-32|0;hb=e;c=hb-32|0;hb=c;x[c+16>>2]=x[d>>2];x[c+24>>2]=f;x[c+8>>2]=i;d=hb-16|0;hb=d;h=x[c+24>>2];i=c+16|0;f=x[i>>2];k=x[c+8>>2]+D((h-f|0)/-24|0,24)|0;h=h-f|0;l=Bg(k,f,h);m=f;f=D((h|0)/24|0,24);x[d+12>>2]=m+f;x[d+8>>2]=f+l;gd(c,d+12|0,d+8|0);hb=d+16|0;d=x[c+8>>2];gd(e+24|0,i,Fb(c,D((k-d|0)/24|0,24)+d|0));hb=c+32|0;x[e+16>>2]=x[e+24>>2];x[e+8>>2]=x[e+28>>2];gd(j+8|0,e+16|0,e+8|0);hb=e+32|0;hb=j+16|0;x[g+24>>2]=x[j+12>>2];x[b+4>>2]=x[g+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Yk(a,xd(a));hb=g+32|0}function Xfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-32|0;hb=e;j=x[a+24>>2];k=x[a+20>>2];l=x[a+16>>2];g=x[a+4>>2];b=x[a>>2];x[e+24>>2]=b;x[e+28>>2]=g;h=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=h;h=a;if(d){while(1){a=x[e+24>>2];i=(((x[e+28>>2]&2147483647)<<1|a>>>31)&-2)+l|0;a=(a>>>21&2040)+32976|0;m=w[a+6>>1];n=w[a+4>>1];o=w[a+2>>1];g=w[a>>1];f=0;b=1;while(1){x[(e+8|0)+(f<<2)>>2]=(((D(v[f+i|0],o)+D(v[(f|-2)+i|0],g)|0)+D(v[(f|2)+i|0],n)|0)+D(v[(f|4)+i|0],m)<<8)/16384;a=b;b=0;f=1;if(a){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],k);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],j);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}b=x[e+24>>2];g=x[e+28>>2]}x[h>>2]=b;x[h+4>>2]=g;hb=e+32|0}function c1(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb+-64|0;hb=c;if(cH(0,c+40|0)){qr(x[114240],8514);p()}e=Ei(c+24|0,c+40|0);x[c+12>>2]=x[c+48>>2]/1e3;f=DG(c+16|0,c+12|0);b=hb-32|0;hb=b;d=hb-16|0;hb=d;g=hb-16|0;hb=g;a=hb-16|0;hb=a;i=a,j=yna(x[e>>2],x[e+4>>2],1e6,0),x[i>>2]=j;x[a+4>>2]=lb;e=Ei(a+8|0,a);h=x[e>>2];e=x[e+4>>2];hb=a+16|0;hb=g+16|0;a=d;x[a+8>>2]=h;x[a+12>>2]=e;d=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=d;hb=a+16|0;a=x[b+8>>2];e=x[b+12>>2];d=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=d;f=x[b>>2];d=a+f|0;a=x[b+4>>2]+e|0;x[b+16>>2]=d;x[b+20>>2]=d>>>0<f>>>0?a+1|0:a;a=Ei(b+24|0,b+16|0);d=x[a>>2];a=x[a+4>>2];hb=b+32|0;x[c+32>>2]=d;x[c+36>>2]=a;b=Ei(c+56|0,c+32|0);a=x[b>>2];hb=c- -64|0;lb=x[b+4>>2];return a|0}function wn(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(c){v[b+829|0]=c;break a}c=y[b+829|0]}d=x[a+480180>>2]&202376205?c&240?c&-16:c:c;c=x[b+688>>2];b:{if(x[a+480180>>2]&69206029){break b}e=d&255;f=d&15;if((f|0)==15){if(e>>>0>=16){Dp(a,b,(d&240)>>>4|0,0);return}if(!(v[b+872|0]&1)){break b}c=y[a+480208|0]&2?c:c-60|0;break b}if((e&240)!=240){break b}if(f){Cp(a,b,f,0);return}if(!(v[b+872|0]&1)){break b}c=y[a+480208|0]&2?c:c+60|0}c:{if(!(!(v[b+872|0]&1)|y[a+480208|0]&2)&(x[a+1074416>>2]!=1|x[a+480180>>2]!=524288)){break c}e=d&15;d:{if(e){if((d&255)>>>0>15?x[a+480180>>2]&16777248:0){break d}c=c-(e<<2)|0;break d}c=((d&255)>>>2&60)+c|0}if(x[a+480180>>2]!=1){break c}x[b+88>>2]=x[b+88>>2]|2097152}g=b,h=Xb(c,0,256),x[g+688>>2]=h}function k1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;e=x[a+28>>2];x[d+16>>2]=e;f=x[a+20>>2];x[d+28>>2]=c;x[d+24>>2]=b;b=f-e|0;x[d+20>>2]=b;f=b+c|0;i=2;a:{b:{b=d+16|0;c:{d:{if(bs(ta(x[a+60>>2],b|0,2,d+12|0)|0)){e=b;break d}while(1){g=x[d+12>>2];if((g|0)==(f|0)){break c}if((g|0)<0){e=b;break b}h=x[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;x[e>>2]=h+x[e>>2];b=(j?12:4)+b|0;x[b>>2]=x[b>>2]-h;f=f-g|0;b=e;i=i-j|0;if(!bs(ta(x[a+60>>2],b|0,i|0,d+12|0)|0)){continue}break}}if((f|0)!=-1){break b}}b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];a=c;break a}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a>>2]=x[a>>2]|32;a=0;if((i|0)==2){break a}a=c-x[e+4>>2]|0}hb=d+32|0;return a|0}function j2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-80|0;hb=d;a=x[a+4>>2];lv(d+16|0,b);x[114414]=0;b=O(2,d|0,13624)|0;e=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){x[114414]=0;T(3,d+32|0,d+16|0,b|0);e=x[114414];x[114414]=0;if((e|0)==1){break h}x[114414]=0;T(695,d+48|0,d+32|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break g}x[114414]=0;T(9,d- -64|0,0,d+48|0);c=x[114414];x[114414]=0;if((c|0)==1){break f}c=x[x[a>>2]+8>>2];x[114414]=0;P(c|0,a|0,d- -64|0);a=x[114414];x[114414]=0;if((a|0)==1){break e}xb(d- -64|0);xb(d+48|0);xb(d+32|0);xb(b);xb(d+16|0);hb=d+80|0;return}a=N()|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;xb(d- -64|0)}xb(d+48|0)}xb(d+32|0)}xb(b)}xb(d+16|0);Q(a|0);p()}function QF(a,b,c,d,e,f){var g=0;g=hb-80|0;hb=g;a:{if((f|0)>=16384){yd(g+32|0,b,c,d,e,0,0,0,2147352576);d=x[g+40>>2];e=x[g+44>>2];b=x[g+32>>2];c=x[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}yd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)>=49149?49149:f)-32766|0;d=x[g+24>>2];e=x[g+28>>2];b=x[g+16>>2];c=x[g+20>>2];break a}if((f|0)>-16383){break a}yd(g- -64|0,b,c,d,e,0,0,0,7471104);d=x[g+72>>2];e=x[g+76>>2];b=x[g+64>>2];c=x[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}yd(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)<=-48920?-48920:f)+32538|0;d=x[g+56>>2];e=x[g+60>>2];b=x[g+48>>2];c=x[g+52>>2]}yd(g,b,c,d,e,0,0,0,f+16383<<16);b=x[g+12>>2];x[a+8>>2]=x[g+8>>2];x[a+12>>2]=b;b=x[g+4>>2];x[a>>2]=x[g>>2];x[a+4>>2]=b;hb=g+80|0}function vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=zc(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(x[yb(a)>>2]-x[a+4>>2]|0)/12>>>0){e=hb-16|0;hb=e;d:{b=sl(e,a,c);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;P(1006,f|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break d}c=c+12|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break c}a=N()|0;Jb(b);Q(a|0);p()}b=yb(a);b=ek(d+8|0,Rm(a,zc(a)+c|0),zc(a),b);x[114414]=0;P(1001,b|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(1002,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}bP(b)}hb=d+32|0;break a}a=N()|0;bP(b);Q(a|0);p()}return}if(b>>>0<c>>>0){b=x[a>>2]+D(b,12)|0;zc(a);dP(a,b);Ht(a)}}function yla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Wi(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(x[yb(a)>>2]-x[a+4>>2]|0)/48>>>0){e=hb-16|0;hb=e;d:{b=rT(e,a,c);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;P(713,f|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break d}c=c+48|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break c}a=N()|0;Jb(b);Q(a|0);p()}b=yb(a);b=pT(d+8|0,qT(a,Wi(a)+c|0),Wi(a),b);x[114414]=0;P(671,b|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(525,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}qu(b)}hb=d+32|0;break a}a=N()|0;qu(b);Q(a|0);p()}return}if(b>>>0<c>>>0){b=x[a>>2]+D(b,48)|0;Wi(a);sT(a,b);CT(a)}}function q0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(A[b+24>>2]>A[b+44>>2]){x[b+44>>2]=x[b+24>>2]}l=-1;m=-1;h=f&24;a:{if(!h|(e|0)==1&(h|0)==24){break a}h=x[b+44>>2];if(h){i=h-Rb(b+32|0)|0;j=i>>31}b:{c:{switch(e|0){case 1:if(f&8){g=x[b+12>>2]-x[b+8>>2]|0;k=g>>31;break b}g=x[b+24>>2]-x[b+20>>2]|0;k=g>>31;break b;case 0:break b;case 2:break c;default:break a}}g=i;k=j}d=d+k|0;c=c+g|0;d=g>>>0>c>>>0?d+1|0:d;if((d|0)<0|(c>>>0>i>>>0&(d|0)>=(j|0)|(d|0)>(j|0))){break a}e=f&8;d:{if(!(c|d)){break d}if(x[b+12>>2]?0:e){break a}if(!(f&16)){break d}if(!x[b+24>>2]){break a}}if(e){Ym(b,x[b+8>>2],c+x[b+8>>2]|0,x[b+44>>2])}if(f&16){zw(b,x[b+20>>2],x[b+28>>2]);Ur(b,c)}l=c;m=d}Ug(a,l,m)}function FL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;h=-1;a:{if(!jy(a,b,2)){break a}d=x[b+656>>2];f=a+1074312|0;g=$b(f,31);i=x[b+752>>2];if(i?0:g){break a}g=d+88|0;f=i-$b(f,31)|0;d=x[a+480180>>2];d=(d|0)==4096?64:(d|0)==16384?192:512;d=Up(g,f,d,x[a+480180>>2]==4096?255:64)-(d>>>1|0)|0;if(y[b+748|0]&16){h=Hp(a,b,!(x[b+88>>2]&32768),d);break a}if(Dj(b)){if((d|0)==x[b+768>>2]){break a}x[b+768>>2]=d;v[b+872|0]=y[b+872|0]|16;break a}a=zp(a);x[e+12>>2]=d;b:{if((d|0)<0){x[e+12>>2]=0-d;Ch(e+12|0,255);a=(x[e+12>>2]<<2)+(a?31424:30400)|0;break b}Ch(e+12|0,255);a=(x[e+12>>2]<<2)+(a?30400:31424)|0}a=x[a>>2];b=a;d=a>>31;a=x[c>>2];j=c,k=Cc(zna(yna(b,d,a,a>>31),lb,65536,0),lb),x[j>>2]=k}hb=e+16|0;return h}function Z8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Lb(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>2>>>0){e=hb-16|0;hb=e;d:{b=je(e,a,c);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;P(1686,f|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break d}c=c+4|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break c}a=N()|0;Jb(b);Q(a|0);p()}b=yb(a);b=Nf(d+8|0,ze(a,Lb(a)+c|0),Lb(a),b);x[114414]=0;P(1683,b|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(1680,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}Ks(b)}hb=d+32|0;break a}a=N()|0;Ks(b);Q(a|0);p()}return}if(b>>>0<c>>>0){b=x[a>>2]+(b<<2)|0;Lb(a);bK(a,b);og(a)}}function Tv(a,b,c){var d=0,e=0,f=0;d=hb+-64|0;hb=d;f=x[a>>2];e=x[f-4>>2];f=x[f-8>>2];x[d+32>>2]=0;x[d+36>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;v[d+55|0]=0;v[d+56|0]=0;v[d+57|0]=0;v[d+58|0]=0;v[d+59|0]=0;v[d+60|0]=0;v[d+61|0]=0;v[d+62|0]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+20>>2]=0;x[d+16>>2]=b;x[d+12>>2]=a;x[d+8>>2]=c;a=a+f|0;b=0;a:{if(tg(e,c,0)){x[d+56>>2]=1;mb[x[x[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=x[d+32>>2]==1?a:0;break a}mb[x[x[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(x[d+44>>2]){case 0:b=x[d+48>>2]==1?x[d+36>>2]==1?x[d+40>>2]==1?x[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(x[d+32>>2]!=1){if(x[d+48>>2]|x[d+36>>2]!=1|x[d+40>>2]!=1){break a}}b=x[d+24>>2]}hb=d- -64|0;return b}function IH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;a:{b:{c:{d:{if((b|0)>=0){if((fp(a+8|0)|0)>(b|0)){break d}}b=ec(8);x[114414]=0;c=O(118,f|0,6687)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}d=a+32|0;a=(x[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;x[a>>2]=c|x[a>>2]&-134218753;a=(x[d>>2]+D(b,896)|0)+1075072|0;x[a>>2]=c|x[a>>2]&-134218753;a=z[x[d>>2]+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){e=D(a,896);if((b|0)==z[(e+x[d>>2]|0)+1075792>>1]){e=(e+x[d>>2]|0)+1075072|0;x[e>>2]=c|x[e>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}hb=f+16|0;return}a=N()|0;hc(b)}Q(a|0)}p()}function Rw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;g=(q(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;C[b>>3]=d;g=d<-.7853981852531433;if(F(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){C[b>>3]=E(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;C[e+8>>3]=(l(2,i-(c<<23)|0),r());c=fH(e+8|0,e,c,1,0);d=C[e>>3];if((g|0)<0){C[b>>3]=-d;c=0-c|0;break a}C[b>>3]=d}hb=e+16|0;return c}function ix(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-80|0;hb=c;d=x[a>>2];e=x[d+4>>2];x[c+40>>2]=x[d+20>>2];f=x[d+16>>2];x[c+32>>2]=x[d+12>>2];x[c+36>>2]=f;gn(c- -64|0,c+32|0,e);d=Mc(c+48|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);e=x[x[a+12>>2]>>2];f=x[x[a+8>>2]>>2];x[c+24>>2]=x[c+72>>2];a=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=a;x[c+8>>2]=x[d+8>>2];a=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=a;if(e){h=c+16|0;i=b+4|0;while(1){a=0;if(f){while(1){d=x[Rf(c,a,g)>>2];gc(b,a);d=(d+((qs(i)^-2147483648)>>>21|0)|0)-2147482624>>>12|0;d=d>>>0<=491520?491520:d;j=fn(h,a,g),k=(d|0)>=557055?557055:d,w[j>>1]=k;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}hb=c+80|0}function dL(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=hb-16|0;hb=h;v[h+15|0]=b;v[h+14|0]=10;Mg(g,y[rc(h+15|0,h+14|0)|0]);v[g+15|0]=c;v[g+16|0]=c;v[g+14|0]=e;v[g+13|0]=d;if(Lb(g)){c=0;while(1){b=D(c,3)+f|0;d=y[b|0]|y[b+1|0]<<8;i=Pb(g,c),j=d>>>4|0,w[i>>1]=j;a:{b:{if(!c){e=0;d=0;break b}d=c-1|0;if(z[Pb(g,c)>>1]>=z[Pb(g,d)>>1]){break a}e=c;d=z[Pb(g,d)>>1]+1|0}i=Pb(g,e),j=d,w[i>>1]=j}b=Md(y[b+2|0],0,64);i=Pb(g,c),j=b,v[i+2|0]=j;c=c+1|0;if(Lb(g)>>>0>c>>>0){continue}break}}b=y[g+12|0]&-2|a&1;v[g+12|0]=b;if(a&2){b=y[g+15|0];b=(Lb(g)>>>0>=b>>>0)<<2|y[g+12|0]&-5}else{b=b&251}v[g+12|0]=b;c:{d:{if(a&4){a=y[g+13|0];if(a>>>0<=y[g+14|0]){break d}}a=b&253;break c}b=Lb(g);a=y[g+12|0]&-3|(a>>>0<=b>>>0)<<1}v[g+12|0]=a;hb=h+16|0}function Sb(a,b,c){var d=0,e=0,f=0,g=0;a:{if(!c){break a}v[a|0]=b;d=a+c|0;v[d-1|0]=b;if(c>>>0<3){break a}v[a+2|0]=b;v[a+1|0]=b;v[d-3|0]=b;v[d-2|0]=b;if(c>>>0<7){break a}v[a+3|0]=b;v[d-4|0]=b;if(c>>>0<9){break a}d=0-a&3;e=d+a|0;b=D(b&255,16843009);x[e>>2]=b;d=c-d&-4;c=d+e|0;x[c-4>>2]=b;if(d>>>0<9){break a}x[e+8>>2]=b;x[e+4>>2]=b;x[c-8>>2]=b;x[c-12>>2]=b;if(d>>>0<25){break a}x[e+24>>2]=b;x[e+20>>2]=b;x[e+16>>2]=b;x[e+12>>2]=b;x[c-16>>2]=b;x[c-20>>2]=b;x[c-24>>2]=b;x[c-28>>2]=b;g=e&4|24;c=d-g|0;if(c>>>0<32){break a}d=yna(b,0,1,1);f=lb;b=e+g|0;while(1){x[b+24>>2]=d;x[b+28>>2]=f;x[b+16>>2]=d;x[b+20>>2]=f;x[b+8>>2]=d;x[b+12>>2]=f;x[b>>2]=d;x[b+4>>2]=f;b=b+32|0;c=c-32|0;if(c>>>0>31){continue}break}}return a}function a5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;x[114414]=0;W(2048,a|0);e=x[114414];x[114414]=0;a:{b:{c:{if((e|0)==1){break c}x[114414]=0;W(2074,b|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;W(2074,c|0);f=x[114414];x[114414]=0;e=1;if((f|0)==1){break c}f=x[a+24>>2];b=tc(d+24|0,b);c=tc(d+16|0,c);x[114414]=0;g=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=g;b=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=b;X(2118,f|0,d+8|0,d|0,1);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,1993,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();e=0}hb=d+32|0;return e|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function jx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);c=hb-80|0;hb=c;d=x[a>>2];f=x[d+4>>2];e=x[d+24>>2];x[c+40>>2]=x[d+20>>2];x[c+44>>2]=e;e=x[d+16>>2];x[c+32>>2]=x[d+12>>2];x[c+36>>2]=e;Nh(c- -64|0,c+32|0,f);d=Mc(c+48|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);f=x[x[a+12>>2]>>2];e=x[x[a+8>>2]>>2];a=x[c+76>>2];x[c+24>>2]=x[c+72>>2];x[c+28>>2]=a;a=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=a;x[c+8>>2]=x[d+8>>2];a=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=a;if(f){d=c+16|0;while(1){a=0;if(e){while(1){h=C[kh(c,a,g)>>3];gc(b,a);i=Cj(Qd(h*134217728));j=In(d,a,g),k=E(+(i|0)*7.450580596923828e-9),B[j>>2]=k;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}hb=c+80|0}function Yka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;x[d+28>>2]=0;Ri(a,d+28|0);a:{b:{e=x[d+28>>2];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Wb(d+16|0);x[114414]=0;w[d+14>>1]=0;f=U(696,a|0,e|0,255)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}if(!f){break d}x[114414]=0;O(687,a|0,d+14|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}x[114414]=0;T(13,d|0,c|0,e|0);f=x[114414];x[114414]=0;if((f|0)==1){break f}x[114414]=0;f=O(697,b|0,d+14|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break e}Db(f,d);xb(d);xb(e);h=h+1|0;if(h>>>0<A[d+28>>2]){continue}break}}Jf(x[x[a>>2]-12>>2]+a|0);break c}a=N()|0;break a}a=N()|0;xb(d);break a}xb(e)}hb=d+32|0;return}a=N()|0}xb(e);Q(a|0);p()}function Xka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;w[d+30>>1]=0;zf(a,d+30|0);a:{b:{e=z[d+30>>1];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Wb(d+16|0);x[114414]=0;w[d+14>>1]=0;f=U(698,a|0,e|0,255)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}if(!f){break d}x[114414]=0;O(687,a|0,d+14|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}x[114414]=0;T(13,d|0,c|0,e|0);f=x[114414];x[114414]=0;if((f|0)==1){break f}x[114414]=0;f=O(697,b|0,d+14|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break e}Db(f,d);xb(d);xb(e);h=h+1|0;if(h>>>0<z[d+30>>1]){continue}break}}Jf(x[x[a>>2]-12>>2]+a|0);break c}a=N()|0;break a}a=N()|0;xb(d);break a}xb(e)}hb=d+32|0;return}a=N()|0}xb(e);Q(a|0);p()}function qfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];f=x[a>>2];x[e+8>>2]=f;x[e+12>>2]=h;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;g=a;if(d){f=b+24|0;while(1){a=x[e+8>>2];b=(x[e+12>>2]<<1)+k|0;a=(((a>>>16|0)+4&131064)<<1)+f|0;a=(((((D(w[b+4>>1],w[a+10>>1])+D(w[b+2>>1],w[a+8>>1])|0)+D(w[b+6>>1],w[a+12>>1])|0)+D(w[b+8>>1],w[a+14>>1])|0)/2|0)+((((D(w[b-4>>1],w[a+2>>1])+D(w[b-6>>1],w[a>>1])|0)+D(w[b-2>>1],w[a+4>>1])|0)+D(w[b>>1],w[a+6>>1])|0)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(a,j);x[c+4>>2]=x[c+4>>2]+D(a,i);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}f=x[e+8>>2];h=x[e+12>>2]}x[g>>2]=f;x[g+4>>2]=h;hb=e+16|0}function IF(a,b){var c=0,d=0,e=0;a:{if(y[b|0]){break a}b=ow(9661);if(y[b|0]?b:0){break a}b=ow(D(a,12)+61760|0);if(y[b|0]?b:0){break a}b=ow(9908);if(y[b|0]?b:0){break a}b=10289}b:{while(1){d=y[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=10289;c:{d:{c=y[b|0];e:{f:{if(!(y[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!y[e+1|0]){break e}}if(!pj(e,10289)){break e}if(pj(e,9361)){break d}}if(!a){c=61668;if(y[e+1|0]==46){break c}}return 0}c=x[115201];if(c){while(1){if(!pj(e,c+8|0)){break c}c=x[c+32>>2];if(c){continue}break}}c=sd(36);if(c){b=x[15418];x[c>>2]=x[15417];x[c+4>>2]=b;b=c+8|0;sc(b,e,d);v[b+d|0]=0;x[c+32>>2]=x[115201];x[115201]=c}c=a|c?c:61668}return c}function Sz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;if(v[a|0]&1){v[b+12|0]=y[b+12|0]|1}if(y[a|0]&2){v[b+12|0]=y[b+12|0]|4}if(y[a|0]&4){v[b+12|0]=y[b+12|0]|2}if(y[a|0]&16){v[b+12|0]=y[b+12|0]|16}if(y[a|0]&32){v[b+12|0]=y[b+12|0]|8}v[g+15|0]=y[a+1|0];v[g+14|0]=25;Mg(b,y[rc(g+15|0,g+14|0)|0]);v[b+15|0]=y[a+2|0];v[b+16|0]=y[a+3|0];v[b+13|0]=y[a+4|0];v[b+14|0]=y[a+5|0];if(Lb(b)){while(1){f=(d<<2)+a|0;e=f+6|0;e=y[e|0]|y[e+1|0]<<8;h=Pb(b,d),i=e,w[h>>1]=i;a:{if(!d){break a}e=d-1|0;if(z[Pb(b,d)>>1]>=z[Pb(b,e)>>1]){break a}e=z[Pb(b,e)>>1];h=Pb(b,d),i=e+1|0,w[h>>1]=i}f=f+8|0;f=Xb((y[f|0]|y[f+1|0]<<8)<<16>>16>>c,0,64);h=Pb(b,d),i=f,v[h+2|0]=i;d=d+1|0;if(Lb(b)>>>0>d>>>0){continue}break}}hb=g+16|0}function Kv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=wc(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>>0){e=hb-16|0;hb=e;d:{b=th(e,a,c);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;P(186,f|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break d}c=c+1|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break c}a=N()|0;Jb(b);Q(a|0);p()}b=yb(a);b=Yh(d+8|0,Wh(a,wc(a)+c|0),wc(a),b);x[114414]=0;P(182,b|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(178,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}Km(b)}hb=d+32|0;break a}a=N()|0;Km(b);Q(a|0);p()}return}if(b>>>0<c>>>0){b=x[a>>2]+b|0;wc(a);HD(a,b);Wp(a)}}function $3(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;c=x[a+4>>2];a=x[a>>2];x[d>>2]=a;x[d+4>>2]=c;x[d+8>>2]=a;x[d+12>>2]=c;a=hb+-64|0;hb=a;a:{if(!x[d+4>>2]){break a}c=77216;b:{while(1){b=x[d+4>>2];x[a+56>>2]=x[d>>2];x[a+60>>2]=b;b=tc(a+48|0,x[c+8>>2]);e=x[a+60>>2];x[a+24>>2]=x[a+56>>2];x[a+28>>2]=e;e=x[b+4>>2];x[a+16>>2]=x[b>>2];x[a+20>>2]=e;if(uL(a+24|0,a+16|0)){break b}c=c+12|0;if((c|0)!=77732){continue}break}c=77744;while(1){b=x[d+4>>2];x[a+40>>2]=x[d>>2];x[a+44>>2]=b;b=tc(a+32|0,x[c+8>>2]);e=x[a+44>>2];x[a+8>>2]=x[a+40>>2];x[a+12>>2]=e;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;b=uL(a+8|0,a);if(b){break a}c=c+12|0;if((c|0)!=77792){continue}break}break a}b=1}hb=a- -64|0;hb=d+16|0;return b|0}function eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=E(0),i=0,j=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];g=x[Mb(e+12|0,e+8|0)>>2];h=B[d>>2];c=Cb(b);if(g){a=x[a+20>>2];b=g;while(1){d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);f=de(E(nf(E((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r())*h),E(-1))*E(32768)));a:{if(E(F(f))<E(2147483648)){d=~~f;break a}d=-2147483648}i=a,j=Uc(d),w[i>>1]=j;d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=de(E(nf(E((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r())*h),E(-1))*E(32768)));b:{if(E(F(f))<E(2147483648)){d=~~f;break b}d=-2147483648}i=a,j=Uc(d),w[i+2>>1]=j;a=a+4|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return g<<3}function C6(a){a=a|0;var b=0;b=4221;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=13331;break a}switch(a-277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=17386;break a}b=4254;break a}b=1518;break a}b=4277;break a}b=4291;break a}b=1874;break a}b=1894;break a}b=4303;break a}b=4235;break a}b=8670;break a}b=7987;break a}b=2446;break a}if((a|0)!=357){break a}b=4188}return Ld(b)|0}function _J(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;c=hb-48|0;hb=c;x[c+8>>2]=542066252;e=c+8|0;d=e|4;v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;d=x[b+4220>>2];v[c+16|0]=d;v[c+17|0]=d>>>8;v[c+18|0]=d>>>16;v[c+19|0]=d>>>24;d=x[b+4224>>2];v[c+20|0]=d;v[c+21|0]=d>>>8;v[c+22|0]=d>>>16;v[c+23|0]=d>>>24;d=x[b+4228>>2];v[c+24|0]=d;v[c+25|0]=d>>>8;v[c+26|0]=d>>>16;v[c+27|0]=d>>>24;d=x[b+4232>>2];v[c+28|0]=d;v[c+29|0]=d>>>8;v[c+30|0]=d>>>16;v[c+31|0]=d>>>24;d=x[b+4236>>2];v[c+32|0]=d;v[c+33|0]=d>>>8;v[c+34|0]=d>>>16;v[c+35|0]=d>>>24;v[c+36|0]=y[b+4240|0];v[c+37|0]=y[b+4241|0];v[c+38|0]=y[b+4242|0];v[c+39|0]=y[b+4243|0];v[c+40|0]=y[b+4244|0];b=b+4208|0;Ok(b,33);sc(x[b>>2],e,33);ej(c,b);Ed(a,c);hb=c+48|0}function xU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;Ad(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=yq(a+4|0,a);x[b+4>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=yq(a+8|0,a);x[b+8>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[d+15|0]=127;v[d+14|0]=y[a+15|0];f=b,g=(((y[rc(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[f+30>>1]=g;e=a+12|0;if(y[e|0]>=16){c=y[e|0];w[b+34>>1]=32;w[b+28>>1]=c&240}c=a+13|0;x[b+24>>2]=(y[c|0]|y[c+1|0]<<8)<<1;if(!(y[c|0]|y[c+1|0]<<8)){x[b+24>>2]=16726}f=b,g=(D(yt(0,y[e|0]<<28>>24),x[b+24>>2])>>>0)/8363|0,x[f+24>>2]=g;if(A[b+4>>2]<A[b+8>>2]){w[b+34>>1]=z[b+34>>1]|2}if(y[a+16|0]&132){w[b+34>>1]=z[b+34>>1]|1}hb=d+16|0}function Tfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];f=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=f;g=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=g;a:{if(!d){g=h>>12;j=i>>12;break a}while(1){g=x[a+32>>2];e=x[b+8>>2];i=x[a+28>>2]+i|0;j=i>>12;f=(x[b+12>>2]<<1)+k|0;e=(e>>>21&2040)+32976|0;e=(((D(w[f>>1],w[e+2>>1])+D(w[f-2>>1],w[e>>1])|0)+D(w[f+2>>1],w[e+4>>1])|0)+D(w[f+4>>1],w[e+6>>1])|0)/16384|0;x[c>>2]=x[c>>2]+D(j,e);h=g+h|0;g=h>>12;x[c+4>>2]=x[c+4>>2]+D(e,g);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];f=x[b+12>>2]}x[a>>2]=e;x[a+4>>2]=f;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=g;hb=b+16|0}function Mg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Lb(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>2>>>0){e=hb-16|0;hb=e;d:{b=je(e,a,c);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;P(336,f|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break d}c=c+4|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break c}a=N()|0;Jb(b);Q(a|0);p()}b=yb(a);b=po(d+8|0,ze(a,Lb(a)+c|0),Lb(a),b);x[114414]=0;P(332,b|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(333,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}_i(b)}hb=d+32|0;break a}a=N()|0;_i(b);Q(a|0);p()}return}if(b>>>0<c>>>0){hv(a,x[a>>2]+(b<<2)|0)}}function SQ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;while(1){j=z[uc(b,i)>>1];m=j+1|0;n=j>>>0<(h&65535)>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=j>>>0<(l&65535)>>>0?l:m;h=n?h:m;i=i+1|0;if((i|0)!=128){continue}break}mg(b,c);c=x[a+8>>2];d=c+d|0;i=z[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(fj(a)&-2)){break c}Rc(a,c+(f<<10)|0);if(!Nz(a,16,1)){break b}w[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((fj(a)|0)!=(d+D(f,i)|0)){break a}}Rc(a,c+D(f,z[e>>1])|0);h=Nz(a,64,1)?h:k}Rc(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(D(c,z[e>>1])<<8)|0)==(fj(a)|0)){break d}}if(c>>>0>=255){Mz(b,254,65534);Mz(b,255,65535)}l=h}return l&65535}function KU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-32|0;hb=e;Ad(b,0);zh(e,1,a+33|0);d=e+16|0;Ic(d,e);x[114414]=0;O(335,b+43|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){f=e+16|0;xb(f);d=a+50|0;x[b>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+54|0;x[b+24>>2]=y[d|0]|y[d+1|0]<<8;v[e+16|0]=y[a+56|0];v[e|0]=64;g=b,h=y[rc(f,e)|0]<<2,w[g+30>>1]=h;d=a+57|0;x[b+4>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=a+61|0;x[b+8>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);if(!(!c|!x[b+4>>2])){x[b+8>>2]=x[b>>2]}a:{if(!y[a|0]){break a}a=x[b+8>>2];if(a>>>0<=x[b+4>>2]+2>>>0|a>>>0>A[b>>2]){break a}w[b+34>>1]=z[b+34>>1]|2}hb=e+32|0;return}a=N()|0;xb(e+16|0);Q(a|0);p()}function FM(a,b,c){var d=0,e=0;a:{if(x[a+480180>>2]==4){d=y[b+833|0];if(c){v[b+833|0]=d&240|c&15;break a}c=d&15;break a}if(x[a+480180>>2]!=1048576){break a}if(c){v[b+833|0]=c;break a}c=y[b+833|0]}b:{if(!(v[b+872|0]&1)){break b}d=x[b+700>>2];if(!d|!(c&255)){break b}c:{d:{if(!(y[a+480208|0]&16)){break d}d=x[b+700>>2];if(x[a+480180>>2]==4){break d}c=Cy(a,c&15);e=yna(c,c>>31,d,d>>31);c=lb;e=e+32768|0;c=e>>>0<32768?c+1|0:c;c=Cc(zna(e,c,65536,0),lb);x[b+700>>2]=c;if((c|0)!=(d|0)){break b}a=a+1074312|0;if(!($b(a,7)|x[b+700>>2]==2147483647)){a=x[b+700>>2]+1|0;break c}if(!$b(a,7)){break b}a=x[b+700>>2];if((a|0)<2){break b}a=a-1|0;break c}a=((c&255)<<2)+d|0;a=(a|0)>=65535?65535:a}x[b+700>>2]=a}}function zN(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c;if(z[a+28>>1]!=(b|0)){pt(a+12|0);w[a+28>>1]=b}c=a+12|0;if(od(c)){CN(c,Xy(a,z[uc(Kp(a),b)>>1]))}b=e+12|0;a:{if(x[c+4>>2]!=x[yb(c)>>2]){d=hb-16|0;hb=d;a=je(d,c,1);c=yb(c);f=x[a+4>>2];x[114414]=0;T(368,c|0,f|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){x[a+4>>2]=x[a+4>>2]+4;Jb(a);hb=d+16|0;break a}b=N()|0;Jb(a);Q(b|0);p()}d=hb-32|0;hb=d;f=yb(c);a=Nf(d+8|0,ze(c,Lb(c)+1|0),Lb(c),f);g=x[a+8>>2];x[114414]=0;T(368,f|0,g|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[a+8>>2]=x[a+8>>2]+4;x[114414]=0;P(98,c|0,a|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}xk(a);hb=d+32|0;break b}b=N()|0;xk(a);Q(b|0);p()}}hb=e+16|0}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=c>>>4;x[f+8>>2]=x[a>>2];d=x[Mb(f+12|0,f+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){e=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);h=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);l(0,h|0);l(1,e|0);g=Qd(Fg(+n())*32768);a:{if(F(g)<2147483648){e=~~g;break a}e=-2147483648}i=a,j=Uc(e),w[i>>1]=j;e=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);h=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);l(0,h|0);l(1,e|0);g=Qd(Fg(+n())*32768);b:{if(F(g)<2147483648){e=~~g;break b}e=-2147483648}i=a,j=Uc(e),w[i+2>>1]=j;a=a+4|0;c=c+16|0;b=b-1|0;if(b){continue}break}}hb=f+16|0;return d<<4}function mk(a,b,c){var d=0,e=0,f=0;e=hb-16|0;hb=e;x[a+4>>2]=0;nj(e+8|0,a,1);a:{b:{d=4;c:{if(!y[e+8|0]){break c}d=x[x[a>>2]-12>>2];x[114414]=0;d=x[(a+d|0)+24>>2];f=x[114414];x[114414]=0;d:{if((f|0)==1){break d}x[114414]=0;b=U(2355,d|0,b|0,c|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break d}x[a+4>>2]=b;d=(b|0)!=(c|0)?6:0;break c}Y(S(0)|0)|0;mj(x[x[a>>2]-12>>2]+a|0,1);b=x[x[a>>2]-12>>2];x[114414]=0;b=x[(a+b|0)+20>>2];c=x[114414];x[114414]=0;e:{if((c|0)!=1){if(!(b&1)){break e}x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break a}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)==1){break b}Q(a|0);p()}_();d=1}Jg(x[x[a>>2]-12>>2]+a|0,d);hb=e+16|0;return}S(0)|0;zb()}p()}function b1(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-48|0;hb=c;if(cH(1,c+24|0)){qr(x[114240],8551);p()}e=Ei(c+8|0,c+24|0);f=DG(c,c+32|0);b=hb-32|0;hb=b;d=hb-16|0;hb=d;g=hb-16|0;hb=g;a=hb-16|0;hb=a;i=a,j=yna(x[e>>2],x[e+4>>2],1e9,0),x[i>>2]=j;x[a+4>>2]=lb;e=Ei(a+8|0,a);h=x[e>>2];e=x[e+4>>2];hb=a+16|0;hb=g+16|0;a=d;x[a+8>>2]=h;x[a+12>>2]=e;d=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=d;hb=a+16|0;a=x[b+8>>2];e=x[b+12>>2];d=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=d;f=x[b>>2];d=a+f|0;a=x[b+4>>2]+e|0;x[b+16>>2]=d;x[b+20>>2]=d>>>0<f>>>0?a+1|0:a;a=Ei(b+24|0,b+16|0);d=x[a>>2];a=x[a+4>>2];hb=b+32|0;x[c+16>>2]=d;x[c+20>>2]=a;b=Ei(c+40|0,c+16|0);a=x[b>>2];hb=c+48|0;lb=x[b+4>>2];return a|0}function rt(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;x[b+40>>2]=0;x[b+44>>2]=0;d=b- -64|0;x[d>>2]=0;x[d+4>>2]=0;x[b+56>>2]=0;x[b+60>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;while(1){GN(b,C[ll(c,0)>>3]);f=f+1|0;if((f|0)!=1e4){continue}break}g=e,h=bc(c),x[g+8>>2]=h;g=e,h=dc(c),x[g>>2]=h;if(Hb(e+8|0,e)){while(1){d=e+8|0;f=x[d>>2];g=f,i=GN(b,C[f>>3]),C[g>>3]=i;Yy(d);if(Hb(d,e)){continue}break}}b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[b+12>>2]=0;d=yb(c);x[114414]=0;U(1213,a+8|0,b+12|0,d|0)|0;d=x[114414];x[114414]=0;a:{if((d|0)!=1){x[a>>2]=x[c>>2];x[a+4>>2]=x[c+4>>2];d=x[yb(c)>>2];g=yb(a),h=d,x[g>>2]=h;g=yb(c),h=0,x[g>>2]=h;x[c>>2]=0;x[c+4>>2]=0;hb=b+16|0;break a}S(0)|0;zb();p()}hb=e+16|0}function tba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;a:{b:{c:{d:{e:{if(vj(b)){break e}w[d+8>>1]=z[a+480190>>1];w[d+24>>1]=x[b+4>>2]-1;c=z[Cf(d+8|0,d+24|0)>>1];if(!c){break e}g=c;while(1){if(!UP(b,c)){x[114414]=0;e=O(1438,a|0,c&65535)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}if(e){x[114414]=0;e=O(118,d+8|0,17386)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}x[114414]=0;O(334,((c<<5)+a|0)+946304|0,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break c}xb(e);h=h+1|0}if(!(z[a+480190>>1]!=(c|0)|c>>>0<2)){w[a+480190>>1]=z[a+480190>>1]-1}}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}hb=d+32|0;return h&65535}c=N()|0;break a}c=N()|0;xb(e);break a}c=N()|0}Q(c|0);p()}function rfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];f=x[a>>2];x[e+8>>2]=f;x[e+12>>2]=h;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;g=a;if(d){f=b+24|0;while(1){a=x[e+8>>2];b=x[e+12>>2]+k|0;a=(((a>>>16|0)+4&131064)<<1)+f|0;a=((((D(v[b+2|0],w[a+10>>1])+D(v[b+1|0],w[a+8>>1])|0)+D(v[b+3|0],w[a+12>>1])|0)+D(v[b+4|0],w[a+14>>1])<<8>>1)+(((D(v[b-2|0],w[a+2>>1])+D(v[b-3|0],w[a>>1])|0)+D(v[b-1|0],w[a+4>>1])|0)+D(v[b|0],w[a+6>>1])<<8>>1)|0)/16384|0;x[c>>2]=x[c>>2]+D(a,j);x[c+4>>2]=x[c+4>>2]+D(a,i);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}f=x[e+8>>2];h=x[e+12>>2]}x[g>>2]=f;x[g+4>>2]=h;hb=e+16|0}function r0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-16|0;hb=e;a:{b:{if(!ne(b,-1)){f=x[a+12>>2];g=x[a+8>>2];if(x[a+24>>2]==x[a+28>>2]){c=-1;if(!(y[a+48|0]&16)){break a}h=x[a+24>>2];i=x[a+20>>2];j=x[a+44>>2];k=x[a+20>>2];x[114414]=0;c=a+32|0;P(107,c|0,0);d=x[114414];x[114414]=0;if((d|0)==1){break b}d=Fc(c);x[114414]=0;P(1649,c|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break b}d=Rb(c);zw(a,d,Bb(c)+d|0);Ur(a,h-i|0);x[a+44>>2]=x[a+20>>2]+(j-k|0)}x[e+12>>2]=x[a+24>>2]+1;l=a,m=x[_c(e+12|0,a+44|0)>>2],x[l+44>>2]=m;if(y[a+48|0]&8){c=Rb(a+32|0);Ym(a,c,c+(f-g|0)|0,x[a+44>>2])}c=tG(a,b<<24>>24);break a}c=Sr(b);break a}Y(S(0)|0)|0;_();c=-1}hb=e+16|0;return c|0}function Ufa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];f=x[a+4>>2];b=x[a>>2];x[e+8>>2]=b;x[e+12>>2]=f;g=x[a+12>>2];x[e>>2]=x[a+8>>2];x[e+4>>2]=g;a:{if(!d){g=h>>12;j=i>>12;break a}while(1){g=x[a+32>>2];b=x[e+8>>2];i=x[a+28>>2]+i|0;j=i>>12;f=x[e+12>>2]+k|0;b=(b>>>21&2040)+32976|0;b=(((D(v[f|0],w[b+2>>1])+D(v[f-1|0],w[b>>1])|0)+D(v[f+1|0],w[b+4>>1])|0)+D(v[f+2|0],w[b+6>>1])<<8)/16384|0;x[c>>2]=x[c>>2]+D(j,b);h=g+h|0;g=h>>12;x[c+4>>2]=x[c+4>>2]+D(b,g);c=c+8|0;Tb(e+8|0,e);d=d-1|0;if(d){continue}break}b=x[e+8>>2];f=x[e+12>>2]}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=g;hb=e+16|0}function Il(a,b){var c=0,d=0,e=0,f=0,g=0;c=Lb(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>2>>>0){e=hb-16|0;hb=e;d:{b=je(e,a,c);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;P(1651,f|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break d}c=c+4|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break c}a=N()|0;Jb(b);Q(a|0);p()}b=yb(a);b=Nf(d+8|0,ze(a,Lb(a)+c|0),Lb(a),b);x[114414]=0;P(1626,b|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(1625,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}pn(b)}hb=d+32|0;break a}a=N()|0;pn(b);Q(a|0);p()}return}if(b>>>0<c>>>0){Ox(a,x[a>>2]+(b<<2)|0)}}function vka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb+-64|0;hb=d;e=d+40|0;bf(e,a,c);a=x[e>>2];x[114414]=0;e=R(421,e|0)|0;f=x[114414];x[114414]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114414]=0;e=R(422,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}x[114414]=0;X(423,d+8|0,3,e|0,a|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;P(355,d+24|0,d+8|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;P(736,d|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}x[114414]=0;O(426,d|0,d+24|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}xb(d+24|0);Hc(d+40|0);hb=d- -64|0;a=!c|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(d+24|0)}Hc(d+40|0);Q(a|0);p()}return a|0}function qna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb+-64|0;hb=d;e=d+40|0;bf(e,a,c);a=x[e>>2];x[114414]=0;e=R(421,e|0)|0;f=x[114414];x[114414]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114414]=0;e=R(422,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}x[114414]=0;X(423,d+8|0,2,e|0,a|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;P(355,d+24|0,d+8|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;P(478,d|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}x[114414]=0;O(426,d|0,d+24|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}xb(d+24|0);Hc(d+40|0);hb=d- -64|0;a=!c|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(d+24|0)}Hc(d+40|0);Q(a|0);p()}return a|0}function os(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0);c=hb-80|0;hb=c;d=x[a>>2];f=x[d+4>>2];e=x[d+24>>2];x[c+40>>2]=x[d+20>>2];x[c+44>>2]=e;e=x[d+16>>2];x[c+32>>2]=x[d+12>>2];x[c+36>>2]=e;Nh(c- -64|0,c+32|0,f);d=Mc(c+48|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);f=x[x[a+12>>2]>>2];e=x[x[a+8>>2]>>2];a=x[c+76>>2];x[c+24>>2]=x[c+72>>2];x[c+28>>2]=a;a=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=a;x[c+8>>2]=x[d+8>>2];a=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=a;if(f){d=c+16|0;while(1){a=0;if(e){while(1){h=x[Rf(c,a,g)>>2];gc(b,a);i=In(d,a,g),j=E(E(h|0)*E(7.450580596923828e-9)),B[i>>2]=j;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}hb=c+80|0}function zS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb+-64|0;hb=d;e=d+40|0;bf(e,a,c);a=x[e>>2];x[114414]=0;e=R(421,e|0)|0;f=x[114414];x[114414]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114414]=0;e=R(422,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}x[114414]=0;X(423,d+8|0,2,e|0,a|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;P(355,d+24|0,d+8|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;P(468,d|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}x[114414]=0;O(426,d|0,d+24|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}xb(d+24|0);Hc(d+40|0);hb=d- -64|0;a=!c|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(d+24|0)}Hc(d+40|0);Q(a|0);p()}return a|0}function wK(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=hb-48|0;hb=f;d=Wb(f+32|0);x[114414]=0;O(1648,a|0,f+24|0)|0;g=x[114414];x[114414]=0;a:{b:{if((g|0)!=1){g=x[f+28>>2];e=x[f+24>>2];He(d);x[114414]=0;g=!g&e>>>0>=255|g?255:e;P(1649,d|0,g|0);e=x[114414];x[114414]=0;if((e|0)==1){break a}if(g){e=0;while(1){h=pc(d,e);x[114414]=0;O(1650,a|0,h|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}e=e+1|0;if((g|0)!=(e|0)){continue}break}}if((iE(d)|0)!=-1){a=iE(d);x[114414]=0;P(1649,d|0,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}}x[114414]=0;T(13,f+8|0,c|0,d|0);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break a}break a}a=f+8|0;Db(b,a);xb(a);xb(d);hb=f+48|0;return}a=N()|0;xb(d);Q(a|0);p()}function aK(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;B[d+12>>2]=c;Gx(a);Ph(d+12|0);a:{b:{switch(b|0){case 0:B[a+4220>>2]=B[d+12>>2];break a;case 1:B[a+4224>>2]=B[d+12>>2];break a;case 2:B[a+4228>>2]=B[d+12>>2];Is(a);break a;case 3:v[a+4240|0]=B[d+12>>2]>=E(.5);Is(a);break a;case 4:b=hb-16|0;hb=b;f=b,g=Uh(E(B[d+12>>2]*E(32))),x[f+12>>2]=g;x[b+8>>2]=0;x[b+4>>2]=5;e=x[dl(b+12|0,b+8|0,b+4|0)>>2];hb=b+16|0;x[a+4232>>2]=e;break a;case 5:v[a+4241|0]=B[d+12>>2]>=E(.5);break a;case 6:v[a+4242|0]=B[d+12>>2]>=E(.5);break a;case 7:v[a+4244|0]=B[d+12>>2]>=E(.5);break a;case 8:break b;default:break a}}c=B[d+12>>2];if(c==E(0)){Fx(a);c=B[d+12>>2]}C[a+4256>>3]=c}hb=d+16|0}function Sg(a,b){var c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0);d=B[a+4268>>2];f=pJ(a);c=E(E(B[a+4224>>2]*E(1.899999976158142))+E(.10000000149011612));e=le(E(10),E(E(E(x[((b<<2)+a|0)+4292>>2])*E(-3))/E(B[a+4268>>2]*E(E(B[a+4220>>2]*E(19.899999618530273))+E(.10000000149011612)))));c=E(E(le(e,E(E(2)-E(E(2)/c)))+E(-1))/E(E(1)-_o(c>E(1)?E(3.1415927410125732):E(E(f*E(6.2831854820251465))/d))));a:{if(c==E(0)){break a}d=E(0);g=E(c+c);f=E(E(-2)-g);c=E(E(f*f)+E(E(c*c)*E(-4)));if(!(c<=E(0))){d=E(M(c))}h=E(E(d-f)/g);if(E(F(h))<=E(1)){break a}h=E(E(-E(d+f))/g)}b=(b<<3)+a|0;B[b+4404>>2]=h;B[b+4400>>2]=e;c=B[a+4272>>2];c=E(c*c);d=E(E(1)-c);e=E(e*e);return E(E(E(E(d*d)*e)/E(E(1)-E(c*e)))+c)}function h5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-32|0;hb=d;x[114414]=0;W(2048,a|0);c=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}x[114414]=0;W(2074,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break f}e=x[a+24>>2];x[114414]=0;c=O(118,d|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break e}x[114414]=0;X(2109,d+16|0,e|0,c|0,1);b=x[114414];x[114414]=0;if((b|0)==1){break d}a=d+16|0;b=Ld(Rb(a));xb(a);xb(c);break b}b=S(0)|0;break c}b=S(0)|0;break c}b=S(0)|0;xb(c)}Y(b|0)|0;b=0;x[114414]=0;X(2023,2786,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_()}hb=d+32|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function P5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-32|0;hb=d;x[114414]=0;W(2048,a|0);c=x[114414];x[114414]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}x[114414]=0;W(2074,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break f}e=x[a+24>>2];x[114414]=0;c=O(118,d|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break e}x[114414]=0;T(2075,d+16|0,e|0,c|0);b=x[114414];x[114414]=0;if((b|0)==1){break d}a=d+16|0;b=Ld(Rb(a));xb(a);xb(c);break b}b=S(0)|0;break c}b=S(0)|0;break c}b=S(0)|0;xb(c)}Y(b|0)|0;b=0;x[114414]=0;X(2023,9158,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_()}hb=d+32|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function nca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=E(0),h=E(0),i=E(0),j=0,k=0;f=hb-16|0;hb=f;j=f,k=D(x[a>>2],Je(a)),x[j+12>>2]=k;xc(f+12|0,c>>>2|0);c=Cb(b);g=B[e+4>>2];e=x[f+12>>2];if(e){while(1){g=E(I(E(F((l(2,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),r()))),g));c=c+4|0;e=e-1|0;if(e){continue}break}}c=g==E(0);a:{if(c){break a}e=x[f+12>>2];if(!e){break a}i=c?E(1):E(E(1)/g);c=x[a+20>>2];while(1){h=de(E(nf(E((l(2,y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24)),r())*i),E(-1))*E(32768)));b:{if(E(F(h))<E(2147483648)){a=~~h;break b}a=-2147483648}j=c,k=Uc(a),w[j>>1]=k;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){B[d>>2]=g}hb=f+16|0;return x[f+12>>2]<<2}function mG(a){a=a|0;var b=0,c=0,d=0;c=hb-16|0;hb=c;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[114414]=0;O(2366,c+8|0,a|0)|0;b=x[114414];x[114414]=0;c:{if((b|0)!=1){d:{if(!y[c+8|0]){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[114414]=0;b=R(2367,b|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[114414]=0;P(2368,a+b|0,1);b=x[114414];x[114414]=0;if((b|0)!=1){break d}}b=S(0)|0;jG(c+8|0);break c}jG(c+8|0);break b}b=S(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[114414]=0;W(19,a+b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}_()}hb=c+16|0;return a|0}a=N()|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function CK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=E(0),i=E(0),j=0,k=E(0);f=hb-16|0;hb=f;if(!(!z[b>>1]|w[d>>1]>w[d+2>>1]|(!(B[c>>2]>E(0))|(w[d+2>>1]-w[d>>1]|0)>32766))){w[a>>1]=3;g=a+4|0;Di(g);w[a+28>>1]=65472;x[f+12>>2]=1065353216;EK(g,128,f+12|0);x[a+32>>2]=0;w[a+30>>1]=0;Di(a+16|0);w[a+28>>1]=z[d>>1];e=hb-16|0;hb=e;w[e+14>>1]=z[b>>1];w[e+12>>1]=32767;b=w[Cf(e+14|0,e+12|0)>>1];hb=e+16|0;w[a+30>>1]=b;h=E(F(B[c>>2]));B[a+32>>2]=h;h=le(h,E(E(1)/E(w[a+30>>1])));e=1;Il(g,(w[d+2>>1]-w[d>>1]|0)+1|0);b=w[d>>1];if((b|0)<=w[d+2>>1]){while(1){i=le(h,E(b|0));j=Pb(g,b-w[a+28>>1]|0),k=i,B[j>>2]=k;c=w[d+2>>1]>(b|0);b=b+1|0;if(c){continue}break}}mp(a)}hb=f+16|0;return e|0}function wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=E(0),h=0,i=0;f=hb-16|0;hb=f;x[f+12>>2]=c>>>3;x[f+8>>2]=x[a>>2];d=x[Mb(f+12|0,f+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);g=de(E(nf((l(2,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24)),r()),E(-1))*E(32768)));a:{if(E(F(g))<E(2147483648)){e=~~g;break a}e=-2147483648}h=a,i=Uc(e),w[h>>1]=i;e=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);g=de(E(nf((l(2,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24)),r()),E(-1))*E(32768)));b:{if(E(F(g))<E(2147483648)){e=~~g;break b}e=-2147483648}h=a,i=Uc(e),w[h+2>>1]=i;a=a+4|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=f+16|0;return d<<3}function Lha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;c=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=c;c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;c=AP(d);a=fq(a);v[a+8|0]=0;x[a+4>>2]=c;x[a>>2]=75552;c=Jj(a+12|0);v[a+24|0]=0;x[114414]=0;O(38,a+28|0,0)|0;e=x[114414];x[114414]=0;a:{if((e|0)!=1){f=a+40|0;c=0;while(1){e=f+D(c,12)|0;x[e>>2]=0;x[e+4>>2]=0;v[e+8|0]=0;c=c+1|0;if((c|0)!=16){continue}break}if(y[a+24|0]){e=a+232|0;c=0;while(1){g=$e(e,c),h=c,x[g>>2]=h;c=c+1|0;if((c|0)!=16){continue}break}}break a}a=N()|0;uh(c);Q(a|0);p()}x[a>>2]=75668;c=x[b+4>>2];x[a+296>>2]=x[b>>2];x[a+300>>2]=c;c=x[b+12>>2];x[a+304>>2]=x[b+8>>2];x[a+308>>2]=c;hb=d+16|0;return a|0}function kp(a,b,c){var d=0,e=0,f=0;d=Wb(a);a=Bb(b);x[114414]=0;P(108,d|0,a|0);a=x[114414];x[114414]=0;if((a|0)!=1){a:{if(Bb(b)){while(1){f=x[qj(b,e)>>2];a=32;b:{c:{while(1){if(x[(a<<2)+c>>2]!=(f|0)){a=a+1|0;if(a>>>0<256){continue}break c}break}x[114414]=0;P(107,d|0,a<<24>>24);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break a}a=0;while(1){d:{if(x[(a<<2)+c>>2]==(f|0)){x[114414]=0;P(107,d|0,a<<24>>24);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break a}if(a>>>0>30){break d}a=a+1|0;if(a>>>0<256){continue}}break}x[114414]=0;P(107,d|0,63);a=x[114414];x[114414]=0;if((a|0)!=1){break b}break a}e=e+1|0;if(Bb(b)>>>0>e>>>0){continue}break}}return}}a=N()|0;xb(d);Q(a|0);p()}function Gy(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;a:{if(!d){break a}if(c){v[b+835|0]=c;break a}c=y[b+835|0]}d=x[a+480180>>2]&1048580;c=d?c&240?c&-16:c:c;b:{c:{d:{e:{if(!d){d=c&240;c=c&15;if((c|0)==15){if(!d){d=0;break e}if(!(y[a+480209|0]&16)){break b}a=0-(d>>>2|0)|0;break d}f=!c;if(!c|(d|0)!=240){break e}if(!(y[a+480209|0]&16)){break b}c=c<<2;break c}if(y[a+480209|0]&16){break b}d=e+8|0;Kb(d,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;if(!Ib(d)){break d}a=a>>2;break d}if(y[a+480209|0]&16){break b}if(!f){c=c<<2;if(!(x[a+480180>>2]&16777248)|!d){break c}break b}a=0-(d>>>2|0)|0}c=a;if(!c){break b}}a=Xb(x[b+692>>2]+c|0,0,256);w[b+796>>1]=0;x[b+692>>2]=a}hb=e+16|0}function W9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jg(a);if(d>>>0<b>>>0){h=hb-32|0;hb=h;a:{b:{f=b-d|0;c:{if(f>>>0<=(x[yb(a)>>2]-x[a+4>>2]|0)/52>>>0){Rx(a,f,c);break c}g=yb(a);e=NK(a,jg(a)+f|0);j=jg(a);d=hb-16|0;hb=d;x[d+12>>2]=0;b=h+8|0;Qe(b+12|0,g);if(e){IK(d,x[b+16>>2],e);i=x[d>>2];e=x[d+4>>2]}else{e=0}x[b>>2]=i;g=D(j,52)+i|0;x[b+8>>2]=g;x[b+4>>2]=g;k=ic(b),l=D(e,52)+i|0,x[k>>2]=l;hb=d+16|0;x[114414]=0;T(1608,b|0,f|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(1609,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}GK(b)}hb=h+32|0;break a}a=N()|0;GK(b);Q(a|0);p()}return}if(b>>>0<d>>>0){OK(a,x[a>>2]+D(b,52)|0)}}function MI(a,b){var c=0,d=0,e=0;c=x[a>>2];x[a>>2]=b;if(c){x[114414]=0;R(1410,c|0)|0;a=x[114414];x[114414]=0;a:{if((a|0)!=1){a=x[c+4>>2];if(a){Ye(a);if(x[a>>2]){e=x[a>>2];b=x[a+4>>2];b:{while(1){if((b|0)==(e|0)){break b}d=yb(a);x[114414]=0;b=b-4|0;P(1450,d|0,b|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=e;Xe(yb(a),x[a>>2],vd(a))}_b(a)}x[c+4>>2]=0;lM(c+1304500|0);zy(c+1304436|0);xb(c+1304424|0);xb(c+1304412|0);xb(c+1304400|0);yy(c+1304396|0);xy(c+1304392|0);et(c+1304360|0);b=c+946300|0;a=c+906300|0;while(1){b=vp(b-160|0);if((a|0)!=(b|0)){continue}break}fz(c+484360|0);gM(c+484344|0);Ge(c+480248|0);break a}S(0)|0;zb();p()}_b(c)}}function fla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-48|0;hb=c;d=c+24|0;f=Jj(d+8|0);x[114414]=0;e=R(296,b|0)|0;g=x[114414];x[114414]=0;a:{b:{if((g|0)==1){break b}x[114414]=0;T(424,d|0,b|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break b}e=x[d>>2];x[114414]=0;O(304,b|0,e|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break a}}a=N()|0;uh(f);Q(a|0);p()}x[114414]=0;P(678,c+8|0,d|0);b=x[114414];x[114414]=0;c:{if((b|0)==1){break c}x[114414]=0;P(679,c+16|0,c+8|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}b=x[c+16>>2];d=x[c+20>>2];x[114414]=0;U(680,a|0,b|0,d|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}Hc(c+24|0);hb=c+48|0;return}a=N()|0;Hc(c+24|0);Q(a|0);p()}function N2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=hb-32|0;hb=b;e=oh(a);Hd(b+24|0);a=0;x[114414]=0;c=O(2228,x[b+24>>2],x[b+28>>2])|0;d=x[114414];x[114414]=0;a:{b:{if((d|0)==1){break b}x[114414]=0;P(1545,e|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}c:{while(1){x[114414]=0;c=O(2228,x[b+24>>2],x[b+28>>2])|0;d=x[114414];x[114414]=0;d:{if((d|0)!=1){if((a|0)<(c|0)){break d}hb=b+32|0;return}a=N()|0;break a}c=x[x[b+24>>2]+(a<<3)>>2];x[114414]=0;c=O(118,b+8|0,c|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){x[114414]=0;P(1547,e|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break c}xb(c);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;xb(c);break a}a=N()|0}qd(e);Q(a|0);p()}function LQ(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(Qb(a,1024)){d=c+24|0;Iz(d,b);Dd(a,d);break a}x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;a=64;while(1){d=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);e=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=d;v[b+5|0]=d>>>8;v[b+6|0]=d>>>16;v[b+7|0]=d>>>24;d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[b+8|0]=e;v[b+9|0]=e>>>8;v[b+10|0]=e>>>16;v[b+11|0]=e>>>24;v[b+12|0]=d;v[b+13|0]=d>>>8;v[b+14|0]=d>>>16;v[b+15|0]=d>>>24;b=b+16|0;a=a-1|0;if(a){continue}break}}hb=c+32|0}function uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0;f=hb-16|0;hb=f;x[f+12>>2]=c>>>3;x[f+8>>2]=x[a>>2];d=x[Mb(f+12|0,f+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){g=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);e=g&16711680;h=e>>>8|0;i=e<<24;e=g&-16777216;k=e>>>24|0;i=i|e<<8;e=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);l(0,i|(((e&255)<<24|g>>>8)&-16777216|((e&16777215)<<8|g>>>24)&16711680|(e>>>8&65280|e>>>24)));e=h|k|(g<<24|(g&65280)<<8);h=0;l(1,e|(h|h));j=Qd(Fg(+n())*32768);a:{if(F(j)<2147483648){e=~~j;break a}e=-2147483648}m=a,o=Uc(e),w[m>>1]=o;a=a+2|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=f+16|0;return d<<3}function Tk(a,b,c,d){var e=0;x[d+8>>2]=b;x[d>>2]=0;x[d+4>>2]=0;x[c>>2]=d;if(x[x[a>>2]>>2]){x[a>>2]=x[x[a>>2]>>2]}d=x[mc(a)>>2];b=x[c>>2];c=(d|0)==(b|0);v[b+12|0]=c;a:{if(c){break a}while(1){if(y[x[b+8>>2]+12|0]){break a}e=Gg(x[b+8>>2]);c=x[b+8>>2];b:{if(e){c=x[x[c+8>>2]+4>>2];if(!(!c|y[c+12|0])){break b}if(!Gg(b)){b=x[b+8>>2];hq(b)}b=x[b+8>>2];v[b+12|0]=1;b=x[b+8>>2];v[b+12|0]=0;gq(b);break a}c=x[x[c+8>>2]>>2];if(!(!c|y[c+12|0])){break b}if(Gg(b)){b=x[b+8>>2];gq(b)}b=x[b+8>>2];v[b+12|0]=1;b=x[b+8>>2];v[b+12|0]=0;hq(b);break a}b=x[b+8>>2];v[b+12|0]=1;b=x[b+8>>2];v[b+12|0]=(b|0)==(d|0);v[c+12|0]=1;if((b|0)!=(d|0)){continue}break}}a=yb(a);x[a>>2]=x[a>>2]+1}function Nea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-48|0;hb=e;a:{b:{if(x[a+8>>2]!=x[ic(a)>>2]){break b}g=a+8|0;h=a+4|0;c=x[a+4>>2];d=x[a>>2];if(c>>>0>d>>>0){f=c;c=((c-d>>2)+1|0)/-2<<2;i=g,j=Yt(f,x[g>>2],f+c|0),x[i>>2]=j;x[h>>2]=c+x[h>>2];break b}i=e,j=x[ic(a)>>2]-x[a>>2]>>1,x[i+24>>2]=j;x[e+44>>2]=1;d=e+24|0;c=x[_c(d,e+44|0)>>2];c=po(d,c,c>>>2|0,x[a+16>>2]);d=Fb(e+16|0,x[a+4>>2]);f=x[Fb(e+8|0,x[a+8>>2])>>2];d=x[d>>2];x[114414]=0;T(1149,c|0,d|0,f|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}Yb(a,c);Yb(h,c+4|0);Yb(g,c+8|0);Yb(ic(a),ic(c));_i(c)}JR(x[a+16>>2],x[a+8>>2],b);x[a+8>>2]=x[a+8>>2]+4;hb=e+48|0;return}a=N()|0;_i(c);Q(a|0);p()}function kja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-528|0;hb=b;c=-1;a:{if(!Yf(a,1468)){break a}Nk(a,1464);c=b+524|0;WQ(a,c);if(!Yd(c,23938)){c=0;if(!Yd(b+524|0,11609)){break a}}Nk(a,20);c=1;b:{while(1){if(!TQ(a,b)){break b}d=Qz(b)+d|0;e=c&65535;c=c+1|0;if(e>>>0<=30){continue}break}c=0;if(d>>>0>40){break a}d=b+520|0;e=hb-16|0;hb=e;c:{if(Yf(a,2)){f=e+8|0;hl(f,d);Hz(a,f);break c}v[e+7|0]=0;EB(d,e+7|0)}hb=e+16|0;e=ed(d);if(y[d|0]>128){break a}c=hb-16|0;hb=c;d:{if(Yf(a,512)){d=c+8|0;YA(d,b);Hz(a,d);break d}AQ(b)}hb=c+16|0;a=y[e|0];d=0;while(1){if(a>>>0>=y[b+d|0]){c=1;d=d+1|0;if((d|0)!=512){continue}break a}break}c=0;break a}c=-1}hb=b+528|0;return c|0}function gx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);c=hb-80|0;hb=c;d=x[a>>2];e=x[d+4>>2];x[c+40>>2]=x[d+20>>2];f=x[d+16>>2];x[c+32>>2]=x[d+12>>2];x[c+36>>2]=f;ep(c- -64|0,c+32|0,e);d=Mc(c+48|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);e=x[x[a+12>>2]>>2];f=x[x[a+8>>2]>>2];x[c+24>>2]=x[c+72>>2];a=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=a;x[c+8>>2]=x[d+8>>2];a=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=a;if(e){d=c+16|0;while(1){a=0;if(f){while(1){h=C[kh(c,a,g)>>3];gc(b,a);i=Cj(Qd(h*134217728));j=Rf(d,a,g),k=E(+(i|0)*7.450580596923828e-9),B[j>>2]=k;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}hb=c+80|0}function tja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-80|0;hb=e;He(b);f=e+56|0;bf(f,a,d);a=x[f>>2];x[114414]=0;f=R(421,f|0)|0;g=x[114414];x[114414]=0;a:{b:{c:{d:{if((g|0)==1){break d}x[114414]=0;f=R(422,f|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}x[114414]=0;X(423,e+8|0,3,f|0,a|0);f=x[114414];x[114414]=0;if((f|0)==1){break d}x[114414]=0;P(355,e+24|0,e+8|0);f=x[114414];x[114414]=0;if((f|0)==1){break d}x[114414]=0;T(13,e+40|0,c|0,e+24|0);c=x[114414];x[114414]=0;if((c|0)==1){break c}c=b;b=e+40|0;Db(c,b);xb(b);xb(e+24|0);Hc(e+56|0);hb=e+80|0;a=!d|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(e+24|0)}Hc(e+56|0);Q(a|0);p()}return a|0}function fja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-80|0;hb=e;He(b);f=e+56|0;bf(f,a,d);a=x[f>>2];x[114414]=0;f=R(421,f|0)|0;g=x[114414];x[114414]=0;a:{b:{c:{d:{if((g|0)==1){break d}x[114414]=0;f=R(422,f|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break d}x[114414]=0;X(423,e+8|0,2,f|0,a|0);f=x[114414];x[114414]=0;if((f|0)==1){break d}x[114414]=0;P(355,e+24|0,e+8|0);f=x[114414];x[114414]=0;if((f|0)==1){break d}x[114414]=0;T(13,e+40|0,c|0,e+24|0);c=x[114414];x[114414]=0;if((c|0)==1){break c}c=b;b=e+40|0;Db(c,b);xb(b);xb(e+24|0);Hc(e+56|0);hb=e+80|0;a=!d|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(e+24|0)}Hc(e+56|0);Q(a|0);p()}return a|0}function BW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-96|0;hb=g;Ii(g+48|0,g+40|0,c);x[114414]=0;c=g+60|0;T(192,c|0,g+32|0,d|0);d=x[114414];x[114414]=0;a:{b:{if((d|0)!=1){c:{x[114414]=0;c=g+72|0;T(192,c|0,g+24|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break c}x[114414]=0;c=g+84|0;T(192,c|0,g+16|0,f|0);d=x[114414];x[114414]=0;if((d|0)==1){break c}x[114414]=0;P(193,g+8|0,g+48|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;T(73,a|0,b|0,g+8|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}FD(g+48|0);hb=g+96|0;return}}a=N()|0;while(1){c=xb(c-12|0);if((c|0)!=(g+48|0)){continue}break}break a}a=N()|0;FD(g+48|0)}Q(a|0);p()}function ty(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=hb-16|0;hb=c;if(!od(a)){l=c,m=bc(a),x[l+8>>2]=m;l=c,m=dc(a),x[l>>2]=m;if(Hb(c+8|0,c)){while(1){e=c+8|0;b=x[e>>2];yo(b,4194304,67108864);d=x[b>>2];f=d+f|0;b=g;g=d>>>0>f>>>0?b+1|0:b;fe(e);if(Hb(e,c)){continue}break}}e=Lb(a);b=Lb(a);l=c,m=bc(a),x[l+8>>2]=m;l=c,m=dc(a),x[l>>2]=m;b=b<<24;if(Hb(c+8|0,c)){e=Bna(f,g,e,0);i=((lb&1)<<31|e>>>1)&2147483647;f=b;g=0;while(1){h=c+8|0;b=x[h>>2];j=b;d=x[b>>2];b=d>>>8|0;d=i+(d<<24)|0;b=b+k|0;d=jd(Bna(d,d>>>0<i>>>0?b+1|0:b,e,k),lb);x[j>>2]=d;b=f;f=b-d|0;g=g-(b>>>0<d>>>0)|0;fe(h);if(Hb(h,c)){continue}break}b=f}a=Ec(a,0);x[a>>2]=x[a>>2]+b}hb=c+16|0}function Gea(a){a=a|0;var b=0,c=0,d=0;d=kF(x[x[a>>2]-12>>2]+a|0,10);c=hb-16|0;hb=c;x[114414]=0;O(15,c+8|0,a|0)|0;b=x[114414];x[114414]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!y[c+8|0]){break e}b=el(c,a);x[114414]=0;O(2364,b|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){if(!cl(b)){break e}b=x[x[a>>2]-12>>2];x[114414]=0;P(18,a+b|0,1);b=x[114414];x[114414]=0;if((b|0)!=1){break e}}b=S(0)|0;Kf(c+8|0);break d}Kf(c+8|0);break c}b=S(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[114414]=0;W(19,a+b|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}_()}hb=c+16|0;break a}a=N()|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}Wr(a);return a|0}function G8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ai(a,b,c,d);x[a>>2]=78484;b=Jj(a+4208|0);c=a+4288|0;x[c>>2]=0;x[c+4>>2]=0;x[a+4280>>2]=0;x[a+4284>>2]=0;x[114414]=0;c=$(1399)|0;d=x[114414];x[114414]=0;a:{if((d|0)==1){break a}x[114414]=0;c=R(1400,c|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}x[a+4228>>2]=1049926264;x[a+4232>>2]=0;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;x[a+4296>>2]=c;v[a+4244|0]=0;x[a+4236>>2]=2147483647;x[a+4240>>2]=0;Is(a);Hs(a);x[114414]=0;U(1673,a+44|0,2,2)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;W(1674,a|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}return a|0}c=N()|0;uh(b);xf(a);Q(c|0);p()}function kga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-32|0;hb=e;k=x[a+24>>2];l=x[a+20>>2];m=x[a+16>>2];f=x[a+4>>2];b=x[a>>2];x[e+24>>2]=b;x[e+28>>2]=f;g=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=g;g=a;if(d){while(1){b=x[e+24>>2];f=b>>>18|0;i=((((x[e+28>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+m|0;h=0;b=1;while(1){a=h<<1;j=w[a+i>>1];x[(e+8|0)+(h<<2)>>2]=j+((D(w[(a|4)+i>>1]-j|0,f)|0)/16384|0);a=b;b=0;h=1;if(a){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],k);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}b=x[e+24>>2];f=x[e+28>>2]}x[g>>2]=b;x[g+4>>2]=f;hb=e+32|0}function J9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=hb-16|0;hb=d;w[a>>1]=0;e=yk(a+4|0);h=yk(a+16|0);x[a+36>>2]=0;i=hd(a+40|0);f=hb-16|0;hb=f;g=f+8|0;b=hb-16|0;hb=b;x[114414]=0;c=a+52|0;R(1622,c+4|0)|0;j=x[114414];x[114414]=0;a:{b:{if((j|0)==1){break b}x[114414]=0;x[b+12>>2]=0;U(1623,c+8|0,b+12|0,g|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}k=c,l=mc(c),x[k>>2]=l;hb=b+16|0;break a}S(0)|0;zb();p()}hb=f+16|0;Di(e);w[a+28>>1]=65472;x[114414]=0;x[d+12>>2]=1065353216;T(1620,e|0,128,d+12|0);b=x[114414];x[114414]=0;if((b|0)!=1){x[a+32>>2]=0;w[a+30>>1]=0;Di(h);hb=d+16|0;return a|0}a=N()|0;mS(c);xb(i);fg(h);fg(e);Q(a|0);p()}function yO(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}v[a+820|0]=0;return}v[a+820|0]=1;return}v[a+820|0]=2;return}v[a+820|0]=3;return}v[a+724|0]=y[a+724|0]&254;return}v[a+724|0]=y[a+724|0]|1;return}v[a+736|0]=y[a+736|0]&254;return}v[a+736|0]=y[a+736|0]|1;return}v[a+748|0]=y[a+748|0]&254;return}v[a+748|0]=y[a+748|0]|1;return}if(x[c+480180>>2]!=16777216){break a}c=a;a=y[a+748|0];v[c+748|0]=(b|0)==13?a&238|1:a|17}}function mia(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-32|0;hb=d;Ad(b,0);PP(d,a+1|0);c=d+16|0;Ic(c,d);x[114414]=0;O(335,b+43|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){xb(d+16|0);c=a+73|0;x[b+24>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+54|0;x[b>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+58|0;x[b+4>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+62|0;if(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)){x[b+8>>2]=(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))+1}w[b+30>>1]=(y[a+68|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;xc(b+8|0,x[b>>2]);xc(b+4|0,x[b+8>>2]);hb=d+32|0;return}a=N()|0;xb(d+16|0);Q(a|0);p()}function l9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb+-64|0;hb=e;d=x[a+28>>2];Sn(x[x[d>>2]-12>>2]+d|0,0);if(x[x[b>>2]+4>>2]){h=x[a+28>>2];d=x[a+12>>2];g=x[x[b>>2]+4>>2];f=g+x[a+8>>2]|0;d=Ug(e+48|0,f,f>>>0<g>>>0?d+1|0:d);f=x[d+12>>2];x[e+16>>2]=x[d+8>>2];x[e+20>>2]=f;f=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=f;lj(h,e+8|0)}d=e+24|0;vf(d,x[a+28>>2]);f=x[d+12>>2];x[e+40>>2]=x[d+8>>2];x[e+44>>2]=f;dz(x[a+28>>2],c,x[x[b>>2]+8>>2]);c=x[b>>2];b=Jm(d,Bc(a+32|0,x[x[b>>2]>>2]),z[x[b>>2]+12>>1]);x[114414]=0;a=Z(1660,a|0,c|0,b|0,e+40|0)|0;c=x[114414];x[114414]=0;a:{if((c|0)!=1){Gb(b);hb=e- -64|0;break a}a=N()|0;Gb(b);Q(a|0);p()}return a|0}function dda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{c=hb-16|0;hb=c;x[c+12>>2]=b;if(b>>>0<=2147483631){b:{if(Fc(a)>>>0>=b>>>0){break b}k=c,l=Bb(a),x[k+8>>2]=l;b=cj(x[_c(c+12|0,c+8|0)>>2]);if((Fc(a)|0)==(b|0)){break b}d=hb-16|0;hb=d;f=Fc(a);g=Bb(a);c:{d:{h=il(b);e:{if(h){i=1;j=b+1|0;b=a;e=x[a>>2];break e}f:{if(b>>>0>f>>>0){Gh(d+8|0,a,b+1|0);break f}x[114414]=0;T(33,d+8|0,a|0,b+1|0);b=x[114414];x[114414]=0;if((b|0)==1){break d}}b=x[d+8>>2];j=x[d+12>>2];i=re(a);e=Rb(a)}Le(b,e,Bb(a)+1|0);if(i){ag(a,e,f+1|0)}g:{if(!h){Ff(a,j);ae(a,g);Ue(a,b);break g}Ce(a,g)}break c}Y(S(0)|0)|0;_()}hb=d+16|0}hb=c+16|0;break a}Ef();p()}}function uL(a,b){var c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;if(x[a+4>>2]==x[b+4>>2]){d=x[a+4>>2];a=x[a>>2];x[c+24>>2]=a;x[c+28>>2]=d;e=x[b+4>>2];b=x[b>>2];x[c+16>>2]=b;x[c+20>>2]=e;x[c+8>>2]=a;x[c+12>>2]=d;x[c>>2]=b;x[c+4>>2]=e;b=0;a=hb-16|0;hb=a;d=c+8|0;x[a+12>>2]=x[d+4>>2];x[a+8>>2]=x[c+4>>2];a:{b:{if(!x[Mb(a+12|0,a+8|0)>>2]){break b}while(1){e=mn(v[Bc(d,b)|0]);f=mn(v[Bc(c,b)|0]);if((e|0)!=(f|0)){b=e>>>0<f>>>0?-1:1;break a}if(e){x[a+12>>2]=x[d+4>>2];x[a+8>>2]=x[c+4>>2];b=b+1|0;if(b>>>0>=A[Mb(a+12|0,a+8|0)>>2]){break b}continue}break}b=0;break a}b=0;if(x[d+4>>2]==x[c+4>>2]){break a}b=A[d+4>>2]<A[c+4>>2]?-1:1}hb=a+16|0;d=!b}hb=c+32|0;return d}function Wo(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=d?d:460792;d=x[g>>2];a:{b:{c:{if(!b){if(d){break c}return 0}e=-2;if(!c){break b}d:{if(d){e=c;break d}d=y[b|0];f=d<<24>>24;if((f|0)>=0){if(a){x[a>>2]=d}return(f|0)!=0|0}if(!x[x[114284]>>2]){e=1;if(!a){break b}x[a>>2]=f&57343;return 1}d=d-194|0;if(d>>>0>50){break c}d=x[(d<<2)+61440>>2];e=c-1|0;if(!e){break a}b=b+1|0}f=y[b|0];h=f>>>3|0;if((h-16|(d>>26)+h)>>>0>7){break c}while(1){e=e-1|0;d=f-128|d<<6;if((d|0)>=0){x[g>>2]=0;if(a){x[a>>2]=d}return c-e|0}if(!e){break a}b=b+1|0;f=y[b|0];if((f&192)==128){continue}break}}x[g>>2]=0;x[114240]=25;e=-1}return e|0}x[g>>2]=d;return-2}function KH(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=hb-16|0;hb=d;a:{b:{c:{d:{if((b|0)>=0){if((fp(a+8|0)|0)>(b|0)){break d}}a=ec(8);x[114414]=0;d=O(118,d|0,6687)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}a=oc(a,d);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}b=N()|0;xb(d);break b}if(!(!(c<0)&c<=1)){a=ec(8);x[114414]=0;d=O(118,d|0,7596)|0;b=x[114414];x[114414]=0;if((b|0)!=1){a=oc(a,d);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}b=N()|0;xb(d);break b}b=N()|0;hc(a);break b}e=Cn(c*64);x[(x[a+32>>2]+D(b,896)|0)+1075744>>2]=e;hb=d+16|0;return}b=N()|0;hc(a)}Q(b|0)}p()}function QP(a,b){var c=0,d=0,e=0;a:{c=hb+-64|0;hb=c;d=c+40|0;bf(d,a,4);a=x[d>>2];x[114414]=0;d=R(421,d|0)|0;e=x[114414];x[114414]=0;b:{c:{d:{if((e|0)==1){break d}x[114414]=0;d=R(422,d|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;X(423,c+8|0,3,d|0,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(355,c+24|0,c+8|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(955,c|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}x[114414]=0;O(426,c|0,c+24|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}xb(c+24|0);Hc(c+40|0);hb=c- -64|0;break a}a=N()|0;break b}a=N()|0;xb(c+24|0)}Hc(c+40|0);Q(a|0);p()}}function rr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-16|0;hb=c;x[c+12>>2]=b;if(b>>>0<=2147483631){a:{if(Fc(a)>>>0>=b>>>0){break a}k=c,l=Bb(a),x[k+8>>2]=l;b=cj(x[_c(c+12|0,c+8|0)>>2]);if((Fc(a)|0)==(b|0)){break a}d=hb-16|0;hb=d;f=Fc(a);g=Bb(a);b:{c:{h=il(b);d:{if(h){i=1;j=b+1|0;b=a;e=x[a>>2];break d}e:{if(b>>>0>f>>>0){Gh(d+8|0,a,b+1|0);break e}x[114414]=0;T(33,d+8|0,a|0,b+1|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}}b=x[d+8>>2];j=x[d+12>>2];i=re(a);e=Rb(a)}Le(b,e,Bb(a)+1|0);if(i){ag(a,e,f+1|0)}f:{if(!h){Ff(a,j);ae(a,g);Ue(a,b);break f}Ce(a,g)}break b}Y(S(0)|0)|0;_()}hb=d+16|0}hb=c+16|0;return}Ef();p()}function CX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-16|0;hb=c;x[c+12>>2]=b;if(b>>>0<=1073741807){a:{if(Om(a)>>>0>=b>>>0){break a}k=c,l=Bb(a),x[k+8>>2]=l;b=ql(x[_c(c+12|0,c+8|0)>>2]);if((Om(a)|0)==(b|0)){break a}d=hb-16|0;hb=d;f=Om(a);g=Bb(a);b:{c:{h=Po(b);d:{if(h){i=1;j=b+1|0;b=a;e=x[a>>2];break d}e:{if(b>>>0>f>>>0){Zj(d+8|0,a,b+1|0);break e}x[114414]=0;T(2896,d+8|0,a|0,b+1|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}}b=x[d+8>>2];j=x[d+12>>2];i=re(a);e=Rb(a)}Kh(b,e,Bb(a)+1|0);if(i){Oo(e,f+1|0)}f:{if(!h){Ff(a,j);ae(a,g);Ue(a,b);break f}Ce(a,g)}break b}Y(S(0)|0)|0;_()}hb=d+16|0}hb=c+16|0;return}Ef();p()}function Gp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=hb-16|0;hb=f;if(e){v[e|0]=0}i=a+484344|0;a:{if(!kg(i,b)){break a}d=Df(Zb(i,b),c,d);g=y[d+5|0];b:{c:{d:{h=y[d+3|0];switch(h-10|0){case 2:case 4:case 7:break c;case 0:break d;default:break a}}x[f+12>>2]=2;j=0;break b}x[f+12>>2]=1;j=0;if((h|0)!=17){break b}j=x[a+480180>>2]==4}l=f,m=x[Zb(i,b)+12>>2]+(c^-1)|0,x[l+8>>2]=m;a=x[Mb(f+8|0,f+12|0)>>2];if(!a){break a}while(1){k=D(zk(Zb(i,b)),6);c=k+d|0;if(y[c+3|0]!=34){break a}h=g<<8;g=j?g>>>0<256?h+-8192|0:h:h;d=y[(d+k|0)+5|0];a=a-1|0;if(e){v[e|0]=1}g=d|g;d=c;if(a){continue}break}}hb=f+16|0;return g|0}function wL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=d;a:{if((c|0)<2){break a}i=c-2>>>1|0;e=d-a|0;if((i|0)<e>>1){break a}h=e+1|0;g=(h<<1)+a|0;x[f+8>>2]=g;b:{c:{e=e+2|0;if((e|0)>=(c|0)){break c}if(!Bk(b,z[g>>1],z[g+2>>1])){break c}g=g+2|0;x[f+8>>2]=g;break b}e=h}if(Bk(b,z[g>>1],z[d>>1])){break a}g=z[x[f+12>>2]>>1];while(1){d:{w[x[f+12>>2]>>1]=z[x[f+8>>2]>>1];j=x[f+8>>2];x[f+12>>2]=j;if((e|0)>(i|0)){break d}e=e<<1;h=e|1;d=(h<<1)+a|0;x[f+8>>2]=d;e:{f:{e=e+2|0;if((e|0)>=(c|0)){break f}if(!Bk(b,z[d>>1],z[d+2>>1])){break f}d=d+2|0;x[f+8>>2]=d;break e}e=h}if(!Bk(b,z[d>>1],g)){continue}}break}w[j>>1]=g}hb=f+16|0}function ns(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0);c=hb-80|0;hb=c;d=x[a>>2];e=x[d+4>>2];x[c+40>>2]=x[d+20>>2];f=x[d+16>>2];x[c+32>>2]=x[d+12>>2];x[c+36>>2]=f;ep(c- -64|0,c+32|0,e);d=Mc(c+48|0,x[x[a+4>>2]>>2],x[x[a+8>>2]>>2],x[x[a+12>>2]>>2]);e=x[x[a+12>>2]>>2];f=x[x[a+8>>2]>>2];x[c+24>>2]=x[c+72>>2];a=x[c+68>>2];x[c+16>>2]=x[c+64>>2];x[c+20>>2]=a;x[c+8>>2]=x[d+8>>2];a=x[d+4>>2];x[c>>2]=x[d>>2];x[c+4>>2]=a;if(e){d=c+16|0;while(1){a=0;if(f){while(1){h=x[Rf(c,a,g)>>2];gc(b,a);i=Rf(d,a,g),j=E(E(h|0)*E(7.450580596923828e-9)),B[i>>2]=j;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}hb=c+80|0}function DF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(!b){return 0}a:{b:{if(!c){break b}d=y[b|0];e=d<<24>>24;if((e|0)>=0){if(a){x[a>>2]=d}return(e|0)!=0|0}if(!x[x[114284]>>2]){b=1;if(!a){break a}x[a>>2]=e&57343;return 1}d=d-194|0;if(d>>>0>50){break b}d=x[(d<<2)+61440>>2];if(d<<D(c,6)-6<0&c>>>0<=3){break b}c=y[b+1|0];e=c>>>3|0;if((e-16|e+(d>>26))>>>0>7){break b}c=c-128|d<<6;if((c|0)>=0){b=2;if(!a){break a}x[a>>2]=c;return 2}d=y[b+2|0]-128|0;if(d>>>0>63){break b}c=d|c<<6;if((c|0)>=0){b=3;if(!a){break a}x[a>>2]=c;return 3}d=y[b+3|0]-128|0;if(d>>>0>63){break b}b=4;if(!a){break a}x[a>>2]=d|c<<6;return 4}x[114240]=25;b=-1}return b|0}function m9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb+-64|0;hb=e;x[e+56>>2]=d;d=x[a+28>>2];Sn(x[x[d>>2]-12>>2]+d|0,0);if(x[x[b>>2]+4>>2]){h=x[a+28>>2];d=x[a+12>>2];g=x[x[b>>2]+4>>2];f=g+x[a+8>>2]|0;d=Ug(e+40|0,f,f>>>0<g>>>0?d+1|0:d);f=x[d+12>>2];x[e+8>>2]=x[d+8>>2];x[e+12>>2]=f;f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;lj(h,e)}d=e+16|0;vf(d,x[a+28>>2]);f=x[d+12>>2];x[e+32>>2]=x[d+8>>2];x[e+36>>2]=f;wK(x[a+28>>2],c,x[e+56>>2]);c=x[b>>2];b=Jm(d,Bc(a+32|0,x[x[b>>2]>>2]),z[x[b>>2]+12>>1]);x[114414]=0;Z(1660,a|0,c|0,b|0,e+32|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){Gb(b);hb=e- -64|0;return}a=N()|0;Gb(b);Q(a|0);p()}function lga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-32|0;hb=e;j=x[a+24>>2];k=x[a+20>>2];l=x[a+16>>2];f=x[a+4>>2];b=x[a>>2];x[e+24>>2]=b;x[e+28>>2]=f;g=x[a+12>>2];x[e+16>>2]=x[a+8>>2];x[e+20>>2]=g;g=a;if(d){while(1){b=x[e+24>>2];f=b>>>10&4194048;i=(((x[e+28>>2]&2147483647)<<1|b>>>31)&-2)+l|0;h=0;b=1;while(1){a=v[h+i|0];x[(e+8|0)+(h<<2)>>2]=((D(v[(h|2)+i|0]-a|0,f)|0)/16384|0)+(a<<8);a=b;b=0;h=1;if(a){continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],k);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],j);c=c+8|0;Tb(e+24|0,e+16|0);d=d-1|0;if(d){continue}break}b=x[e+24>>2];f=x[e+28>>2]}x[g>>2]=b;x[g+4>>2]=f;hb=e+32|0}function k9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb+-64|0;hb=e;x[e+56>>2]=d;d=x[a+28>>2];Sn(x[x[d>>2]-12>>2]+d|0,0);if(x[x[b>>2]+4>>2]){h=x[a+28>>2];d=x[a+12>>2];g=x[x[b>>2]+4>>2];f=g+x[a+8>>2]|0;d=Ug(e+40|0,f,f>>>0<g>>>0?d+1|0:d);f=x[d+12>>2];x[e+8>>2]=x[d+8>>2];x[e+12>>2]=f;f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;lj(h,e)}d=e+16|0;vf(d,x[a+28>>2]);f=x[d+12>>2];x[e+32>>2]=x[d+8>>2];x[e+36>>2]=f;rK(c,x[a+28>>2],x[e+56>>2]);c=x[b>>2];b=Jm(d,Bc(a+32|0,x[x[b>>2]>>2]),z[x[b>>2]+12>>1]);x[114414]=0;Z(1660,a|0,c|0,b|0,e+32|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){Gb(b);hb=e- -64|0;return}a=N()|0;Gb(b);Q(a|0);p()}function aba(a,b){a=a|0;b=b|0;var c=0,d=0;b=77216;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[c+12>>2]=0;U(1533,a+8|0,c+12|0,c+8|0)|0;d=x[114414];x[114414]=0;a:{if((d|0)!=1){hb=c+16|0;break a}S(0)|0;zb();p()}b:{while(1){c:{if(!od(a)){if(!pj(x[b+8>>2],x[xj(a)>>2])){break c}}x[114414]=0;P(1532,a|0,b+8|0);c=x[114414];x[114414]=0;if((c|0)!=1){break c}break b}b=b+12|0;if((b|0)!=77732){continue}break}b=77744;while(1){d:{if(!od(a)){if(!pj(x[b+8>>2],x[xj(a)>>2])){break d}}x[114414]=0;P(1532,a|0,b+8|0);c=x[114414];x[114414]=0;if((c|0)!=1){break d}break b}b=b+12|0;if((b|0)!=77792){continue}break}return}b=N()|0;fy(a);Q(b|0);p()}function Tg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb+-64|0;hb=e;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}if(kg(a,b)){break b}c:{d:{if(jg(a)>>>0<=b>>>0){d=Tx(e+8|0,a);x[114414]=0;T(1605,a|0,b+1|0,d|0);f=x[114414];x[114414]=0;if((f|0)==1){break d}Ck(d)}d=Re(a,b);x[114414]=0;O(1606,d|0,c|0)|0;c=x[114414];x[114414]=0;e:{if((c|0)!=1){c=Re(a,b);x[c+16>>2]=0;x[c+20>>2]=0;c=Re(a,b);x[114414]=0;O(1607,c|0,17386)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break e}}b=S(75016)|0;a=ib;break c}g=xh(Re(a,b));break b}b=S(75016)|0;a=ib;Ck(d)}if((ca(75016)|0)!=(a|0)){break a}Y(b|0)|0;_()}hb=e- -64|0;return g|0}Q(b|0);p()}function nma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;Ad(b,0);zh(d,1,a);c=d+16|0;Ic(c,d);x[114414]=0;O(335,b+43|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){e=d+16|0;xb(e);c=a+32|0;x[b+24>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+13|0;w[b+34>>1]=z[b+34>>1]&65533|(y[c|0]|y[c+1|0]<<8)<<1&2;c=a+16|0;x[b>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+20|0;x[b+4>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+24|0;x[b+8>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[d+16|0]=y[a+15|0];v[d|0]=64;f=b,g=y[rc(e,d)|0]<<2,w[f+30>>1]=g;hb=d+32|0;return}a=N()|0;xb(d+16|0);Q(a|0);p()}function jW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-48|0;hb=e;f=Rb(b);g=Bb(b);i=Rb(c);j=Bb(c);h=-1;a:{if(!g){break a}d=f;g=g+d|0;while(1){if(qo(i,j,d)){d=d+1|0;if((g|0)!=(d|0)){continue}break a}break}h=d-f|0}b:{c:{if((h|0)!=-1){k=e,l=ud(b),x[k+32>>2]=l;c=td(e+40|0,e+32|0);k=e,l=ud(b),x[k+8>>2]=l;k=e,l=Fe(e+8|0,h),x[k+16>>2]=l;d=td(e+24|0,e+16|0);zx(b,x[c>>2],x[d>>2]);break c}if(!Bb(b)){break c}f=Rb(b);h=Bb(b);g=Rb(c);d=-1;i=Bb(c);if(i){c=f+h|0;d:{while(1){if((c|0)==(f|0)){break d}c=c-1|0;if(!qo(g,i,c)){continue}break}d=c-f|0}}if((Bb(b)-1|0)!=(d|0)){break c}hd(a);break b}Jd(a,b)}hb=e+48|0}function xA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;d=(c<<3)+a|0;f=y[d+356|0];v[b+12|0]=y[b+12|0]&248|f&1|f<<1&4|f>>>1&2;Mg(b,Md(y[d+352|0],2,16));v[b+13|0]=y[d+354|0];v[b+14|0]=y[d+355|0];d=y[d+353|0];v[b+15|0]=d;v[b+16|0]=d;d=0;w[e+14>>1]=0;if(Lb(b)){f=((c|0)!=0)<<1;a=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){h=a+(d<<2)|0;g=h+160|0;w[e+12>>1]=y[g|0]|y[g+1|0]<<8;g=z[aj(e+14|0,e+12|0)>>1];w[e+14>>1]=g;i=Pb(b,d),j=g,w[i>>1]=j;w[e+14>>1]=z[e+14>>1]+1;v[e+11|0]=(c^y[h+162|0])>>>f;v[e+10|0]=64;h=y[rc(e+11|0,e+10|0)|0];i=Pb(b,d),j=h,v[i+2|0]=j;d=d+1|0;if(Lb(b)>>>0>d>>>0){continue}break}}lz(b,4,32);hb=e+16|0}function Up(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-16|0;hb=f;g=Lb(a)-1|0;a:{if((Lb(a)|0)==1){break a}while(1){if(z[Ec(a,e)>>1]>=(b|0)){g=e;break a}e=e+1|0;if(e>>>0<Lb(a)-1>>>0){continue}break}}h=z[Ec(a,g)>>1];x[f+12>>2]=0;b:{if((b|0)>=(h|0)){j=f,k=(y[Ec(a,g)+2|0]<<16)/(d|0)|0,x[j+12>>2]=k;break b}e=0;if(g){e=g-1|0;i=(y[Ec(a,e)+2|0]<<16)/(d|0)|0;x[f+12>>2]=i;e=z[Ec(a,e)>>1]}if((b|0)<=(e|0)|e>>>0>=h>>>0){break b}a=((y[Ec(a,g)+2|0]<<16)/(d|0)|0)-i|0;d=a;g=a>>31;a=b-e|0;b=yna(d,g,a,a>>31);a=h-e|0;j=f,k=Cc(zna(b,lb,a,a>>31),lb)+i|0,x[j+12>>2]=k}_d(f+12|0,0,65536);hb=f+16|0;return(D(x[f+12>>2],c)+32768|0)/65536|0}function MM(a,b,c){var d=0;a:{if(x[a+480180>>2]==4){d=y[b+834|0];if(c){v[b+834|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(x[a+480180>>2]!=1048576){break a}if(c){v[b+833|0]=c;break a}c=y[b+833|0]}b:{if(!(v[b+872|0]&1)){break b}d=x[b+700>>2];if(!d|!(c&255)){break b}c:{if(!(y[a+480208|0]&16)){break c}d=x[b+700>>2];if(x[a+480180>>2]==4){break c}a=EM(a,c&15);c=yna(a,a>>31,d,d>>31);a=lb;c=c+32768|0;a=c>>>0<32768?a+1|0:a;a=Cc(zna(c,a,65536,0),lb);x[b+700>>2]=((a|0)==(d|0))+a;return}c=d-(c&255)|0;x[b+700>>2]=c;if((c|0)>0){break b}x[b+700>>2]=1;if(x[a+480180>>2]!=2){break b}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}}function IG(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=hb-208|0;hb=f;x[f+204>>2]=c;c=f+160|0;Sb(c,0,40);x[f+200>>2]=x[f+204>>2];a:{if((HG(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=x[a+76>>2]>=0;g=x[a>>2];if(x[a+72>>2]<=0){x[a>>2]=g&-33}b:{c:{d:{if(!x[a+48>>2]){x[a+48>>2]=80;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;h=x[a+44>>2];x[a+44>>2]=f;break d}if(x[a+16>>2]){break c}}c=-1;if(KG(a)){break b}}c=HG(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){mb[x[a+36>>2]](a,0,0)|0;x[a+48>>2]=0;x[a+44>>2]=h;x[a+28>>2]=0;b=x[a+20>>2];x[a+16>>2]=0;x[a+20>>2]=0;c=b?c:-1}b=a;a=x[a>>2];x[b>>2]=a|g&32;e=a&32?-1:c;if(!i){break a}}hb=f+208|0;return e}function Ai(a,b,c,d){var e=0,f=0,g=0;x[a+20>>2]=d;x[a+16>>2]=c;x[a+12>>2]=b;x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=78688;b=a+24|0;x[b>>2]=0;x[b+4>>2]=0;x[b+16>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;c=UJ(a+44|0);d=UJ(c+12|0);e=TJ(c+24|0);f=TJ(c+36|0);x[114414]=0;U(1673,c|0,2,0)|0;g=x[114414];x[114414]=0;if((g|0)==1){a=N()|0;Gs(f);Gs(e);Fs(d);Fs(c);Q(a|0);p()}d=0;w[a+4204>>1]=0;x[a+4196>>2]=1065353216;x[a+4200>>2]=0;c=x[a+16>>2];x[c+946300>>2]=x[c+946300>>2]+1;x[b>>2]=a+99&-8;e=x[a+20>>2];if((e|0)!=(c+906300|0)){f=a+4200|0;while(1){b=d+1|0;if((e|0)!=((c+D(b,160)|0)+906300|0)){g=d>>>0<248;d=b;if(g){continue}}break}v[f|0]=b}return a}function MU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;Ad(b,0);zh(d,1,a+33|0);c=d+16|0;Ic(c,d);x[114414]=0;O(335,b+43|0,c|0)|0;c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){c=d+16|0;xb(c);e=a+50|0;x[b>>2]=y[e|0]|y[e+1|0]<<8;e=a+52|0;x[b+24>>2]=y[e|0]|y[e+1|0]<<8;v[d+16|0]=y[a+54|0];v[d|0]=64;f=b,g=y[rc(c,d)|0]<<2,w[f+30>>1]=g;c=a+55|0;x[b+4>>2]=y[c|0]|y[c+1|0]<<8;c=a+57|0;c=y[c|0]|y[c+1|0]<<8;x[b+8>>2]=c;if((c|0)!=65535){break b}x[b+4>>2]=0;x[b+8>>2]=0;break a}a=N()|0;xb(d+16|0);Q(a|0);p()}if(!y[a|0]){break a}a=x[b+8>>2];if(a>>>0<=x[b+4>>2]+2>>>0|a>>>0>A[b>>2]){break a}w[b+34>>1]=z[b+34>>1]|2}hb=d+32|0}function Bn(a){var b=0,c=0;b=z[a+24>>1];c=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;x[a+40>>2]=((c&3)<<4)+24368;b=b+(c>>>2|0)|0;w[a+36>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+32>>1]=b;w[a+34>>1]=-1<<b^-1;if(z[a+24>>1]==15){w[a+36>>1]=4095}b=z[a+26>>1];c=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;x[a+52>>2]=((c&3)<<4)+24368;b=b+(c>>>2|0)|0;w[a+48>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+44>>1]=b;w[a+46>>1]=-1<<b^-1;b=z[a+30>>1];c=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;x[a+64>>2]=((c&3)<<4)+24368;b=b+(c>>>2|0)|0;w[a+60>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+56>>1]=b;w[a+58>>1]=-1<<b^-1}function xga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];e=x[a+4>>2];g=x[a>>2];x[b+8>>2]=g;x[b+12>>2]=e;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;a:{if(!d){f=h>>12;j=i>>12;break a}while(1){e=x[b+8>>2];g=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=w[g+2>>1];f=x[a+32>>2];i=x[a+28>>2]+i|0;j=i>>12;x[c>>2]=x[c>>2]+D(j,w[g>>1]);h=f+h|0;f=h>>12;x[c+4>>2]=x[c+4>>2]+D(e,f);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}g=x[b+8>>2];e=x[b+12>>2]}x[a>>2]=g;x[a+4>>2]=e;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=f;hb=b+16|0}function jga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];g=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=g;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;a:{if(!d){f=h>>12;j=i>>12;break a}while(1){f=x[a+32>>2];e=x[b+12>>2]+k|0;g=v[e|0];i=x[a+28>>2]+i|0;j=i>>12;e=((D(v[e+1|0]-g|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(g<<8)|0;x[c>>2]=x[c>>2]+D(j,e);h=f+h|0;f=h>>12;x[c+4>>2]=x[c+4>>2]+D(e,f);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];g=x[b+12>>2]}x[a>>2]=e;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=f;hb=b+16|0}function fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=E(0),i=0,j=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];g=x[Mb(e+12|0,e+8|0)>>2];h=B[d>>2];c=Cb(b);if(g){a=x[a+20>>2];d=g;while(1){f=de(E(nf(E((l(2,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),r())*h),E(-1))*E(32768)));a:{if(E(F(f))<E(2147483648)){b=~~f;break a}b=-2147483648}i=a,j=Uc(b),w[i>>1]=j;f=de(E(nf(E((l(2,y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24)),r())*h),E(-1))*E(32768)));b:{if(E(F(f))<E(2147483648)){b=~~f;break b}b=-2147483648}i=a,j=Uc(b),w[i+2>>1]=j;a=a+4|0;c=c+8|0;d=d-1|0;if(d){continue}break}}hb=e+16|0;return g<<3}function L_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-48|0;hb=f;x[f+40>>2]=b;a:{if(!(x[c+4>>2]&1)){c=mb[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;Dc(a,c);x[114414]=0;a=R(2511,a|0)|0;b=x[114414];x[114414]=0;b:{if((b|0)!=1){Ob(f+24|0);c:{if(e){fh(f+24|0,a);break c}eh(f+24|0,a)}g=f,h=ud(f+24|0),x[g+16>>2]=h;while(1){g=f,h=gk(f+24|0),x[g+8>>2]=h;if(!Hb(f+16|0,f+8|0)){c=x[f+40>>2];Nc(f+24|0);break a}a=x[x[f+16>>2]>>2];x[114414]=0;O(2533,f+40|0,a|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){fe(f+16|0);continue}break}c=N()|0;Nc(f+24|0);break b}c=N()|0;Ob(f+24|0)}Q(c|0);p()}hb=f+48|0;return c|0}function Hba(a){a=a|0;var b=0,c=0,d=0;c=a+1304360|0;b=a+1074984|0;while(1){x[b+104>>2]=0;x[b+656>>2]=0;x[b+76>>2]=0;x[b+16>>2]=0;b=b+896|0;if((c|0)!=(b|0)){continue}break}Sx(a+484344|0);He(a+1304400|0);He(a+1304412|0);He(a+1304424|0);JA(a+1304500|0);b=a+900380|0;c=a+484380|0;while(1){En(c);c=c+104|0;if((c|0)!=(b|0)){continue}break}c=a+901404|0;while(1){d=x[b>>2];if(d){_b(_t(d))}x[b>>2]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){NJ(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}x[a+480180>>2]=0;x[a+480184>>2]=0;a=a+480186|0;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;w[a+6>>1]=0;return 1}function GH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=hb-16|0;hb=e;a:{b:{c:{d=a+8|0;d:{if(!Fl(d)){if((b|0)<0|(xs(d)|0)<=(b|0)){break d}a=Zp(x[a+32>>2],b+1&65535);w[a+34>>1]=z[a+34>>1]&64511|(c?1024:0);break b}d=Fl(d);if((b|0)<0){break d}if((b|0)<(d|0)){break c}}a=ec(8);x[114414]=0;c=O(118,e|0,2427)|0;b=x[114414];x[114414]=0;e:{if((b|0)!=1){a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break e}b=N()|0;hc(a)}Q(b|0);p()}b=b+1<<2;a=a+32|0;if(!x[(b+x[a>>2]|0)+900380>>2]){break b}a=x[(b+x[a>>2]|0)+900380>>2];v[a+15|0]=y[a+15|0]&253|(c?2:0)}hb=e+16|0;return}p()}function JN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;x[a>>2]=0;x[a+4>>2]=0;x[f+12>>2]=0;Xc(a+8|0);if(b){c=hb-16|0;hb=c;if(Iv(a)>>>0<b>>>0){Vc();p()}yb(a);if(b>>>0>268435455){ve();p()}d=Vd(b<<4,8);x[c+12>>2]=b;x[c+8>>2]=d;d=x[c+8>>2];x[a+4>>2]=d;x[a>>2]=d;e=x[c+12>>2];h=yb(a),i=d+(e<<4)|0,x[h>>2]=i;Jo(a,0);hb=c+16|0;d=hb-16|0;hb=d;a:{b:{b=Hm(d,a,b);c=x[b+4>>2];e=x[b+8>>2];if((c|0)!=(e|0)){while(1){g=yb(a);x[114414]=0;P(1216,g|0,c|0);g=x[114414];x[114414]=0;if((g|0)==1){break b}c=c+16|0;x[b+4>>2]=c;if((c|0)!=(e|0)){continue}break}}Jb(b);hb=d+16|0;break a}a=N()|0;Jb(b);Q(a|0);p()}}hb=f+16|0;return a}function W_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-48|0;hb=f;x[f+40>>2]=b;a:{if(!(x[c+4>>2]&1)){c=mb[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;Dc(a,c);x[114414]=0;a=R(2480,a|0)|0;b=x[114414];x[114414]=0;b:{if((b|0)!=1){Ob(f+24|0);c:{if(e){fh(f+24|0,a);break c}eh(f+24|0,a)}g=f,h=ud(f+24|0),x[g+16>>2]=h;while(1){g=f,h=jf(f+24|0),x[g+8>>2]=h;if(!Hb(f+16|0,f+8|0)){c=x[f+40>>2];xb(f+24|0);break a}a=v[x[f+16>>2]];x[114414]=0;O(2364,f+40|0,a|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){bg(f+16|0);continue}break}c=N()|0;xb(f+24|0);break b}c=N()|0;Ob(f+24|0)}Q(c|0);p()}hb=f+48|0;return c|0}function xha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb+-64|0;hb=d;e=d+40|0;bf(e,a,c);a=x[e>>2];x[114414]=0;e=R(421,e|0)|0;f=x[114414];x[114414]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114414]=0;e=R(422,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}x[114414]=0;X(423,d+8|0,2,e|0,a|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;P(355,d+24|0,d+8|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;O(335,b|0,d+24|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}xb(d+24|0);Hc(d+40|0);hb=d- -64|0;a=!c|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(d+24|0)}Hc(d+40|0);Q(a|0);p()}return a|0}function wla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb+-64|0;hb=d;e=d+40|0;bf(e,a,c);a=x[e>>2];x[114414]=0;e=R(421,e|0)|0;f=x[114414];x[114414]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114414]=0;e=R(422,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}x[114414]=0;X(423,d+8|0,2,e|0,a|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;P(355,d+24|0,d+8|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;O(343,b|0,d+24|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}xb(d+24|0);Hc(d+40|0);hb=d- -64|0;a=!c|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(d+24|0)}Hc(d+40|0);Q(a|0);p()}return a|0}function iga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];g=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=g;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;a:{if(!d){f=h>>12;j=i>>12;break a}while(1){f=x[a+32>>2];e=(x[b+12>>2]<<1)+k|0;g=w[e>>1];i=x[a+28>>2]+i|0;j=i>>12;e=g+((D(w[e+2>>1]-g|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;x[c>>2]=x[c>>2]+D(j,e);h=f+h|0;f=h>>12;x[c+4>>2]=x[c+4>>2]+D(e,f);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];g=x[b+12>>2]}x[a>>2]=e;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=f;hb=b+16|0}function Kea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;xc(a,65536);xc(a+4|0,64);xc(a+8|0,256);sg(a+28|0,16384);_e(a+30|0,128);_e(a+31|0,17);if(y[a+16|0]>=4){v[a+16|0]=0}if(y[a+17|0]>=5){v[a+17|0]=0}if(y[a+18|0]>=3){v[a+18|0]=0}_e(a+19|0,64);_e(a+20|0,100);c=-32;d=v[a+26|0];a:{if((d|0)>=-32){c=32;if((d|0)<=32){break a}}v[a+26|0]=c}_e(a+23|0,64);_e(a+24|0,64);kz(a+48|0,64);kz(a+68|0,64);kz(a+88|0,(b|0)==4096?255:64);c=a+108|0;b=0;while(1){b:{if(y[gc(c,b)|0]){if(y[gc(c,b)|0]<121){break b}}e=gc(c,b),f=b+1|0,v[e|0]=f}b=b+1|0;if(b>>>0<128){continue}break}if(!mo(y[a+14|0])){v[a+14|0]=5}if(y[a+34|0]>=251){v[a+34|0]=0}}function Cma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb+-64|0;hb=d;e=d+40|0;bf(e,a,c);a=x[e>>2];x[114414]=0;e=R(421,e|0)|0;f=x[114414];x[114414]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114414]=0;e=R(422,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}x[114414]=0;X(423,d+8|0,3,e|0,a|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;P(355,d+24|0,d+8|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;O(335,b|0,d+24|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}xb(d+24|0);Hc(d+40|0);hb=d- -64|0;a=!c|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(d+24|0)}Hc(d+40|0);Q(a|0);p()}return a|0}function yga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;h=x[a+40>>2];i=x[a+36>>2];k=x[a+16>>2];e=x[a+4>>2];g=x[a>>2];x[b+8>>2]=g;x[b+12>>2]=e;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;a:{if(!d){f=h>>12;j=i>>12;break a}while(1){e=x[b+8>>2];g=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=v[g+1|0];f=x[a+32>>2];i=x[a+28>>2]+i|0;j=i>>12;x[c>>2]=x[c>>2]+(D(j,v[g|0])<<8);h=f+h|0;f=h>>12;x[c+4>>2]=x[c+4>>2]+(D(e,f)<<8);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}g=x[b+8>>2];e=x[b+12>>2]}x[a>>2]=g;x[a+4>>2]=e;x[a+40>>2]=h;x[a+20>>2]=j;x[a+36>>2]=i;x[a+24>>2]=f;hb=b+16|0}function nj(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;v[a|0]=0;f=Jf(x[x[b>>2]-12>>2]+b|0);e=x[x[b>>2]-12>>2]+b|0;a:{b:{if(f){if(x[e+72>>2]){Wr(x[(x[x[b>>2]-12>>2]+b|0)+72>>2])}c:{if(!(x[(x[x[b>>2]-12>>2]+b|0)+4>>2]&4096)|c){break c}c=d+24|0;Dc(c,x[x[b>>2]-12>>2]+b|0);x[114414]=0;f=R(21,c|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}Ob(d+24|0);c=_m(d+16|0,b);e=Xc(d+8|0);while(1){d:{if(Ag(c,e)){break d}if(!zg(f,1,nk(c))){break d}yl(c);continue}break}if(!Ag(c,e)){break c}Jg(x[x[b>>2]-12>>2]+b|0,6)}g=a,h=Jf(x[x[b>>2]-12>>2]+b|0),v[g|0]=h;break b}Jg(e,4)}hb=d+32|0;return}a=N()|0;Ob(d+24|0);Q(a|0);p()}function KT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb+-64|0;hb=d;e=d+40|0;bf(e,a,c);a=x[e>>2];x[114414]=0;e=R(421,e|0)|0;f=x[114414];x[114414]=0;a:{b:{c:{d:{if((f|0)==1){break d}x[114414]=0;e=R(422,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break d}x[114414]=0;X(423,d+8|0,2,e|0,a|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;P(355,d+24|0,d+8|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}x[114414]=0;O(334,b|0,d+24|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}xb(d+24|0);Hc(d+40|0);hb=d- -64|0;a=!c|(a|0)!=0;break a}a=N()|0;break b}a=N()|0;xb(d+24|0)}Hc(d+40|0);Q(a|0);p()}return a|0}function lba(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=hb-32|0;hb=g;a:{if(z[a+480192>>1]<b>>>0){break a}h=x[((b<<2)+a|0)+900380>>2];if(!h){break a}b=g+16|0;uO(b,h);i=g,j=bc(b),x[i+8>>2]=j;i=g,j=Hj(b),x[i>>2]=j;while(1){b:{x[114414]=0;b=O(764,g+8|0,g|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break b}if(!b){cq(g+16|0);break a}x[114414]=0;b=R(765,g+8|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break b}b=z[b>>1];if(b>>>0<=z[a+480190>>1]){b=D(b,104)+a|0;v[b+484421|0]=f;v[b+484418|0]=c;v[b+484420|0]=e;v[b+484419|0]=d}$t(g+8|0);continue}break}a=N()|0;cq(g+16|0);Q(a|0);p()}hb=g+32|0}function X9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;x[e+12>>2]=b;a:{if(tj(a)>>>0>=b>>>0){h=e,i=jg(a),x[h+8>>2]=i;b=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];if(d){while(1){TK(b,c);b=b+52|0;d=d-1|0;if(d){continue}break}}b=x[e+12>>2];d=x[e+8>>2];if(b>>>0>d>>>0){Rx(a,b-d|0,c);break a}OK(a,x[a>>2]+D(b,52)|0);break a}if(x[a>>2]){Sx(a);oy(yb(a),x[a>>2],tj(a));h=yb(a),i=0,x[h>>2]=i;x[a>>2]=0;x[a+4>>2]=0}f=NK(a,b);d=hb-16|0;hb=d;if(JK(a)>>>0<f>>>0){Vc();p()}IK(d+8|0,yb(a),f);f=x[d+8>>2];x[a+4>>2]=f;x[a>>2]=f;g=x[d+12>>2];h=yb(a),i=f+D(g,52)|0,x[h>>2]=i;HK(a,0);hb=d+16|0;Rx(a,b,c)}hb=e+16|0}function d_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=aF(b);bk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;ak(k,a);hi(i,k);Nc(k);eh(k,a);hi(h,k);Nc(k);l=d,m=li(a),x[l>>2]=m;l=e,m=ki(a),x[l>>2]=m;wg(k,a);Db(f,k);xb(k);fh(k,a);hi(g,k);Nc(k);a=$j(a);break a}a=$E(b);bk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;ak(k,a);hi(i,k);Nc(k);eh(k,a);hi(h,k);Nc(k);l=d,m=li(a),x[l>>2]=m;l=e,m=ki(a),x[l>>2]=m;wg(k,a);Db(f,k);xb(k);fh(k,a);hi(g,k);Nc(k);a=$j(a)}x[j>>2]=a;hb=k+16|0}function kX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(tg(a,x[b+8>>2],f)){Qv(b,c,d,e);return}g=y[b+53|0];j=x[a+12>>2];v[b+53|0]=0;h=y[b+52|0];v[b+52|0]=0;m=a+16|0;Ov(m,b,c,d,e,f);k=y[b+53|0];g=g|k;l=y[b+52|0];h=h|l;i=a+24|0;j=(j<<3)+m|0;a:{if(i>>>0>=j>>>0){break a}while(1){h=h&1;g=g&1;if(y[b+54|0]){break a}b:{if(l){if(x[b+24>>2]==1){break a}if(y[a+8|0]&2){break b}break a}if(!k){break b}if(!(v[a+8|0]&1)){break a}}w[b+52>>1]=0;Ov(i,b,c,d,e,f);k=y[b+53|0];g=k|g;l=y[b+52|0];h=l|h;i=i+8|0;if(j>>>0>i>>>0){continue}break}}v[b+53|0]=(g&255)!=0;v[b+52|0]=(h&255)!=0}function ZW(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=hb-32|0;hb=k;n=x[c>>2];l=x[c+8>>2];m=x[c+4>>2];c=k;x[c+8>>2]=m;x[c+12>>2]=l;x[114414]=0;x[c+24>>2]=m;x[c+28>>2]=l;x[c+20>>2]=n;x[c+16>>2]=d;d=x[c+20>>2];x[c>>2]=x[c+16>>2];x[c+4>>2]=d;a=Ea(2041,a|0,b|0,c|0)|0;b=x[114414];x[114414]=0;a:{b:{if((b|0)==1){Y(S(0)|0)|0;x[114414]=0;fa(2034,6396,e|0,f|0,g|0,h|0,i|0,j|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}_();a=-255}hb=k+32|0;break a}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}return a|0}function lea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;x[e+32>>2]=c;x[e+40>>2]=b;x[e+28>>2]=d;x[e+24>>2]=d;a:{if(Hb(e+40|0,e+32|0)){while(1){b=x[e+40>>2];x[114414]=0;T(346,a|0,d|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=e+40|0;ge(b);d=d+2|0;x[e+28>>2]=d;if(Hb(b,e+32|0)){continue}break}}hb=e+48|0;return d|0}Y(S(0)|0)|0;a=Mc(e+8|0,a,e+24|0,e+28|0);x[114414]=0;W(1181,a|0);a=x[114414];x[114414]=0;b:{c:{if((a|0)!=1){x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break c}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break b}S(0)|0;zb()}p()}Q(a|0);p()}function XW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=c;c=hb-16|0;hb=c;x[114414]=0;W(2048,a|0);e=x[114414];x[114414]=0;a:{b:{c:{d:{if((e|0)==1){break d}x[114414]=0;W(2074,b|0);e=x[114414];x[114414]=0;if((e|0)==1){break d}e=x[a+24>>2];b=tc(c+8|0,b);x[114414]=0;g=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=g;Ca(2116,e|0,c|0,f|0,d|0,1);d=x[114414];x[114414]=0;b=1;if((d|0)!=1){break c}}Y(S(0)|0)|0;x[114414]=0;X(2023,4834,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break b}_();b=0}hb=c+16|0;break a}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}return b|0}function ks(a,b,c){var d=0,e=0;d=a,e=si(E(E(E(E(E(E(E(E(E(B[c+3328>>2]+B[c+256>>2])*E(213))+E(E(B[c+3584>>2]-B[c>>2])*E(29)))+E(E(B[c+3072>>2]-B[c+512>>2])*E(459)))+E(E(B[c+2816>>2]+B[c+768>>2])*E(2037)))+E(E(B[c+2560>>2]-B[c+1024>>2])*E(5153)))+E(E(B[c+2304>>2]+B[c+1280>>2])*E(6574)))+E(E(B[c+2048>>2]-B[c+1536>>2])*E(37489)))+E(B[c+1792>>2]*E(75038)))),w[d>>1]=e;d=(b<<5)+a|0,e=si(E(E(E(E(E(E(E(E(B[c+3080>>2]*E(1567))+E(B[c+3592>>2]*E(104)))+E(B[c+2568>>2]*E(9727)))+E(B[c+2056>>2]*E(64019)))+E(B[c+1544>>2]*E(-9975)))+E(B[c+1032>>2]*E(-45)))+E(B[c+520>>2]*E(146)))+E(B[c+8>>2]*E(-5)))),w[d>>1]=e}function k_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=fF(b);bk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;ak(k,a);Db(i,k);xb(k);eh(k,a);Db(h,k);xb(k);l=d,m=li(a),v[l|0]=m;l=e,m=ki(a),v[l|0]=m;wg(k,a);Db(f,k);xb(k);fh(k,a);Db(g,k);xb(k);a=$j(a);break a}a=eF(b);bk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;ak(k,a);Db(i,k);xb(k);eh(k,a);Db(h,k);xb(k);l=d,m=li(a),v[l|0]=m;l=e,m=ki(a),v[l|0]=m;wg(k,a);Db(f,k);xb(k);fh(k,a);Db(g,k);xb(k);a=$j(a)}x[j>>2]=a;hb=k+16|0}function tna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[d+12>>2]=0;U(487,a+8|0,d+12|0,d+8|0)|0;f=x[114414];x[114414]=0;a:{if((f|0)!=1){hb=d+16|0;break a}S(0)|0;zb();p()}d=a;b:{c:{d:{e:{while(1){x[114414]=0;a=O(226,b|0,8)|0;f=x[114414];x[114414]=0;if((f|0)==1){break c}if(!a){break d}x[114414]=0;T(469,e+8|0,b|0,c|0);a=x[114414];x[114414]=0;if((a|0)!=1){x[114414]=0;P(470,d|0,e+8|0);a=x[114414];x[114414]=0;if((a|0)==1){break e}me(e+8|0);continue}break}a=N()|0;break b}a=N()|0;me(e+8|0);break b}hb=e+32|0;return}a=N()|0}TA(d);Q(a|0);p()}function jma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[d+12>>2]=0;U(573,a+8|0,d+12|0,d+8|0)|0;f=x[114414];x[114414]=0;a:{if((f|0)!=1){hb=d+16|0;break a}S(0)|0;zb();p()}d=a;b:{c:{d:{e:{while(1){x[114414]=0;a=O(226,b|0,8)|0;f=x[114414];x[114414]=0;if((f|0)==1){break c}if(!a){break d}x[114414]=0;T(566,e+8|0,b|0,c|0);a=x[114414];x[114414]=0;if((a|0)!=1){x[114414]=0;P(567,d|0,e+8|0);a=x[114414];x[114414]=0;if((a|0)==1){break e}me(e+8|0);continue}break}a=N()|0;break b}a=N()|0;me(e+8|0);break b}hb=e+32|0;return}a=N()|0}BA(d);Q(a|0);p()}function e5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;x[114414]=0;W(2048,a|0);d=x[114414];x[114414]=0;a:{b:{c:{if((d|0)==1){break c}x[114414]=0;W(2074,b|0);d=x[114414];x[114414]=0;if((d|0)==1){break c}d=x[a+24>>2];b=tc(c+8|0,b);x[114414]=0;e=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=e;X(2113,c+16|0,d|0,c|0,1);b=x[114414];x[114414]=0;if((b|0)==1){break c}a=c+16|0;b=Ld(Rb(a));xb(a);break b}Y(S(0)|0)|0;b=0;x[114414]=0;X(2023,2021,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_()}hb=c+32|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function Fka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[d+12>>2]=0;U(743,a+8|0,d+12|0,d+8|0)|0;f=x[114414];x[114414]=0;a:{if((f|0)!=1){hb=d+16|0;break a}S(0)|0;zb();p()}d=a;b:{c:{d:{e:{while(1){x[114414]=0;a=O(226,b|0,6)|0;f=x[114414];x[114414]=0;if((f|0)==1){break c}if(!a){break d}x[114414]=0;T(730,e+8|0,b|0,c|0);a=x[114414];x[114414]=0;if((a|0)!=1){x[114414]=0;P(731,d|0,e+8|0);a=x[114414];x[114414]=0;if((a|0)==1){break e}me(e+8|0);continue}break}a=N()|0;break b}a=N()|0;me(e+8|0);break b}hb=e+32|0;return}a=N()|0}eA(d);Q(a|0);p()}function dw(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;g=f+8|0;Dc(g,b);x[114414]=0;b=R(2510,g|0)|0;g=x[114414];x[114414]=0;a:{if((g|0)==1){break a}x[114414]=0;Z(2523,b|0,64928,64960,c|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}x[114414]=0;b=R(2511,f+8|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;c=R(2524,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}x[d>>2]=c;x[114414]=0;c=R(2520,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}x[e>>2]=c;x[114414]=0;P(2521,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Ob(f+8|0);hb=f+16|0;return}a=N()|0;Ob(f+8|0);Q(a|0);p()}function uO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;c=hb-16|0;hb=c;f=c+8|0;d=hb-16|0;hb=d;x[114414]=0;R(1153,a+4|0)|0;g=x[114414];x[114414]=0;a:{b:{if((g|0)==1){break b}x[114414]=0;x[d+12>>2]=0;U(1154,a+8|0,d+12|0,f|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}h=a,i=mc(a),x[h>>2]=i;hb=d+16|0;break a}S(0)|0;zb();p()}hb=c+16|0;b=b+236|0;d=Et(b);c:{if((b|0)!=(d|0)){while(1){c=z[b>>1];w[e+14>>1]=c;if(c){x[114414]=0;T(1152,e|0,a|0,e+14|0);c=x[114414];x[114414]=0;if((c|0)==1){break c}}b=b+2|0;if((d|0)!=(b|0)){continue}break}}hb=e+16|0;return}b=N()|0;cq(a);Q(b|0);p()}function fw(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;g=f+8|0;Dc(g,b);x[114414]=0;b=R(21,g|0)|0;g=x[114414];x[114414]=0;a:{if((g|0)==1){break a}x[114414]=0;Z(2503,b|0,64928,64960,c|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}x[114414]=0;b=R(2480,f+8|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;c=R(2504,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}v[d|0]=c;x[114414]=0;c=R(2494,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}v[e|0]=c;x[114414]=0;P(2495,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Ob(f+8|0);hb=f+16|0;return}a=N()|0;Ob(f+8|0);Q(a|0);p()}function PJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=hb-16|0;hb=i;d=i+8|0;Eh(d,b);h=hb-16|0;hb=h;f=h+8|0;Ko(f,fi(h,d));d=hb-16|0;hb=d;b=x[a+8>>2];c=x[a+12>>2];g=c;a:{if((c|0)<0){break a}if(!g&Eb(a)>>>0<b>>>0|g){break a}g=Eb(a);b=x[a+8>>2];c=g-b|0;b=0-(x[a+12>>2]+(b>>>0>g>>>0)|0)|0;x[d+8>>2]=c;x[d+12>>2]=b;j=d,k=Vg(f),x[j>>2]=k;x[d+4>>2]=0;c=Jz(d+8|0,d);c=JQ(x[c>>2],x[c+4>>2]);if((c|0)!=(Vg(f)|0)){break a}Ke(x[f>>2],x[f>>2]+c|0,Cb(x[a>>2]+x[a+8>>2]|0));e=x[a+12>>2];b=c+x[a+8>>2]|0;e=b>>>0<c>>>0?e+1|0:e;x[a+8>>2]=b;x[a+12>>2]=e;e=1}hb=d+16|0;hb=h+16|0;hb=i+16|0;return e|0}function Kma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(A[a+4>>2]<A[yb(a)>>2]){e=hb-16|0;hb=e;d=_k(e,a,1);f=yb(a);g=x[d+4>>2];x[114414]=0;X(527,f|0,g|0,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){x[d+4>>2]=x[d+4>>2]+24;Jb(d);hb=e+16|0;break a}a=N()|0;Jb(d);Q(a|0);p()}e=hb-32|0;hb=e;f=yb(a);d=eo(e+8|0,Zk(a,xd(a)+1|0),xd(a),f);g=x[d+8>>2];x[114414]=0;X(527,f|0,g|0,b|0,c|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[d+8>>2]=x[d+8>>2]+24;x[114414]=0;P(528,a|0,d|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}mT(d);hb=e+32|0;break b}a=N()|0;mT(d);Q(a|0);p()}}return yu(a)|0}function zT(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=y[e|0];if(!i|!b){break a}j=2240>>>d&d>>>0<12;g=D(c,-6);k=(d-2&255)>>>0>2;while(1){c=a+g|0;f=y[c+3|0];b:{c:{if(!((f-2&255)>>>0>2|k)){f=1;if(y[(a+g|0)+5|0]<224){break c}break a}f=!(1<<f&2240)|(!j|f>>>0>11)?(d|0)==(f|0):1;if(k){break b}}h=a+g|0;if((y[h+2|0]-11&255)>>>0>2){break b}if(y[h+4|0]){break a}}d:{if(!j){break d}h=a+g|0;if((y[h+2|0]-3&255)>>>0>3){break d}if(y[h+4|0]){break a}}e:{if(!f){break e}a=y[(a+g|0)+5|0];if(a?(a|0)!=(i|0):0){break a}if((a|0)!=(i|0)){break e}v[e|0]=0;return}a=c;b=b-1|0;if(b){continue}break}}}function mH(a){var b=0,c=0,d=0,e=0,f=0,g=0;if(ye(a)){fc(a,31);return 0}f=a,g=ye(a),v[f+1375|0]=g;d=ri(a);b=ri(a);ri(a);f=a,g=ri(a),x[f+1112>>2]=g;ri(a);c=ye(a);x[a+1116>>2]=c;if(!Xw(a,a+1120|0,c)){fc(a,10);return 0}x[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=x[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(y[(b+a|0)+1120|0]==255){continue}break}x[a+1408>>2]=d;x[a+1404>>2]=b}if(y[a+1377|0]){e=x[a+1116>>2];if((e|0)<=0){b=27}else{c=0;b=0;while(1){c=y[(a+b|0)+1120|0]+c|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}b=c+27|0}x[a- -64>>2]=d;x[a+60>>2]=x[a+56>>2]+(b+e|0)}x[a+1380>>2]=0;return 1}function uN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{b=hb-16|0;hb=b;e=hb-144|0;hb=e;d=lh(e+8|0);f=x[x[d>>2]-12>>2];x[114414]=0;g=$(121)|0;h=x[114414];x[114414]=0;b:{c:{if((h|0)==1){break c}x[114414]=0;T(122,e|0,d+f|0,g|0);f=x[114414];x[114414]=0;if((f|0)==1){break c}Ob(e);x[114414]=0;P(132,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break c}x[114414]=0;P(124,b|0,d|0);c=x[114414];x[114414]=0;if((c|0)==1){break c}Xd(d);hb=e+144|0;break b}a=N()|0;Xd(d);Q(a|0);p()}x[114414]=0;T(13,a|0,0,b|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(b);hb=b+16|0;break a}a=N()|0;xb(b);Q(a|0);p()}}function IO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=hb-16|0;hb=f;x[f+8>>2]=e;x[f+12>>2]=d;a:{if(!d){break a}He(a);rr(a,c);if(!c){break a}e=0;while(1){j=c-g|0;x[f+4>>2]=j;h=x[Mb(f+12|0,f+4|0)>>2];Uq(a,Cb(b)+g|0,h);Ip(a,1,13);i=e+h|0;if(i>>>0>e>>>0){while(1){b:{c:{d:{k=v[hE(a,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}l=hE(a,e),m=32,v[l|0]=m}e=e+1|0;if((i|0)!=(e|0)){continue}break}}x[f+4>>2]=j-h;e=i+1|0;g=x[Mb(f+8|0,f+4|0)>>2]+(h+g|0)|0;if(g>>>0<c>>>0){continue}break}}hb=f+16|0;return(d|0)!=0|0}function xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){f=de(E(nf((l(2,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),r()),E(-1))*E(32768)));a:{if(E(F(f))<E(2147483648)){g=~~f;break a}g=-2147483648}h=a,i=Uc(g),w[h>>1]=i;f=de(E(nf((l(2,y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24)),r()),E(-1))*E(32768)));b:{if(E(F(f))<E(2147483648)){g=~~f;break b}g=-2147483648}h=a,i=Uc(g),w[h+2>>1]=i;a=a+4|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<3}function ul(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function rea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=hb-16|0;hb=c;x[c+12>>2]=0;wE(a,c+12|0,1);d=x[c+12>>2];e=d>>>2&3;v[c+11|0]=e;if(e){v[c+4|0]=3;d=y[rc(c+4|0,c+11|0)|0];v[c+4|0]=0;v[c|0]=0;v[c+10|0]=0;a:{if(!d){break a}Fh(a,c+4|0);if((d|0)==1){break a}Fh(a,c);if(d>>>0<3){break a}Fh(a,c+10|0);f=y[c+10|0]<<24}d=y[c+12|0]|(y[c+4|0]<<8|y[c|0]<<16|f);x[c+12>>2]=d}x[c+4>>2]=d>>>4;x[c>>2]=1e6;_v(b,x[Mb(c+4|0,c)>>2]);if(Bb(b)){d=0;while(1){mk(a,pc(b,d),1);d=d+1|0;if(Bb(b)>>>0>d>>>0){continue}break}}d=x[c+12>>2]>>>4|0;b=Bb(b);e=d-b|0;x[c+12>>2]=e;if((b|0)!=(d|0)){xl(a,e,-1)}hb=c+16|0}function z$(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-160|0;hb=d;a=bn(d+16|0,a,8);c=x[x[a>>2]-12>>2];x[114414]=0;b=$(121)|0;e=x[114414];x[114414]=0;a:{b:{if((e|0)==1){break b}x[114414]=0;T(122,d+8|0,a+c|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}Ob(d+8|0);x[114414]=0;c=O(155,a|0,143)|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;c=O(156,c|0,d+4|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[x[c>>2]-12>>2];x[114414]=0;c=R(149,b+c|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}b=x[d+4>>2];Lf(a);hb=d+160|0;a=c?0:b;break a}d=N()|0;Lf(a);Q(d|0);p()}return a|0}function Aaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;ou(e,2,a+2|0);d=e+16|0;Ic(d,e);x[114414]=0;O(334,b+492|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){xb(e+16|0);d=b+236|0;f=c+1|0;c=0;while(1){g=y[(a+c|0)+31|0];h=fd(d,c),i=f+g|0,w[h>>1]=i;c=c+1|0;if(c>>>0<120){continue}break}x[b>>2]=(y[a+223|0]|y[a+224|0]<<8)<<5;a=a+158|0;c=a+1|0;d=a+2|0;f=a+3|0;g=a+4|0;dL(y[a|0]&15,y[c|0]&15,y[d|0]&15,y[f|0]&15,y[g|0]&15,a+5|0,b+48|0);dL(y[a|0]>>>4|0,y[c|0]>>>4|0,y[d|0]>>>4|0,y[f|0]>>>4|0,y[g|0]>>>4|0,a+35|0,b+68|0);hb=e+32|0;return}a=N()|0;xb(e+16|0);Q(a|0);p()}function t6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-32|0;hb=e;c=hb-16|0;hb=c;d=Pe(a);f=mc(a);g=hb-16|0;hb=g;if(d){while(1){h=nt(yb(a),d+16|0,b);f=h?f:d;d=x[(h?d+4|0:d)>>2];if(d){continue}break}}d=x[Fb(g+8|0,f)>>2];hb=g+16|0;x[c+8>>2]=d;i=c,j=Hj(a),x[i>>2]=j;a:{b:{if(!Hb(c+8|0,c)){break b}if(nt(yb(a),b,rh(c+8|0))){break b}b=x[c+8>>2];break a}b=Hj(a)}hb=c+16|0;x[e+24>>2]=b;i=e,j=Hj(a),x[i+16>>2]=j;b=0;if(!Os(e+24|0,e+16|0)){c=x[Fb(e+8|0,x[e+24>>2])>>2];b=hb-16|0;hb=b;x[b+8>>2]=c;c=b+8|0;d=x[c>>2];sK(a,d);mc(a);Ul(rh(c));Sy(d);hb=b+16|0;b=1}hb=e+32|0;return b|0}function c5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[114414]=0;W(2048,a|0);e=x[114414];x[114414]=0;a:{b:{c:{if((e|0)==1){break c}x[114414]=0;W(2074,b|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}e=x[a+24>>2];b=tc(d+8|0,b);x[114414]=0;f=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=f;X(2115,e|0,d|0,(c|0)!=0|0,1);c=x[114414];x[114414]=0;b=1;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,5991,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}hb=d+16|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function YW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;x[114414]=0;W(2048,a|0);c=x[114414];x[114414]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[114414]=0;W(2074,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break d}c=x[a+24>>2];b=tc(d+8|0,b);x[114414]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=VD(c,d,1);e=x[114414];x[114414]=0;c=lb;if((e|0)!=1){break c}}Y(S(0)|0)|0;x[114414]=0;X(2023,4865,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break b}_();b=0;c=0}hb=d+16|0;a=c;break a}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}ib=a;return b|0}function FH(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;a:{b:{c:{c=a+8|0;d:{if(!Fl(c)){if((b|0)<0|(xs(c)|0)<=(b|0)){break d}c=(y[Zp(x[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}c=Fl(c);if((b|0)<0){break d}if((b|0)<(c|0)){break c}}a=ec(8);x[114414]=0;c=O(118,d|0,2427)|0;b=x[114414];x[114414]=0;e:{if((b|0)!=1){a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break e}b=N()|0;hc(a)}Q(b|0);p()}b=b+1<<2;a=a+32|0;c=1;if(!x[(b+x[a>>2]|0)+900380>>2]){break b}c=(y[x[(b+x[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}hb=d+16|0;return c|0}p()}function fB(a,b,c){var d=0,e=0,f=0;d=hb+-64|0;hb=d;e=d+40|0;bf(e,a,c);a=x[e>>2];x[114414]=0;e=R(421,e|0)|0;f=x[114414];x[114414]=0;a:{b:{c:{if((f|0)==1){break c}x[114414]=0;e=R(422,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break c}x[114414]=0;X(423,d+8|0,3,e|0,a|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;P(355,d+24|0,d+8|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;O(334,b|0,d+24|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}xb(d+24|0);Hc(d+40|0);hb=d- -64|0;return!c|(a|0)!=0}a=N()|0;break a}a=N()|0;xb(d+24|0)}Hc(d+40|0);Q(a|0);p()}function eB(a,b,c){var d=0,e=0,f=0;d=hb+-64|0;hb=d;e=d+40|0;bf(e,a,c);a=x[e>>2];x[114414]=0;e=R(421,e|0)|0;f=x[114414];x[114414]=0;a:{b:{c:{if((f|0)==1){break c}x[114414]=0;e=R(422,e|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break c}x[114414]=0;X(423,d+8|0,3,e|0,a|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;P(355,d+24|0,d+8|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;O(343,b|0,d+24|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}xb(d+24|0);Hc(d+40|0);hb=d- -64|0;return!c|(a|0)!=0}a=N()|0;break a}a=N()|0;xb(d+24|0)}Hc(d+40|0);Q(a|0);p()}function cH(a,b){var c=0,d=0,e=0,f=0,g=0;if(!y[456964]){f=456965,g=Va()|0,v[f|0]=g;v[456964]=1}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!y[456965]){break c}d=+Ua();break a}x[114240]=28;return-1}d=+Wa()}c=d/1e3;e:{if(F(c)<0x8000000000000000){e=~~c>>>0;a=F(c)>=1?~~(c>0?H(J(c*2.3283064365386963e-10),4294967295):K((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break e}a=-2147483648}x[b>>2]=e;x[b+4>>2]=a;c=(d-(+(yna(e,a,1e3,0)>>>0)+ +(lb|0)*4294967296))*1e3*1e3;f:{if(F(c)<2147483648){a=~~c;break f}a=-2147483648}x[b+8>>2]=a;return 0}function Dma(a,b){a=a|0;b=b|0;var c=0,d=0;Ad(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=a+4|0;x[b+12>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+8|0;x[b+16>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+12|0;c=y[c|0]|y[c+1|0]<<8;w[b+32>>1]=64;x[b+24>>2]=c;c=a+14|0;if(y[c|0]){d=y[c|0]+1|0}else{d=256}w[b+30>>1]=d;w[b+34>>1]=z[b+34>>1]&32767|!y[c|0]<<15;a=a+15|0;if(!(!(v[a|0]&1)|A[b+16>>2]<=A[b+12>>2])){w[b+34>>1]=z[b+34>>1]|8}if(y[a|0]&2){w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1;x[b+12>>2]=x[b+12>>2]>>>1;x[b+16>>2]=x[b+16>>2]>>>1}}function xea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=Bo(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(1166,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+32;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=cr(d+8|0,xm(a,ue(a)+1|0),ue(a),e);f=x[c+8>>2];x[114414]=0;T(1166,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+32;x[114414]=0;P(1167,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}ut(c);hb=d+32|0;break b}a=N()|0;ut(c);Q(a|0);p()}}function tha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=sl(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(1003,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+12;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=ek(d+8|0,Rm(a,zc(a)+1|0),zc(a),e);f=x[c+8>>2];x[114414]=0;T(1003,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+12;x[114414]=0;P(1e3,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}Gt(c);hb=d+32|0;break b}a=N()|0;Gt(c);Q(a|0);p()}}function saa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=_k(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(1574,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+24;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=eo(d+8|0,Zk(a,xd(a)+1|0),xd(a),e);f=x[c+8>>2];x[114414]=0;T(1574,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+24;x[114414]=0;P(1575,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}cL(c);hb=d+32|0;break b}a=N()|0;cL(c);Q(a|0);p()}}function b5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=hb-16|0;hb=e;x[114414]=0;W(2048,a|0);d=x[114414];x[114414]=0;a:{b:{c:{if((d|0)==1){break c}x[114414]=0;W(2074,b|0);d=x[114414];x[114414]=0;if((d|0)==1){break c}d=x[a+24>>2];b=tc(e+8|0,b);x[114414]=0;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;bb(2117,d|0,e|0,+c,1);d=x[114414];x[114414]=0;b=1;if((d|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,2353,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}hb=e+16|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function Y$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;e=ne(b,-1);d=y[a+52|0];a:{if(e){if(d){break a}b=x[a+48>>2];f=a,g=ne(b,-1)^1,v[f+52|0]=g;break a}b:{if(!d){break b}v[c+19|0]=x[a+48>>2]<<24>>24;c:{d:{e:{d=c+20|0;switch(Rr(x[a+36>>2],x[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((Nr(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}hb=c+32|0;return b|0}function qN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=sl(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(1256,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+12;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=ek(d+8|0,Rm(a,zc(a)+1|0),zc(a),e);f=x[c+8>>2];x[114414]=0;T(1256,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+12;x[114414]=0;P(1257,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}mt(c);hb=d+32|0;break b}a=N()|0;mt(c);Q(a|0);p()}}function q4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=Hm(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(2157,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+16;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=kr(d+8|0,lr(a,rd(a)+1|0),rd(a),e);f=x[c+8>>2];x[114414]=0;T(2157,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+16;x[114414]=0;P(2158,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}gI(c);hb=d+32|0;break b}a=N()|0;gI(c);Q(a|0);p()}}function Pt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;qQ(d,b);e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;v[b+31|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0;hb=c+16|0}return a|0}function $aa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=je(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(1534,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Nf(d+8|0,ze(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114414]=0;T(1534,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114414]=0;P(1535,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}pL(c);hb=d+32|0;break b}a=N()|0;pL(c);Q(a|0);p()}}function yba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=je(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(1434,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Nf(d+8|0,ze(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114414]=0;T(1434,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114414]=0;P(1435,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}LL(c);hb=d+32|0;break b}a=N()|0;LL(c);Q(a|0);p()}}function v9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=je(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(1632,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Nf(d+8|0,ze(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114414]=0;T(1632,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114414]=0;P(1625,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}pn(c);hb=d+32|0;break b}a=N()|0;pn(c);Q(a|0);p()}}function sI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;e=hb-144|0;hb=e;d=lh(e+8|0);f=x[x[d>>2]-12>>2];x[114414]=0;g=$(121)|0;h=x[114414];x[114414]=0;a:{b:{if((h|0)==1){break b}x[114414]=0;T(122,e|0,d+f|0,g|0);f=x[114414];x[114414]=0;if((f|0)==1){break b}Ob(e);x[114414]=0;P(129,d|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(124,c|0,d|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}Xd(d);hb=e+144|0;break a}a=N()|0;Xd(d);Q(a|0);p()}x[114414]=0;T(13,a|0,0,c|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(c);hb=c+16|0;return}a=N()|0;xb(c);Q(a|0);p()}function b8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=je(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(1796,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Nf(d+8|0,ze(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114414]=0;T(1796,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114414]=0;P(1794,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}Es(c);hb=d+32|0;break b}a=N()|0;Es(c);Q(a|0);p()}}function ama(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=Hm(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(580,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+16;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=kr(d+8|0,lr(a,rd(a)+1|0),rd(a),e);f=x[c+8>>2];x[114414]=0;T(580,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+16;x[114414]=0;P(581,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}mu(c);hb=d+32|0;break b}a=N()|0;mu(c);Q(a|0);p()}}function Vka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=sl(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(702,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+12;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=ek(d+8|0,Rm(a,zc(a)+1|0),zc(a),e);f=x[c+8>>2];x[114414]=0;T(702,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+12;x[114414]=0;P(170,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}Ar(c);hb=d+32|0;break b}a=N()|0;Ar(c);Q(a|0);p()}}function Sga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=je(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(1043,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=eu(d+8|0,ze(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114414]=0;T(1043,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114414]=0;P(1044,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}PO(c);hb=d+32|0;break b}a=N()|0;PO(c);Q(a|0);p()}}function FT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=rT(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(524,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+48;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=pT(d+8|0,qT(a,Wi(a)+1|0),Wi(a),e);f=x[c+8>>2];x[114414]=0;T(524,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+48;x[114414]=0;P(525,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}qu(c);hb=d+32|0;break b}a=N()|0;qu(c);Q(a|0);p()}}
function rka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=_k(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(744,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+24;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=eo(d+8|0,Zk(a,xd(a)+1|0),xd(a),e);f=x[c+8>>2];x[114414]=0;T(744,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+24;x[114414]=0;P(745,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}IR(c);hb=d+32|0;break b}a=N()|0;IR(c);Q(a|0);p()}}function jia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=_k(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(956,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+24;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=eo(d+8|0,Zk(a,xd(a)+1|0),xd(a),e);f=x[c+8>>2];x[114414]=0;T(956,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+24;x[114414]=0;P(957,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}MP(c);hb=d+32|0;break b}a=N()|0;MP(c);Q(a|0);p()}}function i9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=je(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(1665,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Nf(d+8|0,ze(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114414]=0;T(1665,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114414]=0;P(1666,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}qK(c);hb=d+32|0;break b}a=N()|0;qK(c);Q(a|0);p()}}function ena(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=_k(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(488,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+24;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=eo(d+8|0,Zk(a,xd(a)+1|0),xd(a),e);f=x[c+8>>2];x[114414]=0;T(488,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+24;x[114414]=0;P(489,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}OT(c);hb=d+32|0;break b}a=N()|0;OT(c);Q(a|0);p()}}function bma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=_k(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(574,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+24;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=eo(d+8|0,Zk(a,xd(a)+1|0),xd(a),e);f=x[c+8>>2];x[114414]=0;T(574,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+24;x[114414]=0;P(575,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}dT(c);hb=d+32|0;break b}a=N()|0;dT(c);Q(a|0);p()}}function Wca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;x[e+12>>2]=c;x[e+8>>2]=x[a>>2]<<1;c=e+8|0;d=x[Mb(c,e+12|0)>>2];x[e+8>>2]=x[a>>2]<<1;x[e+4>>2]=x[e+12>>2]-d;g=d>>>1|0;h=x[Mb(c,e+4|0)>>2];c=Cb(b);if(d>>>0>=2){f=x[a+20>>2];d=g;while(1){j=f,k=(Cb(y[c|0])|Cb(y[c+1|0])<<8)^32768,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Cb(b);if(h>>>0>=2){f=x[a+20>>2]+2|0;c=b+(x[a>>2]<<1)|0;d=i;while(1){j=f,k=(Cb(y[c|0])|Cb(y[c+1|0])<<8)^32768,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}hb=e+16|0;return g+i<<1}function Vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=c;x[f+8>>2]=x[a>>2]<<1;c=f+8|0;e=x[Mb(c,f+12|0)>>2];x[f+8>>2]=x[a>>2]<<1;x[f+4>>2]=x[f+12>>2]-e;i=e>>>1|0;j=x[Mb(c,f+4|0)>>2];c=Cb(b);if(e>>>0>=2){g=x[a+20>>2];e=i;h=d;while(1){h=(Cb(y[c|0])+h|0)+(Cb(y[c+1|0])<<8)|0;w[g>>1]=h;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}h=j>>>1|0;b=Cb(b);if(j>>>0>=2){g=x[a+20>>2]+2|0;c=b+(x[a>>2]<<1)|0;e=h;while(1){d=(Cb(y[c|0])+d|0)+(Cb(y[c+1|0])<<8)|0;w[g>>1]=d;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}hb=f+16|0;return h+i<<1}function Tca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;x[e+12>>2]=c;x[e+8>>2]=x[a>>2]<<1;c=e+8|0;d=x[Mb(c,e+12|0)>>2];x[e+8>>2]=x[a>>2]<<1;x[e+4>>2]=x[e+12>>2]-d;g=d>>>1|0;h=x[Mb(c,e+4|0)>>2];c=Cb(b);if(d>>>0>=2){f=x[a+20>>2];d=g;while(1){j=f,k=(Cb(y[c+1|0])|Cb(y[c|0])<<8)^32768,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Cb(b);if(h>>>0>=2){f=x[a+20>>2]+2|0;c=b+(x[a>>2]<<1)|0;d=i;while(1){j=f,k=(Cb(y[c+1|0])|Cb(y[c|0])<<8)^32768,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}hb=e+16|0;return g+i<<1}function Sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=c;x[f+8>>2]=x[a>>2]<<1;c=f+8|0;e=x[Mb(c,f+12|0)>>2];x[f+8>>2]=x[a>>2]<<1;x[f+4>>2]=x[f+12>>2]-e;i=e>>>1|0;j=x[Mb(c,f+4|0)>>2];c=Cb(b);if(e>>>0>=2){g=x[a+20>>2];e=i;h=d;while(1){h=(Cb(y[c+1|0])+h|0)+(Cb(y[c|0])<<8)|0;w[g>>1]=h;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}h=j>>>1|0;b=Cb(b);if(j>>>0>=2){g=x[a+20>>2]+2|0;c=b+(x[a>>2]<<1)|0;e=h;while(1){d=(Cb(y[c+1|0])+d|0)+(Cb(y[c|0])<<8)|0;w[g>>1]=d;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}hb=f+16|0;return h+i<<1}function tV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=Bo(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(243,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+32;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=cr(d+8|0,xm(a,ue(a)+1|0),ue(a),e);f=x[c+8>>2];x[114414]=0;T(243,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+32;x[114414]=0;P(233,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}br(c);hb=d+32|0;break b}a=N()|0;br(c);Q(a|0);p()}}function K$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=sl(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(169,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+12;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=ek(d+8|0,Rm(a,zc(a)+1|0),zc(a),e);f=x[c+8>>2];x[114414]=0;T(169,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+12;x[114414]=0;P(170,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}Ar(c);hb=d+32|0;break b}a=N()|0;Ar(c);Q(a|0);p()}}function FC(a,b){var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;c=x[b+16>>2];x[a+4>>2]=0;x[a>>2]=c;a:{if(!c){break a}c=b+80|0;d=x[b+84>>2];if(d>>>0<=15){c=x[c>>2]}else{x[e+12>>2]=d-16;c=x[_c(c,e+12|0)>>2]}x[a+8>>2]=c;if(!(y[b+88|0]&2)|!y[b+816|0]){break a}b:{c:{d:{if(!((y[x[b+104>>2]+34|0]&8)>>>3&(x[b+88>>2]&2050)==2)){c=x[b+104>>2];d=x[b+84>>2];break d}d=x[b+84>>2];c=x[b+104>>2];if(x[b+80>>2]!=x[c+12>>2]){break d}if(x[c+16>>2]==(d|0)){break c}}if(x[c+8>>2]!=(d|0)){break a}b=(x[c>>2]-d|0)+48|0;break b}b=(x[c>>2]-d|0)+112|0}f=a,g=x[a>>2]+D(zo(c),b)|0,x[f+4>>2]=g}hb=e+16|0}function vV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=je(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(312,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Nf(d+8|0,ze(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114414]=0;T(312,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114414]=0;P(310,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}Tq(c);hb=d+32|0;break b}a=N()|0;Tq(c);Q(a|0);p()}}function pB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(x[a+4>>2]!=x[yb(a)>>2]){d=hb-16|0;hb=d;c=Yg(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(346,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+2;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=to(d+8|0,$i(a,qc(a)+1|0),qc(a),e);f=x[c+8>>2];x[114414]=0;T(346,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+2;x[114414]=0;P(345,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}Oj(c);hb=d+32|0;break b}a=N()|0;Oj(c);Q(a|0);p()}}function R$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;e=ne(b,-1);d=y[a+52|0];a:{if(e){if(d){break a}b=x[a+48>>2];f=a,g=ne(b,-1)^1,v[f+52|0]=g;break a}b:{if(!d){break b}x[c+16>>2]=x[a+48>>2];c:{d:{e:{d=c+20|0;switch(Rr(x[a+36>>2],x[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((Nr(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}hb=c+32|0;return b|0}function u3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[a>>2]=0;x[a+4>>2]=0;x[f+12>>2]=0;Xc(a+8|0);if(x[b+4>>2]){c=x[b+4>>2];d=hb-16|0;hb=d;if(yr(a)>>>0<c>>>0){Vc();p()}dF(d+8|0,yb(a),c);c=x[d+8>>2];x[a+4>>2]=c;x[a>>2]=c;e=x[d+12>>2];i=yb(a),j=c+D(e,12)|0,x[i>>2]=j;Nm(a,0);hb=d+16|0;c=x[b>>2];e=x[b>>2]+D(x[b+4>>2],12)|0;d=hb-16|0;hb=d;b=sl(d,a,x[b+4>>2]);g=yb(a);h=x[b+4>>2];x[114414]=0;c=Z(2210,g|0,c|0,e|0,h|0)|0;e=x[114414];x[114414]=0;a:{if((e|0)!=1){x[b+4>>2]=c;Jb(b);hb=d+16|0;break a}a=N()|0;Jb(b);Q(a|0);p()}}hb=f+16|0;return a|0}function f5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;x[114414]=0;W(2048,a|0);d=x[114414];x[114414]=0;a:{b:{c:{if((d|0)==1){break c}x[114414]=0;W(2074,b|0);d=x[114414];x[114414]=0;if((d|0)==1){break c}d=x[a+24>>2];b=tc(c+8|0,b);x[114414]=0;f=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=f;e=+ka(2112,d|0,c|0,1);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,2390,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();e=0}hb=c+16|0;return+e}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function Ay(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=je(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(97,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Nf(d+8|0,ze(a,Lb(a)+1|0),Lb(a),e);f=x[c+8>>2];x[114414]=0;T(97,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+4;x[114414]=0;P(98,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}xk(c);hb=d+32|0;break b}a=N()|0;xk(c);Q(a|0);p()}}function Uj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{c=x[a+28>>2];if((c|0)>=(b|0)){f=x[a+24>>2];break a}i=a+32|0;g=x[a+20>>2];d=x[a+16>>2];e=c;while(1){b:{if(d>>>0>=g>>>0){g=Bv(a,i,1024);x[a+16>>2]=0;x[a+20>>2]=g;if(!g){break b}d=0;e=x[a+28>>2]}h=d+1|0;x[a+16>>2]=h;d=y[(a+d|0)+32|0];c=e+8|0;x[a+28>>2]=c;f=x[a+24>>2]|d<<e;x[a+24>>2]=f;d=h;e=c;if((c|0)<(b|0)){continue}break a}break}e=ec(8);x[114414]=0;b=R(230,e|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){a=N()|0;hc(e);Q(a|0);p()}da(b|0,75884,231);p()}x[a+28>>2]=c-b;x[a+24>>2]=f>>>b;return(-1<<b^-1)&f}function kia(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-32|0;hb=d;Ad(b,0);PP(d,a+1|0);c=d+16|0;Ic(c,d);x[114414]=0;O(335,b+43|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){xb(d+16|0);c=a+78|0;x[b+24>>2]=y[c|0]|y[c+1|0]<<8;c=a+58|0;x[b>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+62|0;x[b+4>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=a+66|0;x[b+8>>2]=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);w[b+30>>1]=(y[a+73|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;xc(b+8|0,x[b>>2]);xc(b+4|0,x[b+8>>2]);hb=d+32|0;return}a=N()|0;xb(d+16|0);Q(a|0);p()}function g5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;x[114414]=0;W(2048,a|0);c=x[114414];x[114414]=0;a:{b:{c:{if((c|0)==1){break c}x[114414]=0;W(2074,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break c}c=x[a+24>>2];b=tc(d+8|0,b);x[114414]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=U(2110,c|0,d|0,1)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,6022,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}hb=d+16|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function rU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;d=wc(b);a:{if(d>>>0<c>>>0){g=hb-32|0;hb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=x[yb(b)>>2]-x[b+4>>2]>>>0){xC(b,e);break d}d=yb(b);d=Yh(g+8|0,Wh(b,wc(b)+e|0),wc(b),d);x[114414]=0;P(327,d|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;P(328,b|0,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}Ah(d)}hb=g+32|0;break b}a=N()|0;Ah(d);Q(a|0);p()}break a}if(c>>>0<d>>>0){kv(b,x[b>>2]+c|0)}}c=Qb(a,c);if(c){d=hb-16|0;hb=d;e=f+8|0;jc(e,x[b>>2],wc(b));hb=d+16|0;Dd(a,e)}hb=f+16|0;return c|0}function Ila(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-80|0;hb=f;Ii(f+40|0,f+32|0,c);x[114414]=0;c=f+52|0;T(192,c|0,f+24|0,d|0);d=x[114414];x[114414]=0;a:{b:{if((d|0)!=1){c:{x[114414]=0;c=f- -64|0;T(192,c|0,f+16|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break c}x[114414]=0;P(209,f+8|0,f+40|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;T(73,a|0,b|0,f+8|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}Fm(f+40|0);hb=f+80|0;return}}a=N()|0;while(1){c=xb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=N()|0;Fm(f+40|0)}Q(a|0);p()}function Iha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-80|0;hb=f;Ii(f+40|0,f+32|0,c);x[114414]=0;c=f+52|0;T(208,c|0,f+24|0,d|0);d=x[114414];x[114414]=0;a:{b:{if((d|0)!=1){c:{x[114414]=0;c=f- -64|0;T(192,c|0,f+16|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break c}x[114414]=0;P(209,f+8|0,f+40|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;T(73,a|0,b|0,f+8|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}Fm(f+40|0);hb=f+80|0;return}}a=N()|0;while(1){c=xb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=N()|0;Fm(f+40|0)}Q(a|0);p()}function rW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-80|0;hb=f;Gm(f+40|0,f+32|0,c);x[114414]=0;c=f+52|0;T(208,c|0,f+24|0,d|0);d=x[114414];x[114414]=0;a:{b:{if((d|0)!=1){c:{x[114414]=0;c=f- -64|0;T(208,c|0,f+16|0,e|0);d=x[114414];x[114414]=0;if((d|0)==1){break c}x[114414]=0;P(209,f+8|0,f+40|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;T(73,a|0,b|0,f+8|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}Fm(f+40|0);hb=f+80|0;return}}a=N()|0;while(1){c=xb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=N()|0;Fm(f+40|0)}Q(a|0);p()}function Yfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=g;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;f=a;if(d){while(1){a=x[b+8>>2];e=(x[b+12>>2]<<1)+j|0;a=(a>>>21&2040)+32976|0;a=(((D(w[e>>1],w[a+2>>1])+D(w[e-2>>1],w[a>>1])|0)+D(w[e+2>>1],w[a+4>>1])|0)+D(w[e+4>>1],w[a+6>>1])|0)/16384|0;x[c>>2]=x[c>>2]+D(a,i);x[c+4>>2]=x[c+4>>2]+D(a,h);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];g=x[b+12>>2]}x[f>>2]=e;x[f+4>>2]=g;hb=b+16|0}function s2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+28>>2]=d;x[e+24>>2]=d;a:{if((b|0)!=(c|0)){while(1){x[114414]=0;T(2233,a|0,d|0,b|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}d=d+16|0;x[e+28>>2]=d;b=b+16|0;if((c|0)!=(b|0)){continue}break}}hb=e+32|0;return d|0}Y(S(0)|0)|0;a=Mc(e+8|0,a,e+24|0,e+28|0);x[114414]=0;W(2234,a|0);a=x[114414];x[114414]=0;b:{c:{if((a|0)!=1){x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break c}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break b}S(0)|0;zb()}p()}Q(a|0);p()}function Z1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+28>>2]=d;x[e+24>>2]=d;a:{if((b|0)!=(c|0)){while(1){x[114414]=0;T(2242,a|0,d|0,b|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}d=d+12|0;x[e+28>>2]=d;b=b+12|0;if((c|0)!=(b|0)){continue}break}}hb=e+32|0;return d|0}Y(S(0)|0)|0;a=Mc(e+8|0,a,e+24|0,e+28|0);x[114414]=0;W(2243,a|0);a=x[114414];x[114414]=0;b:{c:{if((a|0)!=1){x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break c}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break b}S(0)|0;zb()}p()}Q(a|0);p()}function V$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;a:{b:{c:{if(ne(b,-1)){break c}v[c+23|0]=b<<24>>24;if(y[a+44|0]){if((oj(c+23|0,1,1,x[a+32>>2])|0)!=1){break b}break c}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=Rr(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((oj(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((oj(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}a=Sr(b);break a}a=-1}hb=c+32|0;return a|0}function tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+28>>2]=d;x[e+24>>2]=d;a:{if((b|0)!=(c|0)){while(1){x[114414]=0;T(1248,a|0,d|0,b|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}d=d+2|0;x[e+28>>2]=d;b=b+2|0;if((c|0)!=(b|0)){continue}break}}hb=e+32|0;return d|0}Y(S(0)|0)|0;a=Mc(e+8|0,a,e+24|0,e+28|0);x[114414]=0;W(1249,a|0);a=x[114414];x[114414]=0;b:{c:{if((a|0)!=1){x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break c}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break b}S(0)|0;zb()}p()}Q(a|0);p()}function jG(a){var b=0,c=0;a:{b=x[a+4>>2];b:{if(!x[(x[x[b>>2]-12>>2]+b|0)+24>>2]){break b}b=x[a+4>>2];if(!Jf(x[x[b>>2]-12>>2]+b|0)){break b}b=x[a+4>>2];if(!(x[(x[x[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(CG()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[114414]=0;b=R(2367,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[114414]=0;P(2368,a+b|0,1);a=x[114414];x[114414]=0;if((a|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)==1){break a}}return}S(0)|0;zb();p()}function hea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+28>>2]=d;x[e+24>>2]=d;a:{if((b|0)!=(c|0)){while(1){x[114414]=0;T(1185,a|0,d|0,b|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}d=d+2|0;x[e+28>>2]=d;b=b+2|0;if((c|0)!=(b|0)){continue}break}}hb=e+32|0;return d|0}Y(S(0)|0)|0;a=Mc(e+8|0,a,e+24|0,e+28|0);x[114414]=0;W(1181,a|0);a=x[114414];x[114414]=0;b:{c:{if((a|0)!=1){x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break c}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break b}S(0)|0;zb()}p()}Q(a|0);p()}function eba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+28>>2]=d;x[e+24>>2]=d;a:{if((b|0)!=(c|0)){while(1){x[114414]=0;T(1453,a|0,d|0,b|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}d=d+1|0;x[e+28>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}hb=e+32|0;return d|0}Y(S(0)|0)|0;a=Mc(e+8|0,a,e+24|0,e+28|0);x[114414]=0;W(1454,a|0);a=x[114414];x[114414]=0;b:{c:{if((a|0)!=1){x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break c}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break b}S(0)|0;zb()}p()}Q(a|0);p()}function baa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+28>>2]=d;x[e+24>>2]=d;a:{if((b|0)!=(c|0)){while(1){x[114414]=0;T(1595,a|0,d|0,b|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}d=d+4|0;x[e+28>>2]=d;b=b+4|0;if((c|0)!=(b|0)){continue}break}}hb=e+32|0;return d|0}Y(S(0)|0)|0;a=Mc(e+8|0,a,e+24|0,e+28|0);x[114414]=0;W(1596,a|0);a=x[114414];x[114414]=0;b:{c:{if((a|0)!=1){x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break c}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break b}S(0)|0;zb()}p()}Q(a|0);p()}function a4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-16|0;hb=f;d=hb-32|0;hb=d;Ct(d+24|0,a,b);h=d+16|0;g=x[d+28>>2];b=hb-32|0;hb=b;e=x[d+24>>2];x[b+20>>2]=e;x[b+24>>2]=c;a:{b:{if((e|0)!=(g|0)){while(1){c=Ub(b+8|0,x[e>>2]);x[114414]=0;O(2241,b+24|0,c|0)|0;i=x[114414];x[114414]=0;if((i|0)==1){break b}xb(c);e=e+4|0;x[b+20>>2]=e;if((e|0)!=(g|0)){continue}break}}ym(h,b+20|0,b+24|0);hb=b+32|0;break a}a=N()|0;xb(c);Q(a|0);p()}j=d,k=Kx(a,x[d+16>>2]),x[j+8>>2]=k;x[d>>2]=x[d+20>>2];gd(f+8|0,d+8|0,d);hb=d+32|0;hb=f+16|0;return x[f+12>>2]}function Pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+28>>2]=d;x[e+24>>2]=d;a:{if((b|0)!=(c|0)){while(1){x[114414]=0;T(1219,a|0,d|0,b|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}d=d+8|0;x[e+28>>2]=d;b=b+8|0;if((c|0)!=(b|0)){continue}break}}hb=e+32|0;return d|0}Y(S(0)|0)|0;a=Mc(e+8|0,a,e+24|0,e+28|0);x[114414]=0;W(1220,a|0);a=x[114414];x[114414]=0;b:{c:{if((a|0)!=1){x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break c}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break b}S(0)|0;zb()}p()}Q(a|0);p()}function Mo(a,b){var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;c=th(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(179,a|0,e|0,b|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+1;Jb(c);hb=d+16|0;break a}a=N()|0;Jb(c);Q(a|0);p()}return}d=hb-32|0;hb=d;e=yb(a);c=Yh(d+8|0,Wh(a,wc(a)+1|0),wc(a),e);f=x[c+8>>2];x[114414]=0;T(179,e|0,f|0,b|0);b=x[114414];x[114414]=0;b:{c:{if((b|0)==1){break c}x[c+8>>2]=x[c+8>>2]+1;x[114414]=0;P(178,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}Km(c);hb=d+32|0;break b}a=N()|0;Km(c);Q(a|0);p()}}function $9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+28>>2]=d;x[e+24>>2]=d;a:{if((b|0)!=(c|0)){while(1){x[114414]=0;T(1599,a|0,d|0,b|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}d=d+6|0;x[e+28>>2]=d;b=b+6|0;if((c|0)!=(b|0)){continue}break}}hb=e+32|0;return d|0}Y(S(0)|0)|0;a=Mc(e+8|0,a,e+24|0,e+28|0);x[114414]=0;W(1600,a|0);a=x[114414];x[114414]=0;b:{c:{if((a|0)!=1){x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break c}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break b}S(0)|0;zb()}p()}Q(a|0);p()}function Xca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;x[e+12>>2]=c;x[e+8>>2]=x[a>>2]<<1;c=e+8|0;d=x[Mb(c,e+12|0)>>2];x[e+8>>2]=x[a>>2]<<1;x[e+4>>2]=x[e+12>>2]-d;g=d>>>1|0;h=x[Mb(c,e+4|0)>>2];c=Cb(b);if(d>>>0>=2){f=x[a+20>>2];d=g;while(1){j=f,k=Cb(y[c|0])|Cb(y[c+1|0])<<8,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Cb(b);if(h>>>0>=2){f=x[a+20>>2]+2|0;c=b+(x[a>>2]<<1)|0;d=i;while(1){j=f,k=Cb(y[c|0])|Cb(y[c+1|0])<<8,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}hb=e+16|0;return g+i<<1}function Vha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+28>>2]=d;x[e+24>>2]=d;a:{if((b|0)!=(c|0)){while(1){x[114414]=0;T(966,a|0,d|0,b|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}d=d+1|0;x[e+28>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}hb=e+32|0;return d|0}Y(S(0)|0)|0;a=Mc(e+8|0,a,e+24|0,e+28|0);x[114414]=0;W(967,a|0);a=x[114414];x[114414]=0;b:{c:{if((a|0)!=1){x[114414]=0;V(83);a=x[114414];x[114414]=0;if((a|0)!=1){break c}}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){break b}S(0)|0;zb()}p()}Q(a|0);p()}function Uca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;x[e+12>>2]=c;x[e+8>>2]=x[a>>2]<<1;c=e+8|0;d=x[Mb(c,e+12|0)>>2];x[e+8>>2]=x[a>>2]<<1;x[e+4>>2]=x[e+12>>2]-d;g=d>>>1|0;h=x[Mb(c,e+4|0)>>2];c=Cb(b);if(d>>>0>=2){f=x[a+20>>2];d=g;while(1){j=f,k=Cb(y[c+1|0])|Cb(y[c|0])<<8,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Cb(b);if(h>>>0>=2){f=x[a+20>>2]+2|0;c=b+(x[a>>2]<<1)|0;d=i;while(1){j=f,k=Cb(y[c+1|0])|Cb(y[c|0])<<8,w[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}hb=e+16|0;return g+i<<1}function _2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;f=oh(a);a:{b:{c:{d:{e:{e=b+24|0;if(z[x[e>>2]+480188>>1]){a=0;while(1){d=x[e>>2];x[114414]=0;P(2220,c|0,(d+(a<<5)|0)+480289|0);d=x[114414];x[114414]=0;if((d|0)==1){break e}x[114414]=0;T(2213,c+16|0,b|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break d}x[114414]=0;P(1547,f|0,c+16|0);d=x[114414];x[114414]=0;if((d|0)==1){break c}xb(c+16|0);xb(c);a=a+1|0;if(a>>>0<z[x[e>>2]+480188>>1]){continue}break}}hb=c+32|0;return}a=N()|0;break a}a=N()|0;break b}a=N()|0;xb(c+16|0)}xb(c)}qd(f);Q(a|0);p()}function Eia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;d=Lb(b);a:{if(d>>>0<c>>>0){g=hb-32|0;hb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=x[yb(b)>>2]-x[b+4>>2]>>2>>>0){aQ(b,e);break d}d=yb(b);d=eu(g+8|0,ze(b,Lb(b)+e|0),Lb(b),d);x[114414]=0;P(920,d|0,e|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}x[114414]=0;P(921,b|0,d|0);e=x[114414];x[114414]=0;if((e|0)==1){break c}YP(d)}hb=g+32|0;break b}a=N()|0;YP(d);Q(a|0);p()}break a}if(c>>>0<d>>>0){d=x[b>>2]+(c<<2)|0;Lb(b);ZP(b,d);og(b)}}c=Qb(a,c<<2);if(c){d=f+8|0;kA(d,b);Dd(a,d)}hb=f+16|0;return c|0}
function _w(a,b,c){var d=0,e=E(0),f=0,g=0,h=E(0),i=E(0),j=E(0),k=E(0),l=E(0),m=E(0),n=0;d=hb-32|0;hb=d;h=B[a+12>>2];e=B[a+24>>2];i=B[a+36>>2];j=B[a+48>>2];uH(E(-B[a>>2]),E(h+e),E(i+j),d+20|0);uH(B[a+60>>2],E(j-i),E(e-h),d+8|0);B[d+12>>2]=-B[d+12>>2];a=0;while(1){f=a<<2;g=f+c|0;h=B[g>>2];n=g;g=f+45920|0;e=B[g>>2];i=B[f+(d+20|0)>>2];j=B[f+(d+8|0)>>2];k=B[g+12>>2];B[n>>2]=E(e*i)-E(j*k);g=b+f|0;l=B[(0-a<<2)+45928>>2];f=5-a<<2;m=B[f+45920>>2];e=E(E(e*j)+E(k*i));B[g>>2]=E(h*l)-E(m*e);B[b+f>>2]=E(m*h)+E(e*l);a=a+1|0;if((a|0)!=3){continue}break}hb=d+32|0}function Zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=g;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;f=a;if(d){while(1){a=x[b+8>>2];e=x[b+12>>2]+j|0;a=(a>>>21&2040)+32976|0;a=(((D(v[e|0],w[a+2>>1])+D(v[e-1|0],w[a>>1])|0)+D(v[e+1|0],w[a+4>>1])|0)+D(v[e+2|0],w[a+6>>1])<<8)/16384|0;x[c>>2]=x[c>>2]+D(a,i);x[c+4>>2]=x[c+4>>2]+D(a,h);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];g=x[b+12>>2]}x[f>>2]=e;x[f+4>>2]=g;hb=b+16|0}function Aga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];e=x[a+4>>2];h=x[a>>2];x[b+8>>2]=h;x[b+12>>2]=e;i=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=i;a:{if(!d){i=f>>12;j=g>>12;break a}while(1){h=x[a+32>>2];g=x[a+28>>2]+g|0;j=g>>12;e=w[(x[b+12>>2]<<1)+k>>1];x[c>>2]=x[c>>2]+D(j,e);f=f+h|0;i=f>>12;x[c+4>>2]=x[c+4>>2]+D(e,i);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}h=x[b+8>>2];e=x[b+12>>2]}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=f;x[a+20>>2]=j;x[a+36>>2]=g;x[a+24>>2]=i;hb=b+16|0}function O$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;a:{b:{c:{if(ne(b,-1)){break c}x[c+20>>2]=b;if(y[a+44|0]){if((oj(c+20|0,4,1,x[a+32>>2])|0)!=1){break b}break c}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=Rr(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((oj(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((oj(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}a=Sr(b);break a}a=-1}hb=c+32|0;return a|0}function Bga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];e=x[a+4>>2];h=x[a>>2];x[b+8>>2]=h;x[b+12>>2]=e;i=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=i;a:{if(!d){i=f>>12;j=g>>12;break a}while(1){h=x[a+32>>2];g=x[a+28>>2]+g|0;j=g>>12;e=v[x[b+12>>2]+k|0]<<8;x[c>>2]=x[c>>2]+D(j,e);f=f+h|0;i=f>>12;x[c+4>>2]=x[c+4>>2]+D(e,i);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}h=x[b+8>>2];e=x[b+12>>2]}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=f;x[a+20>>2]=j;x[a+36>>2]=g;x[a+24>>2]=i;hb=b+16|0}function Fv(a){var b=0,c=0,d=0,e=0;a:{if(A[a+4>>2]<A[yb(a)>>2]){d=hb-16|0;hb=d;b=Bo(d,a,1);c=yb(a);e=x[b+4>>2];x[114414]=0;P(232,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)!=1){x[b+4>>2]=x[b+4>>2]+32;Jb(b);hb=d+16|0;break a}a=N()|0;Jb(b);Q(a|0);p()}d=hb-32|0;hb=d;c=yb(a);b=cr(d+8|0,xm(a,ue(a)+1|0),ue(a),c);e=x[b+8>>2];x[114414]=0;P(232,c|0,e|0);c=x[114414];x[114414]=0;b:{c:{if((c|0)==1){break c}x[b+8>>2]=x[b+8>>2]+32;x[114414]=0;P(233,a|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break c}br(b);hb=d+32|0;break b}a=N()|0;br(b);Q(a|0);p()}}$g(a)}function mg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;w[d+12>>1]=65535;w[d+14>>1]=b;f=d+12|0;b=z[Cf(23296,d+14|0)>>1];c=qc(a);a:{if(b>>>0>c>>>0){e=hb-32|0;hb=e;b:{c:{c=b-c|0;d:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>1>>>0){Eq(a,c,f);break d}b=yb(a);b=to(e+8|0,$i(a,qc(a)+c|0),qc(a),b);x[114414]=0;T(344,b|0,c|0,f|0);c=x[114414];x[114414]=0;if((c|0)==1){break c}x[114414]=0;P(345,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}Oj(b)}hb=e+32|0;break b}a=N()|0;Oj(b);Q(a|0);p()}break a}if(b>>>0<c>>>0){ko(a,x[a>>2]+(b<<1)|0)}}hb=d+16|0}function tC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=y[a+8|0];g=x[a>>2];a=x[a+4>>2];d=Rb(b);b=Bb(b);c=hb-16|0;hb=c;x[c+8>>2]=b;x[c+12>>2]=a;e=x[Mb(c+12|0,c+8|0)>>2];a:{b:{if(!e){a=g;break b}b=e;a=g;while(1){h=y[d|0];v[a|0]=h;if(!h){break a}d=d+1|0;a=a+1|0;b=b-1|0;if(b){continue}break}}b=0}c:{if((f-1&255)>>>0<=1){d=x[c+12>>2];v[c+7|0]=0;Bs(a,((a+d|0)-e|0)+b|0,c+7|0);break c}if((f-3&255)>>>0>1){break c}d=x[c+12>>2];v[c+6|0]=32;Bs(a,((a+d|0)-e|0)+b|0,c+6|0)}d:{switch(f-1|0){case 0:case 3:v[(x[c+12>>2]+g|0)-1|0]=0;break;default:break d}}hb=c+16|0}function B3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;f=e+8|0;c=Me(12);b=hb-16|0;hb=b;x[c>>2]=0;x[c+4>>2]=0;x[b+12>>2]=0;d=yb(a);x[114414]=0;U(2206,c+8|0,b+12|0,d|0)|0;d=x[114414];x[114414]=0;a:{b:{if((d|0)!=1){x[c>>2]=x[a>>2];x[c+4>>2]=x[a+4>>2];d=x[yb(a)>>2];g=yb(c),h=d,x[g>>2]=h;g=yb(a),h=0,x[g>>2]=h;x[a>>2]=0;x[a+4>>2]=0;hb=b+16|0;break b}break a}b=hb-16|0;hb=b;x[114414]=0;x[b+12>>2]=c;a=U(2207,f|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;c:{if((c|0)!=1){hb=b+16|0;break c}break a}hb=e+16|0;return x[a>>2]}S(0)|0;zb();p()}function Bka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-48|0;hb=e;x[114414]=0;c=O(226,a|0,1)|0;d=x[114414];x[114414]=0;a:{if((d|0)==1){break a}b:{c:{if(!c){break c}x[114414]=0;P(733,b|0,64);c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;c=R(403,a|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break b}if(!c){break c}while(1){x[114414]=0;d=O(734,a|0,e+8|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}c=c-1|0;f=d;d=y[e+8|0];if(f&d>>>0<64){sc(TR(b,d),e+8|0,33)}if(c&255){continue}break}}Ab(a);hb=e+48|0;return}}b=N()|0;Ab(a);Q(b|0);p()}function nV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=x[x[a+1056>>2]>>2]-x[a+1060>>2];x[d+8>>2]=16384;e=x[Mb(d+12|0,d+8|0)>>2];x[a+1068>>2]=e;c=17;x[d+4>>2]=17;a:{if(!e){break a}while(1){f=1<<c-1;e=Uj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}Nq(d+4|0,Uj(a,4));break b}if(c>>>0>16){break c}c=f-8|0;if((c|0)>(e|0)|(e|0)>(f+7|0)){break d}Nq(d+4|0,e-c|0);break b}AC(a,e,f,b);break b}c=e&(f^-1);if(e&f){x[d+4>>2]=c+1;break b}AC(a,c,0,b)}if(!x[a+1068>>2]){break a}c=x[d+4>>2];if((c|0)<18){continue}break}}hb=d+16|0}function mV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=x[x[a+1056>>2]>>2]-x[a+1060>>2];x[d+8>>2]=32768;e=x[Mb(d+12|0,d+8|0)>>2];x[a+1068>>2]=e;c=9;x[d+4>>2]=9;a:{if(!e){break a}while(1){f=1<<c-1;e=Uj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}Nq(d+4|0,Uj(a,3));break b}if(c>>>0>8){break c}c=f-4|0;if((c|0)>(e|0)|(e|0)>(f+3|0)){break d}Nq(d+4|0,e-c|0);break b}zC(a,e,f,b);break b}c=e&(f^-1);if(e&f){x[d+4>>2]=c+1;break b}zC(a,c,0,b)}if(!x[a+1068>>2]){break a}c=x[d+4>>2];if((c|0)<10){continue}break}}hb=d+16|0}function jU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-208|0;hb=d;Ku(c,a);nB(c,d+16|0,D(y[a+4|0],3));a:{if(y[a+4|0]<2){break a}v[d+12|0]=64;Mg(b,y[rc(a+4|0,d+12|0)|0]);v[b+13|0]=y[a+2|0];v[b+14|0]=y[a+3|0];a=y[a+1|0];v[b+15|0]=a;v[b+16|0]=a;if(!Lb(b)){break a}a=0;while(1){if(a){c=z[Pb(b,a-1|0)>>1];x[d+12>>2]=1;e=(d+16|0)+D(a,3)|0;x[d+8>>2]=(v[e+1|0]&1)<<8|y[e|0];e=z[Bf(d+12|0,d+8|0)>>1];f=Pb(b,a),g=c+e|0,w[f>>1]=g}c=y[((d+16|0)+D(a,3)|0)+2|0];f=Pb(b,a),g=c,v[f+2|0]=g;a=a+1|0;if(Lb(b)>>>0>a>>>0){continue}break}}hb=d+208|0}function PM(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{if(b){v[c|0]=b;break a}b=y[c|0]}c=x[a+480180>>2]&1048580?b&240?b&-16:b:b;b=c&255;c=c&15;b:{c:{d:{if(!((c|0)!=15|b>>>0<16)){if(!(y[a+480209|0]&16)){break b}b=b>>>3&30;break d}e=x[a+480208>>2]&4096;f=b&240;if(!(!c|(f|0)!=240)){if(!e){break b}b=0-(c<<1)|0;break c}if(e){break b}if(f){if(c?x[a+480180>>2]&59314208:0){break b}b=b>>>3&30;break d}b=0-(c<<1)|0}if(!b){break b}}c=a+1074444|0;x[d+12>>2]=x[c>>2]+(b<<!(x[a+480180>>2]&59314208));_d(d+12|0,0,256);x[c>>2]=x[d+12>>2]}hb=d+16|0}function eY(a){a=a|0;if(y[461168]){return x[115291]}if(!y[462272]){v[462272]=1}$c(461984,71192);$c(461996,71224);$c(462008,71260);$c(462020,71284);$c(462032,71308);$c(462044,71324);$c(462056,71344);$c(462068,71364);$c(462080,71392);$c(462092,71432);$c(462104,71464);$c(462116,71500);$c(462128,71536);$c(462140,71552);$c(462152,71568);$c(462164,71584);$c(462176,71308);$c(462188,71600);$c(462200,71616);$c(462212,71632);$c(462224,71648);$c(462236,71664);$c(462248,71680);$c(462260,71696);v[461168]=1;x[115291]=461984;return 461984}function Wia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,26);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0;hb=c+16|0}return a|0}function waa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-32|0;hb=e;Kg(e,2,a+6|0);d=e+16|0;Ic(d,e);x[114414]=0;O(334,b+492|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){xb(e+16|0);f=b+236|0;g=c+1|0;c=0;d=0;while(1){h=y[(a+c|0)+38|0];i=fd(f,c),j=g+h|0,w[i>>1]=j;d=d+1|0;c=d&255;if(c>>>0<128){continue}break}c=a+226|0;x[b>>2]=(y[c|0]|y[c+1|0]<<8)<<5;_x(a+180|0,b+48|0,0);_x(a+228|0,b+88|0,2);_x(a+276|0,b+68|0,1);a=a+324|0;if(!(y[a|0]|y[a+1|0]<<8)){Sb(b+236|0,0,256)}hb=e+32|0;return}a=N()|0;xb(e+16|0);Q(a|0);p()}function a_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;e=Bb(a);f=Om(a);g=Vt(b,c);a:{if(!g){break a}b:{if(Rb(a)>>>0<=b>>>0){h=Rb(a)+(Bb(a)<<2)>>>0>=b>>>0}else{h=0}if(!h){if(f-e>>>0<g>>>0){fE(a,f,(e+g|0)-f|0,e,e)}f=Rb(a)+(e<<2)|0;while(1){if((b|0)==(c|0)){break b}ug(f,b);b=b+4|0;f=f+4|0;continue}}e=hb-16|0;hb=e;zF(d,b,c);hb=e+16|0;b=Rb(d);c=Bb(d);x[114414]=0;U(2561,a|0,b|0,c|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){Nc(d);break a}a=N()|0;Nc(d);Q(a|0);p()}x[d>>2]=0;ug(f,d);Zg(a,e+g|0)}hb=d+16|0;return a|0}function Bea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;f=z[Pj(a,b)>>1];a:{b:{if(!Rp(a,b)){break b}c=x[a+24>>2]+484360|0;i=d,j=bc(c),x[i+8>>2]=j;i=d,j=dc(c),x[i>>2]=j;if(!Hb(d+8|0,d)){break b}while(1){g=x[d+8>>2];h=zu(g);if(h){e=0;while(1){c:{if(!((a|0)!=(g|0)|(b|0)!=(e|0))|z[uc(g,e)>>1]!=(f|0)){break c}c=LK(x[a+24>>2]+484344|0,f,0);if((c|0)==65535){break c}i=Pj(a,b),j=c,w[i>>1]=j;break a}e=e+1|0;if((h|0)!=(e|0)){continue}break}}c=d+8|0;Ao(c);if(Hb(c,d)){continue}break}}c=f}hb=d+16|0;return c&65535}function tla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;a:{if(iA(a)){x[b>>2]=0;a=0;break a}g=lg(a,f,16);d=Cb(y[f|0]);c=d&127;x[b>>2]=c;if(c){while(1){h=h+1|0;e=c>>>0>1;c=c>>>1|0;if(e){continue}break}}e=d<<24>>24;d=(e|0)<0;c=1;b:{if(g>>>0<2|(e|0)>=0){break b}while(1){d=Cb(y[c+f|0]);x[b>>2]=d&127|x[b>>2]<<7;h=h+7|0;e=d<<24>>24;d=(e|0)<0;c=c+1|0;if((g|0)==(c|0)){cc(a,g);g=lg(a,f,16);c=0}if(c>>>0>=g>>>0){break b}if((e|0)<0){continue}break}}cc(a,c);if(h>>>0>=33){x[b>>2]=-1;a=0;break a}a=!d}hb=f+16|0;return a|0}function o_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;c=hb-128|0;hb=c;x[c+12>>2]=c+116;d=c+16|0;lF(a+8|0,d,c+12|0,e,f,g);g=hb-16|0;hb=g;h=g+8|0;a=hb-32|0;hb=a;xw(a+24|0,d,x[c+12>>2]);i=a+16|0;j=x[a+28>>2];e=hb-16|0;hb=e;f=x[a+24>>2];x[e+4>>2]=f;x[e+8>>2]=b;while(1){if((f|0)!=(j|0)){oG(e+8|0,v[f|0]);f=f+1|0;x[e+4>>2]=f;continue}break}ym(i,e+4|0,e+8|0);hb=e+16|0;k=a,l=ww(d,x[a+16>>2]),x[k+12>>2]=l;x[a+8>>2]=x[a+20>>2];gd(h,a+12|0,a+8|0);hb=a+32|0;hb=g+16|0;hb=c+128|0;return x[g+12>>2]}function ni(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?G(c):G(d)+32|0;gf(f,d,e,0,0,c+49|0);i=x[f>>2];h=x[f+4>>2];e=15372-c<<16;c=x[f+8>>2];d=e|x[f+12>>2]^65536}x[a>>2]=i;x[a+4>>2]=h;x[a+8>>2]=c;x[a+12>>2]=g&-2147483648|d;hb=f+16|0}function iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;a:{d=hb-16|0;hb=d;x[b>>2]=0;x[b+4>>2]=0;x[d+12>>2]=0;yb(c);Xc(b+8|0);a=qc(c);if(a){Ln(b,a);e=x[c>>2];f=x[c+4>>2];g=hb-16|0;hb=g;a=Yg(g,b,a);h=yb(b);i=x[a+4>>2];x[114414]=0;e=Z(1184,h|0,e|0,f|0,i|0)|0;f=x[114414];x[114414]=0;b:{if((f|0)!=1){x[a+4>>2]=e;Jb(a);hb=g+16|0;break b}b=N()|0;Jb(a);Q(b|0);p()}}hb=d+16|0;x[114414]=0;O(4,b+12|0,c+12|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){x[b+24>>2]=x[c+24>>2];w[b+28>>1]=z[c+28>>1];break a}a=N()|0;qf(b);Q(a|0);p()}}function $da(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;NN(d,b);e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+23|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0;hb=c+16|0}return a|0}function NM(a,b,c){var d=0;a:{if(x[a+480180>>2]==4){d=y[b+834|0];if(c){v[b+834|0]=d&240|c&15;break a}c=d&15;break a}if(x[a+480180>>2]!=1048576){break a}if(c){v[b+833|0]=c;break a}c=y[b+833|0]}b:{if(!(v[b+872|0]&1)){break b}d=x[b+700>>2];if(!d|!(c&255)){break b}c:{d:{if(!(y[a+480208|0]&16)){break d}d=x[b+700>>2];if(x[a+480180>>2]==4){break d}a=DM(a,c&15);c=yna(a,a>>31,d,d>>31);a=lb;c=c+32768|0;a=c>>>0<32768?a+1|0:a;a=Cc(zna(c,a,65536,0),lb);a=a-((a|0)==(d|0))|0;break c}a=(c&255)+d|0;a=(a|0)>=65535?65535:a}x[b+700>>2]=a}}function gj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){if(!re(a)){if(!re(b)){x[a+8>>2]=x[b+8>>2];d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;return a|0}e=Rb(b);b=Bb(b);d=hb-16|0;hb=d;a:{if(b>>>0<=10){Ce(a,b);Le(a,e,b);v[d+15|0]=0;Wd(a+b|0,d+15|0);break a}c=uo(a);wo(a,10,b-10|0,c,0,c,b,e)}hb=d+16|0;return a|0}e=Rb(b);b=Bb(b);d=hb-16|0;hb=d;c=ti(a);b:{if(c>>>0>b>>>0){c=x[a>>2];ae(a,b);Le(c,e,b);v[d+15|0]=0;Wd(b+c|0,d+15|0);break b}f=c-1|0;g=(b-c|0)+1|0;c=x[a+4>>2];wo(a,f,g,c,0,c,b,e)}hb=d+16|0}return a|0}function ds(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;h=hb-240|0;hb=h;g=x[c>>2];x[h+232>>2]=g;c=x[c+4>>2];x[h>>2]=a;x[h+236>>2]=c;j=1;a:{b:{c:{if(!(c|(g|0)!=1)){c=a;break c}g=a;while(1){i=(d<<2)+f|0;c=g-x[i>>2]|0;if((Bl(c,a,b)|0)<=0){c=g;break c}d:{if(!((d|0)<2|e)){e=x[i-8>>2];i=g-4|0;if((Bl(i,c,b)|0)>=0){break d}if((Bl(i-e|0,c,b)|0)>=0){break d}}x[(j<<2)+h>>2]=c;g=h+232|0;e=RG(g);es(g,e);j=j+1|0;d=d+e|0;e=0;g=c;if(x[h+236>>2]|x[h+232>>2]!=1){continue}break b}break}c=g;break b}if(e){break a}}QG(h,j);Nw(c,b,d,f)}hb=h+240|0}function bia(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb-160|0;hb=b;a=bn(b+16|0,a,8);d=x[x[a>>2]-12>>2];x[114414]=0;c=$(121)|0;e=x[114414];x[114414]=0;a:{b:{if((e|0)==1){break b}x[114414]=0;T(122,b+8|0,a+d|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break b}Ob(b+8|0);x[114414]=0;d=O(152,a|0,b+6|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break b}c=x[x[d>>2]-12>>2];x[114414]=0;d=R(149,c+d|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break b}c=z[b+6>>1];Lf(a);hb=b+160|0;a=(d?0:c)&65535;break a}b=N()|0;Lf(a);Q(b|0);p()}return a|0}function Gaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;f=$x(a);a:{b:{c:{d:{while(1){x[114414]=0;a=O(226,b|0,8)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}if(a){x[114414]=0;T(1567,e+8|0,b|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(1568,f|0,e+8|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}me(e+8|0);a=yu(f);if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=(d|0)){continue}}break}hb=e+32|0;return}a=N()|0;break a}a=N()|0;me(e+8|0);break a}a=N()|0}Ml(f);Q(a|0);p()}function yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;f=yz(a);a:{b:{c:{d:{while(1){x[114414]=0;a=O(226,b|0,8)|0;g=x[114414];x[114414]=0;if((g|0)==1){break b}if(a){x[114414]=0;T(942,e+8|0,b|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}x[114414]=0;P(943,f|0,e+8|0);a=x[114414];x[114414]=0;if((a|0)==1){break c}me(e+8|0);a=yu(f);if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=(d|0)){continue}}break}hb=e+32|0;return}a=N()|0;break a}a=N()|0;me(e+8|0);break a}a=N()|0}Yl(f);Q(a|0);p()}function fV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;pG(b);a:{if(!(y[a|0]|y[a+1|0]<<8)){c=a+2|0;if(!(y[c|0]|y[c+1|0]<<8)){break a}}x[b+20>>2]=((y[a|0]|y[a+1|0]<<8)>>>9|0)+80;d=b,e=Xb((y[a|0]|y[a+1|0]<<8)>>>5&15,1,12)-1|0,x[d+16>>2]=e;d=b,e=Xb((y[a|0]|y[a+1|0]<<8)&31,1,31),x[d+12>>2]=e;c=a+2|0;d=b,e=Xb((y[c|0]|y[c+1|0]<<8)>>>11|0,0,23),x[d+8>>2]=e;d=b,e=Xb((y[c|0]|y[c+1|0]<<8)>>>5&63,0,59),x[d+4>>2]=e;d=b,e=Xb((y[c|0]|y[c+1|0]<<8)<<1&62,0,59),x[d>>2]=e}a=a+4|0;x[b+44>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24)}function mX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(tg(a,x[b+8>>2],e)){Pv(b,c,d);return}a:{if(tg(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;b:{if(x[b+44>>2]==4){break b}w[b+52>>1]=0;a=x[a+8>>2];mb[x[x[a>>2]+20>>2]](a,b,c,c,1,e);if(y[b+53|0]){x[b+44>>2]=3;if(!y[b+52|0]){break b}break a}x[b+44>>2]=4}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}a=x[a+8>>2];mb[x[x[a>>2]+24>>2]](a,b,c,d,e)}}function X3(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=hb+-64|0;hb=d;x[d+56>>2]=c;c=x[a>>2];e=x[a+4>>2];f=x[a+12>>2];a=x[a+8>>2];x[d+8>>2]=a;x[d+12>>2]=f;x[114414]=0;x[d+32>>2]=a;x[d+36>>2]=f;x[d+24>>2]=c;x[d+28>>2]=e;x[d>>2]=c;x[d+4>>2]=e;T(2192,d+40|0,d|0,0);a=x[114414];x[114414]=0;a:{b:{if((a|0)!=1){a=x[hp(d+16|0,d+56|0)>>2];x[114414]=0;b=+ua(2193,d+40|0,+b,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}Ab(d+40|0);pd(d+56|0);hb=d- -64|0;return+b}a=N()|0;break a}a=N()|0;Ab(d+40|0)}pd(d+56|0);Q(a|0);p()}function G6(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;a:{b:{if(!a){a=Ld(17386);break b}x[114414]=0;c=O(118,b|0,a|0)|0;a=x[114414];x[114414]=0;c:{d:{if((a|0)!=1){x[114414]=0;P(2027,b+16|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}d=b+16|0;a=Ld(Rb(d));xb(d);xb(c);break b}a=S(0)|0;break c}a=S(0)|0;xb(c)}Y(a|0)|0;a=0;x[114414]=0;X(2023,6955,0,0,0);c=x[114414];x[114414]=0;if((c|0)==1){break a}_()}hb=b+32|0;return a|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function kz(a,b){var c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;a:{if(od(a)){break a}w[x[a>>2]>>1]=0;_e(x[a>>2]+2|0,b);f=c,g=bc(a),x[f>>2]=g;f=c,g=Gn(c,1),x[f+8>>2]=g;f=c,g=dc(a),x[f>>2]=g;if(!Hb(c+8|0,c)){break a}while(1){d=c+8|0;e=x[d>>2];f=c,g=xO(d,1),x[f>>2]=g;e=z[aj(e,x[c>>2])>>1];w[x[d>>2]>>1]=e;_e(x[c+8>>2]+2|0,b);fe(d);f=c,g=dc(a),x[f>>2]=g;if(Hb(d,c)){continue}break}}_e(a+14|0,Lb(a)-1&255);_e(a+13|0,y[a+14|0]);_e(a+16|0,Lb(a)-1&255);_e(a+15|0,y[a+16|0]);if(y[a+17|0]!=255){_e(a+17|0,Lb(a)-1&255)}hb=c+16|0}function ska(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-32|0;hb=e;if(HR(b,e+24|0)){d=e+26|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24)}f=e+8|0;Bd(f,b,g);d=y[e+24|0]|y[e+25|0]<<8|(y[e+26|0]<<16|y[e+27|0]<<24);v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;d=y[e+28|0]|y[e+29|0]<<8;v[a+4|0]=d;v[a+5|0]=d>>>8;vm(a+8|0,f);Ab(f);a:{if(!c){break a}d=(g>>>0)%(c>>>0)|0;if(!d){break a}x[114414]=0;O(304,b|0,c-d|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break a}b=N()|0;me(a);Q(b|0);p()}hb=e+32|0}function g2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=E(0),h=0,i=0,j=0;e=hb-16|0;hb=e;i=x[a+4>>2];aI(a,b,c,d);g=B[a+28>>2];b=x[a+24>>2];x[e+8>>2]=x[a+20>>2];x[e+12>>2]=b;b=x[a+16>>2];x[e>>2]=x[a+12>>2];x[e+4>>2]=b;a=hb-16|0;hb=a;b=x[e+12>>2];x[a+8>>2]=x[e+8>>2];x[a+12>>2]=b;b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;b=0;if(!(!d|g==E(1))){while(1){if(c){j=b+i|0;f=0;while(1){h=In(a,f,j);B[h>>2]=B[h>>2]*g;f=f+1|0;if((f|0)!=(c|0)){continue}break}}b=b+1|0;if((d|0)!=(b|0)){continue}break}}hb=a+16|0;hb=e+16|0}function k5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-16|0;hb=g;x[114414]=0;W(2048,a|0);h=x[114414];x[114414]=0;a:{b:{if((h|0)!=1){c:{h=x[a+24>>2];x[114414]=0;fa(2106,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}b=Ld(Rb(g));xb(g);break b}}Y(S(0)|0)|0;b=0;x[114414]=0;X(2023,6645,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_()}hb=g+16|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function j5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-16|0;hb=g;x[114414]=0;W(2048,a|0);h=x[114414];x[114414]=0;a:{b:{if((h|0)!=1){c:{h=x[a+24>>2];x[114414]=0;fa(2107,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}b=Ld(Rb(g));xb(g);break b}}Y(S(0)|0)|0;b=0;x[114414]=0;X(2023,6600,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_()}hb=g+16|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function Sl(a,b,c,d){var e=0;a:{e=a+1074312|0;if($b(e,84)){break a}b:{if(y[a+480209|0]&64){break b}if((d|0)!=8){if(!$b(e,10)){break b}}x[b+88>>2]=x[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0>=64?64:c)<<2;break d;default:break e}}if(!(x[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}x[b+88>>2]=x[b+88>>2]|256;c=128}x[b+692>>2]=c}w[b+796>>1]=0;x[b+88>>2]=x[b+88>>2]|2097152;if(!$b(e,10)){break a}v[b+851|0]=0;w[b+790>>1]=0}}function gY(a){a=a|0;if(y[461160]){return x[115289]}if(!y[461968]){v[461968]=1}Pc(461680,1541);Pc(461692,1532);Pc(461704,6815);Pc(461716,6571);Pc(461728,1751);Pc(461740,7496);Pc(461752,1608);Pc(461764,2095);Pc(461776,5007);Pc(461788,4990);Pc(461800,4998);Pc(461812,5017);Pc(461824,6059);Pc(461836,9114);Pc(461848,5080);Pc(461860,3946);Pc(461872,1751);Pc(461884,5674);Pc(461896,6459);Pc(461908,6827);Pc(461920,5220);Pc(461932,2817);Pc(461944,1978);Pc(461956,9023);v[461160]=1;x[115289]=461680;return 461680}function jO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=b?33:32;f=x[a+8>>2];c=f-1|0;d=x[a+12>>2];g=x[a>>2]+D(d,31)|0;h=b?1:-1;e=h;while(1){b=0;if((d|0)>0){while(1){v[b+g|0]=y[x[a+4>>2]+(D(c,d)+b|0)|0];b=b+1|0;d=x[a+12>>2];if((b|0)<(d|0)){continue}break}f=x[a+8>>2]}b=D(d,h);i=f-1|0;a:{if(!((i|0)!=(c|0)|(e|0)<=0)){if(!y[a+16|0]){e=1;c=0;break a}e=-1;c=c-(y[a+17|0]!=0&(c|0)!=0)|0;break a}if(!((e|0)>=0|c)){c=y[a+16|0];e=c?1:-1;c=c?0:i;break a}c=c+e|0}g=b+g|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}}function Wj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-16|0;hb=e;x[b>>2]=0;x[b+4>>2]=0;v[e+15|0]=0;g=bh(a,e+15|0);c=y[e+15|0];x[b>>2]=(c&252)>>>2;x[b+4>>2]=0;c=c&3;if(c){c=-1<<c;j=(c>>>0>=4294967294?-2:c)^-1;while(1){v[e+15|0]=0;k=bh(a,e+15|0);d=x[b>>2];l=x[b+4>>2];h=y[e+15|0];c=i;f=f+1|0;i=f?c:c+1|0;m=d;c=(f<<3)-2|0;d=c&31;if((c&63)>>>0>=32){c=h<<d;d=0}else{c=(1<<d)-1&h>>>32-d;d=h<<d}x[b>>2]=m|d;x[b+4>>2]=c|l;g=g&k;if((f|0)!=(j|0)|i){continue}break}}hb=e+16|0;return g|0}function yha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;e=hb-16|0;hb=e;c=y[c|0]|y[c+1|0]<<8;w[e+14>>1]=c<<8|c>>>8;c=hb-16|0;hb=c;xI(c,e+14|0);x[114414]=0;f=d+16|0;T(13,f|0,0,c|0);g=x[114414];x[114414]=0;a:{if((g|0)!=1){xb(c);hb=c+16|0;break a}a=N()|0;xb(c);Q(a|0);p()}hb=e+16|0;x[114414]=0;P(72,d|0,f|0);c=x[114414];x[114414]=0;b:{if((c|0)==1){break b}x[114414]=0;T(73,a|0,b|0,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}Gb(d+16|0);hb=d+32|0;return}a=N()|0;Gb(d+16|0);Q(a|0);p()}function nha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{b:{if(!Be(a)){break b}f=x[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break b}En(b);tz(b,a);x[b+20>>2]=0;x[b>>2]=d;if(!Sp(b)){break b}if(x[a>>2]!=(d|0)){Sb(b+68|0,0,36)}f=x[b+20>>2];x[114414]=0;f=R(417,f|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}a=x[a+20>>2];x[114414]=0;a=R(417,a|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}sc(f,a+c|0,d);x[b+8>>2]=e?d:0;x[b+4>>2]=0;w[b+34>>1]=z[b+34>>1]&65533|(e?2:0)}return}S(0)|0;zb();p()}function Al(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function cM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=c;f=d+12|0;c=Lb(a);a:{if(c>>>0<b>>>0){e=hb-32|0;hb=e;b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>2>>>0){OB(a,c,f);break c}b=yb(a);b=Nf(e+8|0,ze(a,Lb(a)+c|0),Lb(a),b);x[114414]=0;T(1451,b|0,c|0,f|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(98,a|0,b|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}xk(b)}hb=e+32|0;break a}a=N()|0;xk(b);Q(a|0);p()}if(b>>>0<c>>>0){OL(a,x[a>>2]+(b<<2)|0)}}ty(a);hb=d+16|0}function kO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=b?33:32;c=y[a+16|0];j=c?-1:1;k=c?1:-1;e=x[a+8>>2]-1|0;l=c?e-(y[a+17|0]!=0&(e|0)!=0)|0:0;m=c?0:e;f=x[a+12>>2];g=x[a>>2]+D(f,62)|0;n=x[a+4>>2];d=b?1:-1;o=D(f,d)<<1;b=e;while(1){if((f|0)>0){c=D(b,f);a=0;while(1){w[(a<<1)+g>>1]=z[(a+c<<1)+n>>1];a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+o|0;a:{if((b|0)==(e|0)){a=l;c=j;if((d|0)>0){break a}}a=b+d|0;b=!b&(d|0)<0;a=b?m:a;c=b?k:d}d=c;b=a;h=h+1|0;if((i|0)!=(h|0)){continue}break}}function C3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-32|0;hb=b;a:{b:{if(vi(a)){gp(b+24|0);break b}c=b+8|0;kn(c,a);x[114414]=0;c=R(2204,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break a}x[b+24>>2]=c;Mf(b+8|0)}if(vi(a)){c=a+36|0}else{c=x[b+24>>2]}a=x[a+8>>2];c:{if((a|0)==-1){f=b,g=bc(c),x[f+8>>2]=g;f=b,g=dc(c),x[f>>2]=g;if(!Hb(b+8|0,b)){break c}while(1){a=b+8|0;d=C[x[a>>2]>>3]+d;Xi(a);if(Hb(a,b)){continue}break}break c}d=C[Tc(c,a)>>3]}sk(b+24|0);hb=b+32|0;return+d}a=N()|0;Mf(b+8|0);Q(a|0);p()}function Tp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=z[a+34>>1];if(!b){if(d&512){pO(a);d=z[a+34>>1]}w[a+34>>1]=d&65023;return}x[a>>2]=4;w[a+34>>1]=d&64958|512;Sp(a);b=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+76|0]=b;v[a+77|0]=b>>>8;v[a+78|0]=b>>>16;v[a+79|0]=b>>>24;b=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a+68|0]=c;v[a+69|0]=c>>>8;v[a+70|0]=c>>>16;v[a+71|0]=c>>>24;v[a+72|0]=b;v[a+73|0]=b>>>8;v[a+74|0]=b>>>16;v[a+75|0]=b>>>24}function Bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>4;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){Cb(y[c|0]);Cb(y[c+1|0]);Cb(y[c+2|0]);Cb(y[c+3|0]);Cb(y[c+4|0]);Cb(y[c+5|0]);f=a,g=Cb(y[c+6|0])|Cb(y[c+7|0])<<8,w[f>>1]=g;Cb(y[c+8|0]);Cb(y[c+9|0]);Cb(y[c+10|0]);Cb(y[c+11|0]);Cb(y[c+12|0]);Cb(y[c+13|0]);f=a,g=Cb(y[c+14|0])|Cb(y[c+15|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+16|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<4}function Ala(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=hb-32|0;hb=f;x[f+28>>2]=c;g=Qb(b,c<<2);a:{if(!g){break a}xc(f+28|0,65535);mg(a,z[f+28>>1]);h=f,i=bc(a),x[h+16>>2]=i;h=f,i=dc(a),x[h+8>>2]=i;if(!Hb(f+16|0,f+8|0)){break a}while(1){a=x[f+16>>2];c=f+24|0;iu(b,c);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);w[a>>1]=c;c=c&65535;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}w[a>>1]=c}a=f+16|0;ge(a);if(Hb(a,f+8|0)){continue}break}}hb=f+32|0;return g|0}function Aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>4;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){Cb(y[c+7|0]);Cb(y[c+6|0]);Cb(y[c+5|0]);Cb(y[c+4|0]);Cb(y[c+3|0]);Cb(y[c+2|0]);f=a,g=Cb(y[c+1|0])|Cb(y[c|0])<<8,w[f>>1]=g;Cb(y[c+15|0]);Cb(y[c+14|0]);Cb(y[c+13|0]);Cb(y[c+12|0]);Cb(y[c+11|0]);Cb(y[c+10|0]);f=a,g=Cb(y[c+9|0])|Cb(y[c+8|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+16|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<4}function F9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;e=w[b>>1];b=w[a+30>>1];a:{if(!b){break a}if((e|0)>=0){e=(e|0)%(b|0)|0;break a}e=b+((e^-1)%(b|0)^-1)|0}w[d+14>>1]=e;b:{if(!Wc(c)){gj(BK(a+52|0,d+14|0),c);break b}f=a+52|0;i=d,j=Nx(f,d+14|0),x[i+8>>2]=j;i=d,j=Ti(f),x[i>>2]=j;if(!Si(d+8|0,d)){break b}g=hb-16|0;hb=g;a=x[Fb(g,x[d+8>>2])>>2];h=hb-16|0;hb=h;x[h+8>>2]=a;e=h+8|0;c=x[e>>2];b=sK(f,c);a=mc(f);Pi(rh(e));_g(a,c,1);hb=h+16|0;Fb(g+8|0,b);hb=g+16|0}hb=d+16|0}function vW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{b:{c:{d:{if(h=Wc(b),i=1,j=x[b+12>>2],j?h:i){hd(a);break d}f=hb-16|0;hb=f;d=Bb(b);e=wf(9998);g=Rb(vw(c+16|0,d+e|0));Le(g,Rb(b),d);d=d+g|0;Le(d,9998,e);yn(d+e|0,1,0);hb=f+16|0;x[114414]=0;P(202,c|0,b+12|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}x[114414]=0;T(3,a|0,c+16|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}xb(c);xb(c+16|0)}hb=c+32|0;return}b=N()|0;break a}b=N()|0;xb(c)}xb(c+16|0);Q(b|0);p()}function LM(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(d>>>0<224){break c}f=e+8|0;Kb(f,a+1074312|0,3);if(Ib(f)){break c}if(!(v[(D(b,896)+a|0)+1075856|0]&1)){break a}c=D(d&15,c>>31|(c|0)!=0);c=d>>>0>239?c<<2:c;break b}if(v[(D(b,896)+a|0)+1075856|0]&1){d=e+8|0;Kb(d,a+1074312|0,3);if(!Ib(d)){break a}}c=c<<2}if(!c){break a}d=Ey(a,b);if(!d){break a}a=x[(D(b,896)+a|0)+1075640>>2];if(a){a=y[a+33|0]}else{a=13}mb[x[x[d>>2]+80>>2]](d,c,a<<24>>24,b)}hb=e+16|0}function p$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{c:{if((a|0)!=(b|0)){d:{e:{f=y[a|0];if((f|0)!=45){break e}a=a+1|0;if((b|0)!=(a|0)){break e}break d}h=x[114240];x[114240]=0;a=Xv(a,e+12|0,d,ie());d=lb;g=x[114240];f:{if(g){if(x[e+12>>2]!=(b|0)){break f}if((g|0)==68){break c}break b}x[114240]=h;if(x[e+12>>2]==(b|0)){break b}}}}x[c>>2]=4;b=0;a=0;break a}x[c>>2]=4;b=-1;a=-1;break a}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d}hb=e+16|0;lb=a;return b|0}function dn(a){var b=0,c=0,d=0;if(!a){if(x[20988]){b=dn(x[20988])}if(x[20912]){b=dn(x[20912])|b}a=x[114243];if(a){while(1){if(x[a+20>>2]!=x[a+28>>2]){b=dn(a)|b}a=x[a+56>>2];if(a){continue}break}}return b}d=x[a+76>>2]>=0;a:{b:{if(x[a+20>>2]==x[a+28>>2]){break b}mb[x[a+36>>2]](a,0,0)|0;if(x[a+20>>2]){break b}b=-1;break a}b=x[a+8>>2];c=x[a+4>>2];if((b|0)!=(c|0)){b=c-b|0;mb[x[a+40>>2]](a,b,b>>31,1)|0}b=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;if(!d){break a}}return b}function rda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;f=Wb(a);a:{b:{c:{if(zc(b)){a=0;while(1){d:{if(!a){break d}x[114414]=0;O(1251,f|0,c|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break d}a=N()|0;break a}d=wd(b,a);x[114414]=0;P(1252,e|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break c}x[114414]=0;O(1251,f|0,e|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break b}xb(e);a=a+1|0;if(zc(b)>>>0>a>>>0){continue}break}}hb=e+16|0;return}a=N()|0;break a}a=N()|0;xb(e)}xb(f);Q(a|0);p()}function Sm(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=hb-16|0;hb=i;a:{b:{if(!a){break b}h=x[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((gm(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=sF(i,b,f);h=Rb(f);x[114414]=0;h=U(2537,a|0,h|0,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}Nc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((gm(a,c,b)|0)!=(b|0)){break b}}uz(e);j=a}hb=i+16|0;return j|0}a=N()|0;Nc(f);Q(a|0);p()}function m5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=hb-16|0;hb=f;x[114414]=0;W(2048,a|0);g=x[114414];x[114414]=0;a:{b:{if((g|0)!=1){c:{g=x[a+24>>2];x[114414]=0;ia(2104,f|0,g|0,b|0,c|0,d|0,e|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}b=Ld(Rb(f));xb(f);break b}}Y(S(0)|0)|0;b=0;x[114414]=0;X(2023,8280,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_()}hb=f+16|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function l5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=hb-16|0;hb=f;x[114414]=0;W(2048,a|0);g=x[114414];x[114414]=0;a:{b:{if((g|0)!=1){c:{g=x[a+24>>2];x[114414]=0;ia(2105,f|0,g|0,b|0,c|0,d|0,e|0);b=x[114414];x[114414]=0;if((b|0)==1){break c}b=Ld(Rb(f));xb(f);break b}}Y(S(0)|0)|0;b=0;x[114414]=0;X(2023,8180,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_()}hb=f+16|0;return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function iB(a,b,c){var d=0,e=0,f=0;e=hb+-64|0;hb=e;He(b);d=e+40|0;bf(d,a,c);a=x[d>>2];x[114414]=0;d=R(421,d|0)|0;f=x[114414];x[114414]=0;a:{if((f|0)==1){break a}x[114414]=0;d=R(422,d|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break a}x[114414]=0;X(423,e+8|0,3,d|0,a|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}x[114414]=0;P(355,e+24|0,e+8|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}d=b;b=e+24|0;Db(d,b);xb(b);Hc(e+40|0);hb=e- -64|0;return!c|(a|0)!=0}a=N()|0;Hc(e+40|0);Q(a|0);p()}function QT(a,b,c){var d=0,e=0,f=0;e=hb+-64|0;hb=e;He(b);d=e+40|0;bf(d,a,c);a=x[d>>2];x[114414]=0;d=R(421,d|0)|0;f=x[114414];x[114414]=0;a:{if((f|0)==1){break a}x[114414]=0;d=R(422,d|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break a}x[114414]=0;X(423,e+8|0,2,d|0,a|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}x[114414]=0;P(355,e+24|0,e+8|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}d=b;b=e+24|0;Db(d,b);xb(b);Hc(e+40|0);hb=e- -64|0;return!c|(a|0)!=0}a=N()|0;Hc(e+40|0);Q(a|0);p()}function oq(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=hb-32|0;hb=f;x[f+28>>2]=c;g=Qb(b,c);a:{if(!g){break a}xc(f+28|0,65535);mg(a,z[f+28>>1]);i=f,j=bc(a),x[i+16>>2]=j;i=f,j=dc(a),x[i+8>>2]=j;if(!Hb(f+16|0,f+8|0)){break a}while(1){a=x[f+16>>2];c=f+27|0;if(!Xf(b,c)){h=hb-16|0;hb=h;mf(c);hb=h+16|0}c=y[f+27|0];w[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}w[a>>1]=c}a=f+16|0;ge(a);if(Hb(a,f+8|0)){continue}break}}hb=f+32|0;return g|0}function t$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=y[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=x[114240];x[114240]=0;a=Xv(a,e+12|0,d,ie());d=lb;g=x[114240];g:{if(g){if(x[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}x[114240]=h;if(x[e+12>>2]==(b|0)){break d}}}}x[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535){break b}}x[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}hb=e+16|0;return a&65535}function lW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;f=hd(a);a:{b:{c:{if(zc(b)){a=0;while(1){d:{if(!a){break d}x[114414]=0;O(160,f|0,c|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){break d}a=N()|0;break a}d=wd(b,a);x[114414]=0;P(220,e|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break c}x[114414]=0;O(160,f|0,e|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break b}xb(e);a=a+1|0;if(zc(b)>>>0>a>>>0){continue}break}}hb=e+16|0;return}a=N()|0;break a}a=N()|0;xb(e)}xb(f);Q(a|0);p()}function LG(a){var b=0,c=0,d=0,e=0;b=hb-160|0;hb=b;a=bn(b+16|0,a,8);d=x[x[a>>2]-12>>2];x[114414]=0;c=$(121)|0;e=x[114414];x[114414]=0;a:{if((e|0)==1){break a}x[114414]=0;T(122,b+8|0,a+d|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}Ob(b+8|0);x[114414]=0;d=O(148,a|0,b+4|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[x[d>>2]-12>>2];x[114414]=0;d=R(149,c+d|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b+4>>2];Lf(a);hb=b+160|0;return d?0:c}b=N()|0;Lf(a);Q(b|0);p()}function x$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[114240];x[114240]=0;a=mE(a,e+12|0,d,ie());d=lb;f=x[114240];d:{if(f){if(x[e+12>>2]!=(b|0)){break d}if((f|0)==68){break b}break c}x[114240]=g;if(x[e+12>>2]==(b|0)){break c}}}x[c>>2]=4;b=0;break a}if((d|0)<0&a>>>0<2147483648|(d|0)<-1|(a>>>0>2147483647&(d|0)>=0|(d|0)>0)){break b}b=a;break a}x[c>>2]=4;b=2147483647;if(!!a&(d|0)>=0|(d|0)>0){break a}b=-2147483648}hb=e+16|0;return b|0}function gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=E(0),h=E(0),i=0,j=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>2;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];h=B[d>>2];c=Cb(b);if(f){d=x[a+20>>2];b=f;while(1){a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);g=de(E(nf(E((l(2,a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)),r())*h),E(-1))*E(32768)));a:{if(E(F(g))<E(2147483648)){a=~~g;break a}a=-2147483648}i=d,j=Uc(a),w[i>>1]=j;d=d+2|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f<<2}function us(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;d=x[b>>2];e=x[b+8>>2];b=x[b+4>>2]?d&24576?d:(e|0)!=-1?d&-12289|8192:d:d;a:{if(b&1){d=142}else{if(!(b&2)){break a}d=143}$w(a,d)}b:{if(b&4096){break b}if(b&8192){f=c,g=Zw(4),x[f+24>>2]=g;rH(a,c+24|0);break b}if(!(b&16384)){break b}f=c,g=Zw(256),x[f+16>>2]=g;rH(a,c+16|0)}c:{if(b&16){b=144}else{if(!(b&32)){break c}b=145}$w(a,b)}if((e|0)!=-1){f=c,g=Zw(e),x[f+8>>2]=g;x[(x[x[a>>2]-12>>2]+a|0)+8>>2]=x[c+8>>2]}hb=c+32|0}function ona(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=hb-32|0;hb=f;x[f+28>>2]=c;g=Qb(b,c<<1);a:{if(!g){break a}xc(f+28|0,65535);mg(a,z[f+28>>1]);h=f,i=bc(a),x[h+16>>2]=i;h=f,i=dc(a),x[h+8>>2]=i;if(!Hb(f+16|0,f+8|0)){break a}while(1){a=x[f+16>>2];c=f+24|0;Mu(b,c);c=y[c|0]|y[c+1|0]<<8;c=c<<8|c>>>8;w[a>>1]=c;c=c&65535;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}w[a>>1]=c}a=f+16|0;ge(a);if(Hb(a,f+8|0)){continue}break}}hb=f+32|0;return g|0}function nga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=g;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;f=a;if(d){while(1){e=x[b+12>>2]+j|0;a=v[e|0];a=((D(v[e+1|0]-a|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(a<<8)|0;x[c>>2]=x[c>>2]+D(a,i);x[c+4>>2]=x[c+4>>2]+D(a,h);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];g=x[b+12>>2]}x[f>>2]=e;x[f+4>>2]=g;hb=b+16|0}function gf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function wF(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=x[a+104>>2];d=(g<<3)+a|0;b=((g+7>>>0)%12<<3)+a|0;f=x[b>>2];e=x[b+4>>2];b=x[a+100>>2];j=b;h=x[a+96>>2];a:{if(!(b|h)){c=x[d+4>>2];b=x[d>>2];i=(c|0)==(e|0)&b>>>0>f>>>0|e>>>0<c>>>0;break a}c=x[d+4>>2];b=x[d>>2];i=!(e|f)|((c|0)==(e|0)&b>>>0>=f>>>0|e>>>0<c>>>0)}c=c+j|0;b=b+h|0;c=b>>>0<h>>>0?c+1|0:c;x[d>>2]=f-b;x[d+4>>2]=e-(c+(b>>>0>f>>>0)|0)&65535;x[a+104>>2]=(g+1>>>0)%12;x[a+96>>2]=i;x[a+100>>2]=0;lb=x[d+4>>2];return x[d>>2]}function R9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{a=hb-16|0;hb=a;x[b>>2]=0;x[b+4>>2]=0;x[a+12>>2]=0;yb(c);Xc(b+8|0);d=hg(c);if(d){sq(b,d);Ux(b,x[c>>2],x[c+4>>2],d)}hb=a+16|0;x[b+20>>2]=x[c+20>>2];a=x[c+16>>2];x[b+12>>2]=x[c+12>>2];x[b+16>>2]=a;x[114414]=0;d=O(1612,b+24|0,c+24|0)|0;a=x[114414];x[114414]=0;b:{c:{if((a|0)!=1){x[114414]=0;O(117,b+36|0,c+36|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}x[b+48>>2]=x[c+48>>2];break a}a=N()|0;break b}a=N()|0;Ge(d)}bm(b);Q(a|0);p()}}function H2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;d=hb-144|0;hb=d;c=lh(d+8|0);e=x[x[c>>2]-12>>2];x[114414]=0;g=$(121)|0;h=x[114414];x[114414]=0;a:{b:{if((h|0)==1){break b}x[114414]=0;T(122,d|0,c+e|0,g|0);e=x[114414];x[114414]=0;if((e|0)==1){break b}Ob(d);x[114414]=0;P(134,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(124,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}Xd(c);hb=d+144|0;break a}a=N()|0;Xd(c);Q(a|0);p()}hb=f+16|0}function F2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;d=hb-144|0;hb=d;c=lh(d+8|0);e=x[x[c>>2]-12>>2];x[114414]=0;g=$(121)|0;h=x[114414];x[114414]=0;a:{b:{if((h|0)==1){break b}x[114414]=0;T(122,d|0,c+e|0,g|0);e=x[114414];x[114414]=0;if((e|0)==1){break b}Ob(d);x[114414]=0;P(135,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break b}x[114414]=0;P(124,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}Xd(c);hb=d+144|0;break a}a=N()|0;Xd(c);Q(a|0);p()}hb=f+16|0}function AW(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb-32|0;hb=b;c=Ub(b,12715);x[114414]=0;T(194,b+16|0,a|0,c|0);a=x[114414];x[114414]=0;a:{b:{c:{if((a|0)!=1){xb(c);if(zc(b+16|0)){break c}a=0;break a}d=N()|0;xb(c);break b}a=0;while(1){d:{c=wd(b+16|0,d);x[114414]=0;c=R(195,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break d}a=(c&255)<<24-(d<<3)|a;c=zc(b+16|0);if(d>>>0>2){break a}d=d+1|0;if(c>>>0>d>>>0){continue}break a}break}d=N()|0;vl(b+16|0)}Q(d|0);p()}vl(b+16|0);hb=b+32|0;return a|0}function b6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[114414]=0;W(2048,a|0);d=x[114414];x[114414]=0;a:{if((d|0)==1){break a}x[114414]=0;W(2059,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}d=x[a+24>>2];x[114414]=0;b=O(2060,d|0,b|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}x[c>>2]=b;return 1}Y(S(0)|0)|0;x[114414]=0;X(2023,6334,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)!=1){_();return 0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function sba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;f=b-1&65535;a:{if(f>>>0>3998){break a}e=(D(b,104)+a|0)+484380|0;if(!Be(e)){break a}g=a+1304360|0;d=a+1074984|0;while(1){if(x[d+104>>2]==(e|0)){x[d+76>>2]=0;x[d>>2]=0;x[d+4>>2]=0;x[d+16>>2]=0}d=d+896|0;if((g|0)!=(d|0)){continue}break}En(e);x[e>>2]=0;a=(D(b,104)+a|0)+484414|0;w[a>>1]=z[a>>1]&65470;x[c+24>>2]=0;x[c+8>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Tp(e,0,c)}hb=c+32|0;return f>>>0<3999|0}function mga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=g;f=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=f;f=a;if(d){while(1){e=(x[b+12>>2]<<1)+j|0;a=w[e>>1];a=a+((D(w[e+2>>1]-a|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;x[c>>2]=x[c>>2]+D(a,i);x[c+4>>2]=x[c+4>>2]+D(a,h);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];g=x[b+12>>2]}x[f>>2]=e;x[f+4>>2]=g;hb=b+16|0}function hda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+8>>2]=x[a>>2];c=d+8|0;g=x[Mb(c,d+12|0)>>2];x[d+8>>2]=x[a>>2];x[d+4>>2]=x[d+12>>2]-g;h=x[Mb(c,d+4|0)>>2];c=Cb(b);if(g){e=x[a+20>>2];f=g;while(1){i=e,j=Cb(y[c|0])^128,v[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=Cb(b);if(h){c=b+x[a>>2]|0;e=x[a+20>>2]+1|0;f=h;while(1){i=e,j=Cb(y[c|0])^128,v[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}hb=d+16|0;return g+h|0}function gda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;x[e+12>>2]=c;x[e+8>>2]=x[a>>2];c=e+8|0;h=x[Mb(c,e+12|0)>>2];x[e+8>>2]=x[a>>2];x[e+4>>2]=x[e+12>>2]-h;i=x[Mb(c,e+4|0)>>2];c=Cb(b);if(h){f=x[a+20>>2];g=h;j=d;while(1){j=Cb(y[c|0])+j|0;v[f|0]=j;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}b=Cb(b);if(i){c=b+x[a>>2]|0;f=x[a+20>>2]+1|0;g=i;while(1){d=Cb(y[c|0])+d|0;v[f|0]=d;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}hb=e+16|0;return h+i|0}function Sw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-32|0;hb=e;x[e+24>>2]=b;j=e,k=ud(a),x[j+16>>2]=k;b=qm(e+24|0,e+16|0);h=hb-16|0;hb=h;a:{g=Bb(a);if(b>>>0<=g>>>0){if(c){f=Fc(a);b:{if(f-g>>>0>=c>>>0){f=Rb(a);if((b|0)==(g|0)){break b}i=b+f|0;fl(i+c|0,i,g-b|0);break b}$k(a,f,(c+g|0)-f|0,g,b,0,c);f=x[a>>2]}yn(b+f|0,c,d);c=c+g|0;Zg(a,c);v[h+15|0]=0;Wd(c+f|0,h+15|0)}hb=h+16|0;break a}om();p()}j=e,k=ud(a),x[j+8>>2]=k;a=Fe(e+8|0,b);hb=e+32|0;return a|0}function Cga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];f=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=f;j=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=j;if(d){while(1){e=x[b+8>>2];f=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+i|0;e=w[f+2>>1];x[c>>2]=x[c>>2]+D(w[f>>1],h);x[c+4>>2]=x[c+4>>2]+D(e,g);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];f=x[b+12>>2]}x[a>>2]=e;x[a+4>>2]=f;hb=b+16|0}function gE(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=hb-16|0;hb=i;if((b^-1)+1073741807>>>0>=c>>>0){k=Rb(a);if(b>>>0<536870887){x[i+12>>2]=b<<1;x[i>>2]=b+c;c=ql(x[_c(i,i+12|0)>>2])+1|0}else{c=1073741807}Zj(i,a,c);j=x[i>>2];if(e){Kh(j,k,e)}if(g){Kh(j+(e<<2)|0,h,g)}c=e+f|0;h=d-c|0;if((c|0)!=(d|0)){c=e<<2;Kh((c+j|0)+(g<<2)|0,(c+k|0)+(f<<2)|0,h)}b=b+1|0;if((b|0)!=2){Oo(k,b)}Ue(a,j);Ff(a,x[i+4>>2]);b=a;a=h+(e+g|0)|0;ae(b,a);x[i+12>>2]=0;ug(j+(a<<2)|0,i+12|0);hb=i+16|0;return}Ef();p()}function X1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;x[e+40>>2]=c;c=x[b+12>>2];x[e+32>>2]=x[b+8>>2];x[e+36>>2]=c;c=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=c;b=x[hp(e+16|0,e+40|0)>>2];x[114414]=0;c=x[e+36>>2];x[e+8>>2]=x[e+32>>2];x[e+12>>2]=c;c=x[e+28>>2];x[e>>2]=x[e+24>>2];x[e+4>>2]=c;Z(2046,a+8|0,e|0,b|0,d|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){a=WH(a);b=VH(a+88|0);x[a>>2]=83160;x[b>>2]=83248;pd(e+40|0);hb=e+48|0;return a|0}a=N()|0;pd(e+40|0);Q(a|0);p()}function GL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{if(y[b+813|0]!=27){a=v[b+851|0];break a}e=a+1074312|0;c=$b(e,21);d=a;a=y[b+841|0];a=ky(d,y[b+848|0],c?a:a+16>>>2|0);b:{if(!(!$b(e,45)|y[b+848|0]!=3)){c=y[b+841|0];c:{if(!(!c|c>>>0>=y[b+849|0])){a=y[b+852|0];d=c+1|0;break c}v[b+852|0]=a;d=1}v[b+841|0]=d;a=a<<24>>24;break b}v[b+841|0]=y[b+841|0]+y[b+849|0]}if(!$b(e,47)){break a}v[b+851|0]=a}if(a){f=b,g=Xb(x[b+684>>2]+((D(y[b+850|0],a)+2|0)/8|0)|0,0,256),x[f+684>>2]=g}}function SM(a,b){var c=0,d=0,e=0;a:{b:{if(!y[b+866|0]|x[a+480180>>2]!=1){break b}d=x[b+104>>2];if(!d){break b}if(!Be(d)|(z[d+34>>1]&3)!=2){break b}c=y[b+867|0]+y[(y[b+866|0]&15)+26496|0]|0;v[b+867|0]=c;if(c<<24>>24>=0){break b}v[b+867|0]=0;c=x[b+784>>2]+1|0;x[b+784>>2]=c>>>0<x[d+8>>2]-x[d+4>>2]>>>0?c:0;c=x[d+20>>2];x[114414]=0;c=R(417,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break a}b=Cb(c)+(x[b+784>>2]+x[d+4>>2]|0)|0;v[b|0]=y[b|0]^-1;oO(d,a,0)}return}S(0)|0;zb();p()}function Dga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];f=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=f;j=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=j;if(d){while(1){e=x[b+8>>2];f=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+i|0;e=v[f+1|0];x[c>>2]=x[c>>2]+(D(v[f|0],h)<<8);x[c+4>>2]=x[c+4>>2]+(D(e,g)<<8);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];f=x[b+12>>2]}x[a>>2]=e;x[a+4>>2]=f;hb=b+16|0}function Bba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=(b-a|0)/160|0;if((b|0)>0){while(1){x[a>>2]=x[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){e=hb-16|0;hb=e;f=x[c+4>>2];h=x[c+8>>2];g=Yi(f,h);a:{if(g>>>0<=pf(d)>>>0){if(wc(d)>>>0<g>>>0){x[e+12>>2]=f;NL(e+12|0,wc(d));Ke(f,x[e+12>>2],x[d>>2]);ML(d,x[e+12>>2],h,g-wc(d)|0);break a}aA(d,Ke(f,h,x[d>>2]));break a}Oy(d);Pk(d,Wh(d,g));ML(d,f,h,g)}hb=e+16|0}sc(a+16|0,c+16|0,144);a=a+160|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function ida(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+8>>2]=x[a>>2];c=d+8|0;g=x[Mb(c,d+12|0)>>2];x[d+8>>2]=x[a>>2];x[d+4>>2]=x[d+12>>2]-g;h=x[Mb(c,d+4|0)>>2];c=Cb(b);if(g){e=x[a+20>>2];f=g;while(1){i=e,j=bl(y[c|0]),v[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=Cb(b);if(h){c=b+x[a>>2]|0;e=x[a+20>>2]+1|0;f=h;while(1){i=e,j=bl(y[c|0]),v[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}hb=d+16|0;return g+h|0}function XN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=b;a:{if(Aj(a)){e=hb-16|0;hb=e;c=Me(3848);b=x[d+12>>2];x[114414]=0;f=O(1193,c|0,b|0)|0;b=x[114414];x[114414]=0;b:{if((b|0)!=1){c=hb-16|0;hb=c;x[114414]=0;x[c+12>>2]=f;b=U(1194,e+8|0,c+12|0,c+8|0)|0;f=x[114414];x[114414]=0;c:{if((f|0)!=1){hb=c+16|0;break c}S(0)|0;zb();p()}hb=e+16|0;b=x[b>>2];break b}a=N()|0;_b(c);Q(a|0);p()}x[d+8>>2]=b;b=d+8|0;Vs(a,b);dg(b);break a}_N(x[a>>2],b)}WN(a);hb=d+16|0}function Tla(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=hb-32|0;hb=f;x[f+16>>2]=e;x[f+24>>2]=d;e=Bb(a);d=Fc(a);a:{if(d-e>>>0>=b>>>0){d=Rb(a);if((c|0)==(e|0)){break a}g=c+d|0;fl(g+b|0,g,e-c|0);break a}$k(a,d,(b+e|0)-d|0,e,c,0,b);d=x[a>>2]}b=b+e|0;Zg(a,b);v[f+15|0]=0;Wd(b+d|0,f+15|0);if(Hb(f+24|0,f+16|0)){e=c+d|0;while(1){b=f+24|0;Wd(e,x[b>>2]);e=e+1|0;bg(b);if(Hb(b,f+16|0)){continue}break}}h=f,i=ud(a),x[h+8>>2]=i;a=Fe(f+8|0,c);hb=f+32|0;return a|0}function $ja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=x[b>>2];g=fT(b);b=hb-16|0;hb=b;e=Vt(d,g);a:{if(e>>>0<=vd(a)>>>0){if(Lb(a)>>>0<e>>>0){x[b+12>>2]=d;pR(b+12|0,Lb(a));Ke(d,x[b+12>>2],x[a>>2]);oR(a,x[b+12>>2],g,e-Lb(a)|0);break a}hv(a,Ke(d,g,x[a>>2]));break a}nR(a);c=ze(a,e);f=hb-16|0;hb=f;if(wk(a)>>>0<c>>>0){Vc();p()}kC(f+8|0,yb(a),c);c=x[f+8>>2];x[a+4>>2]=c;x[a>>2]=c;h=x[f+12>>2];i=yb(a),j=c+(h<<2)|0,x[i>>2]=j;vk(a,0);hb=f+16|0;oR(a,d,g,e)}hb=b+16|0}function mja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=hb-608|0;hb=f;b=hb-16|0;hb=b;c=b+8|0;e=f+8|0;BQ(c,e);d=Eb(c);c=nd(a,ac(b,c));if((d|0)==(c|0)){Yc(a,Eb(b+8|0))}hb=b+16|0;c=(c|0)==(d|0);if(!c){CQ(e)}b=-1;a:{if(!c){break a}b=0;if(!MQ(f+8|0)){break a}b=-1;if(!Yf(a,1024)){break a}b=0;e=hb-1024|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;Iz(d,e);g=Eb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;if((d|0)==(g|0)){b=Kz(e,0)>>>0<17}hb=e+1024|0}hb=f+608|0;return b|0}function YQ(a,b,c,d){var e=0,f=0;f=hb-16|0;hb=f;e=z[c>>1];while(1){a:{e=e<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!Oe(a,f+15|0)){break a}e=y[f+15|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;w[c>>1]=y[c|0]}v[d|0]=y[b|0]+(y[d|0]<<1);e=z[c>>1]<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!Oe(a,f+14|0)){break a}e=y[f+14|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;e=y[c|0];w[c>>1]=e;if(y[b|0]){continue}break a}if(y[b|0]){continue}}break}hb=f+16|0}function im(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=hb-16|0;hb=i;a:{b:{if(!a){break b}g=x[e+12>>2];h=c-b|0;if((h|0)>0){if((gm(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=Lj(i,b,f);g=Rb(f);x[114414]=0;g=U(31,a|0,g|0,b|0)|0;h=x[114414];x[114414]=0;if((h|0)==1){break a}xb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((gm(a,c,b)|0)!=(b|0)){break b}}uz(e);j=a}hb=i+16|0;return j|0}a=N()|0;xb(f);Q(a|0);p()}function UI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;d=Fc(a);a:{b:{c:{f=Yi(b,c);if(d>>>0<f>>>0){if(xx(a,b)){break c}g=d;h=f-d|0;d=Bb(a);$k(a,g,h,d,0,d,0)}d=Rb(a);if((b|0)!=(c|0)){while(1){Wd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}v[e+15|0]=0;Wd(d,e+15|0);Zg(a,f);break b}b=yi(e,b,c);c=Rb(b);d=Bb(b);x[114414]=0;U(120,a|0,c|0,d|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}xb(b)}hb=e+16|0;return a|0}a=N()|0;xb(b);Q(a|0);p()}function yF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=y[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=x[114240];x[114240]=0;a=Xv(a,e+12|0,d,ie());d=lb;g=x[114240];g:{if(g){if(x[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}x[114240]=h;if(x[e+12>>2]==(b|0)){break d}}}}x[c>>2]=4;a=0;break a}if(!d){break b}}x[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}hb=e+16|0;return a|0}function pl(a,b){a=a|0;b=b|0;var c=0;x[a>>2]=0;x[a+4>>2]=0;x[a+20>>2]=0;w[a+16>>1]=65535;x[a+8>>2]=0;x[a+12>>2]=0;x[a+24>>2]=11;x[a+28>>2]=b;jE(a+32|0);b=hb-16|0;hb=b;c=a+44|0;x[c>>2]=0;x[c+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(177,c+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;a:{if((c|0)!=1){hb=b+16|0;break a}S(0)|0;zb();p()}x[a+72>>2]=0;x[a+76>>2]=0;x[a+64>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;x[a+80>>2]=0;x[a+84>>2]=0;x[a+88>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;return a|0}function as(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!x[x[114284]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){v[a+1|0]=b&63|128;v[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){v[a+2|0]=b&63|128;v[a|0]=b>>>12|224;v[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){v[a+3|0]=b&63|128;v[a|0]=b>>>18|240;v[a+2|0]=b>>>6&63|128;v[a+1|0]=b>>>12&63|128;return 4}}x[114240]=25;a=-1}else{a=1}return a|0}v[a|0]=b;return 1}function fs(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==y[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}if(!(y[a|0]==(b&255)|c>>>0<4)){d=D(b&255,16843009);while(1){e=d^x[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==y[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=E(0),h=0,i=0;f=hb-16|0;hb=f;x[f+12>>2]=c>>>2;x[f+8>>2]=x[a>>2];d=x[Mb(f+12|0,f+8|0)>>2];c=Cb(b);if(d){b=x[a+20>>2];a=d;while(1){e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);g=de(E(nf((l(2,e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24)),r()),E(-1))*E(32768)));a:{if(E(F(g))<E(2147483648)){e=~~g;break a}e=-2147483648}h=b,i=Uc(e),w[h>>1]=i;b=b+2|0;c=c+4|0;a=a-1|0;if(a){continue}break}}hb=f+16|0;return d<<2}function lc(a,b){var c=0,d=0,e=0;a:{b:{c=x[a+1396>>2];if((c|0)>=0){if((b|0)>(c|0)){if((b|0)>24){return lc(a,24)+(lc(a,b-24|0)<<24)|0}if(!c){x[a+1392>>2]=0}while(1){d=js(a);if((d|0)==-1){break b}e=x[a+1396>>2];c=e+8|0;x[a+1396>>2]=c;x[a+1392>>2]=x[a+1392>>2]+(d<<e);if((b|0)>(c|0)){continue}break}}if((b|0)>(c|0)){break a}x[a+1396>>2]=c-b;c=a;a=x[a+1392>>2];x[c+1392>>2]=a>>>b;a=a&(-1<<b^-1)}else{a=0}return a}x[a+1396>>2]=-1;return 0}ea(6063,9049,1632,3155);p()}function C7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ai(a,b,c,d);x[a>>2]=79808;b=yk(a+4208|0);x[a+4240>>2]=0;x[a+4244>>2]=0;c=Ze(c);x[a+4260>>2]=0;x[a+4256>>2]=c;x[a+4236>>2]=0;c=a+4228|0;x[c>>2]=1048550822;x[c+4>>2]=1048550822;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;x[114414]=0;U(1673,a+44|0,2,2)|0;c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}x[114414]=0;W(1674,a|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}return a|0}c=N()|0;fg(b);xf(a);Q(c|0);p()}function xP(a){var b=0,c=0,d=0;a:{if((y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1179472976|y[a+28|0]!=26|y[a+30|0]>2){break a}b=a+40|0;if(y[b|0]|y[b+1|0]<<8){break a}b=a+38|0;c=y[b+1|0]<<8;if(!(y[b|0]|c)|(c|y[b|0])>>>0>32){break a}b=a+32|0;c=y[b+1|0]<<8;if(!(y[b|0]|c)|(c|y[b|0])>>>0>256){break a}b=a+34|0;c=y[b+1|0]<<8;if(!(y[b|0]|c)|(c|y[b|0])>>>0>255){break a}a=a+36|0;if(!(y[a|0]|y[a+1|0]<<8)){break a}d=(y[a|0]|y[a+1|0]<<8)>>>0<129}return d}function vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){f=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);l(0,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));l(1,f|0);g=Qd(Fg(+n())*32768);a:{if(F(g)<2147483648){f=~~g;break a}f=-2147483648}h=a,i=Uc(f),w[h>>1]=i;a=a+2|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<3}function qU(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=hb-32|0;hb=f;x[f+28>>2]=c;g=Qb(b,c<<1);a:{if(!g){break a}xc(f+28|0,65535);mg(a,z[f+28>>1]);h=f,i=bc(a),x[h+16>>2]=i;h=f,i=dc(a),x[h+8>>2]=i;if(!Hb(f+16|0,f+8|0)){break a}while(1){a=x[f+16>>2];c=f+24|0;Mu(b,c);c=y[c|0]|y[c+1|0]<<8;w[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}w[a>>1]=c}a=f+16|0;ge(a);if(Hb(a,f+8|0)){continue}break}}hb=f+32|0;return g|0}function b2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=E(0),h=0,i=0,j=0;e=hb-16|0;hb=e;i=x[a+4>>2];YH(a,b,c,d);g=B[a+24>>2];x[e+8>>2]=x[a+20>>2];b=x[a+16>>2];x[e>>2]=x[a+12>>2];x[e+4>>2]=b;a=hb-16|0;hb=a;x[a+8>>2]=x[e+8>>2];b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;b=0;if(!(!d|g==E(1))){while(1){if(c){j=b+i|0;f=0;while(1){h=Rf(a,f,j);B[h>>2]=B[h>>2]*g;f=f+1|0;if((f|0)!=(c|0)){continue}break}}b=b+1|0;if((d|0)!=(b|0)){continue}break}}hb=a+16|0;hb=e+16|0}function IS(a,b){a=a|0;b=b|0;var c=0,d=0;d=y[a+3|0];a:{if(d>>>0>18){break a}d=1<<d;b:{if(!(d&126991)){if(d&396800){break b}break a}if(!y[a|0]){break a}}c:{d:{e:{switch(y[a+3|0]){case 10:case 17:case 18:c=8;break d;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:c=y[a|0];if(!(c&7)){break d}case 11:c=b+1>>>1|0;b=(y[a+3|0]==11)<<4;break c;case 9:break e;default:break d}}c=16}c=D(c>>>3|0,b);b=(y[a+3|0]==11)<<4}c=b+D(BS(a),c)|0}return c|0}function Cv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,20);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0;hb=c+16|0}return a|0}function wT(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=x[a+1060>>2];if((b|0)>255){break a}while(1){f=(D(b,6)+a|0)+1068|0,g=Uj(a,7),v[f|0]=g;d=Uj(a,1);e=Uj(a,1);c=x[a+1056>>2];if((c|0)>255){break a}b=x[a+1060>>2]+1|0;x[a+1056>>2]=b;x[a+1060>>2]=b;b:{if(d){w[(D(c,6)+a|0)+1064>>1]=b;wT(a);b=x[a+1060>>2];break b}w[(D(c,6)+a|0)+1064>>1]=65535}x[a+1056>>2]=b;if(e){w[(D(c,6)+a|0)+1066>>1]=b;if((b|0)<=255){continue}break a}break}w[(D(c,6)+a|0)+1066>>1]=65535}}function lla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hg(a);if(d>>>0<b>>>0){e=hb-32|0;hb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=(x[yb(a)>>2]-x[a+4>>2]|0)/6>>>0){sA(a,d,c);break c}b=yb(a);b=$R(e+8|0,gA(a,hg(a)+d|0),hg(a),b);x[114414]=0;T(682,b|0,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(683,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}cu(b)}hb=e+32|0;break a}a=N()|0;cu(b);Q(a|0);p()}return}if(b>>>0<d>>>0){rA(a,x[a>>2]+D(b,6)|0)}}function Y5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;x[114414]=0;W(2048,a|0);h=x[114414];x[114414]=0;a:{b:{if((h|0)!=1){h=x[a+24>>2];x[114414]=0;b=qa(2065,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,8817,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function V5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;x[114414]=0;W(2048,a|0);h=x[114414];x[114414]=0;a:{b:{if((h|0)!=1){h=x[a+24>>2];x[114414]=0;b=qa(2068,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,8749,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function zka(a,b){a=a|0;b=b|0;var c=0,d=0;c=rd(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>4>>>0){MB(a,c);break c}b=yb(a);b=kr(d+8|0,lr(a,rd(a)+c|0),rd(a),b);x[114414]=0;P(735,b|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(581,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}mu(b)}hb=d+32|0;break a}a=N()|0;mu(b);Q(a|0);p()}return}if(b>>>0<c>>>0){b=x[a>>2]+(b<<4)|0;rd(a);yB(a,b);LD(a)}}function pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ue(a);if(d>>>0<b>>>0){e=hb-32|0;hb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=x[yb(a)>>2]-x[a+4>>2]>>5>>>0){ez(a,d,c);break c}b=yb(a);b=cr(e+8|0,xm(a,ue(a)+d|0),ue(a),b);x[114414]=0;T(1180,b|0,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(1167,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}ut(b)}hb=e+32|0;break a}a=N()|0;ut(b);Q(a|0);p()}return}if(b>>>0<d>>>0){dO(a,x[a>>2]+(b<<5)|0)}}function g_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;d=Bb(a);e=Fc(a);g=Yi(b,c);a:{if(!g){break a}b:{if(!xx(a,b)){if(e-d>>>0<g>>>0){$k(a,e,(d+g|0)-e|0,d,d,0,0)}e=Rb(a)+d|0;while(1){if((b|0)==(c|0)){break b}Wd(e,b);b=b+1|0;e=e+1|0;continue}}b=yi(f,b,c);c=Rb(b);d=Bb(b);x[114414]=0;U(2553,a|0,c|0,d|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){xb(b);break a}a=N()|0;xb(b);Q(a|0);p()}v[f+15|0]=0;Wd(e,f+15|0);Zg(a,d+g|0)}hb=f+16|0;return a|0}function LJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ai(a,b,c,d);x[a>>2]=79168;b=yk(a+4260|0);x[a+4232>>2]=1061997773;c=a+4224|0;x[c>>2]=1061158912;x[c+4>>2]=1059082943;c=a+4216|0;x[c>>2]=1038174126;x[c+4>>2]=1065353216;x[a+4208>>2]=1056964608;x[a+4212>>2]=1036831949;x[114414]=0;U(1673,a+44|0,2,2)|0;c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}x[114414]=0;W(1674,a|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}return a|0}c=N()|0;fg(b);xf(a);Q(c|0);p()}function wo(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=hb-16|0;hb=i;if((b^-1)+2147483631>>>0>=c>>>0){k=Rb(a);if(b>>>0<1073741799){x[i+12>>2]=b<<1;x[i>>2]=b+c;c=cj(x[_c(i,i+12|0)>>2])+1|0}else{c=2147483631}Gh(i,a,c);j=x[i>>2];if(e){Le(j,k,e)}if(g){Le(e+j|0,h,g)}c=e+f|0;h=d-c|0;if((c|0)!=(d|0)){Le((e+j|0)+g|0,(e+k|0)+f|0,h)}b=b+1|0;if((b|0)!=11){ag(a,k,b)}Ue(a,j);Ff(a,x[i+4>>2]);b=a;a=h+(e+g|0)|0;ae(b,a);v[i+12|0]=0;Wd(a+j|0,i+12|0);hb=i+16|0;return}Ef();p()}function EK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Lb(a);if(d>>>0<b>>>0){e=hb-32|0;hb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=x[yb(a)>>2]-x[a+4>>2]>>2>>>0){Mx(a,d,c);break c}b=yb(a);b=Nf(e+8|0,ze(a,Lb(a)+d|0),Lb(a),b);x[114414]=0;T(1624,b|0,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(1625,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}pn(b)}hb=e+32|0;break a}a=N()|0;pn(b);Q(a|0);p()}return}if(b>>>0<d>>>0){Ox(a,x[a>>2]+(b<<2)|0)}}function I_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-256|0;hb=a;x[a+248>>2]=37;x[a+252>>2]=0;g=a+248|0;hk(g|1,6568,1,x[c+4>>2]);h=ie();x[a>>2]=e;x[a+4>>2]=f;e=a+224|0;f=ff(e,24,h,g,a)+e|0;g=vg(e,f,c);h=a+16|0;Dc(h,c);x[114414]=0;fa(2534,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=x[114414];x[114414]=0;a:{if((e|0)!=1){Ob(a+16|0);b=Sm(b,a+32|0,x[a+28>>2],x[a+24>>2],c,d);hb=a+256|0;break a}b=N()|0;Ob(a+16|0);Q(b|0);p()}return b|0}function G_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-256|0;hb=a;x[a+248>>2]=37;x[a+252>>2]=0;g=a+248|0;hk(g|1,6568,0,x[c+4>>2]);h=ie();x[a>>2]=e;x[a+4>>2]=f;e=a+224|0;f=ff(e,24,h,g,a)+e|0;g=vg(e,f,c);h=a+16|0;Dc(h,c);x[114414]=0;fa(2534,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=x[114414];x[114414]=0;a:{if((e|0)!=1){Ob(a+16|0);b=Sm(b,a+32|0,x[a+28>>2],x[a+24>>2],c,d);hb=a+256|0;break a}b=N()|0;Ob(a+16|0);Q(b|0);p()}return b|0}function EN(a,b){var c=0,d=0,e=0;w[a+24>>1]=0;x[a+20>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;d=3546895/+(b>>>0);c=d*.25;a:{if(F(c)<2147483648){b=~~c;break a}b=-2147483648}x[a+16>>2]=b;c=(d-+(b<<2))*4294967296;b:{if(F(c)<0x8000000000000000){e=~~c>>>0;b=F(c)>=1?~~(c>0?H(J(c*2.3283064365386963e-10),4294967295):K((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break b}b=-2147483648}x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=e;x[a+12>>2]=b;return a}function T_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-112|0;hb=a;x[a+104>>2]=37;x[a+108>>2]=0;g=a+104|0;hk(g|1,6568,1,x[c+4>>2]);h=ie();x[a>>2]=e;x[a+4>>2]=f;e=a+80|0;f=ff(e,24,h,g,a)+e|0;g=vg(e,f,c);h=a+16|0;Dc(h,c);x[114414]=0;fa(2525,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=x[114414];x[114414]=0;a:{if((e|0)!=1){Ob(a+16|0);b=im(b,a+32|0,x[a+28>>2],x[a+24>>2],c,d);hb=a+112|0;break a}b=N()|0;Ob(a+16|0);Q(b|0);p()}return b|0}function R_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-112|0;hb=a;x[a+104>>2]=37;x[a+108>>2]=0;g=a+104|0;hk(g|1,6568,0,x[c+4>>2]);h=ie();x[a>>2]=e;x[a+4>>2]=f;e=a+80|0;f=ff(e,24,h,g,a)+e|0;g=vg(e,f,c);h=a+16|0;Dc(h,c);x[114414]=0;fa(2525,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=x[114414];x[114414]=0;a:{if((e|0)!=1){Ob(a+16|0);b=im(b,a+32|0,x[a+28>>2],x[a+24>>2],c,d);hb=a+112|0;break a}b=N()|0;Ob(a+16|0);Q(b|0);p()}return b|0}function AK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=b;a:{if(vd(a)>>>0>=b>>>0){f=d,g=Lb(a),x[f+8>>2]=g;b=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];if(e){while(1){B[b>>2]=B[c>>2];b=b+4|0;e=e-1|0;if(e){continue}break}}b=x[d+12>>2];e=x[d+8>>2];if(b>>>0>e>>>0){Mx(a,b-e|0,c);break a}Ox(a,x[a>>2]+(b<<2)|0);break a}if(x[a>>2]){Di(a);Xe(yb(a),x[a>>2],vd(a));f=yb(a),g=0,x[f>>2]=g;x[a>>2]=0;x[a+4>>2]=0}ho(a,ze(a,b));Mx(a,b,c)}hb=d+16|0}function nm(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=hb-32|0;hb=d;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d+12>>2]=c;a:{if(c){while(1){x[d+8>>2]=16;f=0;e=x[Mb(d+8|0,d+12|0)>>2];h=x[a>>2];if((e|0)!=((j=h,k=Cb(d+16|0),l=x[a+8>>2]+g|0,m=e,i=x[x[h>>2]+28>>2],mb[i](j|0,k|0,l|0,m|0)|0)|0)){break a}if(cd(d+16|0,b+g|0,e)){break a}f=x[d+12>>2];x[d+12>>2]=f-e;g=e+g|0;if((e|0)!=(f|0)){continue}break}}cc(a,c);f=1}hb=d+32|0;return f}function a1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;x[d+16>>2]=b;e=x[a+48>>2];x[d+20>>2]=c-((e|0)!=0);g=x[a+44>>2];x[d+28>>2]=e;x[d+24>>2]=g;a:{b:{if(bs(Pa(x[a+60>>2],d+16|0,2,d+12|0)|0)){b=32}else{e=x[d+12>>2];if((e|0)>0){break b}b=e?32:16}x[a>>2]=b|x[a>>2];break a}f=e;g=x[d+20>>2];if(g>>>0>=e>>>0){break a}f=x[a+44>>2];x[a+4>>2]=f;x[a+8>>2]=f+(e-g|0);if(x[a+48>>2]){x[a+4>>2]=f+1;v[(b+c|0)-1|0]=y[f|0]}f=c}hb=d+32|0;return f|0}function S4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;x[114414]=0;W(2121,a|0);f=x[114414];x[114414]=0;a:{b:{if((f|0)!=1){f=x[a+28>>2];g=x[x[f>>2]+72>>2];x[114414]=0;b=_a(g|0,f|0,b|0,c|0,+d,+e)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,7178,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=-1}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function PS(a){var b=0,c=0,d=0;a:{if((y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24))!=808537417){break a}b=a+32|0;if((y[b|0]|y[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if(y[a+49|0]<32|(y[b|0]|y[b+1|0]<<8)>>>0>255|y[a+50|0]>64){break a}b=a+51|0;if(y[b|0]<4|v[b|0]<0){break a}d=a+576|0;a=a- -64|0;b=0;while(1){c=0;b:{switch(y[a+15|0]){case 0:case 1:b=1;break;case 2:break b;default:break a}}c=b;a=a+16|0;if((d|0)!=(a|0)){continue}break}}return c&1}function Hma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;Xc(a+8|0);if(b){sq(a,b);e=hb-16|0;hb=e;a:{b:{b=rq(e,a,b);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;P(531,f|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break b}c=c+6|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break a}a=N()|0;Jb(b);Q(a|0);p()}}hb=d+16|0;v[a+16|0]=6;x[a+12>>2]=2015363072;return a|0}function mx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!ws(b)){break a}a=a+24|0;if(!kg(x[a>>2]+484344|0,b&65535)){break a}b=Zb(x[a>>2]+484344|0,b);if((d|0)<0|x[b+12>>2]<=(c|0)|(c|0)<0|(z[x[a>>2]+480188>>1]<=d>>>0|e>>>0>5)){break a}b=Df(b,c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}f=y[b|0]}return f|0}function Kc(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;if(x[a+4>>2]==x[b+4>>2]){c=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=c;x[d+8>>2]=b;x[d+12>>2]=c;b=hb-16|0;hb=b;x[b+12>>2]=x[a+4>>2];c=x[d+4>>2];x[114414]=0;x[b+8>>2]=c;c=O(35,b+12|0,b+8|0)|0;e=x[114414];x[114414]=0;a:{if((e|0)!=1){c=on(x[a>>2],x[d>>2],x[c>>2]);b:{if(c){break b}c=0;if(x[a+4>>2]==x[d+4>>2]){break b}c=A[a+4>>2]<A[d+4>>2]?-1:1}hb=b+16|0;break a}S(0)|0;zb();p()}c=!c}hb=d+16|0;return c}function r2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;f=x[c+12>>2];a:{if(!f){break a}c=y[c+16|0];e=Bb(b);if(!e){break a}g=e-1|0;h=c<<24>>24;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(g|0)){if(y[pc(b,0)|0]==43){break b}if(y[pc(b,0)|0]==45){break b}}i=d,j=ud(b),x[i+8>>2]=j;i=d,j=Fe(d+8|0,e-c|0),x[i+16>>2]=j;Sw(b,x[td(d+24|0,d+16|0)>>2],1,h)}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Jd(a,b);hb=d+32|0}function Ld(a){var b=0,c=0,d=0;d=Yo(wf(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){b=y[a|0];break b}if(a&3){while(1){b=y[a|0];v[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=x[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){x[c>>2]=b;b=x[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}v[c|0]=b;if(!(b&255)){break a}while(1){b=y[a+1|0];v[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function Aba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;f=a+1304392|0;if(!zd(f)){d=hb-16|0;hb=d;b=Me(532);a=x[a+24620>>2];x[114414]=0;a=O(1433,b|0,a|0)|0;e=x[114414];x[114414]=0;a:{if((e|0)!=1){b=hb-16|0;hb=b;x[114414]=0;x[b+12>>2]=a;a=U(1436,d+8|0,b+12|0,b+8|0)|0;e=x[114414];x[114414]=0;b:{if((e|0)!=1){hb=b+16|0;break b}S(0)|0;zb();p()}hb=d+16|0;a=x[a>>2];break a}a=N()|0;_b(b);Q(a|0);p()}x[c+8>>2]=a;a=c+8|0;hM(f,ke(a));xy(a)}hb=c+16|0}function pla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=wc(a);if(d>>>0<b>>>0){e=hb-32|0;hb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=x[yb(a)>>2]-x[a+4>>2]>>>0){qq(a,d,c);break c}b=yb(a);b=Yh(e+8|0,Wh(a,wc(a)+d|0),wc(a),b);x[114414]=0;T(677,b|0,d|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(328,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}Ah(b)}hb=e+32|0;break a}a=N()|0;Ah(b);Q(a|0);p()}return}if(b>>>0<d>>>0){kv(a,x[a>>2]+b|0)}}function zx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=hb-32|0;hb=d;x[d+16>>2]=c;x[d+24>>2]=b;k=d,l=ud(a),x[k+8>>2]=l;b=d+24|0;h=d+8|0;f=qm(b,h);b=qm(d+16|0,b);a:{if(Bb(a)>>>0>=f>>>0){if((b|0)==-1){jC(a,f);break a}e=hb-16|0;hb=e;x[e+12>>2]=b;if(b){c=Bb(a);i=Rb(a);b=c-f|0;x[e+8>>2]=b;g=x[Mb(e+12|0,e+8|0)>>2];x[e+12>>2]=g;if((b|0)!=(g|0)){j=f+i|0;fl(j,g+j|0,b-g|0);b=x[e+12>>2]}Wu(a,i,c-b|0)}hb=e+16|0;break a}om();p()}Fe(h,f);hb=d+32|0}function hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=E(0),h=E(0),i=0,j=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>2;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];h=B[d>>2];c=Cb(b);if(f){a=x[a+20>>2];d=f;while(1){g=de(E(nf(E((l(2,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),r())*h),E(-1))*E(32768)));a:{if(E(F(g))<E(2147483648)){b=~~g;break a}b=-2147483648}i=a,j=Uc(b),w[i>>1]=j;a=a+2|0;c=c+4|0;d=d-1|0;if(d){continue}break}}hb=e+16|0;return f<<2}function Faa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;e=$x(a);a:{b:{c:{d:{while(1){x[114414]=0;a=O(226,b|0,8)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}if(!a){break c}x[114414]=0;T(1567,d+8|0,b|0,c|0);a=x[114414];x[114414]=0;if((a|0)!=1){x[114414]=0;P(1568,e|0,d+8|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}me(d+8|0);continue}break}a=N()|0;break a}a=N()|0;me(d+8|0);break a}hb=d+32|0;return}a=N()|0}Ml(e);Q(a|0);p()}function V4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[114414]=0;W(2121,a|0);e=x[114414];x[114414]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+12>>2];x[114414]=0;b=Z(f|0,e|0,b|0,c|0,d|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,7323,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=-1}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function xia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;e=yz(a);a:{b:{c:{d:{while(1){x[114414]=0;a=O(226,b|0,8)|0;f=x[114414];x[114414]=0;if((f|0)==1){break b}if(!a){break c}x[114414]=0;T(942,d+8|0,b|0,c|0);a=x[114414];x[114414]=0;if((a|0)!=1){x[114414]=0;P(943,e|0,d+8|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}me(d+8|0);continue}break}a=N()|0;break a}a=N()|0;me(d+8|0);break a}hb=d+32|0;return}a=N()|0}Yl(e);Q(a|0);p()}function cC(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if((y[a|0]|y[a+1|0]<<8)!=26217){if((y[a|0]|y[a+1|0]<<8)!=20042){break a}if(y[a+110|0]<=64){break b}break a}if(y[a+110|0]>64){break a}}c:{if(v[a+112|0]<0|y[a+111|0]>128){break c}c=v[a+113|0];if((c|0)<-2){break c}while(1){d=a+b|0;e=y[d+241|0];if(!e&c<<24>>24>=0|e>>>0>15|y[d+369|0]>=64){break a}f=b>>>0>126;b=b+1|0;if((b|0)==128){break a}c=v[(a+b|0)+113|0];if((c|0)>=-2){continue}break}}}return f}function by(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-48|0;hb=e;a:{if(!c){b=vc(a,b);a=x[d+12>>2];x[b+8>>2]=x[d+8>>2];x[b+12>>2]=a;a=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=a;break a}f=x[d+12>>2];x[e+24>>2]=x[d+8>>2];x[e+28>>2]=f;f=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=f;f=c>>>1|0;by(a,b,f,e+16|0);Rh(e+32|0,d,vc(a,c));d=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=d;d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;by(a,b|c,f,e)}hb=e+48|0}function U4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[114414]=0;W(2121,a|0);e=x[114414];x[114414]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+8>>2];x[114414]=0;b=Z(f|0,e|0,b|0,c|0,d|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,7359,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=-1}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function s4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;Dc(a,b);x[114414]=0;T(127,d+8|0,b|0,c|0);e=x[114414];x[114414]=0;a:{if((e|0)==1){break a}Ob(d+8|0);x[114414]=0;e=R(30,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break a}if(e){x[114414]=0;b=R(30,b|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break a}x[114414]=0;T(128,d|0,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}Ob(d)}hb=d+16|0;return}b=N()|0;Ob(a);Q(b|0);p()}function TK(a,b){var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){c=hb-16|0;hb=c;f=x[b+4>>2];d=x[b>>2];e=(f-d|0)/6|0;a:{if(e>>>0<=Vi(a)>>>0){if(hg(a)>>>0<e>>>0){x[c+12>>2]=d;g=hg(a);x[c+12>>2]=x[c+12>>2]+D(g,6);PK(d,x[c+12>>2],x[a>>2]);Ux(a,x[c+12>>2],f,e-hg(a)|0);break a}rA(a,PK(d,f,x[a>>2]));break a}QK(a);sq(a,gA(a,e));Ux(a,d,f,e)}hb=c+16|0}x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=x[b+20>>2];SK(a+24|0,b+24|0);gj(a+36|0,b+36|0)}function Q4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[114414]=0;W(2121,a|0);d=x[114414];x[114414]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+64>>2];x[114414]=0;T(f|0,d|0,b|0,(c|0)!=0|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,2989,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();e=0}return e|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function O4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[114414]=0;W(2121,a|0);d=x[114414];x[114414]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+56>>2];x[114414]=0;T(f|0,d|0,b|0,(c|0)!=0|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,3043,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();e=0}return e|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function PB(a,b){a=a|0;b=b|0;var c=0,d=0;c=qc(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>1>>>0){DB(a,c);break c}b=yb(a);b=to(d+8|0,$i(a,qc(a)+c|0),qc(a),b);x[114414]=0;P(367,b|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(345,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}Oj(b)}hb=d+32|0;break a}a=N()|0;Oj(b);Q(a|0);p()}return}if(b>>>0<c>>>0){ko(a,x[a>>2]+(b<<1)|0)}}function Fu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=hb-32|0;hb=d;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d+12>>2]=c;a:{if(c){while(1){x[d+8>>2]=16;f=0;e=x[Mb(d+8|0,d+12|0)>>2];if((e|0)!=((i=a,j=Cb(d+16|0),k=x[a+12>>2]+g|0,l=e,h=x[x[a>>2]+28>>2],mb[h](i|0,j|0,k|0,l|0)|0)|0)){break a}if(cd(d+16|0,b+g|0,e)){break a}f=x[d+12>>2];x[d+12>>2]=f-e;g=e+g|0;if((e|0)!=(f|0)){continue}break}}Yc(a,c);f=1}hb=d+32|0;return f}function xI(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-144|0;hb=d;c=lh(d+8|0);e=x[x[c>>2]-12>>2];x[114414]=0;f=$(121)|0;g=x[114414];x[114414]=0;a:{if((g|0)==1){break a}x[114414]=0;T(122,d|0,c+e|0,f|0);e=x[114414];x[114414]=0;if((e|0)==1){break a}Ob(d);x[114414]=0;P(131,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}x[114414]=0;P(124,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Xd(c);hb=d+144|0;return}a=N()|0;Xd(c);Q(a|0);p()}function wx(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-144|0;hb=d;c=lh(d+8|0);e=x[x[c>>2]-12>>2];x[114414]=0;f=$(121)|0;g=x[114414];x[114414]=0;a:{if((g|0)==1){break a}x[114414]=0;T(122,d|0,c+e|0,f|0);e=x[114414];x[114414]=0;if((e|0)==1){break a}Ob(d);x[114414]=0;P(123,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}x[114414]=0;P(124,a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Xd(c);hb=d+144|0;return}a=N()|0;Xd(c);Q(a|0);p()}function tW(a,b){a=a|0;b=b|0;var c=0;a=hd(a);a:{if(y[b+16|0]){x[114414]=0;O(203,a|0,1452)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}}if(y[b+17|0]){x[114414]=0;O(203,a|0,8355)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}}if(Wc(a)){x[114414]=0;O(203,a|0,6053)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}}if(y[b+18|0]){x[114414]=0;O(203,a|0,7006)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}}return}b=N()|0;xb(a);Q(b|0);p()}function ly(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{if(!Dj(b)){c=BM(a,c,x[b+704>>2],d);break a}c=x[b+700>>2]}x[e+12>>2]=c;b=x[b+656>>2];b:{if(!b){break b}d=x[b+40>>2];if(!d){break b}b=(d|0)/2|0;f=x[a+1074420>>2];f=yna(f,f>>31,c,c>>31);c=b+f|0;b=lb+(b>>31)|0;g=e,h=Cc(zna(c,c>>>0<f>>>0?b+1|0:b,d,d>>31),lb),x[g+12>>2]=h}xc(e+12|0,2147483647);c=x[a+24620>>2]<<4;a=zna(0,x[e+12>>2],c,0);hb=e+16|0;return a|0}function K_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=hb-160|0;hb=a;x[a+152>>2]=37;x[a+156>>2]=0;f=a+152|0;hk(f|1,6727,1,x[c+4>>2]);g=ie();x[a>>2]=e;e=a+139|0;f=ff(e,13,g,f,a)+e|0;g=vg(e,f,c);h=a+16|0;Dc(h,c);x[114414]=0;fa(2534,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=x[114414];x[114414]=0;a:{if((e|0)!=1){Ob(a+16|0);b=Sm(b,a+32|0,x[a+28>>2],x[a+24>>2],c,d);hb=a+160|0;break a}b=N()|0;Ob(a+16|0);Q(b|0);p()}return b|0}function H_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=hb-160|0;hb=a;x[a+152>>2]=37;x[a+156>>2]=0;f=a+152|0;hk(f|1,6727,0,x[c+4>>2]);g=ie();x[a>>2]=e;e=a+139|0;f=ff(e,13,g,f,a)+e|0;g=vg(e,f,c);h=a+16|0;Dc(h,c);x[114414]=0;fa(2534,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=x[114414];x[114414]=0;a:{if((e|0)!=1){Ob(a+16|0);b=Sm(b,a+32|0,x[a+28>>2],x[a+24>>2],c,d);hb=a+160|0;break a}b=N()|0;Ob(a+16|0);Q(b|0);p()}return b|0}function SF(a,b,c,d,e){var f=0,g=0,h=0;h=-1;g=d&2147483647;f=(g|0)==2147418112;a:{if(f&!c?a|b:f&(c|0)!=0|g>>>0>2147418112){break a}f=e&2147483647;if(((f|0)==2147418112&0|f>>>0>2147418112)&(f|0)!=2147418112){break a}if(!(a|c|(f|g|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(((c|0)!=0|(d|0)!=(e|0))&(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function yka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,18);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0;hb=c+16|0}return a|0}function vY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}g=1;f=hb-16|0;hb=f;x[f+12>>2]=x[a+8>>2];i=Hh(f+8|0,f+12|0);x[114414]=0;j=BF(c,d-c|0,b);l=x[114414];x[114414]=0;b:{if((l|0)!=1){Ne(i);hb=f+16|0;break b}a=N()|0;Ne(i);Q(a|0);p()}c:{switch(j+2|0){default:g=j;break;case 0:case 1:break a;case 2:break c}}h=h+1|0;k=g+k|0;c=c+g|0;continue}break}return k|0}function Ve(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;i=yna(b,c,h,i);h=lb;e=yna(d,e,f,g);i=e+i|0;d=lb+h|0;h=e>>>0>i>>>0?d+1|0:d;j=g;e=0;k=c;d=0;c=yna(g,e,c,d);g=c+i|0;i=lb+h|0;l=g;c=c>>>0>g>>>0?i+1|0:i;g=yna(f,0,b,0);h=lb;i=0;d=yna(f,i,k,d);h=h+d|0;f=lb+i|0;f=d>>>0>h>>>0?f+1|0:f;i=f+l|0;d=c;f=f>>>0>i>>>0?d+1|0:d;c=yna(b,m,j,e)+h|0;e=lb;e=c>>>0<h>>>0?e+1|0:e;h=e+i|0;i=f;x[a+8>>2]=h;x[a+12>>2]=e>>>0>h>>>0?i+1|0:i;x[a>>2]=g;x[a+4>>2]=c}function $W(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;x[114414]=0;m=a;a=0;a=WD(2039,m|a,b,c,d,a|e,f);b=x[114414];x[114414]=0;a:{b:{if((b|0)==1){Y(S(0)|0)|0;x[114414]=0;fa(2034,4964,g|0,h|0,i|0,j|0,k|0,l|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}_();a=-255}break a}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}return a|0}function Eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;x[d+12>>2]=c;e=bc(b);f=dc(b);c=hb-32|0;hb=c;x[c+16>>2]=f;x[c+24>>2]=e;x[c+8>>2]=d+12;a:{if(!Hb(c+24|0,c+16|0)){break a}while(1){e=x[c+24>>2];if(x[x[c+8>>2]>>2]==(y[e|0]|y[e+1|0]<<8)){break a}e=c+24|0;Xi(e);if(Hb(e,c+16|0)){continue}break}}hb=c+32|0;x[d+8>>2]=x[c+24>>2];g=d,h=dc(b),x[g>>2]=h;b:{if(Hb(d+8|0,d)){df(a,yb(x[d+8>>2]));break b}ci(a)}hb=d+16|0}function n5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[114414]=0;W(2048,a|0);f=x[114414];x[114414]=0;a:{b:{if((f|0)!=1){f=x[a+24>>2];x[114414]=0;b=aa(2103,f|0,b|0,c|0,d|0,e|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,8233,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function Z5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[114414]=0;W(2048,a|0);f=x[114414];x[114414]=0;a:{b:{if((f|0)!=1){f=x[a+24>>2];x[114414]=0;b=aa(2064,f|0,b|0,c|0,d|0,e|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,5610,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function W5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[114414]=0;W(2048,a|0);f=x[114414];x[114414]=0;a:{b:{if((f|0)!=1){f=x[a+24>>2];x[114414]=0;b=aa(2067,f|0,b|0,c|0,d|0,e|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,5538,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function M4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[114414]=0;W(2121,a|0);d=x[114414];x[114414]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+48>>2];x[114414]=0;ab(f|0,d|0,b|0,+c);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,7522,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();e=0}return e|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function V_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=hb-80|0;hb=a;x[a+72>>2]=37;x[a+76>>2]=0;f=a+72|0;hk(f|1,6727,1,x[c+4>>2]);g=ie();x[a>>2]=e;e=a+59|0;f=ff(e,13,g,f,a)+e|0;g=vg(e,f,c);h=a+16|0;Dc(h,c);x[114414]=0;fa(2525,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=x[114414];x[114414]=0;a:{if((e|0)!=1){Ob(a+16|0);b=im(b,a+32|0,x[a+28>>2],x[a+24>>2],c,d);hb=a+80|0;break a}b=N()|0;Ob(a+16|0);Q(b|0);p()}return b|0}function S_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=hb-80|0;hb=a;x[a+72>>2]=37;x[a+76>>2]=0;f=a+72|0;hk(f|1,6727,0,x[c+4>>2]);g=ie();x[a>>2]=e;e=a+59|0;f=ff(e,13,g,f,a)+e|0;g=vg(e,f,c);h=a+16|0;Dc(h,c);x[114414]=0;fa(2525,e|0,g|0,f|0,a+32|0,a+28|0,a+24|0,h|0);e=x[114414];x[114414]=0;a:{if((e|0)!=1){Ob(a+16|0);b=im(b,a+32|0,x[a+28>>2],x[a+24>>2],c,d);hb=a+80|0;break a}b=N()|0;Ob(a+16|0);Q(b|0);p()}return b|0}function Rt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=(y[gc(a,0)|0]&15)<<8|y[gc(a,1)|0];a:{if(!d|(d|0)==4095){break a}e=108;while(1){f=z[(c<<1)+25936>>1];if(f>>>0<=d>>>0){if(!(!c|(d|0)==(f|0)|(z[(c<<1)+25934>>1]-d|0)>=(d-f|0))){e=c+24|0;break a}e=c+25|0;break a}c=c+1|0;if(c>>>0<84){continue}break}}v[b|0]=e;c=y[gc(a,2)|0];g=b,h=y[gc(a,0)|0]&16|c>>>4,v[g+1|0]=h;g=b,h=y[gc(a,2)|0]&15,v[g+3|0]=h;g=b,h=y[gc(a,3)|0],v[g+5|0]=h}function R7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ai(a,b,c,d);x[a>>2]=79400;b=yk(a+4256|0);c=a+4224|0;x[c>>2]=1017370378;x[c+4>>2]=1065353216;c=a+4216|0;x[c>>2]=1028670828;x[c+4>>2]=1059760811;x[a+4208>>2]=1056964608;x[a+4212>>2]=1017370378;x[114414]=0;U(1673,a+44|0,2,2)|0;c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}x[114414]=0;W(1674,a|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}return a|0}c=N()|0;fg(b);xf(a);Q(c|0);p()}function M6(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;v[a+4202|0]=1;b=Li(E(E(Ze(x[a+16>>2])>>>0)*E(.04500000178813934)));c=Li(E(E(b>>>0)*E(1.1892070770263672)));d=Li(E(E(c>>>0)*E(1.1892070770263672)));g=Li(E(E(d>>>0)*E(1.1892070770263672)));e=Li(E(E(b+d>>>0)*E(.11546666920185089)));f=Li(E(E(c+g>>>0)*E(.11546666920185089)));x[a+4292>>2]=f;x[a+4288>>2]=e;x[a+4276>>2]=d-e;x[a+4272>>2]=b-e;x[a+4284>>2]=g-f;x[a+4280>>2]=c-f;kJ(a);iJ(a)}function L3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=hb-16|0;hb=h;a:{b:{c:{if(g?!f|(!d|!e):1){b=ec(8);x[114414]=0;c=O(118,h|0,4405)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}wi(a,b,4);c=qx(a,c,d,e,f,g);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=h+16|0;return c|0}a=N()|0;hc(b)}Q(a|0)}p()}function I3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=hb-16|0;hb=h;a:{b:{c:{if(g?!f|(!d|!e):1){b=ec(8);x[114414]=0;c=O(118,h|0,4405)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}wi(a,b,4);c=px(a,c,d,e,f,g);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=h+16|0;return c|0}a=N()|0;hc(b)}Q(a|0)}p()}function Ok(a,b){a=a|0;b=b|0;var c=0,d=0;c=wc(a);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=x[yb(a)>>2]-x[a+4>>2]>>>0){GR(a,c);break c}b=yb(a);b=Yh(d+8|0,Wh(a,wc(a)+c|0),wc(a),b);x[114414]=0;P(42,b|0,c|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;P(41,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}uu(b)}hb=d+32|0;break a}a=N()|0;uu(b);Q(a|0);p()}return}if(b>>>0<c>>>0){aA(a,x[a>>2]+b|0)}}function mB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[a>>2]=0;x[a+4>>2]=0;x[e+12>>2]=0;Xc(a+8|0);if(b){Pk(a,b);f=hb-16|0;hb=f;a:{b:{b=th(f,a,b);d=x[b+4>>2];h=x[b+8>>2];if((d|0)!=(h|0)){while(1){g=yb(a);x[114414]=0;T(331,g|0,d|0,c|0);g=x[114414];x[114414]=0;if((g|0)==1){break b}d=d+1|0;x[b+4>>2]=d;if((d|0)!=(h|0)){continue}break}}Jb(b);hb=f+16|0;break a}a=N()|0;Jb(b);Q(a|0);p()}}hb=e+16|0;return a|0}function Uy(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;xi(d+8|0,c);a=hb-16|0;hb=a;c=x[d+12>>2];x[a+8>>2]=x[d+8>>2];x[a+12>>2]=c;g=a,h=Bb(b),x[g+4>>2]=h;x[a>>2]=x[a+12>>2];b=Rb(b);c=x[a+8>>2];x[114414]=0;e=O(35,a+4|0,a|0)|0;f=x[114414];x[114414]=0;a:{if((f|0)!=1){b=on(b,c,x[e>>2]);b:{if(b){break b}b=-1;c=x[a+4>>2];e=x[a>>2];if(c>>>0<e>>>0){break b}b=c>>>0>e>>>0}hb=a+16|0;break a}S(0)|0;zb();p()}hb=d+16|0;return b>>>31|0}function Iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;x[e+24>>2]=b;d=hb-16|0;hb=d;x[d>>2]=c;x[d+8>>2]=b;b=Zt(d,d+8|0);hb=d+16|0;a:{b=bi(e+8|0,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];d=x[b>>2];f=x[e+24>>2];x[114414]=0;T(741,c|0,d|0,f|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}x[b>>2]=x[b>>2]+4;fe(e+24|0);if(x[b>>2]!=x[b+4>>2]){continue}break}}Ac(b);hb=e+32|0;return}a=N()|0;Ac(b);Q(a|0);p()}function hW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-32|0;hb=b;c=hb-16|0;hb=c;d=c+8|0;e=b+16|0;hD(d,e);f=Eb(d);d=nd(a,ac(c,d));if((f|0)==(d|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;d=(d|0)==(f|0);if(!d){iD(e)}c=-1;a:{if(!d){break a}c=0;if(!yD(b+16|0)){break a}c=hb-16|0;hb=c;d=c+8|0;fD(d,b);e=Eb(d);d=nd(a,ac(c,d));if((e|0)==(d|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){gD(b)}c=-1;if(!a){break a}c=xD(b)}hb=b+32|0;return c|0}function Ns(a){var b=0,c=0,d=0;b=y[a+4266|0];B[a+4236>>2]=E(b>>>0)*E(.00390625);B[a+4240>>2]=E(256-b|0)*E(.00390625);c=y[a+4267|0];b=y[a+4265|0];B[a+4244>>2]=E(D(c,b)|0)*E(152587890625e-16);d=c|-256;B[a+4256>>2]=E(D(d,b|-256)|0)*E(152587890625e-16);B[a+4252>>2]=E(D(b,d)|0)*E(152587890625e-16);B[a+4248>>2]=E(D(256-b|0,c)|0)*E(152587890625e-16);b=a;c=x[a+4232>>2];a=y[a+4264|0];x[b+4228>>2]=(D(c,(a?a:-89)&255)+250>>>0)/500}function B0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+12>>2];f=x[a+16>>2];b:{if(d>>>0<f>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=f-d>>2;x[e+4>>2]=c-g;d=x[be(e+12|0,be(e+8|0,e+4|0))>>2];Kh(b,x[a+12>>2],d);f=d<<2;x[a+12>>2]=f+x[a+12>>2];b=b+f|0;break b}d=mb[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}x[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}hb=e+16|0;return g|0}function oK(a){var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;a:{b:{if(uk(a)>>>0<=sf(a)>>>0){break b}b=yb(a);d=sf(a);e=sf(a);x[114414]=0;b=Z(1677,c+8|0,d|0,e|0,b|0)|0;d=x[114414];x[114414]=0;c:{d:{if((d|0)!=1){x[114414]=0;P(1678,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}Ls(b);break b}a=S(0)|0;break c}a=S(0)|0;Ls(b)}Y(a|0)|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)==1){break a}}hb=c+32|0;return}S(0)|0;zb();p()}function mK(a){var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;a:{b:{if(vd(a)>>>0<=Lb(a)>>>0){break b}b=yb(a);d=Lb(a);e=Lb(a);x[114414]=0;b=Z(1679,c+8|0,d|0,e|0,b|0)|0;d=x[114414];x[114414]=0;c:{d:{if((d|0)!=1){x[114414]=0;P(1680,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}Ks(b);break b}a=S(0)|0;break c}a=S(0)|0;Ks(b)}Y(a|0)|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)==1){break a}}hb=c+32|0;return}S(0)|0;zb();p()}function eL(a){var b=0,c=0,d=0,e=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1163089229){break a}b=a+4|0;c=y[b+1|0]<<8;d=y[b+2|0]<<16|y[b+3|0]<<24;if((y[b|0]|c|d)!=-1346458146&(d|(c|y[b|0]))!=-1095062050){break a}b=a+16|0;if(!(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))){break a}a=a+8|0;e=((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))+24|0)==(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))}return e}function b9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ai(a,b,c,d);x[a>>2]=78280;b=yk(a+4208|0);x[a+4220>>2]=0;x[a+4224>>2]=0;e=a,f=Ze(c),x[e+4232>>2]=f;x[114414]=0;W(1672,a+4260|0);c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}x[114414]=0;U(1673,a+44|0,2,2)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}x[114414]=0;W(1674,a|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}return a|0}c=N()|0;fg(b);xf(a);Q(c|0);p()}function iH(a){var b=E(0),c=0,d=E(0),e=E(0),f=E(0),g=E(0),h=0,i=E(0),j=0,k=0,l=E(0),m=E(0),n=E(0),o=E(0),p=0;j=a-24|0;b=B[j>>2];c=a-8|0;d=B[c>>2];e=E(b+d);k=a-16|0;f=B[k>>2];l=B[a>>2];g=E(f+l);B[a>>2]=e+g;B[c>>2]=g-e;c=a-28|0;g=B[c>>2];h=a-12|0;m=B[h>>2];e=E(g+m);p=h;h=a-20|0;i=B[h>>2];a=a-4|0;n=B[a>>2];o=E(i+n);B[p>>2]=o-e;i=E(n-i);b=E(d-b);B[c>>2]=i+b;d=E(m-g);f=E(l-f);B[k>>2]=d+f;B[j>>2]=f-d;B[a>>2]=o+e;B[h>>2]=i-b}function zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>2;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){f=de(E(nf((l(2,y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),r()),E(-1))*E(32768)));a:{if(E(F(f))<E(2147483648)){g=~~f;break a}g=-2147483648}h=a,i=Uc(g),w[h>>1]=i;a=a+2|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<2}function yU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,17);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+16|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0;hb=c+16|0}return a|0}function wia(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;v[b+15|0]=128;a=xu(a,127,b+15|0);x[114414]=0;v[b+14|0]=64;d=U(858,a+12|0,127,b+14|0)|0;c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){x[114414]=0;v[b+13|0]=0;U(945,a+24|0,127,b+13|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break b}x[a+36>>2]=-1;x[a+40>>2]=108855296;x[a+44>>2]=0;x[a+48>>2]=0;w[a+52>>1]=0;hb=b+16|0;return a|0}b=N()|0;break a}b=N()|0;$d(d)}$d(a);Q(b|0);p()}function kf(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;g=sn(a);a:{if(b){f=x[b+4>>2];h=x[b>>2];break a}h=sn(a)}x[e+8>>2]=h;x[e+12>>2]=f;f=x[a+12>>2];a=1;b:{if(!b){break b}b=c+f|0;d=c>>>0>b>>>0?d+1|0:d;x[e>>2]=2048;x[e+4>>2]=0;a=cv(e+8|0,e);c=x[a>>2];a=x[a+4>>2];c:{if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break c}break b}a=0;f=x[e+12>>2];if((d|0)==(f|0)&b>>>0>A[e+8>>2]|d>>>0>f>>>0){break b}}a=1}hb=e+16|0;return a}function aha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;g=hb-48|0;hb=g;a:{b:{if(c>>>0>d>>>0){break b}if(Ae(b)>>>0<=d>>>0){break b}while(1){f=c&65535;if(xh(Re(b,f))){h=bc(Re(b,f));i=dc(Re(b,f));f=YO(g,e);x[114414]=0;X(1018,g+24|0,h|0,i|0,f|0);h=x[114414];x[114414]=0;if((h|0)==1){break a}ce(g+24|0);ce(f)}c=c+1|0;if((c&65535)>>>0<=d>>>0){continue}break}}WO(a,e);hb=g+48|0;return}a=N()|0;ce(f);Q(a|0);p()}function Wka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;d=hb-16|0;hb=d;c=Pe(a);f=mc(a);g=hb-16|0;hb=g;if(c){while(1){h=Qn(yb(a),c+16|0,b);f=h?f:c;c=x[(h?c+4|0:c)>>2];if(c){continue}break}}c=x[Fb(g+8|0,f)>>2];hb=g+16|0;x[d+8>>2]=c;i=d,j=Hj(a),x[i>>2]=j;a:{b:{if(!Hb(d+8|0,d)){break b}if(Qn(yb(a),b,rh(d+8|0))){break b}a=x[d+8>>2];break a}a=Hj(a)}hb=d+16|0;a=x[Fb(e+8|0,a)>>2];hb=e+16|0;return a|0}function Cea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;w[e+12>>1]=c;w[e+14>>1]=b;sg(e+14|0,z[x[x[a+24>>2]+8>>2]+12>>1]);c=e+12|0;b=hb-16|0;hb=b;d=z[e+14>>1];x[b+12>>2]=d;a:{if(Vf(a)>>>0>=d>>>0){g=b,h=qc(a),x[g+8>>2]=h;$z(x[a>>2],x[Mb(b+12|0,b+8|0)>>2],c);f=x[b+8>>2];d=x[b+12>>2];if(f>>>0<d>>>0){Eq(a,d-f|0,c);break a}ko(a,x[a>>2]+(d<<1)|0);break a}hO(a);Ln(a,$i(a,d));Eq(a,d,c)}hb=b+16|0;hb=e+16|0}function T4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[114414]=0;W(2121,a|0);c=x[114414];x[114414]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+76>>2];x[114414]=0;P(e|0,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,7188,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function Nx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;d=hb-16|0;hb=d;c=Pe(a);f=mc(a);g=hb-16|0;hb=g;if(c){while(1){h=Ps(yb(a),c+16|0,b);f=h?f:c;c=x[(h?c+4|0:c)>>2];if(c){continue}break}}c=x[Fb(g+8|0,f)>>2];hb=g+16|0;x[d+8>>2]=c;i=d,j=Hj(a),x[i>>2]=j;a:{b:{if(!Hb(d+8|0,d)){break b}if(Ps(yb(a),b,rh(d+8|0))){break b}a=x[d+8>>2];break a}a=Hj(a)}hb=d+16|0;a=x[Fb(e+8|0,a)>>2];hb=e+16|0;return a|0}function GQ(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;hb=b+16|0}function F4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[114414]=0;W(2121,a|0);c=x[114414];x[114414]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+20>>2];x[114414]=0;P(e|0,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,5269,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function E4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[114414]=0;W(2121,a|0);c=x[114414];x[114414]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+16>>2];x[114414]=0;P(e|0,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,8619,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function wR(a){var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;a:{b:{if(pf(a)>>>0<=wc(a)>>>0){break b}b=yb(a);d=wc(a);e=wc(a);x[114414]=0;b=Z(40,c+8|0,d|0,e|0,b|0)|0;d=x[114414];x[114414]=0;c:{d:{if((d|0)!=1){x[114414]=0;P(41,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break d}uu(b);break b}a=S(0)|0;break c}a=S(0)|0;uu(b)}Y(a|0)|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)==1){break a}}hb=c+32|0;return}S(0)|0;zb();p()}function K4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[114414]=0;W(2121,a|0);c=x[114414];x[114414]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+40>>2];x[114414]=0;ma(e|0,c|0,+b);c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,7560,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114414]=0;V(20);d=x[114414];x[114414]=0;if((d|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function I4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[114414]=0;W(2121,a|0);c=x[114414];x[114414]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+32>>2];x[114414]=0;ma(e|0,c|0,+b);c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,4009,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114414]=0;V(20);d=x[114414];x[114414]=0;if((d|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function G4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[114414]=0;W(2121,a|0);c=x[114414];x[114414]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+24>>2];x[114414]=0;ma(e|0,c|0,+b);c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,3957,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114414]=0;V(20);d=x[114414];x[114414]=0;if((d|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function ky(a,b,c){if($b(a+1074312|0,21)){c=c&255;a:{switch((b&3)-1|0){default:return v[c+26704|0];case 0:return 64-(c+1>>>1|0)|0;case 1:return(c>>>0<128)<<6;case 2:break a}}return AL(un(a))+-64|0}if(x[a+480180>>2]&67633152){return v[(c>>>1&31)+25824|0]}a=c&63;b:{switch((b&3)-1|0){default:return v[a+26576|0];case 0:return(a>>>0>=32?255:0)-(a<<2)|0;case 1:return a>>>0<32?127:-127;case 2:break b}}return v[a+26640|0]}function _5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;x[114414]=0;W(2048,a|0);e=x[114414];x[114414]=0;a:{b:{if((e|0)!=1){e=x[a+24>>2];x[114414]=0;b=Z(2063,e|0,b|0,c|0,d|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,5408,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function X5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;x[114414]=0;W(2048,a|0);e=x[114414];x[114414]=0;a:{b:{if((e|0)!=1){e=x[a+24>>2];x[114414]=0;b=Z(2066,e|0,b|0,c|0,d|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,5377,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function U5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;x[114414]=0;W(2048,a|0);e=x[114414];x[114414]=0;a:{b:{if((e|0)!=1){e=x[a+24>>2];x[114414]=0;b=Z(2069,e|0,b|0,c|0,d|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,5571,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function T5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;x[114414]=0;W(2048,a|0);e=x[114414];x[114414]=0;a:{b:{if((e|0)!=1){e=x[a+24>>2];x[114414]=0;b=Z(2070,e|0,b|0,c|0,d|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,8780,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function Sp(a){a=a|0;var b=0,c=0,d=0,e=0;En(a);b=x[a>>2];c=zo(a);if(b-268435457>>>0>=4026531840){b=b+208|0;d=D(b,c);yna(c,0,b,0);d=lb?0:d}else{d=0}a:{if(!d){break a}x[114414]=0;b=R(2891,d|0)|0;c=x[114414];x[114414]=0;b:{c:{if((c|0)==1){Y(S(0)|0)|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;b=0;if((c|0)==1){break c}}break b}S(0)|0;zb();p()}if(!b){break a}e=Sb(b,0,d)- -64|0}x[a+20>>2]=e;if(!e){return 0}return Kj(a)|0}function S5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;x[114414]=0;W(2048,a|0);e=x[114414];x[114414]=0;a:{b:{if((e|0)!=1){e=x[a+24>>2];x[114414]=0;b=Z(2071,e|0,b|0,c|0,d|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,5493,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function R5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;x[114414]=0;W(2048,a|0);e=x[114414];x[114414]=0;a:{b:{if((e|0)!=1){e=x[a+24>>2];x[114414]=0;b=Z(2072,e|0,b|0,c|0,d|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,8706,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function N4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[114414]=0;W(2121,a|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+52>>2];x[114414]=0;d=+$a(e|0,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,7541,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();d=0}return+d}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function GC(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179340888|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1213419859){break a}b=a+4|0;if(!(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))){break a}a=a+12|0;if(!(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))){break a}a=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);c=(a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24))>>>0>27}return c}function R4(a,b){a=a|0;b=b|0;var c=0,d=0;x[114414]=0;W(2121,a|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+68>>2];x[114414]=0;b=O(d|0,c|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,3016,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=-1}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function P4(a,b){a=a|0;b=b|0;var c=0,d=0;x[114414]=0;W(2121,a|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+60>>2];x[114414]=0;b=O(d|0,c|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,3067,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=-1}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function Ad(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;En(a);x[a+16>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0;x[a+4>>2]=0;w[a+32>>1]=64;x[a+24>>2]=8363;x[a+28>>2]=16777344;x[a+36>>2]=0;v[a+39|0]=0;v[a+40|0]=0;v[a+41|0]=0;v[a+42|0]=0;c=z[a+34>>1]&-25151;w[a+34>>1]=(b|0)==4?c|32:c;b=Ub(d,17386);x[114414]=0;O(335,a+43|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){xb(b);pO(a);hb=d+16|0;return}a=N()|0;xb(b);Q(a|0);p()}function vJ(a){var b=E(0),c=0,d=E(0);b=B[a+4224>>2];B[a+4260>>2]=M(E(E(1)-E(b*b)));v[a+4264|0]=B[a+4236>>2]>E(.5);d=E(A[a+4256>>2]);b=E(E(E(B[a+4228>>2]*E(1.999000072479248))+E(.0010000000474974513))*d);a:{if(b<E(4294967296)&b>=E(0)){c=~~b>>>0;break a}c=0}x[a+4248>>2]=c;c=a+4252|0;b=E(E(E(B[a+4232>>2]*E(1.999000072479248))+E(.0010000000474974513))*d);b:{if(b<E(4294967296)&b>=E(0)){a=~~b>>>0;break b}a=0}x[c>>2]=a}function _T(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;x[d+12>>2]=c;e=bc(b);f=dc(b);c=hb-32|0;hb=c;x[c+16>>2]=f;x[c+24>>2]=e;x[c+8>>2]=d+12;a:{if(!Hb(c+24|0,c+16|0)){break a}while(1){if((Qj(x[c+24>>2])|0)==x[x[c+8>>2]>>2]){break a}e=c+24|0;Xi(e);if(Hb(e,c+16|0)){continue}break}}hb=c+32|0;x[d+8>>2]=x[c+24>>2];g=d,h=dc(b),x[g>>2]=h;b:{if(Hb(d+8|0,d)){df(a,yb(x[d+8>>2]));break b}ci(a)}hb=d+16|0}function Uga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;Xc(a+8|0);if(b){ho(a,b);e=hb-16|0;hb=e;a:{b:{b=je(e,a,b);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;P(1042,f|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break b}c=c+4|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break a}a=N()|0;Jb(b);Q(a|0);p()}}hb=d+16|0;return a|0}function yda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;Xc(a+8|0);if(b){Ln(a,b);e=hb-16|0;hb=e;a:{b:{b=Yg(e,a,b);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;P(330,f|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break b}c=c+2|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break a}a=N()|0;Jb(b);Q(a|0);p()}}hb=d+16|0;return a|0}function iM(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];x[a>>2]=b;if(c){a=hb-16|0;hb=a;f=a,g=bc(c),x[f+8>>2]=g;f=a,g=dc(c),x[f>>2]=g;if(Hb(a+8|0,a)){while(1){e=x[a+8>>2];a:{while(1){b=x[e>>2];d=x[b>>2];if(!d){break a}b=x[x[d>>2]+8>>2];x[114414]=0;W(b|0,d|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}Gb(b+20|0);Gb(b+8|0);_b(b);b=a+8|0;fe(b);if(Hb(b,a)){continue}break}}b=MJ(c);hb=a+16|0;_b(b)}}function Hja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;Xc(a+8|0);if(b){_Q(a,b);e=hb-16|0;hb=e;a:{b:{b=je(e,a,b);c=x[b+4>>2];g=x[b+8>>2];if((c|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;P(852,f|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break b}c=c+4|0;x[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Jb(b);hb=e+16|0;break a}a=N()|0;Jb(b);Q(a|0);p()}}hb=d+16|0;return a|0}function Ega(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];f=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=f;j=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=j;if(d){while(1){e=w[(x[b+12>>2]<<1)+i>>1];x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];f=x[b+12>>2]}x[a>>2]=e;x[a+4>>2]=f;hb=b+16|0}function jH(a,b){var c=0,d=0,e=0;if(!y[b+21|0]){fc(a,21);return-1}if(x[a+1396>>2]<=9){pk(a)}d=x[a+1392>>2];c=w[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=y[d+x[b+8>>2]|0];x[a+1392>>2]=e>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:d;break a}c=Dl(a,b)}if(!((c|0)>=x[b+2092>>2]?y[b+23|0]:0)){if(!(!(x[a+1384>>2]?y[a+1376|0]:1)|(c|0)>=0)){fc(a,21)}return c}ea(3778,9049,1793,2236);p()}function wy(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=0,f=0;x[a+1074372>>2]=b;vL(a+1074332|0,b);f=a+946300|0;a=a+906300|0;while(1){b=x[a>>2];if(b){c=E(1);d=x[b+20>>2];if(d){c=E(E(y[d+26|0])*E(.10000000149011612))}c=c<E(.10000000149011612)?E(1):c;if(mb[x[x[b>>2]+132>>2]](b)|0){d=SJ(x[b+16>>2]);e=x[b+16>>2];c=E(E(c*E(A[e+480232>>2]))/E(B[d+8>>2]*B[SJ(e)+20>>2]))}B[b+4196>>2]=c}a=a+160|0;if((f|0)!=(a|0)){continue}break}}function oU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{b:{if(!Yf(a,7)){break b}c=0;if(!wB(a,13673)){break a}if(!Yf(a,1)){break b}c=-1;if(!Yc(a,Lu(a))){break a}c=hb-16|0;hb=c;d=c+8|0;f=e+8|0;Eu(d,f);g=Eb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;d=(d|0)==(g|0);if(!d){dB(f)}c=-1;if(!d){break a}c=0;if(!sB(e+8|0)){break a}c=kf(a,b,rB(e+8|0),lb);break a}c=-1}hb=e+16|0;return c|0}function Y0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=x[a+16>>2];g=x[a+12>>2];b:{if(d>>>0>g>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=d-g;x[e+4>>2]=c-f;d=x[be(e+12|0,be(e+8|0,e+4|0))>>2];Le(b,x[a+12>>2],d);x[a+12>>2]=x[a+12>>2]+d;break b}d=mb[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b|0]=d<<24>>24;d=1}b=b+d|0;f=d+f|0;continue}break}hb=e+16|0;return f|0}function Uw(a){var b=0,c=0,d=0;a:{b:{if(!x[a+1384>>2]){b=x[a+1380>>2];if((b|0)==-1){x[a+1388>>2]=x[a+1116>>2]-1;if(!is(a)){x[a+1384>>2]=1;return 0}if(!(v[a+1375|0]&1)){break b}b=x[a+1380>>2]}d=b+1|0;x[a+1380>>2]=d;c=y[(a+b|0)+1120|0];if((c|0)!=255){x[a+1388>>2]=b;x[a+1384>>2]=1}if(x[a+1116>>2]<=(d|0)){x[a+1380>>2]=-1}if(y[a+1376|0]){break a}v[a+1376|0]=c}return c}fc(a,32);return 0}ea(11751,9049,1564,2463);p()}function n$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=E(0),g=0,h=E(0);e=hb-16|0;hb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[114240];x[114240]=0;ie();d=hb-16|0;hb=d;iw(d,a,e+12|0,0);f=LF(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);hb=d+16|0;a=x[114240];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[114240]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}hb=e+16|0;return E(f)}function Fga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];f=x[a+4>>2];e=x[a>>2];x[b+8>>2]=e;x[b+12>>2]=f;j=x[a+12>>2];x[b>>2]=x[a+8>>2];x[b+4>>2]=j;if(d){while(1){e=v[x[b+12>>2]+i|0]<<8;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);c=c+8|0;Tb(b+8|0,b);d=d-1|0;if(d){continue}break}e=x[b+8>>2];f=x[b+12>>2]}x[a>>2]=e;x[a+4>>2]=f;hb=b+16|0}function $5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[114414]=0;W(2048,a|0);d=x[114414];x[114414]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[114414]=0;T(2062,d|0,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,6302,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();e=0}return e|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function gma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,15);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;hb=c+16|0}return a|0}function V0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=x[a+28>>2];g=x[a+24>>2];if(d>>>0<=g>>>0){if(((i=a,j=Wg(v[b|0]),h=x[x[a>>2]+52>>2],mb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{x[e+12>>2]=d-g;x[e+8>>2]=c-f;d=x[be(e+12|0,e+8|0)>>2];Le(x[a+24>>2],b,d);x[a+24>>2]=d+x[a+24>>2];f=f+d|0;b=b+d|0}continue}break}hb=e+16|0;return f|0}function tS(a,b){var c=0,d=0,e=0,f=0;a:{b:{if(!b){break b}if(!Qb(a,b)){break b}if(b>>>0<=3){c=hb-16|0;hb=c;c:{if(!b){break c}if(!Qb(a,b)){break c}while(1){v[c+11|0]=0;d:{if(b>>>0>d>>>0){Xf(a,c+11|0);e=v[c+11|0];f=e>>>31|0;break d}e=0-f|0}v[(c+12|0)+d|0]=e;d=d+1|0;if((d|0)!=4){continue}break}x[c>>2]=x[c+12>>2];d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)}hb=c+16|0;break a}d=Gf(a);cc(a,b-4|0)}}return d}function c6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[114414]=0;W(2048,a|0);d=x[114414];x[114414]=0;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[114414]=0;e=+ka(2058,d|0,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,1836,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();e=0}return+e}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function M3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!(e?d:0)){b=ec(8);x[114414]=0;c=O(118,f|0,4405)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}wi(a,b,2);c=qx(a,c,d,e,0,0);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=f+16|0;return c|0}a=N()|0;hc(b)}Q(a|0)}p()}function J3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!(e?d:0)){b=ec(8);x[114414]=0;c=O(118,f|0,4405)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}wi(a,b,2);c=px(a,c,d,e,0,0);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=f+16|0;return c|0}a=N()|0;hc(b)}Q(a|0)}p()}function H5(a,b){a=a|0;b=b|0;var c=0,d=E(0);x[114414]=0;W(2048,a|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114414]=0;d=E(la(2083,c|0,b|0));b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,5334,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();d=E(0)}return E(d)}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function G5(a,b){a=a|0;b=b|0;var c=0,d=E(0);x[114414]=0;W(2048,a|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114414]=0;d=E(la(2084,c|0,b|0));b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,2616,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();d=E(0)}return E(d)}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function F5(a,b){a=a|0;b=b|0;var c=0,d=E(0);x[114414]=0;W(2048,a|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114414]=0;d=E(la(2085,c|0,b|0));b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,2523,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();d=E(0)}return E(d)}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function D5(a,b){a=a|0;b=b|0;var c=0,d=E(0);x[114414]=0;W(2048,a|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114414]=0;d=E(la(2086,c|0,b|0));b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,2659,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();d=E(0)}return E(d)}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function C5(a,b){a=a|0;b=b|0;var c=0,d=E(0);x[114414]=0;W(2048,a|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114414]=0;d=E(la(2087,c|0,b|0));b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,2567,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();d=E(0)}return E(d)}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function v$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;a:{b:{if((a|0)!=(b|0)){g=x[114240];x[114240]=0;a=mE(a,e+12|0,d,ie());d=lb;f=x[114240];c:{if(f){if(x[e+12>>2]!=(b|0)){break c}if((f|0)==68){break b}break a}x[114240]=g;if(x[e+12>>2]==(b|0)){break a}}}x[c>>2]=4;a=0;d=0;break a}x[c>>2]=4;if(!!a&(d|0)>=0|(d|0)>0){a=-1;d=2147483647;break a}a=0;d=-2147483648}hb=e+16|0;lb=d;return a|0}function L4(a){a=a|0;var b=0,c=0,d=0;x[114414]=0;W(2121,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+44>>2];x[114414]=0;c=+ha(d|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,7578,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();c=0}return+c}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function J4(a){a=a|0;var b=0,c=0,d=0;x[114414]=0;W(2121,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+36>>2];x[114414]=0;c=+ha(d|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,4026,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();c=0}return+c}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function H4(a){a=a|0;var b=0,c=0,d=0;x[114414]=0;W(2121,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+28>>2];x[114414]=0;c=+ha(d|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,3974,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();c=0}return+c}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function $ka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;x[e+24>>2]=d;g=Vj(a,c);vf(e,x[a+28>>2]);d=x[e+12>>2];x[e+16>>2]=x[e+8>>2];x[e+20>>2]=d;a:{if(!g){if(Cd(a,5)){break a}}h=x[a+28>>2];i=x[e+24>>2];f=hb-16|0;hb=f;d=hd(f);x[114414]=0;Z(669,b|0,h|0,d|0,i|0)|0;b=x[114414];x[114414]=0;b:{if((b|0)!=1){xb(d);hb=f+16|0;break b}a=N()|0;xb(d);Q(a|0);p()}}hj(a,g,c,e+16|0);hb=e+32|0}function vea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;uA(e+24|0,e+16|0,c);x[114414]=0;T(645,e+36|0,e+8|0,d|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){x[114414]=0;P(646,e|0,e+24|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;T(477,a|0,b|0,e|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}lf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;lf(e+24|0)}Q(c|0);p()}function _W(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;x[114414]=0;a=Fa(2040,a|0,b|0,c|0,d|0)|0;b=x[114414];x[114414]=0;a:{b:{if((b|0)==1){Y(S(0)|0)|0;x[114414]=0;fa(2034,7041,e|0,f|0,g|0,h|0,i|0,j|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}_();a=-255}break a}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}return a|0}function Jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;Ii(e+24|0,e+16|0,c);x[114414]=0;T(850,e+36|0,e+8|0,d|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){x[114414]=0;P(646,e|0,e+24|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;T(477,a|0,b|0,e|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}lf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;lf(e+24|0)}Q(c|0);p()}function xe(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=ap(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(eH(a,b)&3){case 0:c=ap(C[b>>3],C[b+8>>3]);break a;case 1:c=-$o(C[b>>3],C[b+8>>3],1);break a;case 2:c=-ap(C[b>>3],C[b+8>>3]);break a;default:break b}}c=$o(C[b>>3],C[b+8>>3],1)}a=c;hb=b+16|0;return a}function l$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[114240];x[114240]=0;ie();d=hb-16|0;hb=d;iw(d,a,e+12|0,1);f=Jw(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);hb=d+16|0;a=x[114240];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[114240]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}hb=e+16|0;return+f}function fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a=hb-16|0;hb=a;x[b>>2]=0;x[b+4>>2]=0;x[a+12>>2]=0;d=yb(c);x[114414]=0;U(1186,b+8|0,a+12|0,d|0)|0;d=x[114414];x[114414]=0;a:{if((d|0)!=1){x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];d=x[yb(c)>>2];e=yb(b),f=d,x[e>>2]=f;e=yb(c),f=0,x[e>>2]=f;x[c>>2]=0;x[c+4>>2]=0;hb=a+16|0;break a}S(0)|0;zb();p()}Jd(b+12|0,c+12|0);w[b+28>>1]=z[c+28>>1];x[b+24>>2]=x[c+24>>2]}function Jba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=hb-896|0;hb=d;b=Sb(a,0,66);x[b+72>>2]=0;x[b+76>>2]=0;x[b+68>>2]=256;w[b+66>>1]=65535;x[b+80>>2]=0;x[b+84>>2]=0;v[b+88|0]=1;e=b+229984|0;c=b+608|0;a=c;while(1){a=jM(a)+896|0;if((e|0)!=(a|0)){continue}break}d=Sb(d,0,896);e=jM(d);a=((c+229376|0)-c|0)/896|0;if((a|0)>0){while(1){Bp(c,e);c=c+896|0;f=a>>>0>1;a=a-1|0;if(f){continue}break}}hb=d+896|0;return b|0}function HO(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a=Wb(a);d=Bb(b);x[114414]=0;P(108,a|0,d|0);d=x[114414];x[114414]=0;if((d|0)!=1){a:{e=c,f=ud(b),x[e+8>>2]=f;e=c,f=jf(b),x[e>>2]=f;if(Hb(c+8|0,c)){while(1){b=y[x[c+8>>2]];if((b|0)==13){b=10}x[114414]=0;P(107,a|0,b<<24>>24);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=c+8|0;bg(b);if(Hb(b,c)){continue}break}}hb=c+16|0;return}}b=N()|0;xb(a);Q(b|0);p()}function E6(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;a:{b:{if(!a){break b}a=tc(b+8|0,a);x[114414]=0;c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=R(2030,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break a}Y(S(0)|0)|0;x[114414]=0;X(2023,8362,0,0,0);a=x[114414];x[114414]=0;if((a|0)!=1){_();break b}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}a=0}hb=b+16|0;return a|0}function sla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;Gm(e+24|0,e+16|0,c);x[114414]=0;T(192,e+36|0,e+8|0,d|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){x[114414]=0;P(79,e|0,e+24|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;T(73,a|0,b|0,e|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}lf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;lf(e+24|0)}Q(c|0);p()}function sF(a,b,c){var d=0,e=0,f=0,g=0;g=hb-16|0;hb=g;d=hb-16|0;hb=d;a:{if(b>>>0<=1073741807){b:{if(Po(b)){Ce(a,b);e=a;break b}Zj(d+8|0,a,ql(b)+1|0);e=x[d+8>>2];Ue(a,e);Ff(a,x[d+12>>2]);ae(a,b)}f=hb-16|0;hb=f;x[114414]=0;x[f+12>>2]=c;eE(e,b,f+12|0);c=x[114414];x[114414]=0;c:{if((c|0)!=1){hb=f+16|0;break c}S(0)|0;zb();p()}x[d+4>>2]=0;ug((b<<2)+e|0,d+4|0);hb=d+16|0;break a}Ef();p()}hb=g+16|0;return a}function Rma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;Gm(e+24|0,e+16|0,c);x[114414]=0;T(208,e+36|0,e+8|0,d|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){x[114414]=0;P(79,e|0,e+24|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;T(73,a|0,b|0,e|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}lf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;lf(e+24|0)}Q(c|0);p()}function zU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;Qu(e+24|0,e+16|0,c);x[114414]=0;T(394,e+36|0,e+8|0,d|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){x[114414]=0;P(79,e|0,e+24|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;T(73,a|0,b|0,e|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}lf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;lf(e+24|0)}Q(c|0);p()}function Kda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;uN(e+24|0,e+16|0,c);x[114414]=0;T(78,e+36|0,e+8|0,d|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){x[114414]=0;P(79,e|0,e+24|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;T(73,a|0,b|0,e|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}lf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;lf(e+24|0)}Q(c|0);p()}function CW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;Ii(e+24|0,e+16|0,c);x[114414]=0;T(192,e+36|0,e+8|0,d|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){x[114414]=0;P(79,e|0,e+24|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;T(73,a|0,b|0,e|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}lf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;lf(e+24|0)}Q(c|0);p()}function jr(a){var b=0,c=0;Tn(a,1,10759);x[114414]=0;b=$(196)|0;c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}x[a+12>>2]=b;x[114414]=0;b=$(197)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}v[a+16|0]=b;x[114414]=0;b=$(198)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}v[a+18|0]=0;v[a+17|0]=b;x[114414]=0;W(199,a+20|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}return}b=N()|0;xb(a);Q(b|0);p()}function j6(a,b){a=a|0;b=b|0;var c=0,d=0;x[114414]=0;W(2048,a|0);c=x[114414];x[114414]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114414]=0;P(2051,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,6840,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function h6(a,b){a=a|0;b=b|0;var c=0,d=0;x[114414]=0;W(2048,a|0);c=x[114414];x[114414]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114414]=0;P(2053,c|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,2270,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();d=0}return d|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function JH(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{d:{if((b|0)>=0){if((fp(a+8|0)|0)>(b|0)){break d}}a=ec(8);x[114414]=0;c=O(118,c|0,6687)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break b}hb=c+16|0;return+(+x[(x[a+32>>2]+D(b,896)|0)+1075744>>2]*.015625)}b=N()|0;hc(a)}Q(b|0)}p()}function C_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=hb-208|0;hb=a;f=ie();x[a>>2]=e;g=a+176|0;i=ff(g,20,f,5233,a);e=i+g|0;g=vg(g,e,c);f=a+8|0;Dc(f,c);x[114414]=0;f=R(2510,f|0)|0;h=x[114414];x[114414]=0;if((h|0)!=1){Ob(a+8|0);h=f;f=a+16|0;vF(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=Sm(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);hb=a+208|0;return b|0}b=N()|0;Ob(a+8|0);Q(b|0);p()}function Jq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=hb-16|0;hb=c;d=x[a+4>>2];e=x[a>>2];v[c+12|0]=0;f=e;d=d+e|0;e=c+12|0;Bs(f,d,e);d=Rb(b);g=Rb(b);h=c,i=Bb(b),x[h+12>>2]=i;x[c+8>>2]=x[a+4>>2]-1;f=d;d=c+8|0;Ke(f,g+x[Mb(e,d)>>2]|0,x[a>>2]);g=x[a>>2];h=c,i=Bb(b),x[h+12>>2]=i;x[c+8>>2]=x[a+4>>2]-1;b=x[Mb(e,d)>>2];e=x[a+4>>2];d=x[a>>2];v[c+7|0]=0;Bs(b+g|0,d+e|0,c+7|0);hb=c+16|0;return a|0}function zQ(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808604749){break a}b=a+8|0;c=y[b+1|0]<<8;if((y[b|0]|c)>>>0<512|(c|y[b|0])>>>0>767){break a}b=a+112|0;c=y[b+1|0]<<8;if(!(y[b|0]|c)|(c|y[b|0])>>>0>64){break a}b=a+106|0;if((y[b|0]|y[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((y[b|0]|y[b+1|0]<<8)>>>0>255){break a}a=a+124|0;d=(y[a|0]|y[a+1|0]<<8)>>>0<4e3}return d}function U3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=hb-32|0;hb=b;x[b+24>>2]=e;x[b+28>>2]=f;a:{a=Ws(a,$l(b+16|0,Cb(c),d),b+24|0);if(a+1>>>0>=3){a=ec(8);x[114414]=0;b=O(118,b|0,4262)|0;c=x[114414];x[114414]=0;b:{if((c|0)!=1){a=oc(a,b);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}d=N()|0;xb(b);break b}d=N()|0;hc(a)}Q(d|0);p()}hb=b+32|0;return a|0}p()}function HH(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{d:{if((b|0)>=0){if((fp(a+8|0)|0)>(b|0)){break d}}a=ec(8);x[114414]=0;c=O(118,c|0,6687)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break b}hb=c+16|0;return(y[(x[a+32>>2]+D(b,896)|0)+1075073|0]&4)>>>2|0}b=N()|0;hc(a)}Q(b|0)}p()}function p5(a,b){a=a|0;b=b|0;var c=0;x[114414]=0;W(2048,a|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114414]=0;b=O(2101,c|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,5713,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function o5(a,b){a=a|0;b=b|0;var c=0;x[114414]=0;W(2048,a|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114414]=0;b=O(2102,c|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,2953,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function lU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;oB(e+24|0,c);x[114414]=0;T(192,e+36|0,e+8|0,d|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){x[114414]=0;P(79,e|0,e+24|0);c=x[114414];x[114414]=0;if((c|0)==1){break b}x[114414]=0;T(73,a|0,b|0,e|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}lf(e+24|0);hb=e+48|0;return}c=N()|0;xb(e+24|0);break a}c=N()|0;lf(e+24|0)}Q(c|0);p()}function SK(a,b){var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){c=hb-16|0;hb=c;d=x[b>>2];e=x[b+4>>2];b=Vt(d,e);a:{if(b>>>0<=vd(a)>>>0){if(Lb(a)>>>0<b>>>0){x[c+12>>2]=d;pR(c+12|0,Lb(a));Ke(d,x[c+12>>2],x[a>>2]);Wx(a,x[c+12>>2],e,b-Lb(a)|0);break a}OL(a,Ke(d,e,x[a>>2]));break a}if(x[a>>2]){pt(a);Xe(yb(a),x[a>>2],vd(a));f=yb(a),g=0,x[f>>2]=g;x[a>>2]=0;x[a+4>>2]=0}ho(a,ze(a,b));Wx(a,d,e,b)}hb=c+16|0}}function oi(a){var b=0,c=0;b=hb-16|0;hb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=$o(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(eH(a,b)&3){case 0:a=$o(C[b>>3],C[b+8>>3],1);break a;case 1:a=ap(C[b>>3],C[b+8>>3]);break a;case 2:a=-$o(C[b>>3],C[b+8>>3],1);break a;default:break b}}a=-ap(C[b>>3],C[b+8>>3])}hb=b+16|0;return a}function Xha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{a=KP(b,c);x[114414]=0;d=O(963,a+12|0,c+12|0)|0;b=x[114414];x[114414]=0;b:{c:{if((b|0)!=1){x[114414]=0;O(964,a+24|0,c+24|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}b=x[c+40>>2];x[a+36>>2]=x[c+36>>2];x[a+40>>2]=b;w[a+52>>1]=z[c+52>>1];b=x[c+48>>2];x[a+44>>2]=x[c+44>>2];x[a+48>>2]=b;break a}b=N()|0;break b}b=N()|0;$d(d)}$d(a);Q(b|0);p()}}function N3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){b=ec(8);x[114414]=0;c=O(118,e|0,4405)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}wi(a,b,1);c=qx(a,c,d,0,0,0);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=e+16|0;return c|0}a=N()|0;hc(b)}Q(a|0)}p()}function K3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){b=ec(8);x[114414]=0;c=O(118,e|0,4405)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}wi(a,b,1);c=px(a,c,d,0,0,0);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=e+16|0;return c|0}a=N()|0;hc(b)}Q(a|0)}p()}function vv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;c=fi(e+8|0,b);f=hb-16|0;hb=f;g=f+8|0;h=hb-16|0;hb=h;b=hb-16|0;hb=b;d=hb-16|0;hb=d;x[b+4>>2]=1;i=b,j=lD(1),x[i+8>>2]=j;hb=d+16|0;d=x[b+8>>2];x[114414]=0;O(237,d|0,c|0)|0;c=x[114414];x[114414]=0;a:{if((c|0)!=1){c=Go(b);Fo(g,ic(c),c);nD(b);hb=b+16|0;break a}a=N()|0;nD(b);Q(a|0);p()}hb=h+16|0;zm(a,g);Ab(g);hb=f+16|0;hb=e+16|0}function uba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=b;a:{if(pf(a)>>>0>=b>>>0){f=d,g=wc(a),x[f+8>>2]=g;Th(x[a>>2],x[Mb(d+12|0,d+8|0)>>2],c);b=x[d+12>>2];e=x[d+8>>2];if(b>>>0>e>>>0){qq(a,b-e|0,c);break a}kv(a,b+x[a>>2]|0);break a}if(x[a>>2]){wc(a);CC(a);Wp(a);ag(yb(a),x[a>>2],pf(a));f=yb(a),g=0,x[f>>2]=g;x[a>>2]=0;x[a+4>>2]=0}Pk(a,Wh(a,b));qq(a,b,c)}hb=d+16|0}function t8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;b=c+8|0;_J(b,a,0);if(Vg(b)){a=x[a+20>>2];x[a+148>>2]=-1;b=hb-16|0;hb=b;d=x[c+8>>2];f=x[c+12>>2];e=Yi(d,f);a=a+4|0;a:{if(e>>>0<=pf(a)>>>0){if(wc(a)>>>0<e>>>0){x[b+12>>2]=d;NL(b+12|0,wc(a));Ke(d,x[b+12>>2],x[a>>2]);ZJ(a,x[b+12>>2],f,e-wc(a)|0);break a}aA(a,Ke(d,f,x[a>>2]));break a}Oy(a);Pk(a,Wh(a,e));ZJ(a,d,f,e)}hb=b+16|0}hb=c+16|0}function oz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-32|0;hb=f;x[f+8>>2]=c;g=f,h=uf(b),x[g+28>>2]=h;c=f+8|0;bf(c,b,x[Mb(c,f+28|0)>>2]);x[114414]=0;b=R(421,c|0)|0;c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}c=x[f+8>>2];x[114414]=0;a=aa(389,a|0,b|0,c|0,d|0,e|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}Hc(f+8|0);hb=f+32|0;return a|0}a=N()|0;Hc(f+8|0);Q(a|0);p()}function Z3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=hb-32|0;hb=b;x[b+24>>2]=e;x[b+28>>2]=f;a:{a=Ws(a,$l(b+16|0,c,d),b+24|0);if(a+1>>>0>=3){a=ec(8);x[114414]=0;b=O(118,b|0,4262)|0;c=x[114414];x[114414]=0;b:{if((c|0)!=1){a=oc(a,b);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}d=N()|0;xb(b);break b}d=N()|0;hc(a)}Q(d|0);p()}hb=b+32|0;return a|0}p()}function Y4(a){a=a|0;var b=0;x[114414]=0;W(2121,a|0);b=x[114414];x[114414]=0;if((b|0)!=1){x[a+24>>2]=0;b=x[a+28>>2];if(b){mb[x[x[b>>2]+4>>2]](b)}x[a+28>>2]=0;b=x[a+20>>2];if(b){_b(b);x[a+20>>2]=0}_b(a);return}Y(S(0)|0)|0;x[114414]=0;X(2023,1558,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)!=1){_();return}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function WP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;e=nq(a);f=d,g=bc(b),x[f+8>>2]=g;f=d,g=dc(b),x[f>>2]=g;a:{if(Hb(d+8|0,d)){while(1){a=x[d+8>>2];if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==(c|0)){a=yb(a);x[114414]=0;P(568,e|0,a|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}}a=d+8|0;Xi(a);if(Hb(a,d)){continue}break}}hb=d+16|0;return}a=N()|0;id(e);Q(a|0);p()}function z1(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=x[(((y[b|0]^a)&255)<<2)+37808>>2]^a>>>8;a=a>>>8^x[(((a^y[b+1|0])&255)<<2)+37808>>2];a=a>>>8^x[(((a^y[b+2|0])&255)<<2)+37808>>2];a=a>>>8^x[(((a^y[b+3|0])&255)<<2)+37808>>2];b=b+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=x[(((y[b|0]^a)&255)<<2)+37808>>2]^a>>>8;b=b+1|0;c=c-1|0;if(c){continue}break}}return a^-1}function uF(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(b>>>0>=d>>>0){if(!e){return d}d=a+d|0;h=a+b|0;b=h;f=hb-16|0;hb=f;e=c+e|0;a:{if((e|0)==(c|0)){b=d;break a}g=b-d|0;e=e-c|0;if((g|0)<(e|0)){break a}v[f+15|0]=y[c|0];i=1-e|0;while(1){d=qo(d,g+i|0,f+15|0);if(!d){break a}if(!on(d,c,e)){b=d;break a}d=d+1|0;g=b-d|0;if((e|0)<=(g|0)){continue}break}}hb=f+16|0;a=(b|0)==(h|0)?-1:b-a|0}else{a=-1}return a}function u0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;gj(c,b);x[a+44>>2]=0;b=x[a+48>>2];if(b&8){d=a,e=Rb(c)+Bb(c)|0,x[d+44>>2]=e;Ym(a,Rb(c),Rb(c),x[a+44>>2]);b=x[a+48>>2]}a:{if(!(b&16)){break a}b=Bb(c);d=a,e=b+Rb(c)|0,x[d+44>>2]=e;_v(c,Fc(c));zw(a,Rb(c),Rb(c)+Bb(c)|0);if(!(y[a+48|0]&3)){break a}while(1){if((b|0)<0){Ur(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}Ur(a,b)}}function gz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;Ct(d+24|0,a,b);kl(d+16|0,x[d+24>>2],x[d+28>>2],c);f=x[d+16>>2];b=hb-16|0;hb=b;x[b+8>>2]=a;a=f;f=b+8|0;g=a-zt(f)>>1;a=hb-16|0;hb=a;x[a+8>>2]=x[f>>2];cO(a+8|0,g);hb=a+16|0;hb=b+16|0;x[d+8>>2]=x[a+8>>2];h=d,i=rg(c,x[d+20>>2]),x[h+4>>2]=i;gd(e+8|0,d+8|0,d+4|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function e6(a,b){a=a|0;b=+b;var c=0;x[114414]=0;W(2048,a|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[114414]=0;b=+cb(2056,c|0,+b);c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,3818,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return+b}a=N()|0;x[114414]=0;V(20);c=x[114414];x[114414]=0;if((c|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function ST(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;if(RA(b,e+24|0)){d=e+28|0;d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)}f=e+8|0;Bd(f,b,d);a=QA(a,e+24|0,f);Ab(f);a:{if(!c){break a}d=(d>>>0)%(c>>>0)|0;if(!d){break a}x[114414]=0;O(304,b|0,c-d|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break a}b=N()|0;me(a);Q(b|0);p()}hb=e+32|0}function M_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=hb-96|0;hb=a;f=ie();x[a>>2]=e;g=a- -64|0;i=ff(g,20,f,5233,a);e=i+g|0;g=vg(g,e,c);f=a+8|0;Dc(f,c);x[114414]=0;f=R(21,f|0)|0;h=x[114414];x[114414]=0;if((h|0)!=1){Ob(a+8|0);h=f;f=a+16|0;xF(h,a- -64|0,e,f);h=b;b=f+i|0;b=im(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);hb=a+96|0;return b|0}b=N()|0;Ob(a+8|0);Q(b|0);p()}function Lw(a,b,c){var d=0,e=0,f=0;d=x[c+16>>2];a:{if(!d){if(KG(c)){break a}d=x[c+16>>2]}f=x[c+20>>2];if(d-f>>>0<b>>>0){return mb[x[c+36>>2]](c,a,b)|0}b:{if(x[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(y[e+a|0]!=10){continue}break}e=mb[x[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=x[c+20>>2]}sc(f,a,b);x[c+20>>2]=x[c+20>>2]+b;e=b+d|0}return e}function H3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){b=ec(8);x[114414]=0;c=O(118,e|0,4405)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}wi(a,b,2);c=CI(a,c,2,d);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=e+16|0;return c|0}a=N()|0;hc(b)}Q(a|0)}p()}function F3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){b=ec(8);x[114414]=0;c=O(118,e|0,4405)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}wi(a,b,4);c=CI(a,c,4,d);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=e+16|0;return c|0}a=N()|0;hc(b)}Q(a|0)}p()}function E3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){b=ec(8);x[114414]=0;c=O(118,e|0,4405)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}wi(a,b,2);c=BI(a,c,2,d);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=e+16|0;return c|0}a=N()|0;hc(b)}Q(a|0)}p()}function D3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){b=ec(8);x[114414]=0;c=O(118,e|0,4405)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}a=oc(b,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}wi(a,b,4);c=BI(a,c,4,d);C[a+16>>3]=+(c>>>0)/+(b|0)+C[a+16>>3];hb=e+16|0;return c|0}a=N()|0;hc(b)}Q(a|0)}p()}function cA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;DR(a,b);e=b+8|0;e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);Rc(a,(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))+504|0);CR(a,d);a:{b=b+32|0;if(!(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))){break a}b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!Rc(a,b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24))){break a}Vn(a,c);return}Sb(c,0,80)}function PK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;d=hb-32|0;hb=d;uD(d+24|0,a,b);b=hb-16|0;hb=b;g=x[d+28>>2];e=x[d+24>>2];h=g-e|0;if((e|0)!=(g|0)){Bg(c,e,h)}g=e;e=D((h|0)/6|0,6);x[b+12>>2]=g+e;x[b+8>>2]=c+e;gd(d+16|0,b+12|0,b+8|0);hb=b+16|0;i=d,j=On(a,x[d+16>>2]),x[i+12>>2]=j;i=d,j=On(c,x[d+20>>2]),x[i+8>>2]=j;gd(f+8|0,d+12|0,d+8|0);hb=d+32|0;hb=f+16|0;return x[f+12>>2]}function i6(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;b=R(2052,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,6870,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=-1}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function Fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){Cb(y[c|0]);Cb(y[c+1|0]);f=a,g=Cb(y[c+2|0])|Cb(y[c+3|0])<<8,w[f>>1]=g;Cb(y[c+4|0]);Cb(y[c+5|0]);f=a,g=Cb(y[c+6|0])|Cb(y[c+7|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<3}function Eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){Cb(y[c+3|0]);Cb(y[c+2|0]);f=a,g=Cb(y[c+1|0])|Cb(y[c|0])<<8,w[f>>1]=g;Cb(y[c+7|0]);Cb(y[c+6|0]);f=a,g=Cb(y[c+5|0])|Cb(y[c+4|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<3}function Dx(a){var b=E(0),c=E(0),d=0,e=E(0),f=0;b=E(Ze(x[a+16>>2])>>>0);c=E(E(mb[x[x[a>>2]+200>>2]](a))*b);d=a,e=E(E(c*E(2.0480000972747803))*E(mb[x[x[a>>2]+192>>2]](a))),B[d+4248>>2]=e;d=a,f=Uh(E(E(c*E(4.0960001945495605))+E(8192))),x[d+4256>>2]=f;c=E(mb[x[x[a>>2]+204>>2]](a));B[a+4252>>2]=c;b=E(c/b);if(!(mb[x[x[a>>2]+188>>2]](a)|0)){b=MG(E(b*E(3.1415927410125732)))}B[a+4244>>2]=b+b}function z5(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;b=R(2090,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,3191,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function y5(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;b=R(2091,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,3259,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function x5(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;b=R(2092,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,3112,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function w5(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;b=R(2093,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,3692,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function g6(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;b=R(2054,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,2302,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function X8(a){a=a|0;var b=0,c=0;b=x[a+20>>2];x[b+148>>2]=-1;x[114414]=0;P(464,b+4|0,8);b=x[114414];x[114414]=0;if((b|0)!=1){b=x[a+4264>>2];c=x[x[a+20>>2]+4>>2];a=x[a+4260>>2];v[c|0]=a;v[c+1|0]=a>>>8;v[c+2|0]=a>>>16;v[c+3|0]=a>>>24;v[c+4|0]=b;v[c+5|0]=b>>>8;v[c+6|0]=b>>>16;v[c+7|0]=b>>>24;return}b=S(75016)|0;if((ib|0)==(ca(75016)|0)){Y(b|0)|0;jt(x[a+20>>2]+4|0);_();return}Q(b|0);p()}function N5(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;b=R(2077,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,8637,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function M5(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;b=R(2078,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,5287,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function L5(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;b=R(2079,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,4917,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function K5(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;b=R(2080,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,5678,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function J5(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;b=R(2081,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,1805,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function I5(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;b=R(2082,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,3416,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function B5(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;b=R(2088,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,3502,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function A5(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;b=R(2089,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,3384,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();b=0}return b|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function ci(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;f=hb-16|0;hb=f;e=d+8|0;c=hb-16|0;hb=c;b=hb-16|0;hb=b;x[c+4>>2]=1;g=c,h=ID(1),x[g+8>>2]=h;hb=b+16|0;b=x[c+8>>2];x[114414]=0;R(241,b|0)|0;b=x[114414];x[114414]=0;a:{if((b|0)!=1){b=Go(c);Fo(e,ic(b),b);dD(c);hb=c+16|0;break a}a=N()|0;dD(c);Q(a|0);p()}hb=f+16|0;zm(a,e);Ab(e);hb=d+16|0;x[a+8>>2]=0;x[a+12>>2]=0;return a|0}function y0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;while(1){a:{if((c|0)<=(e|0)){break a}f=x[a+24>>2];g=x[a+28>>2];if(f>>>0>=g>>>0){if((mb[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){break a}e=e+1|0;b=b+4|0}else{x[d+12>>2]=g-f>>2;x[d+8>>2]=c-e;f=x[be(d+12|0,d+8|0)>>2];Kh(x[a+24>>2],b,f);g=f<<2;x[a+24>>2]=g+x[a+24>>2];e=e+f|0;b=b+g|0}continue}break}hb=d+16|0;return e|0}function f6(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;c=+ha(2055,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,3890,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();c=0}return+c}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function d6(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;c=+ha(2057,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,3854,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();c=0}return+c}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function O5(a){a=a|0;var b=0,c=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[114414]=0;c=+ha(2076,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){break b}}Y(S(0)|0)|0;x[114414]=0;X(2023,6130,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();c=0}return+c}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function H$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;g=hb-16|0;hb=g;e=x[b>>2];a:{if(!e|!c){break a}d=a?d:0;while(1){f=as(d>>>0<4?g+12|0:a,x[e>>2],0);if((f|0)==-1){h=-1;break a}if(a){if(d>>>0<=3){if(d>>>0<f>>>0){break a}sc(a,g+12|0,f)}d=d-f|0;a=a+f|0}else{a=0}if(!x[e>>2]){e=0;break a}h=f+h|0;e=e+4|0;c=c-1|0;if(c){continue}break}}if(a){x[b>>2]=e}hb=g+16|0;return h|0}function SZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;d=hb-16|0;hb=d;a:{if(!re(f)){x[a+8>>2]=x[f+8>>2];b=x[f+4>>2];x[a>>2]=x[f>>2];x[a+4>>2]=b;break a}c=x[f>>2];e=hb-16|0;hb=e;b:{c:{f=x[f+4>>2];d:{if(Po(f)){b=a;Ce(a,f);break d}if(f>>>0>1073741807){break c}Zj(e+8|0,a,ql(f)+1|0);b=x[e+8>>2];Ue(a,b);Ff(a,x[e+12>>2]);ae(a,f)}Kh(b,c,f+1|0);hb=e+16|0;break b}Ef();p()}}hb=d+16|0}function J7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ai(a,b,c,d);x[a+4208>>2]=1060320051;x[a+4212>>2]=1041865114;x[a+4224>>2]=1049951732;b=a+4216|0;x[b>>2]=1065353216;x[b+4>>2]=1049951732;x[a>>2]=79604;x[114414]=0;U(1673,a+44|0,2,2)|0;b=x[114414];x[114414]=0;a:{if((b|0)==1){break a}x[114414]=0;W(1674,a|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}return a|0}b=N()|0;xf(a);Q(b|0);p()}function Ema(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;FB(d,b);e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0;hb=c+16|0}return a|0}function Uf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-16|0;hb=e;a:{if(!re(b)){x[a+8>>2]=x[b+8>>2];c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;break a}f=x[b>>2];d=hb-16|0;hb=d;b:{c:{c=x[b+4>>2];d:{if(il(c)){b=a;Ce(a,c);break d}if(c>>>0>2147483631){break c}Gh(d+8|0,a,cj(c)+1|0);b=x[d+8>>2];Ue(a,b);Ff(a,x[d+12>>2]);ae(a,c)}Le(b,f,c+1|0);hb=d+16|0;break b}Ef();p()}}hb=e+16|0;return a|0}function QH(a,b){a=a|0;b=+b;var c=0,d=0;c=hb-16|0;hb=c;a:{b:{c:{if(!(!(b<=0)&b<=4)){d=ec(8);x[114414]=0;c=O(118,c|0,4086)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}a=oc(d,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}d=gg(65536/b);a=a+32|0;x[x[a>>2]+480244>>2]=d;sp(x[a>>2]);hb=c+16|0;return}a=N()|0;hc(d)}Q(a|0)}p()}function OH(a,b){a=a|0;b=+b;var c=0,d=0;c=hb-16|0;hb=c;a:{b:{c:{if(!(!(b<=0)&b<=4)){d=ec(8);x[114414]=0;c=O(118,c|0,4107)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}a=oc(d,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}d=gg(b*65536);a=a+32|0;x[x[a>>2]+480240>>2]=d;sp(x[a>>2]);hb=c+16|0;return}a=N()|0;hc(d)}Q(a|0)}p()}function Iia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-48|0;hb=c;a:{b:{if(Mt(a)>>>0<b>>>0){if($u(a)>>>0<b>>>0){break b}Dz(a);d=Cz(c+32|0);x[114414]=0;P(908,d|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=c+16|0;Ej(b,a);e=c+8|0;Mk(e,a);x[114414]=0;T(909,d|0,b|0,e|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}Bz(a,d);ce(d)}hb=c+48|0;return}Vc();p()}a=N()|0;ce(d);Q(a|0);p()}function ey(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=H(c,.999);c=d*32768;h=d*3.141592653589793;i=Ts(b);while(1){e=((f^-1)<<12&28672)+(f>>>3|0)|0;if((e|0)!=16384){g=+(e-16384|0);d=g*.000244140625;g=Ts(M(g*-152587890625e-16*d+1)*b);d=h*d;d=g*oi(d)/(d*i)}else{d=1}d=J(c*d+.5);a:{if(F(d)<2147483648){e=~~d;break a}e=-2147483648}w[a>>1]=e;a=a+2|0;f=f+1|0;if((f|0)!=32768){continue}break}}function aE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=Ub(d,c);x[114414]=0;T(2897,d+16|0,b|0,e|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){x[114414]=0;a=O(2898,a|0,d+16|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break b}xb(d+16|0);xb(e);x[a>>2]=74260;c=x[b+4>>2];x[a+8>>2]=x[b>>2];x[a+12>>2]=c;hb=d+32|0;return a|0}c=N()|0;break a}c=N()|0;xb(d+16|0)}xb(e);Q(c|0);p()}function raa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;f=-1;e=hb-16|0;hb=e;c=e+8|0;g=d+8|0;$K(c,g);h=Eb(c);c=nd(a,ac(e,c));if((h|0)==(c|0)){Yc(a,Eb(e+8|0))}hb=e+16|0;a=(c|0)==(h|0);if(!a){bL(g)}a:{if(!a){break a}f=0;if(!eL(d+8|0)){break a}if(b){a=d+16|0;if(x[b>>2]!=(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))|x[b+4>>2]){break a}}f=1}hb=d+32|0;return f|0}function Vda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;yb(b);Xc(a+8|0);c=Og(b);if(c){FN(a,c);e=x[b>>2];g=x[b+4>>2];f=hb-16|0;hb=f;b=Yq(f,a,c);c=yb(a);h=x[b+4>>2];x[114414]=0;c=Z(1214,c|0,e|0,g|0,h|0)|0;e=x[114414];x[114414]=0;a:{if((e|0)!=1){x[b+4>>2]=c;Jb(b);hb=f+16|0;break a}a=N()|0;Jb(b);Q(a|0);p()}}hb=d+16|0;return a|0}function BN(a,b,c){var d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;x[a+4>>2]=0;a:{if(b){b:{if(Mt(a)>>>0>=b>>>0){x[a+4>>2]=b;break b}Dz(a);e=Cz(d+16|0);x[114414]=0;f=O(904,a|0,b|0)|0;g=x[114414];x[114414]=0;if((g|0)==1){break a}x[114414]=0;P(905,e|0,f|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}x[e+4>>2]=b;Bz(a,e);ce(e)}Ej(d,a);Gq(d,b,y[c|0])}hb=d+32|0;return}a=N()|0;ce(e);Q(a|0);p()}function pz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;x[e+8>>2]=c;f=e,g=uf(b),x[f+28>>2]=g;c=e+8|0;bf(c,b,x[Mb(c,e+28|0)>>2]);x[114414]=0;b=R(421,c|0)|0;c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}c=x[e+8>>2];x[114414]=0;Z(1047,a|0,b|0,c|0,d|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break a}Hc(e+8|0);hb=e+32|0;return 1}a=N()|0;Hc(e+8|0);Q(a|0);p()}function iT(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=777268804){break a}b=a+4|0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if((c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24))>>>0<14){break a}b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if((b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24))>>>0>256){break a}a=a+8|0;d=!(y[a|0]|y[a+1|0]<<8)}return d}function KP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;yb(b);Xc(a+8|0);c=wc(b);if(c){Pk(a,c);e=x[b>>2];g=x[b+4>>2];f=hb-16|0;hb=f;b=th(f,a,c);c=yb(a);h=x[b+4>>2];x[114414]=0;c=Z(965,c|0,e|0,g|0,h|0)|0;e=x[114414];x[114414]=0;a:{if((e|0)!=1){x[b+4>>2]=c;Jb(b);hb=f+16|0;break a}a=N()|0;Jb(b);Q(a|0);p()}}hb=d+16|0;return a|0}function uda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;Rj(a);e=x[b+4>>2];yb(a);f=Fb(d+16|0,c);g=Fb(d+8|0,x[a>>2]);h=Fb(d,x[b+4>>2]);i=d,j=Xh(x[f>>2],x[g>>2],x[h>>2]),x[i+24>>2]=j;x[b+4>>2]=x[d+24>>2];i=b,j=Rz(yb(a),c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Mq(a,qc(a));hb=d+32|0;return e|0}function rja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;Xn(a);e=x[b+4>>2];yb(a);f=Fb(d+16|0,c);g=Fb(d+8|0,x[a>>2]);h=Fb(d,x[b+4>>2]);i=d,j=Xh(x[f>>2],x[g>>2],x[h>>2]),x[i+24>>2]=j;x[b+4>>2]=x[d+24>>2];i=b,j=Rz(yb(a),c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];wA(a,wc(a));hb=d+32|0;return e|0}function jaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;tu(a);e=x[b+4>>2];yb(a);f=Fb(d+16|0,c);g=Fb(d+8|0,x[a>>2]);h=Fb(d,x[b+4>>2]);i=d,j=ZR(x[f>>2],x[g>>2],x[h>>2]),x[i+24>>2]=j;x[b+4>>2]=x[d+24>>2];yb(a);i=b,j=UK(c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];FA(a,hg(a));hb=d+32|0;return e|0}function Mea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;Ye(a);e=x[b+4>>2];yb(a);f=Fb(d+16|0,c);g=Fb(d+8|0,x[a>>2]);h=Fb(d,x[b+4>>2]);i=d,j=Xh(x[f>>2],x[g>>2],x[h>>2]),x[i+24>>2]=j;x[b+4>>2]=x[d+24>>2];i=b,j=Rz(yb(a),c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];vk(a,Lb(a));hb=d+32|0;return e|0}function sia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;QP(a,c+11|0);if((y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24))==1414807888){QP(a,c+11|0);v[b|0]=1;a=0}else{a=1}b=hb-16|0;hb=b;a:{b:{a=(c+11|0)+a|0;if(a){a=Ub(b,a);x[114414]=0;d=R(947,a|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break b}xb(a)}hb=b+16|0;break a}b=N()|0;xb(a);Q(b|0);p()}hb=c+16|0;return d|0}function Hy(a,b,c,d){var e=0,f=0;a:{if(x[a+1074392>>2]!=(c|0)){break a}e=D(b,896)+a|0;f=e+1075072|0;b:{if(d){c=D(b,896)+a|0;x[c+1075680>>2]=0;d=c+1074992|0;x[d>>2]=0;x[d+4>>2]=0;c=x[c+1075072>>2]|4096;break b}c=D(b,896)+a|0;x[c+1075672>>2]=0;c=x[c+1075072>>2]}x[f>>2]=c|2097152;Ql(a,b,255,0);if(!(y[e+1075073|0]&2)){break a}a=a+1304392|0;if(!zd(a)){break a}Ji(x[a>>2],b,0)}}function E8(a,b){a=a|0;b=b|0;var c=E(0);a:{switch(b|0){case 0:return E(B[a+4220>>2]);case 1:return E(B[a+4224>>2]);case 2:return E(B[a+4228>>2]);case 3:return E(y[a+4240|0]?E(1):E(0));case 4:return E(E(E(x[a+4232>>2])*E(.03125)));case 5:return E(y[a+4241|0]?E(1):E(0));case 6:return E(y[a+4242|0]?E(1):E(0));case 7:c=y[a+4244|0]?E(1):E(0);break;default:break a}}return E(c)}function DH(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b>>>0>=256){a=ec(8);x[114414]=0;c=O(118,c|0,6687)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break b}a=x[a+32>>2]+D(b,896)|0;x[a+1075e3>>2]=0;x[a+1075060>>2]=0;hb=c+16|0;return}b=N()|0;hc(a)}Q(b|0)}p()}function cea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[d>>2]=x[a+8>>2];e=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=e+(b<<5);a:{if(x[d>>2]!=x[d+4>>2]){while(1){b=x[a+16>>2];e=x[d>>2];x[114414]=0;T(1164,b|0,e|0,c|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[d>>2]+32|0;x[d>>2]=b;if((b|0)!=x[d+4>>2]){continue}break}}Ac(d);hb=d+16|0;return}a=N()|0;Ac(d);Q(a|0);p()}function P9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[d>>2]=x[a+8>>2];e=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=e+D(b,52);a:{if(x[d>>2]!=x[d+4>>2]){while(1){b=x[a+16>>2];e=x[d>>2];x[114414]=0;T(1603,b|0,e|0,c|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[d>>2]+52|0;x[d>>2]=b;if((b|0)!=x[d+4>>2]){continue}break}}Ac(d);hb=d+16|0;return}a=N()|0;Ac(d);Q(a|0);p()}function j9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;c=Me(64);x[114414]=0;e=R(1440,c|0)|0;f=x[114414];x[114414]=0;a:{if((f|0)!=1){c=sy(d,e);e=x[c>>2];x[114414]=0;a=U(1664,e|0,a|0,b|0)|0;b=x[114414];x[114414]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}ry(d+8|0);break b}a=N()|0;Tf(c);break a}iq(d+8|0,c)}Tf(c);hb=d+16|0;return x[d+8>>2]}a=N()|0;_b(c)}Q(a|0);p()}function Yma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+24>>2]=b;a:{b=rm(d+8|0,a+8|0,OA(b,c));if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];f=x[d+24>>2];x[114414]=0;T(481,c|0,e|0,f|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}x[b>>2]=x[b>>2]+2;ge(d+24|0);if(x[b>>2]!=x[b+4>>2]){continue}break}}Ac(b);hb=d+32|0;return}a=N()|0;Ac(b);Q(a|0);p()}function Lda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[d+12>>2]=0;U(1223,a+8|0,d+12|0,d+8|0)|0;e=x[114414];x[114414]=0;a:{if((e|0)!=1){hb=d+16|0;break a}S(0)|0;zb();p()}d=Dk(a+12|0);v[a+30|0]=c;w[a+28>>1]=0;x[a+24>>2]=b;x[114414]=0;P(1222,a|0,1);b=x[114414];x[114414]=0;if((b|0)!=1){return a|0}b=N()|0;Ge(d);DN(a);Q(b|0);p()}function Kka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[d>>2]=x[a+8>>2];e=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=e+D(b,6);a:{if(x[d>>2]!=x[d+4>>2]){while(1){b=x[a+16>>2];e=x[d>>2];x[114414]=0;T(681,b|0,e|0,c|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[d>>2]+6|0;x[d>>2]=b;if((b|0)!=x[d+4>>2]){continue}break}}Ac(d);hb=d+16|0;return}a=N()|0;Ac(d);Q(a|0);p()}function Ika(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=-1;a:{if(!Tj(a,d+8|0)){break a}c=d+8|0;b:{if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=(Qj(5099)|0)){break b}c=c+4|0;if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))>>>0>259){break b}e=(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))>>>0>255}c=0;if(!e){break a}c=kf(a,b,36,0)}hb=d+16|0;return c|0}function t4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;b=b+4|0;yb(b);Xc(a+8|0);c=rd(b);if(c){NB(a,c);f=x[b>>2];g=x[b+4>>2];e=hb-16|0;hb=e;b=Hm(e,a,c);a=yb(a);c=x[b+4>>2];x[114414]=0;a=Z(2155,a|0,f|0,g|0,c|0)|0;c=x[114414];x[114414]=0;a:{if((c|0)!=1){x[b+4>>2]=a;Jb(b);hb=e+16|0;break a}a=N()|0;Jb(b);Q(a|0);p()}}hb=d+16|0}function Op(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;e=bc(a);f=dc(a);b=hb-16|0;hb=b;x[b>>2]=f;x[b+8>>2]=e;if(Hb(b+8|0,b)){while(1){e=b+8|0;d=C[x[e>>2]>>3]+d;Yy(e);if(Hb(e,b)){continue}break}}hb=b+16|0;g=c,h=bc(a),x[g+8>>2]=h;g=c,h=dc(a),x[g>>2]=h;if(Hb(c+8|0,c)){d=-d;while(1){a=c+8|0;b=x[a>>2];d=C[b>>3]+d;C[b>>3]=d;Yy(a);if(Hb(a,c)){continue}break}}hb=c+16|0}function yK(a,b){var c=0,d=0,e=0,f=E(0),g=0,h=E(0);c=hb-16|0;hb=c;e=0;a:{if(!Jf(x[x[a>>2]-12>>2]+a|0)){break a}x[c+12>>2]=0;Ri(a,c+12|0);d=x[c+12>>2];e=0;if(d>>>0>65535){break a}Il(b,d);if(x[c+12>>2]){d=0;while(1){x[c+8>>2]=0;lp(a,c+8|0);f=B[c+8>>2];g=Pb(b,d),h=f,B[g>>2]=h;d=d+1|0;if(d>>>0<A[c+12>>2]){continue}break}}e=Jf(x[x[a>>2]-12>>2]+a|0)}d=e;hb=c+16|0;return d}function xK(a,b){var c=0,d=0,e=0,f=E(0),g=0,h=E(0);c=hb-16|0;hb=c;e=0;a:{if(!Jf(x[x[a>>2]-12>>2]+a|0)){break a}w[c+14>>1]=0;zf(a,c+14|0);d=z[c+14>>1];e=0;if(d>>>0>65535){break a}Il(b,d);if(z[c+14>>1]){d=0;while(1){x[c+8>>2]=0;lp(a,c+8|0);f=B[c+8>>2];g=Pb(b,d),h=f,B[g>>2]=h;d=d+1|0;if(d>>>0<z[c+14>>1]){continue}break}}e=Jf(x[x[a>>2]-12>>2]+a|0)}a=e;hb=c+16|0;return a}function qk(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=hb-32|0;hb=c;f=tc(c+24|0,x[a>>2]);d=x[e+8>>2];g=x[d>>2];d=x[d+4>>2];x[c+16>>2]=g;x[c+20>>2]=d;h=x[f+4>>2];x[c+8>>2]=x[f>>2];x[c+12>>2]=h;x[c>>2]=g;x[c+4>>2]=d;f=Kc(c+8|0,c);hb=c+32|0;if(f){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}hb=e+16|0;return a}function Jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=(c>>>0)/6;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){Cb(y[c|0]);f=a,g=Cb(y[c+1|0])|Cb(y[c+2|0])<<8,w[f>>1]=g;Cb(y[c+3|0]);f=a,g=Cb(y[c+4|0])|Cb(y[c+5|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+6|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return D(d,6)|0}function Ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=(c>>>0)/6;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){Cb(y[c+2|0]);f=a,g=Cb(y[c+1|0])|Cb(y[c|0])<<8,w[f>>1]=g;Cb(y[c+5|0]);f=a,g=Cb(y[c+4|0])|Cb(y[c+3|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+6|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return D(d,6)|0}function El(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return v[a+47360|0]}if(a>>>0<=511){return v[(a>>>5|0)+47360|0]+5|0}return v[(a>>>10|0)+47360|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return v[(a>>>15|0)+47360|0]+15|0}return v[(a>>>20|0)+47360|0]+20|0}if(a>>>0<=536870911){return v[(a>>>25|0)+47360|0]+25|0}a=v[(a>>>30|0)+47360|0]+30|0}else{a=0}return a}function $k(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=hb-16|0;hb=h;if(2147483631-b>>>0>=c>>>0){i=Rb(a);if(b>>>0<1073741799){x[h+12>>2]=b<<1;x[h>>2]=b+c;c=cj(x[_c(h,h+12|0)>>2])+1|0}else{c=2147483631}Gh(h,a,c);j=x[h>>2];if(e){Le(j,i,e)}c=e+f|0;if((c|0)!=(d|0)){Le((e+j|0)+g|0,(e+i|0)+f|0,d-c|0)}b=b+1|0;if((b|0)!=11){ag(a,i,b)}Ue(a,j);Ff(a,x[h+4>>2]);hb=h+16|0;return}Ef();p()}function r6(a){a=a|0;var b=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;if((b|0)!=1){b=x[a+24>>2];if(b){_b(ys(b))}x[a+24>>2]=0;b=x[a+20>>2];if(b){_b(b);x[a+20>>2]=0}_b(a);return}Y(S(0)|0)|0;x[114414]=0;X(2023,1585,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)!=1){_();return}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function gF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;f=x[mc(a)>>2];d=x[c>>2]-x[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=x[b>>2];i=x[a>>2];g=$r((f|0)!=2542?x[a>>2]:0,d);if(g){if((f|0)!=2542){ke(a)}x[e+4>>2]=2484;f=Pd(e+8|0,g,e+4|0);cF(a,f);Jc(f);x[b>>2]=x[a>>2]+(h-i|0);x[c>>2]=x[a>>2]+(d&-4);hb=e+16|0;return}Wv();p()}function Dr(a,b,c){var d=0,e=0;if(c&2048){v[a|0]=43;a=a+1|0}if(c&1024){v[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){v[a|0]=46;v[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}v[a|0]=b;return(d|0)!=260}function Dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){Cb(y[c|0]);Cb(y[c+1|0]);Cb(y[c+2|0]);Cb(y[c+3|0]);Cb(y[c+4|0]);Cb(y[c+5|0]);f=a,g=Cb(y[c+6|0])|Cb(y[c+7|0])<<8,w[f>>1]=g;a=a+2|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<3}function Cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){Cb(y[c+7|0]);Cb(y[c+6|0]);Cb(y[c+5|0]);Cb(y[c+4|0]);Cb(y[c+3|0]);Cb(y[c+2|0]);f=a,g=Cb(y[c+1|0])|Cb(y[c|0])<<8,w[f>>1]=g;a=a+2|0;c=c+8|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<3}function Bj(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;if(!od(a)){c=gO(a);e=Gj(a);b=hb-16|0;hb=b;x[b>>2]=e;x[b+8>>2]=c;a:{if(!wt(b+8|0,b)){break a}while(1){c=hb-16|0;hb=c;x[c+8>>2]=x[b+8>>2];e=x[dm(c+8|0)>>2];hb=c+16|0;if(z[e>>1]!=65535){break a}c=b+8|0;dm(c);if(wt(c,b)){continue}break}}hb=b+16|0;x[d+8>>2]=x[b+8>>2];b=OA(bc(a),x[d+8>>2])}hb=d+16|0;return b&65535}function qT(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=89478485;x[114414]=0;x[b+8>>2]=2147483647;e=O(35,b+12|0,b+8|0)|0;f=x[114414];x[114414]=0;a:{if((f|0)!=1){hb=b+16|0;b=x[e>>2];break a}S(0)|0;zb();p()}if(b>>>0>=d>>>0){a=cm(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Vc();p()}function NP(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28486832|y[a+63|0]!=26|(y[a+66|0]|y[a+65|0]!=16&y[a+65|0]!=1)){break a}if(y[a- -64|0]&3){break a}b=a+78|0;if((y[b|0]|y[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((y[a|0]|y[a+1|0]<<8)>>>0>127){break a}c=hb-16|0;hb=c;d=KB(b,a);hb=c+16|0;a=d?a:b;c=(y[a|0]|y[a+1|0]<<8)!=0}return c}function K8(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[c>>2]=x[a+8>>2];d=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=d+(b<<11);a:{if(x[c>>2]!=x[c+4>>2]){while(1){b=x[a+16>>2];d=x[c>>2];x[114414]=0;P(1684,b|0,d|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[c>>2]+2048|0;x[c>>2]=b;if((b|0)!=x[c+4>>2]){continue}break}}Ac(c);hb=c+16|0;return}a=N()|0;Ac(c);Q(a|0);p()}function Dp(a,b,c,d){a:{if(x[a+480180>>2]==4){if(c){v[b+830|0]=y[b+830|0]&15|c<<4;break a}c=y[b+830|0]>>>4|0;break a}if(d){if(c){v[b+854|0]=c;break a}c=y[b+854|0];break a}if(c){v[b+830|0]=c;break a}c=y[b+830|0]}b:{if(!(v[b+872|0]&1)){break b}c=x[b+688>>2]+((c&255)<<2)|0;x[b+688>>2]=(c|0)>=256?256:c;if(!(x[a+480180>>2]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function l6(a,b){a=a|0;b=b|0;var c=0;x[114414]=0;W(2048,a|0);c=x[114414];x[114414]=0;a:{b:{if((c|0)!=1){x[a+16>>2]=b;b=x[a+20>>2];if(!b){break b}_b(b);x[a+20>>2]=0;return}Y(S(0)|0)|0;x[114414]=0;X(2023,2146,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_()}return}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function oka(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[c>>2]=x[a+8>>2];d=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=d+D(b,33);a:{if(x[c>>2]!=x[c+4>>2]){while(1){b=x[a+16>>2];d=x[c>>2];x[114414]=0;P(739,b|0,d|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[c>>2]+33|0;x[c>>2]=b;if((b|0)!=x[c+4>>2]){continue}break}}Ac(c);hb=c+16|0;return}a=N()|0;Ac(c);Q(a|0);p()}function i_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;f=x[mc(a)>>2];d=x[c>>2]-x[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:1;h=x[b>>2];i=x[a>>2];g=$r((f|0)!=2542?x[a>>2]:0,d);if(g){if((f|0)!=2542){ke(a)}x[e+4>>2]=2484;f=Pd(e+8|0,g,e+4|0);cF(a,f);Jc(f);x[b>>2]=x[a>>2]+(h-i|0);x[c>>2]=d+x[a>>2];hb=e+16|0;return}Wv();p()}function Nka(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[c>>2]=x[a+8>>2];d=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=d+D(b,48);a:{if(x[c>>2]!=x[c+4>>2]){while(1){b=x[a+16>>2];d=x[c>>2];x[114414]=0;P(713,b|0,d|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[c>>2]+48|0;x[c>>2]=b;if((b|0)!=x[c+4>>2]){continue}break}}Ac(c);hb=c+16|0;return}a=N()|0;Ac(c);Q(a|0);p()}function MH(a,b){a=a|0;b=+b;var c=0,d=0;c=hb-16|0;hb=c;a:{b:{c:{if(!(!(b<0)&b<=1)){d=ec(8);x[114414]=0;c=O(118,c|0,7596)|0;a=x[114414];x[114414]=0;if((a|0)==1){break c}a=oc(d,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);break b}d=gg(b*256);x[x[a+32>>2]+1074444>>2]=d;hb=c+16|0;return}a=N()|0;hc(d)}Q(a|0)}p()}function iY(a){a=a|0;if(y[461152]){return x[115287]}if(!y[461672]){v[461672]=1}$c(461504,70852);$c(461516,70880);$c(461528,70908);$c(461540,70940);$c(461552,70980);$c(461564,71016);$c(461576,71044);$c(461588,71080);$c(461600,71096);$c(461612,71112);$c(461624,71128);$c(461636,71144);$c(461648,71160);$c(461660,71176);v[461152]=1;x[115287]=461504;return 461504}function RH(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b-513>>>0<=4294966814){a=ec(8);x[114414]=0;c=O(118,c|0,5320)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break b}x[x[a+32>>2]+1074420>>2]=D(b,1e4);hb=c+16|0;return}b=N()|0;hc(a)}Q(b|0)}p()}function uja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=E(0);if(d){e=a+e|0;a=0;while(1){h=de(E(nf(B[b>>2],E(-1))*E(128)));a:{if(E(F(h))<E(2147483648)){g=~~h;break a}g=-2147483648}f=hb-16|0;hb=f;x[f+12>>2]=g;x[f+8>>2]=-128;x[f+4>>2]=127;g=v[Bf(f+8|0,be(f+12|0,f+4|0))|0];hb=f+16|0;v[e|0]=g;e=c+e|0;b=b+4|0;a=a+1|0;if((d|0)!=(a|0)){continue}break}}}function Ria(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[c>>2]=x[a+8>>2];d=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=d+(b<<3);a:{if(x[c>>2]!=x[c+4>>2]){while(1){b=x[a+16>>2];d=x[c>>2];x[114414]=0;P(897,b|0,d|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}b=x[c>>2]+8|0;x[c>>2]=b;if((b|0)!=x[c+4>>2]){continue}break}}Ac(c);hb=c+16|0;return}a=N()|0;Ac(c);Q(a|0);p()}function KI(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=x[d+8>>2];b:{c:{e=x[a>>2];f=wf(e);if((f|0)==(Bb(c)|0)){x[114414]=0;c=aa(311,c|0,0,-1,e|0,f|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){break c}c=!c}else{c=0}break b}S(0)|0;zb();p()}if(c){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}hb=d+16|0;return a}function X6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ai(a,b,c,d);x[a+4272>>2]=1065353216;x[a+4208>>2]=1056880300;x[a+4212>>2]=1050733080;x[a>>2]=80652;x[a+4216>>2]=1056964608;x[114414]=0;U(1673,a+44|0,2,2)|0;b=x[114414];x[114414]=0;a:{if((b|0)==1){break a}x[114414]=0;W(1674,a|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}return a|0}b=N()|0;xf(a);Q(b|0);p()}function TH(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){a=ec(8);x[114414]=0;c=O(118,c|0,2334)|0;b=x[114414];x[114414]=0;if((b|0)==1){break c}a=oc(a,c);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}b=N()|0;xb(c);break b}x[x[a+32>>2]+1074416>>2]=b;hb=c+16|0;return}b=N()|0;hc(a)}Q(b|0)}p()}function k6(a){a=a|0;var b=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){x[a+16>>2]=0;b=x[a+20>>2];if(!b){break b}_b(b);x[a+20>>2]=0;return}Y(S(0)|0)|0;x[114414]=0;X(2023,5037,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_()}return}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function Tm(a,b,c){var d=0,e=0,f=0;e=hb-16|0;hb=e;d=e+8|0;Dc(d,b);x[114414]=0;b=R(2511,d|0)|0;d=x[114414];x[114414]=0;a:{if((d|0)==1){break a}x[114414]=0;d=R(2520,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break a}x[c>>2]=d;x[114414]=0;P(2521,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Ob(e+8|0);hb=e+16|0;return}a=N()|0;Ob(e+8|0);Q(a|0);p()}function _I(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;c=Me(12);b=x[b>>2];a=x[a>>2];x[114414]=0;a=U(2035,c|0,a|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){b=hb-16|0;hb=b;x[114414]=0;x[b+12>>2]=a;a=U(2037,d+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;a:{if((c|0)!=1){hb=b+16|0;break a}S(0)|0;zb();p()}hb=d+16|0;return x[a>>2]}a=N()|0;_b(c);Q(a|0);p()}function Yx(a,b,c,d){var e=0,f=0;a:{e=y[a|0];f=y[c|0];b:{if(!(y[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){v[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(y[b|0]|(e-5&255)>>>0>1){break a}v[a|0]=(e|0)==5?7:6;v[b|0]=y[d|0];break b}if(!((e|0)!=10|(f|0)!=20|y[d|0]!=159)){v[a|0]=39;break b}if(y[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}v[a|0]=39;v[b|0]=y[d|0]}v[c|0]=0}}function Vm(a,b,c){var d=0,e=0,f=0;e=hb-16|0;hb=e;d=e+8|0;Dc(d,b);x[114414]=0;b=R(2480,d|0)|0;d=x[114414];x[114414]=0;a:{if((d|0)==1){break a}x[114414]=0;d=R(2494,b|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){break a}v[c|0]=d;x[114414]=0;P(2495,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Ob(e+8|0);hb=e+16|0;return}a=N()|0;Ob(e+8|0);Q(a|0);p()}function pda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=x[a>>2];b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(1263,c|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){S(0)|0;zb();p()}Ro(e,a);tr(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function fha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=x[a>>2];b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(1013,c|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){S(0)|0;zb();p()}cP(e,a);tr(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function Dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+16>>2]=b;e=d,f=Lz(a,b,c),x[e+24>>2]=f;a:{if(!Hb(d+24|0,d+16|0)){break a}x[d+8>>2]=x[d+24>>2];if(!Hb(ge(d+8|0),d+16|0)){break a}while(1){if(z[x[d+8>>2]>>1]!=z[c>>1]){a=d+24|0;w[x[a>>2]>>1]=z[x[d+8>>2]>>1];ge(a)}if(Hb(ge(d+8|0),d+16|0)){continue}break}}hb=d+32|0;return x[d+24>>2]}function m6(a){a=a|0;var b=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){a=x[a+20>>2];if(!a){break b}return Ld(a)|0}Y(S(0)|0)|0;x[114414]=0;X(2023,8009,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();return 0}return Ld(17386)|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function ji(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+8>>2]=b;b=0;g=6;a:{b:{if(Ag(a,f+8|0)){break b}g=4;h=nk(a);if(!zg(d,64,h)){break b}b=Qm(d,h);while(1){c:{yl(a);b=b-48|0;if(Ag(a,f+8|0)|(e|0)<2){break c}g=nk(a);if(!zg(d,64,g)){break a}e=e-1|0;b=Qm(d,g)+D(b,10)|0;continue}break}g=2;if(!Ag(a,f+8|0)){break a}}x[c>>2]=x[c>>2]|g}hb=f+16|0;return b}function ii(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+8>>2]=b;b=0;g=6;a:{b:{if(hh(a,f+8|0)){break b}g=4;h=wl(a);if(!lk(d,64,h)){break b}b=Pm(d,h);while(1){c:{Zm(a);b=b-48|0;if(hh(a,f+8|0)|(e|0)<2){break c}g=wl(a);if(!lk(d,64,g)){break a}e=e-1|0;b=Pm(d,g)+D(b,10)|0;continue}break}g=2;if(!hh(a,f+8|0)){break a}}x[c>>2]=x[c>>2]|g}hb=f+16|0;return b}function T3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=hb-32|0;hb=b;a:{a=Ws(a,$l(b+24|0,Cb(c),d),0);if(a+1>>>0>=3){a=ec(8);x[114414]=0;b=O(118,b+8|0,4262)|0;c=x[114414];x[114414]=0;b:{if((c|0)!=1){a=oc(a,b);x[114414]=0;T(2042,a|0,82448,2050);a=x[114414];x[114414]=0;if((a|0)!=1){break a}d=N()|0;xb(b);break b}d=N()|0;hc(a)}Q(d|0);p()}hb=b+32|0;return a|0}p()}function Pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>2;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(f){a=x[a+20>>2];b=f;g=d;while(1){g=(Cb(y[c|0])+g|0)+(Cb(y[c+1|0])<<8)|0;w[a>>1]=g;d=(Cb(y[c+2|0])+d|0)+(Cb(y[c+3|0])<<8)|0;w[a+2>>1]=d;a=a+4|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f<<2}function Mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>2;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(f){a=x[a+20>>2];b=f;g=d;while(1){g=(Cb(y[c+1|0])+g|0)+(Cb(y[c|0])<<8)|0;w[a>>1]=g;d=(Cb(y[c+3|0])+d|0)+(Cb(y[c+2|0])<<8)|0;w[a+2>>1]=d;a=a+4|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f<<2}function M$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=x[a+84>>2];f=x[e>>2];d=x[e+4>>2];h=x[a+28>>2];g=x[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){sc(f,h,g);f=g+x[e>>2]|0;x[e>>2]=f;d=x[e+4>>2]-g|0;x[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){sc(f,b,d);f=d+x[e>>2]|0;x[e>>2]=f;x[e+4>>2]=x[e+4>>2]-d}v[f|0]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;return c|0}function iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;x[f+12>>2]=d;Az(a,c,d);d=0;e=x[a+16>>2];if(e>>>0>c>>>0){x[f+8>>2]=e-c;d=x[Mb(f+8|0,f+12|0)>>2];e=hb-32|0;hb=e;a=a+4|0;h=e,i=bc(a),x[h+24>>2]=i;g=Fe(e+24|0,c);h=e,i=bc(a),x[h+8>>2]=i;h=e,i=Fe(e+8|0,c),x[h+16>>2]=i;NQ(g,Fe(e+16|0,d),b);hb=e+32|0}hb=f+16|0;return d|0}function cZ(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=x[a>>2];b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(174,c|0)|0;f=x[114414];x[114414]=0;if((f|0)==1){S(0)|0;zb();p()}Ro(e,a);tr(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function Mma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-48|0;hb=d;a:{b:{e=dM(b,c);if((e|0)!=-1){f=d,g=ud(b),x[f+16>>2]=g;f=d,g=Fe(d+16|0,e),x[f+24>>2]=g;f=d,g=Fe(d+24|0,1),x[f+32>>2]=g;c=td(d+40|0,d+32|0);f=d,g=jf(b),x[f>>2]=g;e=td(d+8|0,d);zx(b,x[c>>2],x[e>>2]);break b}if(!Bb(b)){break b}if(TI(b,c)){break b}hd(a);break a}Jd(a,b)}hb=d+48|0}
function sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;x[e+24>>2]=d;d=Vj(a,c);vf(e,x[a+28>>2]);f=x[e+12>>2];x[e+16>>2]=x[e+8>>2];x[e+20>>2]=f;a:{if(!d){if(Cd(a,5)){break a}}f=x[a+28>>2];PB(b,x[e+24>>2]);if(x[e+24>>2]){while(1){aO(f,uc(b,g));g=g+1|0;if(g>>>0<A[e+24>>2]){continue}break}}}a=hj(a,d,c,e+16|0);hb=e+32|0;return a|0}function kP(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=860902483){break a}b=a+4|0;b=y[b|0]|y[b+1|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>2|y[a+6|0]>128){break a}b=a+200|0;b=y[b|0]|y[b+1|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>3999){break a}b=a+140|0;if(!(y[b|0]|y[b+1|0]<<8)){break a}a=a+148|0;c=(y[a|0]|y[a+1|0]<<8)==12800}return c}function ema(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;a=nq(a);e=d,f=bc(b),x[e+8>>2]=f;e=d,f=dc(b),x[e>>2]=f;a:{if(Hb(d+8|0,d)){while(1){b=x[d+8>>2];if((Qj(b)|0)==(c|0)){b=yb(b);x[114414]=0;P(568,a|0,b|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}}b=d+8|0;Xi(b);if(Hb(b,d)){continue}break}}hb=d+16|0;return}b=N()|0;id(a);Q(b|0);p()}function Q6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ai(a,b,c,d);x[a+4208>>2]=1065353216;x[a+4212>>2]=1065353216;b=a+4216|0;x[b>>2]=1051372203;x[b+4>>2]=0;x[a>>2]=80856;x[114414]=0;U(1673,a+44|0,2,2)|0;b=x[114414];x[114414]=0;a:{if((b|0)==1){break a}x[114414]=0;W(1674,a|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}return a|0}b=N()|0;xf(a);Q(b|0);p()}function DX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+8>>2]=e;x[f+12>>2]=c;c=Bb(a);if(!((e|0)==-1|c>>>0<b>>>0)){x[f>>2]=c-b;g=f,h=x[Mb(f+12|0,f)>>2],x[g+4>>2]=h;b=on(Rb(a)+b|0,d,x[Mb(f+4|0,f+8|0)>>2]);a:{if(b){break a}b=-1;a=x[f+4>>2];c=x[f+8>>2];if(a>>>0<c>>>0){break a}b=a>>>0>c>>>0}hb=f+16|0;return b|0}om();p()}function Az(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(y[a+20|0]){break a}d=b;b=-1-b|0;b=d+(b>>>0<c>>>0?b:c)|0;if(b>>>0<=A[a+16>>2]){break a}b=Gz(b,4096);wQ(a,b-x[a+16>>2]|0);e=a,f=(h=a,i=Bc(a+4|0,x[a+16>>2]),j=b-x[a+16>>2]|0,g=x[x[a>>2]+48>>2],mb[g](h|0,i|0,j|0)|0)+x[a+16>>2]|0,x[e+16>>2]=f;if(!(mb[x[x[a>>2]+44>>2]](a)|0)){break a}v[a+20|0]=1}}function b0(a){a=a|0;a:{x[114414]=0;R(2455,459928)|0;a=x[114414];x[114414]=0;b:{if((a|0)==1){break b}x[114414]=0;R(2455,460264)|0;a=x[114414];x[114414]=0;if((a|0)==1){break b}x[114414]=0;R(2456,460012)|0;a=x[114414];x[114414]=0;if((a|0)==1){break b}x[114414]=0;R(2456,460348)|0;a=x[114414];x[114414]=0;if((a|0)==1){break b}break a}S(0)|0;zb();p()}}function Xx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-16|0;hb=f;a:{b:{while(1){h=g&255;if(Zx(b,c,h>>>0>1)){break b}wh(b,d);wh(c,e);g=g+1|0;if(h>>>0<3){continue}break}if(rn(y[b|0])>>>0>rn(y[d|0])>>>0){wh(b,d);wh(c,e)}v[f+13|0]=y[b|0];iz(a,f+13|0,c);v[b|0]=0;v[c|0]=0;break a}v[f+15|0]=0;v[f+14|0]=0;iz(a,f+15|0,f+14|0)}hb=f+16|0}function W8(a,b){a=a|0;b=b|0;var c=0;a:{b:{if((wc(x[a+20>>2]+4|0)|0)!=8){break b}c=x[x[a+20>>2]+4>>2];if((y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=1869112133){break b}b=x[x[a+20>>2]+4>>2];c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);b=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=c;x[a+4264>>2]=b;break a}OJ(a,b)}Ns(a)}function E5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-48|0;hb=d;a:{b:{e=dM(b,c);if((e|0)!=-1){f=d,g=ud(b),x[f+16>>2]=g;f=d,g=Fe(d+16|0,e),x[f+24>>2]=g;f=d,g=Fe(d+24|0,1),x[f+32>>2]=g;c=td(d+40|0,d+32|0);f=d,g=jf(b),x[f>>2]=g;e=td(d+8|0,d);zx(b,x[c>>2],x[e>>2]);break b}if(!Bb(b)){break b}if(TI(b,c)){break b}Wb(a);break a}Jd(a,b)}hb=d+48|0}function Cp(a,b,c,d){a:{if(x[a+480180>>2]==4){d=y[b+830|0];if(c){v[b+830|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){v[b+854|0]=c;break a}c=y[b+854|0];break a}if(c){v[b+830|0]=c;break a}c=y[b+830|0]}b:{if(!(v[b+872|0]&1)){break b}c=x[b+688>>2]-((c&255)<<2)|0;x[b+688>>2]=(c|0)>0?c:0;if(!(x[a+480180>>2]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function ZR(a,b,c){var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;e=hb-32|0;hb=e;d=hb-32|0;hb=d;x[d+16>>2]=b;x[d+24>>2]=a;x[d+8>>2]=c;b=x[d+24>>2];c=d+16|0;g=x[c>>2];a=x[d+8>>2]+D((b-g|0)/-6|0,6)|0;YR(d,g,b,a);gd(e+24|0,c,Fb(d,On(x[d+8>>2],a)));hb=d+32|0;x[e+16>>2]=x[e+24>>2];x[e+8>>2]=x[e+28>>2];gd(f+8|0,e+16|0,e+8|0);hb=e+32|0;hb=f+16|0;return x[f+12>>2]}function Qca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>2;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Cb(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=(Cb(y[c|0])|Cb(y[c+1|0])<<8)^32768,w[f>>1]=g;f=a,g=(Cb(y[c+2|0])|Cb(y[c+3|0])<<8)^32768,w[f+2>>1]=g;a=a+4|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<2}function Nca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>2;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Cb(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=(Cb(y[c+1|0])|Cb(y[c|0])<<8)^32768,w[f>>1]=g;f=a,g=(Cb(y[c+3|0])|Cb(y[c+2|0])<<8)^32768,w[f+2>>1]=g;a=a+4|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<2}function My(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;a:{if(x[b+480180>>2]&64671904){b=y[c+4|0];v[e+15|0]=0;x[a>>2]=y[(b&15)+25920|0];v[a+4|0]=y[e+15|0];break a}v[e+14|0]=0;f=y[c+4|0];if(!(y[c+3|0]!=4|x[b+480180>>2]!=4)){v[e+14|0]=1;f=f<<1}if(!(!d|!$b(b+1074312|0,66))){x[e+8>>2]=0;Qi(a,e+8|0,e+14|0);break a}x[e+4>>2]=f<<4;Qi(a,e+4|0,e+14|0)}hb=e+16|0}function mP(a){var b=0,c=0,d=0;a:{if(y[a+29|0]!=2){break a}b=y[a+28|0];if((b|0)!=26&(b|0)!=2|y[a+30|0]!=2){break a}b=y[a+31|0];if(b>>>0>21|!(1<<b&3146753)|y[a+33|0]>64){break a}b=y[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}b=a+28|0;a=a+20|0;while(1){c=y[a|0]-32&255;d=c>>>0<95;if(c>>>0>94){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}}return d}function kY(a){a=a|0;if(y[461144]){return x[115285]}if(!y[461496]){v[461496]=1}Pc(461328,1730);Pc(461340,1737);Pc(461352,1703);Pc(461364,1711);Pc(461376,1694);Pc(461388,1744);Pc(461400,1721);Pc(461412,5670);Pc(461424,5950);Pc(461436,7174);Pc(461448,8702);Pc(461460,1989);Pc(461472,6737);Pc(461484,2916);v[461144]=1;x[115285]=461328;return 461328}function fE(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;if(1073741807-b>>>0>=c>>>0){g=Rb(a);if(b>>>0<536870887){x[f+12>>2]=b<<1;x[f>>2]=b+c;c=ql(x[_c(f,f+12|0)>>2])+1|0}else{c=1073741807}Zj(f,a,c);h=x[f>>2];if(e){Kh(h,g,e)}if((d|0)!=(e|0)){c=e<<2;Kh(c+h|0,c+g|0,d-e|0)}b=b+1|0;if((b|0)!=2){Oo(g,b)}Ue(a,h);Ff(a,x[f+4>>2]);hb=f+16|0;return}Ef();p()}function Qv(a,b,c,d){v[a+53|0]=1;a:{if(x[a+4>>2]!=(c|0)){break a}v[a+52|0]=1;c=x[a+16>>2];b:{if(!c){x[a+36>>2]=1;x[a+24>>2]=d;x[a+16>>2]=b;if((d|0)!=1){break a}if(x[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=x[a+24>>2];if((c|0)==2){x[a+24>>2]=d;c=d}if(x[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}x[a+36>>2]=x[a+36>>2]+1}v[a+54|0]=1}}function AP(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=x[a>>2];b:{if(!b){break b}c=x[a+8>>2];if(!c){break b}d=x[a+12>>2];if(!d){break b}a=mb[d|0](b)|0;e=lb;if((e|0)<0){break b}if((mb[c|0](b,0,0,0)|0)<0){break a}if((mb[c|0](b,0,0,2)|0)<0){break a}d=mb[d|0](b)|0;f=lb;mb[c|0](b,a,e,0)|0;if((f|0)<0){break b}g=JQ(d,f)}return g}mb[c|0](b,a,e,0)|0;return 0}function Rx(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d>>2]=a;e=x[a+4>>2];x[d+4>>2]=e;x[d+8>>2]=e+D(b,52);a:{b=x[d+4>>2];f=x[d+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114414]=0;T(1603,e|0,b|0,c|0);e=x[114414];x[114414]=0;if((e|0)==1){break a}b=b+52|0;x[d+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(d);hb=d+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function vda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;a:{c=rm(e,a+8|0,Vy(b,c));if(x[c>>2]!=x[c+4>>2]){while(1){d=x[a+16>>2];f=x[c>>2];x[114414]=0;T(1248,d|0,f|0,b|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}d=x[c>>2]+2|0;x[c>>2]=d;b=b+2|0;if((d|0)!=x[c+4>>2]){continue}break}}Ac(c);hb=e+16|0;return}a=N()|0;Ac(c);Q(a|0);p()}function gha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{a=hb-16|0;hb=a;x[b>>2]=0;x[b+4>>2]=0;x[a+12>>2]=0;d=yb(c);x[114414]=0;U(1012,b+8|0,a+12|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];d=x[yb(c)>>2];e=yb(b),f=d,x[e>>2]=f;e=yb(c),f=0,x[e>>2]=f;x[c>>2]=0;x[c+4>>2]=0;hb=a+16|0;break a}S(0)|0;zb();p()}}function bG(a,b){var c=0,d=0;b=!x[a+24>>2]|b;x[a+16>>2]=b;if(b&x[a+20>>2]){c=hb-16|0;hb=c;b=ec(16);a=hb-16|0;hb=a;if(!y[457664]){v[457664]=1}dd(a+8|0,1,83656);d=x[a+12>>2];c=c+8|0;x[c>>2]=x[a+8>>2];x[c+4>>2]=d;hb=a+16|0;x[114414]=0;U(2435,b|0,5064,c|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){da(b|0,60608,2436);p()}a=N()|0;hc(b);Q(a|0);p()}}function Mp(a){var b=0,c=0,d=0;ml(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-16|0;P(1217,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;yb(a);b=x[a>>2];a=ei(a);x[114414]=0;T(27,b|0,a<<4,8);a=x[114414];x[114414]=0;if((a|0)==1){S(0)|0;zb();p()}}}function Kd(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;Bm(b);d=hb-16|0;hb=d;x[d+12>>2]=b;b=td(e+8|0,d+12|0);hb=d+16|0;a:{a=a+8|0;if(Lb(a)>>>0<=c>>>0){x[114414]=0;P(2612,a|0,c+1|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}}if(x[Pb(a,c)>>2]){Am(x[Pb(a,c)>>2])}d=ke(b);f=Pb(a,c),g=d,x[f>>2]=g;LE(b);hb=e+16|0;return}a=N()|0;LE(b);Q(a|0);p()}function zA(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=c;c=f+12|0;xc(c,256);xc(c,65535);h=z[f+12>>1];mg(a,h);if(h){c=0;while(1){g=y[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Pj(a,c),j=g,w[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}hb=f+16|0;return 1}function rX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=hb+-64|0;hb=e;d=1;a:{if(tg(a,b,0)){break a}d=0;if(!b){break a}b=Tv(b,74512,74560);d=0;if(!b){break a}d=e+8|0;Sb(d|4,0,52);x[e+56>>2]=1;x[e+20>>2]=-1;x[e+16>>2]=a;x[e+8>>2]=b;mb[x[x[b>>2]+28>>2]](b,d,x[c>>2],1);a=x[e+32>>2];if((a|0)==1){x[c>>2]=x[e+24>>2]}d=(a|0)==1}hb=e- -64|0;return d|0}function ok(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)>=3069?3069:b)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)<=-2960?-2960:b)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function bn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=rs(a+60|0);x[a>>2]=60312;x[d>>2]=60332;x[114414]=0;e=a+8|0;a=U(150,a|0,60344,e|0)|0;f=x[114414];x[114414]=0;a:{b:{if((f|0)!=1){x[a>>2]=60312;x[d>>2]=60332;x[114414]=0;U(151,e|0,b|0,c|8)|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}return a|0}a=N()|0;break a}a=N()|0}gh(d);Q(a|0);p()}function b4(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;a=oh(a);x[114414]=0;P(2187,c+16|0,0);b=x[114414];x[114414]=0;a:{b:{if((b|0)!=1){b=c+16|0;d=bc(b);b=dc(b);e=x[Fb(c+8|0,a)>>2];x[114414]=0;U(2188,d|0,b|0,e|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}fy(c+16|0);hb=c+32|0;return}b=N()|0;break a}b=N()|0;fy(c+16|0)}qd(a);Q(b|0);p()}function Pf(a){var b=0,c=0,d=0;er(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-8|0;P(1218,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;yb(a);b=x[a>>2];a=dj(a);x[114414]=0;T(27,b|0,a<<3,8);a=x[114414];x[114414]=0;if((a|0)==1){S(0)|0;zb();p()}}}function RN(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function VF(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;e=b+16|0;a:{while(1){d=x[a+36>>2];c=b+8|0;f=mb[x[x[d>>2]+20>>2]](d,x[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=x[b+4>>2]-c|0;if((oj(g,1,c,x[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=dn(x[a+32>>2])?-1:0}hb=b+16|0;return d|0}function Xh(a,b,c){var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;e=hb-32|0;hb=e;d=hb-32|0;hb=d;x[d+16>>2]=b;x[d+24>>2]=a;x[d+8>>2]=c;b=d+16|0;c=x[b>>2];g=x[d+24>>2];a=x[d+8>>2]+(c-g|0)|0;ES(d,c,g,a);gd(e+24|0,b,Fb(d,rg(x[d+8>>2],a)));hb=d+32|0;x[e+16>>2]=x[e+24>>2];x[e+8>>2]=x[e+28>>2];gd(f+8|0,e+16|0,e+8|0);hb=e+32|0;hb=f+16|0;return x[f+12>>2]}function s0(a,b){a=a|0;b=b|0;if(A[a+24>>2]>A[a+44>>2]){x[a+44>>2]=x[a+24>>2]}a:{if(A[a+8>>2]>=A[a+12>>2]){break a}if(ne(b,-1)){Ym(a,x[a+8>>2],x[a+12>>2]-1|0,x[a+44>>2]);return Sr(b)|0}if(!(y[a+48|0]&16)){if(!ne(b<<24>>24,v[x[a+12>>2]-1|0])){break a}}Ym(a,x[a+8>>2],x[a+12>>2]-1|0,x[a+44>>2]);v[x[a+12>>2]]=b<<24>>24;return b|0}return-1}function oaa(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(1579,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}me(a);bo(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function dea(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(1190,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}Kk(a);XC(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function Nda(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(bd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;R(1221,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){S(0)|0;zb();p()}x[c>>2]=x[c>>2]-8;if(bd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function Dda(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(1232,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}ce(a);tr(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function xf(a){a=a|0;var b=0,c=0;x[a>>2]=78688;b=x[a+12>>2];if(x[b>>2]==(a|0)){x[b>>2]=x[a+4>>2]}b=x[a+20>>2];if(b){x[b>>2]=0;x[a+20>>2]=0}b=x[a+4>>2];if(b){x[b+8>>2]=x[a+8>>2]}c=x[a+8>>2];if(c){x[c+4>>2]=b}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+16>>2];x[b+946300>>2]=x[b+946300>>2]-1;b=a+44|0;Gs(b+36|0);Gs(b+24|0);Fs(b+12|0);Fs(b);return a|0}function qma(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(540,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}me(a);bo(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function l2(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(2238,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}Pi(a);bT(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function jka(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(749,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}me(a);bo(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function e9(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(1670,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}Tf(a);fe(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function _ma(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(493,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}me(a);bo(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function _la(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(579,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}me(a);bo(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function _ha(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(961,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}me(a);bo(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function _9(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(bd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;R(1601,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){S(0)|0;zb();p()}x[c>>2]=x[c>>2]-6;if(bd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function Vla(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(586,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}Ab(a);bT(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function Sha(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(974,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}Kt(a);BP(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function M9(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(1619,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}Ck(a);Zl(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function De(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{if(!Bb(a)|(c-b|0)<5){break a}Vo(b,c);e=c-4|0;c=Rb(a);f=c+Bb(a)|0;b:{while(1){c:{a=v[c|0];if(b>>>0>=e>>>0){break c}if(!((a|0)<=0|(a|0)>=127)&x[b>>2]!=v[c|0]){break b}b=b+4|0;c=((f-c|0)>1)+c|0;continue}break}if((a|0)<=0|(a|0)>=127|v[c|0]>>>0>x[e>>2]-1>>>0){break a}}x[d>>2]=4}}function o6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[114414]=0;W(2048,a|0);d=x[114414];x[114414]=0;if((d|0)!=1){x[a+16>>2]=0;x[a+12>>2]=c;x[a+8>>2]=b;return}Y(S(0)|0)|0;x[114414]=0;X(2023,8908,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)!=1){_();return}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function PV(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;a=R(247,c|0)|0;e=x[114414];x[114414]=0;if((e|0)==1){S(0)|0;zb();p()}dr(a);XC(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function NV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;e=hb-16|0;hb=e;f=hb-16|0;hb=f;x[e+4>>2]=1;h=e,i=ZC(1),x[h+8>>2]=i;hb=f+16|0;f=x[e+8>>2];x[114414]=0;Z(251,f|0,b|0,c|0,d|0)|0;b=x[114414];x[114414]=0;a:{if((b|0)!=1){b=a;a=Go(e);Fo(b,ic(a),a);PC(e);hb=e+16|0;break a}a=N()|0;PC(e);Q(a|0);p()}hb=g+16|0}function tJ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=Ze(x[a+16>>2]);b=hb-16|0;hb=b;h=b,i=Li(E(B[a+4208>>2]*E(999))),x[h+12>>2]=i;x[b+8>>2]=0;x[b+4>>2]=-2;e=b+4|0;f=hb-16|0;hb=f;c=b+12|0;d=b+8|0;if(!ro(c,d)){d=ro(e,c)?e:c}hb=f+16|0;hb=b+16|0;b=(g>>>0)/(x[d>>2]+1>>>0)|0;b=b>>>0<=2?2:b;x[a+4216>>2]=b;x[a+4220>>2]=b>>>1;xc(a+4224|0,b)}function uB(a){var b=0,c=0,d=0,e=0;c=a+9|0;d=y[c|0]|y[c+1|0]<<8;c=yna(y[a+3|0],0,18,0);d=d+c|0;b=lb;e=c>>>0>d>>>0?b+1|0:b;b=a+6|0;c=y[b|0]|y[b+1|0]<<8;b=c>>>31|0;c=c<<1;d=c+d|0;b=b+e|0;c=c>>>0>d>>>0?b+1|0:b;a=a+4|0;a=y[a|0]|y[a+1|0]<<8;b=a>>>30|0;e=d;d=a<<2;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e+3|0;lb=b>>>0<3?a+1|0:a;return b}function ot(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;d=c+8|0;b=hb-16|0;hb=b;x[114414]=0;R(1253,a+4|0)|0;e=x[114414];x[114414]=0;a:{b:{if((e|0)==1){break b}x[114414]=0;x[b+12>>2]=0;U(1254,a+8|0,b+12|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break b}f=a,g=mc(a),x[f>>2]=g;hb=b+16|0;break a}S(0)|0;zb();p()}hb=c+16|0;return a}function TS(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28490681|y[a+68|0]!=13|(y[a+69|0]!=10|y[a+70|0]!=26)){break a}if(y[a+76|0]|((y[a+71|0]|y[a+72|0]<<8|(y[a+73|0]<<16|y[a+74|0]<<24))!=1397116231|y[a+75|0]!=1)){break a}a=a+116|0;if((y[a|0]|y[a+1|0]<<8)>>>0>=10){break a}b=(y[a|0]|y[a+1|0]<<8)!=0}return b}function Rca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>2;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Cb(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=Cb(y[c|0])|Cb(y[c+1|0])<<8,w[f>>1]=g;f=a,g=Cb(y[c+2|0])|Cb(y[c+3|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<2}function Oca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>2;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Cb(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=Cb(y[c+1|0])|Cb(y[c|0])<<8,w[f>>1]=g;f=a,g=Cb(y[c+3|0])|Cb(y[c+2|0])<<8,w[f+2>>1]=g;a=a+4|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<2}function oja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb+-64|0;hb=d;b=-1;a:{if(!(mb[x[x[a>>2]+36>>2]](a,0,1084)|0)){break a}Nk(a,1080);e=d+60|0;WQ(a,e);c=e;e=VQ(d+40|0);b=0;if(!UQ(c,e)){break a}Nk(a,20);b=1;while(1){c=d+8|0;TQ(a,c);f=Qz(c)+f|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}b=A[e+4>>2]>=f>>>0}hb=d- -64|0;return b|0}function BU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-16|0;hb=e;c=-1;a:{if(!Yf(a,7)){break a}c=0;if(!wB(a,7618)){break a}c=hb-16|0;hb=c;d=c+8|0;jB(d,e);f=Eb(d);d=nd(a,ac(c,d));if((f|0)==(d|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;d=(d|0)==(f|0);if(!d){kB(e)}c=-1;if(!d){break a}c=0;if(!vB(e)){break a}c=kf(a,b,uB(e),lb)}hb=e+16|0;return c|0}function Tka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;He(b);x[d+12>>2]=0;a:{if(!Ri(a,d+12|0)){break a}f=c;c=x[d+12>>2];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{v[d+11|0]=0;if(!bh(a,d+11|0)){break b}No(b,v[d+11|0]);e=1;c=c+1|0;if((c|0)!=x[d+12>>2]){continue}break a}break}e=0}hb=d+16|0;return e|0}function RZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;g=Xc(a+8|0),h=0,v[g+128|0]=h;if(b){c=hb-16|0;hb=c;if(qE(a)>>>0<b>>>0){Vc();p()}pE(c+8|0,rl(a),b);e=x[c+8>>2];x[a+4>>2]=e;x[a>>2]=e;f=x[c+12>>2];g=yb(a),h=(f<<2)+e|0,x[g>>2]=h;vk(a,0);hb=c+16|0;VE(a,b)}hb=d+16|0;return a|0}function CJ(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=(Ze(x[a+16>>2])|0)/5|0;b=Cc(b,b>>31);x[a+4272>>2]=b;x[114414]=0;x[c+12>>2]=0;T(1681,a+4256|0,b<<1,c+12|0);b=x[114414];x[114414]=0;a:{if((b|0)==1){b=S(75016)|0;if((ib|0)!=(ca(75016)|0)){break a}Y(b|0)|0;x[a+4272>>2]=0;_()}x[a+4276>>2]=0;x[a+4268>>2]=0;hb=c+16|0;return}Q(b|0);p()}function Aea(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[c+12>>2]=0;U(1162,a+8|0,c+12|0,c+8|0)|0;d=x[114414];x[114414]=0;a:{if((d|0)!=1){hb=c+16|0;break a}S(0)|0;zb();p()}v[a+16|0]=0;x[a+12>>2]=b;x[114414]=0;W(1161,a|0);b=x[114414];x[114414]=0;if((b|0)!=1){return a|0}b=N()|0;fz(a);Q(b|0);p()}function u9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;a:{b=bi(e,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){d=x[a+16>>2];f=x[b>>2];x[114414]=0;T(1632,d|0,f|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}d=x[b>>2]+4|0;x[b>>2]=d;if((d|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=e+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function gba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;a:{b=bi(e,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){d=x[a+16>>2];f=x[b>>2];x[114414]=0;T(368,d|0,f|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}d=x[b>>2]+4|0;x[b>>2]=d;if((d|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=e+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function gV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b+18|0;b=b+46|0;a=ad(a,y[d|0]&2?16:8,1,0,(y[b|0]^-1)&1);if(!(!(y[d|0]&4)|c>>>0<532)){mC(a)}a:{b:{if(y[d|0]&8){b=y[b|0]&4?5:4;break b}if(!(y[d|0]&2|y[b|0]!=255)){b=11;break b}if(y[b|0]&2){v[a+2|0]=1}if(y[b|0]&4){pm(a,2)}if(!(y[b|0]&8)){break a}b=9;if(!(y[d|0]&2)){break a}}pm(a,b)}}function Rka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;He(b);v[d+15|0]=0;a:{if(!bh(a,d+15|0)){break a}f=c;c=y[d+15|0];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{v[d+14|0]=0;if(!bh(a,d+14|0)){break b}No(b,v[d+14|0]);e=1;c=c+1|0;if(y[d+15|0]!=(c&255)){continue}break a}break}e=0}hb=d+16|0;return e|0}function Lka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;a:{b=Dt(e,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){d=x[a+16>>2];f=x[b>>2];x[114414]=0;T(532,d|0,f|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}d=x[b>>2]+1|0;x[b>>2]=d;if((d|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=e+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function XU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;a:{b=rm(e,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){d=x[a+16>>2];f=x[b>>2];x[114414]=0;T(346,d|0,f|0,c|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}d=x[b>>2]+2|0;x[b>>2]=d;if((d|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=e+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function Cba(a){a=a|0;var b=0,c=0,d=0;c=hb-16|0;hb=c;b=Me(2500);x[114414]=0;a=U(95,b|0,a|0,0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){b=hb-16|0;hb=b;x[114414]=0;x[b+12>>2]=a;a=U(99,c+8|0,b+12|0,b+8|0)|0;d=x[114414];x[114414]=0;a:{if((d|0)!=1){hb=b+16|0;break a}S(0)|0;zb();p()}hb=c+16|0;return x[a>>2]}a=N()|0;_b(b);Q(a|0);p()}function p6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[114414]=0;W(2048,a|0);d=x[114414];x[114414]=0;if((d|0)!=1){x[a+4>>2]=c;x[a>>2]=b?b:2031;return}Y(S(0)|0)|0;x[114414]=0;X(2023,8938,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)!=1){_();return}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function Aia(a,b){a=a|0;b=b|0;var c=0;b=hb-32|0;hb=b;c=-1;a:{if(!EA(a,b+16|0)){break a}c=0;if(!XP(b+16|0)){break a}c=-1;if(!Tj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))){break a}a=b+8|0;a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=(a&2139062143)==(a|0)}a=c;hb=b+32|0;return a|0}function y2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;a:{if(!(y[c+1|0]&4)){break a}c=x[c+4>>2];g=d,h=ud(b),x[g+8>>2]=h;b:{if(!Bb(b)){break b}if(y[pc(b,0)|0]!=43){if(y[pc(b,0)|0]!=45){break b}}Qw(d+8|0);c=c+1|0}if(Bb(b)>>>0>=c>>>0){break a}e=td(d,d+8|0);f=Bb(b);Sw(b,x[e>>2],c-f|0,48)}Jd(a,b);hb=d+16|0}function sda(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(bd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;R(1250,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){S(0)|0;zb();p()}dm(c);if(bd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function kea(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(bd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;R(1182,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){S(0)|0;zb();p()}dm(c);if(bd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function eT(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;hb=b+16|0}function dba(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(bd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;R(1455,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){S(0)|0;zb();p()}IP(c);if(bd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function bL(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;hb=b+16|0}function aaa(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(bd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;R(1597,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){S(0)|0;zb();p()}Jp(c);if(bd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function TI(a,b){var c=0,d=0,e=0,f=0;d=Rb(a);c=Bb(a);e=Rb(b);a=Bb(b);if(!a|!c){a=-1}else{f=a+e|0;a=d;c=c+a|0;a:{if((a|0)==(c|0)){break a}while(1){b=e;if((f|0)!=(b|0)){while(1){if(ne(v[a|0],v[b|0])){break a}b=b+1|0;if((f|0)!=(b|0)){continue}break}}a=a+1|0;if((c|0)!=(a|0)){continue}break}a=c}a=(a|0)==(c|0)?-1:a-d|0}return a}function IU(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;c=hb-32|0;hb=c;x[c+16>>2]=b;x[c+24>>2]=a;a:{if(!Hb(c+24|0,c+16|0)){break a}x[c+8>>2]=x[c+24>>2];if(!Hb(ge(c+8|0),c+16|0)){break a}while(1){if(KB(x[c+24>>2],x[c+8>>2])){x[c+24>>2]=x[c+8>>2]}if(Hb(ge(c+8|0),c+16|0)){continue}break}}hb=c+32|0;hb=d+16|0;return x[c+24>>2]}function Xma(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(kd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;R(499,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){S(0)|0;zb();p()}ge(c);if(kd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function Uha(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=Fb(d+8|0,x[x[a+8>>2]>>2]);a=Fb(d,x[x[a+4>>2]>>2]);c=x[b>>2];b=hb-16|0;hb=b;x[b>>2]=x[a>>2];x[b+8>>2]=c;if(bd(b+8|0,b)){while(1){x[114414]=0;c=b+8|0;R(968,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){S(0)|0;zb();p()}IP(c);if(bd(c,b)){continue}break}}hb=b+16|0;hb=d+16|0}function OI(){var a=0,b=0,c=0,d=0;c=hb-16|0;hb=c;b=Me(1304568);x[114414]=0;d=R(2164,b|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){a=hb-16|0;hb=a;x[114414]=0;x[a+12>>2]=d;b=U(2168,c+8|0,a+12|0,a+8|0)|0;d=x[114414];x[114414]=0;a:{if((d|0)!=1){hb=a+16|0;break a}S(0)|0;zb();p()}hb=c+16|0;return x[b>>2]}a=N()|0;_b(b);Q(a|0);p()}function kQ(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;f=y[b|0]|y[b+1|0]<<8;c=yna(y[a+30|0],0,37,0);d=lb;b=a+24|0;b=yna(y[b|0]|y[b+1|0]<<8,0,192,0);c=b+c|0;d=lb+d|0;b=b>>>0>c>>>0?d+1|0:d;a=y[a+26|0];d=a>>>26|0;e=c;c=a<<6;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+f|0;a=b>>>0<e>>>0?a+1|0:a;b=b+192|0;lb=b>>>0<192?a+1|0:a;return b}function yR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;x[e+12>>2]=a;a:{if(!(!c|b)){a=gg(+(D(a,d)>>>0)*2500);break a}b:{if(!(!a|!b)){xc(e+12|0,10);a=y[x[e+12>>2]+23856|0];x[e+12>>2]=a;break b}if(a-1>>>0>9){break b}a=gg(7338401.379310345/+(a>>>0));break a}a=gg(+(a>>>0)*37878.78787878787)}hb=e+16|0;return a|0}function CP(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;c=yb(b);x[114414]=0;U(973,a+8|0,d+12|0,c|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=x[yb(b)>>2];e=yb(a),f=c,x[e>>2]=f;e=yb(b),f=0,x[e>>2]=f;x[b>>2]=0;x[b+4>>2]=0;hb=d+16|0;return a}S(0)|0;zb();p()}function A9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=E(0),f=0,g=0,h=E(0);c=hb-32|0;hb=c;Wj(a,c+24|0);f=c,g=jd(x[c+24>>2],x[c+28>>2]),x[f+16>>2]=g;x[c+12>>2]=256;Il(b,x[Mb(c+16|0,c+12|0)>>2]);if(Lb(b)){while(1){x[c+16>>2]=0;lp(a,c+16|0);e=B[c+16>>2];f=Pb(b,d),h=e,B[f>>2]=h;d=d+1|0;if(Lb(b)>>>0>d>>>0){continue}break}}hb=c+32|0}function yN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;f=hb-16|0;hb=f;a:{if(qc(Kp(a))>>>0<=b>>>0){break a}b:{c:{if(zc(a)>>>0>b>>>0){if(A[wd(a,b)+4>>2]>c>>>0){break c}}if(!d){break a}Wy(a,b,c,1);break b}e=f+8|0;oe(e,wd(a,b),c);e=Ib(e);if(e|!d){break a}d=f+8|0;oe(d,wd(a,b),c);he(d,1);zN(a,b,c)}e=0}hb=f+16|0;return e|0}function qy(a,b){var c=0,d=0,e=0;nR(a);Wl(a,b);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=x[yb(b)>>2];d=yb(a),e=c,x[d>>2]=e;d=yb(b),e=0,x[d>>2]=e;x[b>>2]=0;x[b+4>>2]=0;v[a+12|0]=y[b+12|0];c=y[b+13|0]|y[b+14|0]<<8|(y[b+15|0]<<16|y[b+16|0]<<24);v[a+13|0]=c;v[a+14|0]=c>>>8;v[a+15|0]=c>>>16;v[a+16|0]=c>>>24;v[a+17|0]=y[b+17|0]}function lX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(tg(a,x[b+8>>2],e)){Pv(b,c,d);return}a:{if(!tg(a,x[b>>2],e)){break a}if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+20>>2]=c;x[b+32>>2]=d;x[b+40>>2]=x[b+40>>2]+1;if(!(x[b+36>>2]!=1|x[b+24>>2]!=2)){v[b+54|0]=1}x[b+44>>2]=4}}function X7(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=Ze(x[a+16>>2]);b=Cc(zna(yna(b,b>>31,3840,0),lb,1e3,0),lb);x[a+4276>>2]=b;x[114414]=0;x[c+12>>2]=0;T(1681,a+4260|0,b|0,c+12|0);b=x[114414];x[114414]=0;a:{if((b|0)==1){b=S(75016)|0;if((ib|0)!=(ca(75016)|0)){break a}Y(b|0)|0;x[a+4276>>2]=0;_()}hb=c+16|0;return}Q(b|0);p()}function rna(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;v[d+15|0]=b;a:{b:{c:{if(!re(a)){c=10;b=uo(a);if((b|0)==10){break c}Rb(a);c=a;Ce(a,b+1|0);break a}c=ti(a);b=x[a+4>>2];c=c-1|0;if((b|0)!=(c|0)){break b}}$k(a,c,1,c,c,0,0);b=c}Rb(a);c=x[a>>2];ae(a,b+1|0)}a=b+c|0;Wd(a,d+15|0);v[d+14|0]=0;Wd(a+1|0,d+14|0);hb=d+16|0}function lL(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-1641380927){break a}b=a+12|0;if(!(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))){break a}b=a+20|0;if(!(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))){break a}a=a+28|0;c=(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=0}return c}function jha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=aP(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(1006,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+12|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function hJ(a){var b=0;x[a+4116>>2]=0;x[a+4132>>2]=0;x[a+4136>>2]=0;w[a+4128>>1]=0;x[a+4104>>2]=0;x[a+4108>>2]=0;b=a+4140|0;x[b>>2]=0;x[b+4>>2]=0;b=a+4148|0;x[b>>2]=0;x[b+4>>2]=0;gJ(a+4164|0);gJ(a+4156|0);wp(a+54060|0);wp(a+62252|0);wp(a+70444|0);wp(a+78636|0);Sb(a+4332|0,0,32768);qz(a+37100|0);Sb(a+37612|0,0,16384)}function Nw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=hb-240|0;hb=g;x[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-x[(i<<2)+d>>2]|0;if((Bl(a,f,b)|0)>=0){if((Bl(a,e,b)|0)>=0){break a}}j=f;f=(Bl(f,e,b)|0)>=0;e=f?j:e;x[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}QG(g,h);hb=g+240|0}function Hda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=aP(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(1227,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+12|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function ika(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=JD(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(369,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+16|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function s9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=bi(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(1651,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+4|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function Sja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=bi(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(801,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+4|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function Rja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=rm(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(807,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+2|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function Pka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=bi(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(712,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+4|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function No(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;v[c+15|0]=b;e=re(a);a:{if(!e){b=10;d=uo(a);break a}b=ti(a)-1|0;d=x[a+4>>2]}b:{c:{if((b|0)==(d|0)){$k(a,b,1,b,b,0,0);Rb(a);break c}Rb(a);if(e){break c}b=a;Ce(a,d+1|0);break b}b=x[a>>2];ae(a,d+1|0)}a=b+d|0;Wd(a,c+15|0);v[c+14|0]=0;Wd(a+1|0,c+14|0);hb=c+16|0}function JW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=JD(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(184,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+16|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function I8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=bi(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(1686,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+4|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function Bia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=bi(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(918,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+4|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function AX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[c+12>>2]=b;e=re(a);a:{if(!e){b=1;d=uo(a);break a}b=ti(a)-1|0;d=x[a+4>>2]}b:{c:{if((b|0)==(d|0)){fE(a,b,1,b,b);Rb(a);break c}Rb(a);if(e){break c}b=a;Ce(a,d+1|0);break b}b=x[a>>2];ae(a,d+1|0)}a=(d<<2)+b|0;ug(a,c+12|0);x[c+8>>2]=0;ug(a+4|0,c+8|0);hb=c+16|0}function lV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=Dt(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(329,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+1|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function dV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=bi(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(336,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+4|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function Kfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=Dt(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(39,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+1|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function FW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=Dt(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(186,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+1|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function FU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=rm(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(370,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+2|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function EU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b=rm(d,a+8|0,b);if(x[b>>2]!=x[b+4>>2]){while(1){c=x[a+16>>2];e=x[b>>2];x[114414]=0;P(374,c|0,e|0);c=x[114414];x[114414]=0;if((c|0)==1){break a}c=x[b>>2]+2|0;x[b>>2]=c;if((c|0)!=x[b+4>>2]){continue}break}}Ac(b);hb=d+16|0;return}a=N()|0;Ac(b);Q(a|0);p()}function kW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;b=Uf(d,b);x[114414]=0;T(221,d+16|0,b|0,c|0);e=x[114414];x[114414]=0;a:{b:{if((e|0)!=1){x[114414]=0;T(5,a|0,d+16|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}xb(d+16|0);xb(b);hb=d+32|0;return}a=N()|0;break a}a=N()|0;xb(d+16|0)}xb(b);Q(a|0);p()}function Xba(){var a=0,b=0,c=0,d=0;c=hb-16|0;hb=c;b=Me(1);x[114414]=0;d=R(87,b|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){a=hb-16|0;hb=a;x[114414]=0;x[a+12>>2]=d;b=U(92,c+8|0,a+12|0,a+8|0)|0;d=x[114414];x[114414]=0;a:{if((d|0)!=1){hb=a+16|0;break a}S(0)|0;zb();p()}hb=c+16|0;return x[b>>2]}a=N()|0;_b(b);Q(a|0);p()}function VI(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;f=Yi(b,c);if(f>>>0<=2147483631){a:{if(il(f)){Ce(a,f);e=a;break a}Gh(d+8|0,a,cj(f)+1|0);e=x[d+8>>2];Ue(a,e);Ff(a,x[d+12>>2]);ae(a,f)}if((b|0)!=(c|0)){while(1){Wd(e,b);e=e+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}v[d+7|0]=0;Wd(e,d+7|0);hb=d+16|0;return}Ef();p()}function Hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>2;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){Cb(y[c|0]);Cb(y[c+1|0]);f=a,g=Cb(y[c+2|0])|Cb(y[c+3|0])<<8,w[f>>1]=g;a=a+2|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<2}function Gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>2;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){Cb(y[c+3|0]);Cb(y[c+2|0]);f=a,g=Cb(y[c+1|0])|Cb(y[c|0])<<8,w[f>>1]=g;a=a+2|0;c=c+4|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return d<<2}function Qma(a,b){a=a|0;b=b|0;var c=0;St(a,b);Fj(b);a=y[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=y[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}v[b+5|0]=159;v[b+3|0]=20;return}if((a|0)!=64){break a}v[b+3|0]=0;v[b|0]=254;return}v[b+3|0]=20;v[b+5|0]=a&15|160;return}v[b+3|0]=0}}function lh(a){var b=0,c=0,d=0;c=rs(a+56|0);x[a>>2]=60132;x[c>>2]=60152;x[114414]=0;b=a+4|0;a=U(125,a|0,60164,b|0)|0;d=x[114414];x[114414]=0;a:{b:{if((d|0)!=1){x[a>>2]=60132;x[c>>2]=60152;x[114414]=0;O(126,b|0,16)|0;b=x[114414];x[114414]=0;if((b|0)==1){break b}return a}a=N()|0;break a}a=N()|0}gh(c);Q(a|0);p()}function Nia(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;a:{if(!Yf(a,8)){break a}c=0;if(!Fu(a,9899,8)){break a}c=-1;if(!Tj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))){break a}c=!((y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24))&-2139062144)}a=c;hb=b+16|0;return a|0}function zY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;x[e>>2]=c;a=$v(f+12|0,0,b,x[a+8>>2]);b=2;a:{if(a+1>>>0<2){break a}c=a-1|0;b=1;if(c>>>0>d-x[e>>2]>>>0){break a}d=f+12|0;while(1){if(c){a=y[d|0];b=x[e>>2];x[e>>2]=b+1;v[b|0]=a;c=c-1|0;d=d+1|0;continue}break}b=0}a=b;hb=f+16|0;return a|0}function v_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-32|0;hb=g;h=x[16291];x[g+24>>2]=x[16290];x[g+28>>2]=h;h=x[16289];x[g+16>>2]=x[16288];x[g+20>>2]=h;h=x[16287];x[g+8>>2]=x[16286];x[g+12>>2]=h;h=x[16285];x[g>>2]=x[16284];x[g+4>>2]=h;h=a;a=g+32|0;b=jj(h,b,c,d,e,f,g,a);hb=a;return b|0}function lK(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=x[a+4232>>2];b=(b>>>1)+(b>>>6)|0;x[a+4220>>2]=b;x[114414]=0;x[c+12>>2]=0;T(1681,a+4208|0,b<<1,c+12|0);b=x[114414];x[114414]=0;a:{if((b|0)==1){b=S(75016)|0;if((ib|0)!=(ca(75016)|0)){break a}Y(b|0)|0;x[a+4220>>2]=0;_()}x[a+4224>>2]=0;hb=c+16|0;return}Q(b|0);p()}function jp(a,b,c){var d=0,e=0;a=Cg(a);d=Bb(b);x[114414]=0;P(110,a|0,d|0);d=x[114414];x[114414]=0;if((d|0)!=1){a:{if(Bb(b)){while(1){d=x[(y[pc(b,e)|0]<<2)+c>>2];x[114414]=0;P(109,a|0,d|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}e=e+1|0;if(Bb(b)>>>0>e>>>0){continue}break}}return}}b=N()|0;Nc(a);Q(b|0);p()}function eC(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}while(1){v[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){Xf(a,c+11|0);e=y[c+11|0]}else{e=0}v[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}x[c>>2]=x[c+12>>2];d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)}hb=c+16|0;return d}function Lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=(c>>>0)/3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){Cb(y[c|0]);f=a,g=Cb(y[c+1|0])|Cb(y[c+2|0])<<8,w[f>>1]=g;a=a+2|0;c=c+3|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return D(d,3)|0}function Kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=(c>>>0)/3;x[e+8>>2]=x[a>>2];d=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(d){a=x[a+20>>2];b=d;while(1){Cb(y[c+2|0]);f=a,g=Cb(y[c+1|0])|Cb(y[c|0])<<8,w[f>>1]=g;a=a+2|0;c=c+3|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return D(d,3)|0}function FP(a){var b=0,c=0,d=0,e=0,f=0;c=x[a>>2];a:{if(!c){break a}d=x[a+8>>2];if(!d){break a}e=x[a+12>>2];if(!e){break a}a=mb[e|0](c)|0;f=lb;if((f|0)<0){break a}b=0;b:{if((mb[d|0](c,0,0,0)|0)<0){break b}b=0;if((mb[d|0](c,0,0,2)|0)<0){break b}mb[e|0](c)|0;b=lb;b=(b|0)>0|(b|0)>=0}mb[d|0](c,a,f,0)|0}return b}function gK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;Qe(a+12|0,d);if(b){if(b>>>0>2097151){ve();p()}d=Vd(b<<11,4);x[e+4>>2]=b;x[e>>2]=d;f=x[e>>2];b=x[e+4>>2]}else{b=0}x[a>>2]=f;c=(c<<11)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=ic(a),h=(b<<11)+f|0,x[g>>2]=h;hb=e+16|0;return a|0}function Mr(a){var b=0,c=0;b=x[a+76>>2];a:{if(!((b|0)>=0&(!b|x[114266]!=(b&-1073741825)))){b=x[a+4>>2];if((b|0)!=x[a+8>>2]){x[a+4>>2]=b+1;a=y[b|0];break a}a=uw(a);break a}b=a+76|0;c=x[b>>2];x[b>>2]=c?c:1073741823;c=x[a+4>>2];b:{if((c|0)!=x[a+8>>2]){x[a+4>>2]=c+1;a=y[c|0];break b}a=uw(a)}x[b>>2]=0}return a}function xM(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{d=_k(e,a,b);b=x[d+4>>2];g=x[d+8>>2];if((b|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;T(1389,f|0,b|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}b=b+24|0;x[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function j4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;kn(c,a);if(x[b>>2]){xd(b);PI(b);Yp(b);xp(yb(b),x[b>>2],af(b));d=yb(b),e=0,x[d>>2]=e;x[b>>2]=0;x[b+4>>2]=0}Wl(b,c);x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];a=x[yb(c)>>2];d=yb(b),e=a,x[d>>2]=e;d=yb(c),e=0,x[d>>2]=e;x[c>>2]=0;x[c+4>>2]=0;Mf(c);hb=c+16|0}function ez(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{d=Bo(e,a,b);b=x[d+4>>2];g=x[d+8>>2];if((b|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;T(1164,f|0,b|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}b=b+32|0;x[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function Is(a){var b=0,c=0,d=0;b=jh(+B[a+4228>>2]*8)*.25+-.25;C[a+4248>>3]=b;if(y[a+4240|0]){if(b<=45e-5){b=0}else{b=Zo(b)*1.4426950408889634;d=J(b);b=b-d;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=jh(c+d)*.5}C[a+4248>>3]=b}Hs(a)}function eda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>1;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Cb(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=Cb(y[c|0])^128,v[f|0]=g;f=a,g=Cb(y[c+1|0])^128,v[f+1|0]=g;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<1}function cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>1;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(f){a=x[a+20>>2];b=f;g=d;while(1){g=Cb(y[c|0])+g|0;v[a|0]=g;d=Cb(y[c+1|0])+d|0;v[a+1|0]=d;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f<<1}function c3(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;a:{b:{if(vi(a)){gp(b+24|0);break b}c=b+8|0;kn(c,a);x[114414]=0;c=R(2204,c|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}x[b+24>>2]=c;Mf(b+8|0)}if(vi(a)){a=a+36|0}else{a=x[b+24>>2]}a=xd(a);sk(b+24|0);hb=b+32|0;return a|0}a=N()|0;Mf(b+8|0);Q(a|0);p()}function QG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=4;f=hb-256|0;hb=f;if((b|0)>=2){h=(b<<2)+a|0;x[h>>2]=f;while(1){e=c>>>0>=256?256:c;sc(x[h>>2],x[a>>2],e);d=0;while(1){g=(d<<2)+a|0;d=d+1|0;sc(x[g>>2],x[(d<<2)+a>>2],e);x[g>>2]=x[g>>2]+e;if((b|0)!=(d|0)){continue}break}c=c-e|0;if(c){continue}break}}hb=f+256|0}function Mx(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{d=je(e,a,b);b=x[d+4>>2];g=x[d+8>>2];if((b|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;T(1632,f|0,b|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}b=b+4|0;x[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function Jn(a,b,c,d){var e=0,f=0,g=0;a:{if(x[c>>2]|x[d>>2]){if(b){while(1){e=x[d>>2];f=x[c>>2];x[c>>2]=f-(((-2147483648-f>>>31|0)-1&255)+f>>8);x[d>>2]=x[d>>2]-(e+((-2147483648-e>>>31|0)-1&255)>>8);e=(g<<3)+a|0;x[e>>2]=x[c>>2];x[e+4>>2]=x[d>>2];g=g+1|0;if((g|0)!=(b|0)){continue}break}}break a}FO(a,b<<1)}}function wQ(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;c=a+4|0;a:{if(wc(c)>>>0>=x[a+16>>2]+b>>>0){break a}if(!wc(c)){Ok(c,Gz(x[a+16>>2]+b|0,65536));break a}f=d,g=wc(c),x[f+12>>2]=g;e=mQ(d+12|0);a=x[a+16>>2]+b|0;if(e>>>0<a>>>0){Ok(c,Gz(a,65536));break a}f=d,g=wc(c),x[f+8>>2]=g;Ok(c,mQ(d+8|0))}hb=d+16|0}function sA(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{d=rq(e,a,b);b=x[d+4>>2];g=x[d+8>>2];if((b|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;T(681,f|0,b|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}b=b+6|0;x[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function qq(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{d=th(e,a,b);b=x[d+4>>2];g=x[d+8>>2];if((b|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;T(532,f|0,b|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}b=b+1|0;x[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function hk(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}v[a|0]=43;a=a+1|0}if(d&512){v[a|0]=35;a=a+1|0}while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}v[a|0]=b}function OB(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{d=je(e,a,b);b=x[d+4>>2];g=x[d+8>>2];if((b|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;T(368,f|0,b|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}b=b+4|0;x[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function Eq(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;a:{d=Yg(e,a,b);b=x[d+4>>2];g=x[d+8>>2];if((b|0)!=(g|0)){while(1){f=yb(a);x[114414]=0;T(346,f|0,b|0,c|0);f=x[114414];x[114414]=0;if((f|0)==1){break a}b=b+2|0;x[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function SP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;if(RA(b,d+24|0)){e=zz(d+24|0)}f=d+8|0;Bd(f,b,e);a=QA(a,d+24|0,f);Ab(f);a:{if(!c){break a}e=(e>>>0)%(c>>>0)|0;if(!e){break a}x[114414]=0;O(304,b|0,c-e|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break a}b=N()|0;me(a);Q(b|0);p()}hb=d+32|0}function L8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;dK(a);yb(a);d=Fb(c+16|0,x[a+4>>2]);e=Fb(c+8|0,x[a>>2]);f=Fb(c,x[b+4>>2]);g=c,h=Xh(x[d>>2],x[e>>2],x[f>>2]),x[g+24>>2]=h;x[b+4>>2]=x[c+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];sf(a);uk(a);uk(a);hb=c+32|0}function Mz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;w[d+14>>1]=b;w[d+12>>1]=c;if((b|0)!=(c|0)){b=bc(a);c=dc(a);a=hb-16|0;hb=a;x[a>>2]=c;x[a+8>>2]=b;if(Hb(a+8|0,a)){while(1){if(z[x[a+8>>2]>>1]==z[d+14>>1]){w[x[a+8>>2]>>1]=z[d+12>>1]}b=a+8|0;ge(b);if(Hb(b,a)){continue}break}}hb=a+16|0}hb=d+16|0}function Ir(a,b,c,d){var e=0,f=0,g=0;e=hb-160|0;hb=e;f=b?a:e+158|0;x[e+144>>2]=f;a=-1;g=b-1|0;x[e+148>>2]=b>>>0>=g>>>0?g:0;e=Sb(e,0,144);x[e+76>>2]=-1;x[e+36>>2]=2479;x[e+80>>2]=-1;x[e+44>>2]=e+159;x[e+84>>2]=e+144;a:{if((b|0)<0){x[114240]=61;break a}v[f|0]=0;a=IG(e,c,d,2341,2342)}hb=e+160|0;return a}function y8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=hb-96|0;hb=c;kK(b,c,c+96|0);b=0;while(1){d=b<<3;e=d+a|0;f=c+d|0;d=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=d&65535;b=b+1|0;if((b|0)!=12){continue}break}x[a+104>>2]=0;x[a+96>>2]=!(x[a+88>>2]|x[a+92>>2]);x[a+100>>2]=0;hb=c+96|0;x[a+112>>2]=0;return a|0}function Dq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=c;c=f+12|0;xc(c,256);xc(c,65535);h=z[f+12>>1];mg(a,h);if(h){c=0;while(1){g=y[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Pj(a,c),j=g,w[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}hb=f+16|0}function $n(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=c;c=f+12|0;xc(c,128);xc(c,65535);h=z[f+12>>1];mg(a,h);if(h){c=0;while(1){g=y[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Pj(a,c),j=g,w[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}hb=f+16|0}function vS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 2:Fh(a,b);return;default:break a}}d=hb-32|0;hb=d;x[d+28>>2]=c;v[d+27|0]=0;x[d+20>>2]=1;nl(a,d+27|0,x[Mb(d+28|0,d+20|0)>>2]);a=lb;if((a|0)>0|(a|0)>=0){x[d+16>>2]=1;Mb(d+28|0,d+16|0)}v[d+8|0]=y[d+27|0];v[b|0]=y[d+8|0];hb=d+32|0}function oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>1;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(f){a=x[a+20>>2];b=f;while(1){g=Cb(y[c|0])+d|0;d=g+Cb(y[c+1|0])|0;w[a>>1]=d<<8|g&255;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f<<1}function gka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb+-64|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;f=e+8|0;sR(d,f);g=Eb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;d=(d|0)==(g|0);if(!d){tR(f)}c=-1;a:{if(!d){break a}c=0;if(!FR(e+8|0)){break a}c=kf(a,b,ER(e+8|0),lb)}hb=e- -64|0;return c|0}function Waa(a){a=a|0;var b=0,c=0,d=0;b=x[a+2496>>2];c=(b+1>>>0)%624|0;d=x[(c<<2)+a>>2];b=0-(d&1)&-1727483681^(x[((b+397>>>0)%624<<2)+a>>2]^(d&2147483647|x[(b<<2)+a>>2]&-2147483648)>>>1);x[(x[a+2496>>2]<<2)+a>>2]=b;x[a+2496>>2]=c;a=b^b>>>11;a=a<<7&-1658038656^a;a=a<<15&-272236544^a;return a>>>18^a}function V1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;x[f+8>>2]=d;d=x[hp(f,f+8|0)>>2];x[114414]=0;aa(2047,a+8|0,b|0,c|0,d|0,e|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){a=WH(a);b=VH(a+88|0);x[a>>2]=83160;x[b>>2]=83248;pd(f+8|0);hb=f+16|0;return a|0}a=N()|0;pd(f+8|0);Q(a|0);p()}function Sla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-112|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;f=e+8|0;WS(d,f);g=Eb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;d=(d|0)==(g|0);if(!d){XS(f)}c=-1;a:{if(!d){break a}c=0;if(!_S(e+8|0)){break a}c=kf(a,b,ZS(e+8|0),lb)}hb=e+112|0;return c|0}function MB(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=Hm(d,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114414]=0;P(369,e|0,b|0);e=x[114414];x[114414]=0;if((e|0)==1){break a}b=b+16|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function xC(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=th(d,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114414]=0;P(329,e|0,b|0);e=x[114414];x[114414]=0;if((e|0)==1){break a}b=b+1|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function o7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ai(a,b,c,d);x[a+4208>>2]=1017370378;x[a+4212>>2]=0;x[a>>2]=80244;x[114414]=0;U(1673,a+44|0,2,2)|0;b=x[114414];x[114414]=0;a:{if((b|0)==1){break a}x[114414]=0;W(1674,a|0);b=x[114414];x[114414]=0;if((b|0)==1){break a}return a|0}b=N()|0;xf(a);Q(b|0);p()}function nla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=d+16|0;uA(e,d+8|0,c);x[114414]=0;P(476,d|0,e|0);c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}x[114414]=0;T(477,a|0,b|0,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Gb(d+16|0);hb=d+32|0;return}a=N()|0;Gb(d+16|0);Q(a|0);p()}
function aQ(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=je(d,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114414]=0;P(918,e|0,b|0);e=x[114414];x[114414]=0;if((e|0)==1){break a}b=b+4|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function _U(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-512|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;f=e+8|0;YB(d,f);g=Eb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;d=(d|0)==(g|0);if(!d){ZB(f)}c=-1;a:{if(!d){break a}c=0;if(!cC(e+8|0)){break a}c=kf(a,b,bC(e+8|0),lb)}hb=e+512|0;return c|0}function Qia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;er(a);yb(a);d=Fb(c+16|0,x[a+4>>2]);e=Fb(c+8|0,x[a>>2]);f=Fb(c,x[b+4>>2]);g=c,h=Xh(x[d>>2],x[e>>2],x[f>>2]),x[g+24>>2]=h;x[b+4>>2]=x[c+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];rv(a,Og(a));hb=c+32|0}function Pba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;wm(a);yb(a);d=Fb(c+16|0,x[a+4>>2]);e=Fb(c+8|0,x[a>>2]);f=Fb(c,x[b+4>>2]);g=c,h=Xh(x[d>>2],x[e>>2],x[f>>2]),x[g+24>>2]=h;x[b+4>>2]=x[c+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];ar(a,ue(a));hb=c+32|0}function Jka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;tu(a);yb(a);d=Fb(c+16|0,x[a+4>>2]);e=Fb(c+8|0,x[a>>2]);f=Fb(c,x[b+4>>2]);g=c,h=ZR(x[d>>2],x[e>>2],x[f>>2]),x[g+24>>2]=h;x[b+4>>2]=x[c+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];FA(a,hg(a));hb=c+32|0}function DB(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=Yg(d,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114414]=0;P(370,e|0,b|0);e=x[114414];x[114414]=0;if((e|0)==1){break a}b=b+2|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function zF(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;f=Vt(b,c);if(f>>>0<=1073741807){a:{if(Po(f)){Ce(a,f);e=a;break a}Zj(d+8|0,a,ql(f)+1|0);e=x[d+8>>2];Ue(a,e);Ff(a,x[d+12>>2]);ae(a,f)}while(1){if((b|0)!=(c|0)){ug(e,b);e=e+4|0;b=b+4|0;continue}break}x[d+4>>2]=0;ug(e,d+4|0);hb=d+16|0;return}Ef();p()}function nh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;Ye(a);yb(a);d=Fb(c+16|0,x[a+4>>2]);e=Fb(c+8|0,x[a>>2]);f=Fb(c,x[b+4>>2]);g=c,h=Xh(x[d>>2],x[e>>2],x[f>>2]),x[g+24>>2]=h;x[b+4>>2]=x[c+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];vk(a,Lb(a));hb=c+32|0}function fna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=d+16|0;Ii(e,d+8|0,c);x[114414]=0;P(476,d|0,e|0);c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}x[114414]=0;T(477,a|0,b|0,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Gb(d+16|0);hb=d+32|0;return}a=N()|0;Gb(d+16|0);Q(a|0);p()}function fda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>1;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Cb(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=bl(y[c|0]),v[f|0]=g;f=a,g=bl(y[c+1|0]),v[f+1|0]=g;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<1}function Uu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;Rj(a);yb(a);d=Fb(c+16|0,x[a+4>>2]);e=Fb(c+8|0,x[a>>2]);f=Fb(c,x[b+4>>2]);g=c,h=Xh(x[d>>2],x[e>>2],x[f>>2]),x[g+24>>2]=h;x[b+4>>2]=x[c+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Mq(a,qc(a));hb=c+32|0}function KM(a,b,c){var d=0,e=0,f=0,g=0;e=x[a+1074416>>2];a=x[a+1074392>>2];v[b+872|0]=y[b+872|0]|16;d=a?y[b+833|0]:0;g=(c|0)<0?d:0-d|0;f=(+(a>>>0)+1)*+(c|0)/+(e>>>0);a:{if(F(f)<2147483648){d=~~f;break a}d=-2147483648}x[b+876>>2]=g+(d+x[b+876>>2]|0);c=(a+1|0)==(e|0)?c:d;a=c>>31;v[b+833|0]=(a^c)-a}function JX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;Ye(a);rl(a);d=Fb(c+16|0,x[a+4>>2]);e=Fb(c+8|0,x[a>>2]);f=Fb(c,x[b+4>>2]);g=c,h=Xh(x[d>>2],x[e>>2],x[f>>2]),x[g+24>>2]=h;x[b+4>>2]=x[c+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];vk(a,Lb(a));hb=c+32|0}function IW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;ml(a);yb(a);d=Fb(c+16|0,x[a+4>>2]);e=Fb(c+8|0,x[a>>2]);f=Fb(c,x[b+4>>2]);g=c,h=Xh(x[d>>2],x[e>>2],x[f>>2]),x[g+24>>2]=h;x[b+4>>2]=x[c+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];Jo(a,rd(a));hb=c+32|0}function GR(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=th(d,a,b);b=x[c+4>>2];f=x[c+8>>2];if((b|0)!=(f|0)){while(1){e=yb(a);x[114414]=0;P(39,e|0,b|0);e=x[114414];x[114414]=0;if((e|0)==1){break a}b=b+1|0;x[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function GA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;Xn(a);yb(a);d=Fb(c+16|0,x[a+4>>2]);e=Fb(c+8|0,x[a>>2]);f=Fb(c,x[b+4>>2]);g=c,h=Xh(x[d>>2],x[e>>2],x[f>>2]),x[g+24>>2]=h;x[b+4>>2]=x[c+24>>2];Yb(a,b+4|0);Yb(a+4|0,b+8|0);Yb(yb(a),ic(b));x[b>>2]=x[b+4>>2];wA(a,wc(a));hb=c+32|0}function dz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 3:aO(a,b);return;default:break a}}d=hb-16|0;hb=d;x[d+12>>2]=c;w[d+10>>1]=0;x[d>>2]=2;nl(a,d+10|0,x[Mb(d+12|0,d)>>2]);a=lb;if((a|0)>0|(a|0)>=0){x[d>>2]=2;Mb(d+12|0,d)}w[d>>1]=z[d+10>>1];w[b>>1]=y[d|0]|y[d+1|0]<<8;hb=d+16|0}function VU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-48|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;f=e+8|0;IB(d,f);g=Eb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;d=(d|0)==(g|0);if(!d){JB(f)}c=-1;a:{if(!d){break a}c=0;if(!VB(e+8|0)){break a}c=kf(a,b,UB(e+8|0),lb)}hb=e+48|0;return c|0}function T9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-48|0;hb=c;d=c+40|0;b=z[b>>1];v[d|0]=b;v[d+1|0]=b>>>8;b=c+16|0;hl(b,d);b=Cb(x[b>>2]);e=c+8|0;hl(e,d);b=yi(c+24|0,b,Cb(x[e>>2]+2|0));x[114414]=0;O(1179,a|0,b|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){xb(b);hb=c+48|0;return}a=N()|0;xb(b);Q(a|0);p()}function gea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=d+16|0;Ii(e,d+8|0,c);x[114414]=0;P(72,d|0,e|0);c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}x[114414]=0;T(73,a|0,b|0,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Gb(d+16|0);hb=d+32|0;return}a=N()|0;Gb(d+16|0);Q(a|0);p()}function cd(a,b,c){var d=0,e=0;a:{b:{if(c>>>0>=4){if((a|b)&3){break b}while(1){if(x[a>>2]!=x[b>>2]){break b}b=b+4|0;a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}while(1){d=y[a|0];e=y[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}return d-e|0}return 0}function yg(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=G(e);gf(d,e,0,0,0,c+81|0);e=0+x[d+8>>2]|0;c=(x[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=x[d+4>>2];b=x[d>>2]}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=e;x[a+12>>2]=f;hb=d+16|0}function mW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=d+16|0;Gm(e,d+8|0,c);x[114414]=0;P(72,d|0,e|0);c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}x[114414]=0;T(73,a|0,b|0,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Gb(d+16|0);hb=d+32|0;return}a=N()|0;Gb(d+16|0);Q(a|0);p()}function cU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-1968|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;f=e+8|0;ZA(d,f);g=Eb(d);d=nd(a,ac(c,d));if((g|0)==(d|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;d=(d|0)==(g|0);if(!d){_A(f)}c=-1;a:{if(!d){break a}c=0;if(!cB(e+8|0)){break a}c=kf(a,b,1024,0)}hb=e+1968|0;return c|0}function Wy(a,b,c,d){var e=0,f=0;f=hb-16|0;hb=f;e=Kp(a);a:{if(qc(e)>>>0<=b>>>0){break a}if(Xy(a,z[uc(e,b)>>1])>>>0<=c>>>0){break a}b:{if(zc(a)>>>0>b>>>0){if(A[wd(a,b)+4>>2]>c>>>0){break b}}Hk(a,0);if(zc(a)>>>0<=b>>>0){break a}}e=f+8|0;oe(e,wd(a,b),c);he(e,d);if(!d){break a}zN(a,b,c)}hb=f+16|0}function RU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=d+16|0;Qu(e,d+8|0,c);x[114414]=0;P(72,d|0,e|0);c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}x[114414]=0;T(73,a|0,b|0,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Gb(d+16|0);hb=d+32|0;return}a=N()|0;Gb(d+16|0);Q(a|0);p()}function uJ(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=x[a+4256>>2];x[a+4240>>2]=b<<1;x[114414]=0;x[c+12>>2]=0;T(1681,a+4208|0,b<<2,c+12|0);b=x[114414];x[114414]=0;a:{if((b|0)==1){b=S(75016)|0;if((ib|0)!=(ca(75016)|0)){break a}Y(b|0)|0;x[a+4240>>2]=0;_()}x[a+4244>>2]=0;hb=c+16|0;return}Q(b|0);p()}function n6(a){a=a|0;var b=0;x[114414]=0;W(2048,a|0);b=x[114414];x[114414]=0;if((b|0)!=1){return x[a+16>>2]}Y(S(0)|0)|0;x[114414]=0;X(2023,2176,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)!=1){_();return-1}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function Lj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;d=hb-16|0;hb=d;a:{if(b>>>0<=2147483631){b:{if(il(b)){Ce(a,b);e=a;break b}Gh(d+8|0,a,cj(b)+1|0);e=x[d+8>>2];Ue(a,e);Ff(a,x[d+12>>2]);ae(a,b)}yn(e,b,c);v[d+7|0]=0;Wd(b+e|0,d+7|0);hb=d+16|0;break a}Ef();p()}hb=f+16|0;return a|0}function $B(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=d+12|0;xc(c,128);xc(c,65535);f=z[d+12>>1];mg(a,f);if(f){c=0;while(1){e=y[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=Pj(a,c),h=e,w[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}hb=d+16|0}function dC(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}f=1;while(1){v[c+13|0]=0;e=(c+14|0)+d|0;if(b>>>0>d>>>0){Xf(a,c+13|0);d=y[c+13|0]}else{d=0}v[e|0]=d;d=1;e=f;f=0;if(e){continue}break}w[c+8>>1]=z[c+14>>1];a=c+8|0;d=y[a|0]|y[a+1|0]<<8}hb=c+16|0;return d}function bj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(b){c=x[a+4>>2];e=x[a+12>>2];i=x[a+8>>2];d=x[a>>2];while(1){if(!d){x[a>>2]=8;c=i;if((e|0)!=(c|0)){c=e-1|0;x[a+12>>2]=c}d=8;e=c;c=y[c|0]}f=c;d=d-1|0;x[a>>2]=d;c=f>>>1|0;x[a+4>>2]=c;g=f&1|g<<1;h=h+1|0;if((h|0)!=(b|0)){continue}break}}return g}function ada(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>1;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Cb(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=(Cb(y[c|0])|Cb(y[c+1|0])<<8)^32768,w[f>>1]=g;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<1}function Zca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>1;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Cb(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=(Cb(y[c+1|0])|Cb(y[c|0])<<8)^32768,w[f>>1]=g;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<1}function X4(a){a=a|0;var b=0;x[114414]=0;W(2121,a|0);b=x[114414];x[114414]=0;a:{if((b|0)==1){Y(S(0)|0)|0;x[114414]=0;X(2023,7818,a|0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();a=0}return a|0}a=N()|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;if((b|0)!=1){Q(a|0);p()}S(0)|0;zb();p()}function Um(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;Dc(d,a);x[114414]=0;a=R(2510,d|0)|0;d=x[114414];x[114414]=0;a:{b:{if((d|0)==1){break b}x[114414]=0;Z(2523,a|0,64928,64954,b|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break b}Ob(c+8|0);hb=c+16|0;break a}a=N()|0;Ob(c+8|0);Q(a|0);p()}return b}function zJ(a,b,c){var d=0,e=0,f=0;if(E(F(a))<E(0x8000000000000000)){d=~~a>>>0}else{d=0}f=d&-2147483648;e=f?0-d|0:d;a:{if(!((e|0)<0|(b|0)<=0)){while(1){d=b-1|0;e=e<<1;if(b>>>0<2){break a}b=d;if((e|0)>=0){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return E((f?b^-1|f:b)|0)}function iw(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-160|0;hb=e;x[e+60>>2]=b;x[e+20>>2]=b;x[e+24>>2]=-1;f=e+16|0;Jh(f,0,0);NF(e,f,d,1);d=x[e+8>>2];g=x[e+12>>2];f=x[e>>2];h=x[e+4>>2];if(c){x[c>>2]=((x[e+20>>2]+x[e+136>>2]|0)-x[e+60>>2]|0)+b}x[a+8>>2]=d;x[a+12>>2]=g;x[a>>2]=f;x[a+4>>2]=h;hb=e+160|0}function iQ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(!y[a+20|0]){if(!(mb[x[x[a>>2]+44>>2]](a)|0)){b=a+4|0;while(1){wQ(a,65536);c=a,d=(f=a,g=Bc(b,x[a+16>>2]),h=65536,e=x[x[a>>2]+48>>2],mb[e](f|0,g|0,h|0)|0)+x[a+16>>2]|0,x[c+16>>2]=d;if(!(mb[x[x[a>>2]+44>>2]](a)|0)){continue}break}}v[a+20|0]=1}}function $ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=d+16|0;tQ(e,c);x[114414]=0;P(476,d|0,e|0);c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}x[114414]=0;T(477,a|0,b|0,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Gb(d+16|0);hb=d+32|0;return}a=N()|0;Gb(d+16|0);Q(a|0);p()}function Yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>1;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(f){a=x[a+20>>2];b=f;while(1){d=(Cb(y[c+1|0])+d|0)+(Cb(y[c|0])<<8)|0;w[a>>1]=d;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f<<1}function BT(a,b,c){var d=0;d=hb-32|0;hb=d;x[d+16>>2]=b;x[d+24>>2]=a;x[d+8>>2]=c;a:{if(!Hb(d+24|0,d+16|0)){break a}while(1){a=x[d+24>>2];if(x[x[d+8>>2]>>2]==(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))){break a}a=d+24|0;Xi(a);if(Hb(a,d+16|0)){continue}break}}hb=d+32|0;return x[d+24>>2]}function $ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;x[e+12>>2]=c>>>1;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(f){a=x[a+20>>2];b=f;while(1){d=(Cb(y[c|0])+d|0)+(Cb(y[c+1|0])<<8)|0;w[a>>1]=d;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f<<1}function wja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=E(0),g=0,h=0,i=0;if(d){e=(e<<1)+a|0;a=0;c=c<<1;while(1){f=de(E(nf(B[b>>2],E(-1))*E(32768)));a:{if(E(F(f))<E(2147483648)){g=~~f;break a}g=-2147483648}h=e,i=Uc(g),w[h>>1]=i;b=b+4|0;e=c+e|0;a=a+1|0;if((d|0)!=(a|0)){continue}break}}}function Lma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=d+16|0;oB(e,c);x[114414]=0;P(72,d|0,e|0);c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}x[114414]=0;T(73,a|0,b|0,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Gb(d+16|0);hb=d+32|0;return}a=N()|0;Gb(d+16|0);Q(a|0);p()}function Gha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(!x[a+300>>2]){return 0}if((mb[x[a+304>>2]](x[a+296>>2],c,0,0)|0)>=0){a:{if(!d){break a}while(1){c=mb[x[a+300>>2]](x[a+296>>2],b,d)|0;if(!c){break a}b=b+c|0;e=c+e|0;f=c>>>0>e>>>0?f+1|0:f;d=d-c|0;if(d){continue}break}}}return e|0}function DV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;x[e+12>>2]=d;d=0;if(A[a+16>>2]>c>>>0){d=x[a+4>>2];f=x[a+12>>2];x[e+8>>2]=x[a+16>>2]-c;d=(h=d,i=b,j=c+f|0,k=x[Mb(e+12|0,e+8|0)>>2],g=x[x[d>>2]+28>>2],mb[g](h|0,i|0,j|0,k|0)|0)}hb=e+16|0;return d|0}function w6(){var a=0,b=0;x[114414]=0;a=$(2038)|0;b=x[114414];x[114414]=0;a:{if((b|0)==1){Y(S(0)|0)|0;x[114414]=0;X(2023,7084,0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();a=0}return a|0}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb();p()}function KX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;b=bi(d,a+8|0,b);c=x[b>>2];a:{while(1){if(x[b+4>>2]==(c|0)){break a}c=x[a+16>>2];e=x[b>>2];x[114414]=0;Yv(c,e);c=x[114414];x[114414]=0;if((c|0)!=1){c=x[b>>2]+4|0;x[b>>2]=c;continue}break}a=N()|0;Ac(b);Q(a|0);p()}Ac(b);hb=d+16|0}function J6(){var a=0,b=0;x[114414]=0;a=$(2022)|0;b=x[114414];x[114414]=0;a:{if((b|0)==1){Y(S(0)|0)|0;x[114414]=0;X(2023,5855,0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();a=0}return a|0}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb();p()}function H6(){var a=0,b=0;x[114414]=0;a=$(2026)|0;b=x[114414];x[114414]=0;a:{if((b|0)==1){Y(S(0)|0)|0;x[114414]=0;X(2023,5883,0,0,0);a=x[114414];x[114414]=0;if((a|0)==1){break a}_();a=0}return a|0}b=N()|0;x[114414]=0;V(20);a=x[114414];x[114414]=0;if((a|0)!=1){Q(b|0);p()}S(0)|0;zb();p()}function GK(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-52|0;x[a+8>>2]=c;x[114414]=0;P(1449,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){oy(x[a+16>>2],x[a>>2],(x[ic(a)>>2]-x[a>>2]|0)/52|0)}}function zma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;v[d+15|0]=1;v[d+14|0]=a>>>2;a=y[Xg(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){v[d+13|0]=1;v[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=y[Xg(d+13|0,d+12|0)|0]}hb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function qu(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-48|0;x[a+8>>2]=c;x[114414]=0;P(535,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){nT(x[a+16>>2],x[a>>2],(x[ic(a)>>2]-x[a>>2]|0)/48|0)}}function kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{if(!y[a+40|0]){if(!x[a+28>>2]){break a}b:{if(!c){break b}while(1){d=mb[x[a+28>>2]](x[a+24>>2],b,c)|0;if(!d){v[a+40|0]=1;break b}b=b+d|0;e=d+e|0;f=e>>>0<d>>>0?f+1|0:f;c=c-d|0;if(c){continue}break}}}return e|0}v[a+40|0]=1;return 0}function PR(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-33|0;x[a+8>>2]=c;x[114414]=0;P(740,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){RR(x[a+16>>2],x[a>>2],(x[ic(a)>>2]-x[a>>2]|0)/33|0)}}function LP(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-56|0;x[a+8>>2]=c;x[114414]=0;P(962,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){It(x[a+16>>2],x[a>>2],(x[ic(a)>>2]-x[a>>2]|0)/56|0)}}function sja(a){a=a|0;var b=0,c=0,d=0,e=0;if(!y[a+8|0]){if(y[a+24|0]){v[a+24|0]=0;c=a+40|0;while(1){d=Oi(c,b),e=0,v[d+8|0]=e;b=b+1|0;if((b|0)!=16){continue}break}b=a+28|0;Ok(b,0);wR(b)}b=a+12|0;Ok(b,x[a+4>>2]);mb[x[x[a>>2]+44>>2]](a,x[b>>2],0,x[a+4>>2])|0;v[a+8|0]=1}return x[a+12>>2]}function sh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;g=Vj(a,c);e=f+8|0;vf(e,x[a+28>>2]);h=x[e+12>>2];x[f+24>>2]=x[e+8>>2];x[f+28>>2]=h;a:{b:{if(!g){e=-1;if(!Cd(a,5)){break b}break a}e=x[g+8>>2]}mb[d|0](x[a+28>>2],b,e)}a=hj(a,g,c,f+24|0);hb=f+32|0;return a|0}function sV(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-48|0;hb=c;d=-1;a:{if(!JC(a,c+8|0)){break a}d=0;if(!GC(c+8|0)){break a}if(b){a=c+12|0;a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);if(!x[b+4>>2]&A[b>>2]<(a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24))-8>>>0){break a}}d=1}hb=c+48|0;return d|0}function WK(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>28){break c}d=1<<a;c=1;if(d&270014517){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c|0}function pT(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;Qe(a+12|0,d);if(b){if(b>>>0>89478485){ve();p()}d=Vd(D(b,48),4);x[e+4>>2]=b;x[e>>2]=d;f=x[e>>2];b=x[e+4>>2]}else{b=0}x[a>>2]=f;c=D(c,48)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=ic(a),h=D(b,48)+f|0,x[g>>2]=h;hb=e+16|0;return a}function kE(a,b,c){var d=0,e=0,f=0;f=hb-16|0;hb=f;e=Bb(a);d=Fc(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Rb(a);if(e){fl(c+d|0,d,e);b=(b>>>0>=d>>>0?d+e>>>0>b>>>0?c:0:0)+b|0}fl(d,b,c);b=c+e|0;Zg(a,b);v[f+15|0]=0;Wd(b+d|0,f+15|0);break a}wo(a,d,(c+e|0)-d|0,e,0,0,c,b)}hb=f+16|0;return a}function cu(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-6|0;x[a+8>>2]=c;x[114414]=0;P(708,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){su(x[a+16>>2],x[a>>2],(x[ic(a)>>2]-x[a>>2]|0)/6|0)}}function bda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>1;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Cb(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=Cb(y[c|0])|Cb(y[c+1|0])<<8,w[f>>1]=g;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<1}function _ca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c>>>1;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Cb(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=Cb(y[c+1|0])|Cb(y[c|0])<<8,w[f>>1]=g;a=a+2|0;c=c+2|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e<<1}function Ls(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-2048|0;x[a+8>>2]=c;x[114414]=0;P(1685,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){cK(x[a+16>>2],x[a>>2],x[ic(a)>>2]-x[a>>2]>>11)}}function z2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a=Eo(a);x[a>>2]=82728;e=ic(a);x[114414]=0;d=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=d;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;O(2231,e|0,c+8|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){hb=c+32|0;return a|0}Q(N()|0);p()}function v2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a=Eo(a);x[a>>2]=82768;e=ic(a);x[114414]=0;d=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=d;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;O(2232,e|0,c+8|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){hb=c+32|0;return a|0}Q(N()|0);p()}function aea(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[114414]=0;a=U(1192,a|0,c+8|0,c|0)|0;d=x[114414];x[114414]=0;a:{if((d|0)!=1){hb=c+16|0;break a}S(0)|0;zb();p()}v[a+530|0]=0;x[114414]=0;P(1191,a|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){return a|0}b=N()|0;dg(a);Q(b|0);p()}function yY(a){a=a|0;var b=0,c=0;b=x[a+8>>2];x[114414]=0;b=Z(2624,0,0,4,b|0)|0;c=x[114414];x[114414]=0;a:{if((c|0)==1){break a}if(b){a=-1}else{a=x[a+8>>2];if(!a){return 1}x[114414]=0;a=R(2625,a|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}a=(a|0)==1}return a|0}S(0)|0;zb();p()}function aG(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a=Zr(a);x[a+32>>2]=b;x[a>>2]=60780;b=d+8|0;Tr(b,a);x[114414]=0;b=R(2452,b|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){Ob(d+8|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=Xm(b),v[f+44|0]=g;hb=d+16|0;return}b=N()|0;Ob(d+8|0);zl(a);Q(b|0);p()}function ZF(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a=nG(a);x[a+32>>2]=b;x[a>>2]=60984;b=d+8|0;Tr(b,a);x[114414]=0;b=R(2454,b|0)|0;e=x[114414];x[114414]=0;if((e|0)!=1){Ob(d+8|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=Xm(b),v[f+44|0]=g;hb=d+16|0;return}b=N()|0;Ob(d+8|0);Xo(a);Q(b|0);p()}function zq(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;Qe(a+12|0,d);if(b){if(b>>>0>2147483647){ve();p()}d=Vd(b<<1,1);x[e+4>>2]=b;x[e>>2]=d;f=x[e>>2];b=x[e+4>>2]}else{b=0}x[a>>2]=f;c=(c<<1)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=ic(a),h=(b<<1)+f|0,x[g>>2]=h;hb=e+16|0;return a}function de(a){var b=E(0),c=0,d=0;c=(q(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return E(a*E(0))}a=(c|0)>=0?a:E(-a);b=E(E(E(a+E(8388608))+E(-8388608))-a);a:{if(b>E(.5)){a=E(E(a+b)+E(-1));break a}a=E(a+b);if(!(b<=E(-.5))){break a}a=E(a+E(1))}a=(c|0)>=0?a:E(-a)}return a}function Lm(a,b){var c=0,d=0,e=0,f=0;f=hb-16|0;hb=f;c=FF(b);d=hb-16|0;hb=d;a:{if(c>>>0<=1073741807){b:{if(Po(c)){Ce(a,c);e=a;break b}Zj(d+8|0,a,ql(c)+1|0);e=x[d+8>>2];Ue(a,e);Ff(a,x[d+12>>2]);ae(a,c)}Kh(e,b,c);x[d+4>>2]=0;ug((c<<2)+e|0,d+4|0);hb=d+16|0;break a}Ef();p()}hb=f+16|0}function JS(a){var b=0,c=0,d=0,e=0;b=a+32|0;d=y[b|0]|y[b+1|0]<<8;b=a+38|0;e=y[b|0]|y[b+1|0]<<8;b=a+34|0;a=a+36|0;c=y[a|0]|y[a+1|0]<<8;b=(y[b|0]|y[b+1|0]<<8)+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=(c>>>0>b>>>0?a+1|0:a)<<2|b>>>30;c=d;d=b<<2;b=c+d|0;lb=b>>>0<d>>>0?a+1|0:a;return b}function $s(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(!b){return 0}j=$b(a+1074312|0,73)?c- -64|0:c;c=120;h=zp(a);k=h^-1;e=1;while(1){f=c>>>1|0;i=f+e|0;g=eg(a,i,j,d);a:{if(!(!(g>>>0>b>>>0&k)&(!(!g|h)|b>>>0<=g>>>0))){e=i+1|0;c=(f^-1)+c|0;break a}c=f}if(c){continue}break}return e}function tX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;a:{if(x[b>>2]){if(!Wc(c)){Gv(c,13624)}e=x[b+4>>2];mb[x[x[e>>2]+24>>2]](d,e,x[b>>2]);x[114414]=0;O(1251,c|0,d|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}xb(d)}Jd(a,c);hb=d+16|0;return}a=N()|0;xb(d);Q(a|0);p()}function nQ(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-8|0;x[a+8>>2]=c;x[114414]=0;P(894,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){wv(x[a+16>>2],x[a>>2],x[ic(a)>>2]-x[a>>2]>>3)}}function Sd(a,b){var c=0,d=0,e=0,f=0;c=x[a+4>>2];d=c+b|0;x[a+4>>2]=d;if((d|0)<=x[a+8>>2]){d=x[a>>2]+(c>>3)|0;a=c&7;c=y[d|0]&255>>>a;a=a+b|0;a:{if((a|0)<9){b=a;break a}while(1){b=a-8|0;e=c<<b|e;f=a>>>0>16;c=y[d+1|0];d=d+1|0;a=b;if(f){continue}break}}a=c>>>8-b|e}else{a=0}return a}function Pha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-608|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;uP(d,e);f=Eb(d);d=nd(a,ac(c,d));if((f|0)==(d|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;d=(d|0)==(f|0);if(!d){vP(e)}c=-1;a:{if(!d){break a}c=0;if(!xP(e)){break a}c=kf(a,b,wP(e),lb)}hb=e+608|0;return c|0}function Ola(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-576|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;LS(d,e);f=Eb(d);d=nd(a,ac(c,d));if((f|0)==(d|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;d=(d|0)==(f|0);if(!d){MS(e)}c=-1;a:{if(!d){break a}c=0;if(!PS(e)){break a}c=kf(a,b,OS(e),lb)}hb=e+576|0;return c|0}function MV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;f=Eo(a);x[f>>2]=76132;g=ic(f);a=jl(e+16|0,b);b=x[d>>2];c=x[c>>2];d=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=d;a=fq(g);x[a>>2]=76172;d=e+8|0;jl(a+4|0,d);x[a+16>>2]=b;x[a+12>>2]=c;Ab(d);hb=e+32|0;return f|0}function Gla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-192|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;xq(d,e);f=Eb(d);d=nd(a,ac(c,d));if((f|0)==(d|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;d=(d|0)==(f|0);if(!d){hS(e)}c=-1;a:{if(!d){break a}c=0;if(!KS(e)){break a}c=kf(a,b,JS(e),lb)}hb=e+192|0;return c|0}function kU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-16|0;hb=e;f=Qb(a,120);a:{if(f){c=hb-16|0;hb=c;d=e+8|0;jc(d,b,120);hb=c+16|0;Dd(a,d);break a}a=0;c=hb-16|0;hb=c;d=hb-16|0;hb=d;while(1){mf(a+b|0);a=a+1|0;if((a|0)!=120){continue}break}hb=d+16|0;hb=c+16|0}hb=e+16|0;return f|0}function Ql(a,b,c,d){var e=0,f=0;a:{f=x[(D(b,896)+a|0)+1075640>>2];if(!f){break a}if(!Ki(f)){break a}e=y[f+34|0];if((e-1&255)>>>0>249){break a}e=x[(D(e,160)+a|0)+906140>>2];if(!e){break a}mb[x[x[e>>2]+88>>2]](e,f,c,d,b);if(c>>>0>250){break a}w[(D(b,896)+a|0)+1075846>>1]=65535}}function A0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;xw(d+24|0,a,(b<<2)+a|0);kl(d+16|0,x[d+24>>2],x[d+28>>2],c);f=d,g=ww(a,x[d+16>>2]),x[f+12>>2]=g;f=d,g=rg(c,x[d+20>>2]),x[f+8>>2]=g;gd(e+8|0,d+12|0,d+8|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function nea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-48|0;hb=c;d=c+40|0;v[d|0]=y[b|0];b=c+16|0;Vq(b,d);b=Cb(x[b>>2]);e=c+8|0;Vq(e,d);b=yi(c+24|0,b,Cb(x[e>>2]+1|0));x[114414]=0;O(1179,a|0,b|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){xb(b);hb=c+48|0;return}a=N()|0;xb(b);Q(a|0);p()}function _ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-80|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;bS(d,e);f=Eb(d);d=nd(a,ac(c,d));if((f|0)==(d|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;d=(d|0)==(f|0);if(!d){cS(e)}c=-1;a:{if(!d){break a}c=0;if(!VO(e)){break a}c=kf(a,b,UO(e),lb)}hb=e+80|0;return c|0}function Tx(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[c+12>>2]=0;U(1604,a+8|0,c+12|0,c+8|0)|0;d=x[114414];x[114414]=0;a:{if((d|0)!=1){hb=c+16|0;break a}S(0)|0;zb();p()}x[a+20>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;Dk(a+24|0);Wb(a+36|0);x[a+48>>2]=b;return a}function r4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-48|0;hb=d;x[d+44>>2]=b;b=d+8|0;rj(b,0,c);c=d+24|0;x[c>>2]=x[d+44>>2];Jd(c+4|0,b);x[114414]=0;P(2156,a+4|0,c|0);a=x[114414];x[114414]=0;if((a|0)!=1){Pi(d+24|0);xb(d+8|0);hb=d+48|0;return}a=N()|0;Pi(d+24|0);xb(d+8|0);Q(a|0);p()}function jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Cb(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=Xb(bl(y[c|0]),-64,63)<<1,v[f|0]=g;a=a+1|0;c=c+1|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e|0}function hj(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=hb-48|0;hb=c;a:{if(!b){b=1;if(Cd(a,5)){break a}e=TD(c+32|0),f=x[d>>2]-x[a+8>>2]|0,x[e+4>>2]=f;vf(c,x[a+28>>2]);XD(c+16|0,c,x[d>>2],x[d+4>>2])}x[a>>2]=x[a>>2]|134217728;x[a+20>>2]=x[a+20>>2]+1;b=0}hb=c+48|0;return b|0}function dja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-128|0;hb=e;c=hb-16|0;hb=c;d=c+8|0;rQ(d,e);f=Eb(d);d=nd(a,ac(c,d));if((f|0)==(d|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;d=(d|0)==(f|0);if(!d){sQ(e)}c=-1;a:{if(!d){break a}c=0;if(!zQ(e)){break a}c=kf(a,b,256,0)}hb=e+128|0;return c|0}function qr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=ec(16);if(!y[462921]){v[462921]=1}a=dd(c+8|0,a,83960);x[114414]=0;e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;U(2899,d|0,c|0,b|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){da(d|0,74296,2900);p()}a=N()|0;hc(d);Q(a|0);p()}function h9(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[c+8>>2]=b;b=0;a:{if(Lb(a)>>>0>511){break a}if(!zd(c+8|0)){break a}d=c+8|0;b=x[d>>2];x[114414]=0;P(1662,a|0,d|0);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;Tf(c+8|0);Q(a|0);p()}Tf(c+8|0);hb=c+16|0;return b|0}function eU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;if(!Qb(b,c)){c=uf(b)}x[a>>2]=c;d=x[b>>2];if(mb[x[x[d>>2]+16>>2]](d)|0){c=a;a=x[b>>2];e=c,f=(mb[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0,x[e+4>>2]=f;return}d=a+8|0;Ok(d,x[a>>2]);if(!od(d)){lg(b,Bc(d,0),c)}}function KS(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1297108297){b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=778924148){break a}}c=a+34|0;b=0;if((y[c|0]|y[c+1|0]<<8)>>>0>255){break a}a=a+36|0;b=(y[a|0]|y[a+1|0]<<8)>>>0<4e3}return b}function c8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;x[a+4>>2]=b;x[a>>2]=0;b=vt(a+8|0,e);x[114414]=0;O(1795,a+20|0,d|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){x[a+32>>2]=0;x[a+36>>2]=0;v[a+42|0]=0;v[a+40|0]=0;v[a+41|0]=y[a+41|0]&240|c|8;return a|0}a=N()|0;Gb(b);Q(a|0);p()}function G$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b|0];g=v[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function Bma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}v[d+15|0]=1;v[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=y[Xg(d+15|0,d+14|0)|0]}a=e;hb=d+16|0;return a&255}function Raa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(xg(a)>>>0<b>>>0){if(yr(a)>>>0<b>>>0){break b}d=yb(a);b=ek(c+8|0,b,zc(a),d);x[114414]=0;P(1257,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}mt(b)}hb=c+32|0;return}Vc();p()}a=N()|0;mt(b);Q(a|0);p()}function Qd(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function Nja(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(pf(a)>>>0<b>>>0){if(Au(a)>>>0<b>>>0){break b}d=yb(a);b=Yh(c+8|0,b,wc(a),d);x[114414]=0;P(328,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Ah(b)}hb=c+32|0;return}Vc();p()}a=N()|0;Ah(b);Q(a|0);p()}
function uha(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(xg(a)>>>0<b>>>0){if(yr(a)>>>0<b>>>0){break b}d=yb(a);b=ek(c+8|0,b,zc(a),d);x[114414]=0;P(1e3,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Gt(b)}hb=c+32|0;return}Vc();p()}a=N()|0;Gt(b);Q(a|0);p()}function e8(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(vd(a)>>>0<b>>>0){if(wk(a)>>>0<b>>>0){break b}d=yb(a);b=Nf(c+8|0,b,Lb(a),d);x[114414]=0;P(1794,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Es(b)}hb=c+32|0;return}Vc();p()}a=N()|0;Es(b);Q(a|0);p()}function Y1(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;d=x[a>>2];b=Fb(c+8|0,x[x[a+8>>2]>>2]);e=Fb(c,x[x[a+4>>2]>>2]);b=x[b>>2];a=hb-16|0;hb=a;x[a>>2]=x[e>>2];x[a+8>>2]=b;if(bd(a+8|0,a)){while(1){b=a+8|0;Ro(d,nN(b));ij(b);if(bd(b,a)){continue}break}}hb=a+16|0;hb=c+16|0}function Wja(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(Vf(a)>>>0<b>>>0){if(jv(a)>>>0<b>>>0){break b}d=yb(a);b=to(c+8|0,b,qc(a),d);x[114414]=0;P(345,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Oj(b)}hb=c+32|0;return}Vc();p()}a=N()|0;Oj(b);Q(a|0);p()}function Qx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(!jg(a)){break a}while(1){if(!xh(Re(a,e))){break a}d=d+1|0;e=d&65535;if(jg(a)>>>0>e>>>0){continue}break}}b:{if(c){c=65535;if(z[x[x[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0){break b}}c=Tg(a,d&65535,b)?d:-1}return c&65535}function yf(a,b){var c=0,d=0,e=0,f=0;c=Bb(a);a:{if((c|0)!=(Bb(b)|0)){break a}d=Rb(a);b=Rb(b);b:{if(!re(a)){if(c){break b}return 1}return!on(d,b,c)}while(1){a=y[b|0];e=y[d|0];f=(a|0)==(e|0);if((a|0)!=(e|0)){break a}b=b+1|0;d=d+1|0;c=c-1|0;if(c){continue}break}}return f}function wV(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(vd(a)>>>0<b>>>0){if(wk(a)>>>0<b>>>0){break b}d=yb(a);b=Nf(c+8|0,b,Lb(a),d);x[114414]=0;P(310,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Tq(b)}hb=c+32|0;return}Vc();p()}a=N()|0;Tq(b);Q(a|0);p()}function eD(a){a=a|0;var b=0,c=0;a=hd(a);x[114414]=0;R(239,a+12|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){b=hb-16|0;hb=b;x[114414]=0;U(240,a+28|0,b+8|0,b|0)|0;c=x[114414];x[114414]=0;a:{if((c|0)!=1){hb=b+16|0;break a}S(0)|0;zb();p()}return a|0}b=N()|0;xb(a);Q(b|0);p()}function AC(a,b,c,d){var e=0,f=0;b=x[a+1072>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1072>>2]=b;c=b+x[a+1076>>2]|0;x[a+1076>>2]=c;w[(x[a+1064>>2]<<1)+d>>1]=y[a+1080|0]?c:b;x[a+1060>>2]=x[a+1060>>2]+1;e=a,f=Je(x[a+1056>>2])+x[a+1064>>2]|0,x[e+1064>>2]=f;x[a+1068>>2]=x[a+1068>>2]-1}function wJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=hb-16|0;hb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Rb(d);yi(b,a,Bb(d)+a|0);break c}XJ(e,c,d);x[114414]=0;T(112,a|0,b|0,e|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}Nc(e)}hb=e+16|0;break a}a=N()|0;Nc(e);Q(a|0);p()}}function u7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=6){Ph(d+12|0);c=B[d+12>>2];a:{if(!((b|0)!=1|c>=E(1))){x[d+12>>2]=0;c=E(0);break a}if((b|0)!=4){break a}c=E(de(E(c*E(4)))*E(.25));B[d+12>>2]=c}B[((b<<2)+a|0)+4208>>2]=c;Dx(a)}hb=d+16|0}function Z7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=6){Ph(d+12|0);c=B[d+12>>2];a:{if(!((b|0)!=3|c>=E(1))){x[d+12>>2]=0;c=E(0);break a}if((b|0)!=4){break a}c=E(de(E(c*E(4)))*E(.25));B[d+12>>2]=c}B[((b<<2)+a|0)+4208>>2]=c;Dx(a)}hb=d+16|0}function Kz(a,b){var c=0,d=0,e=0,f=0;c=a;d=a+1024|0;a:{if((d|0)==(a|0)){b=0;break a}f=b?224:240;b=0;while(1){a=c;e=a+16|0;if((a|0)!=(e|0)){while(1){b=((y[gc(a,0)|0]&f)!=0)+b|0;a=a+4|0;if((e|0)!=(a|0)){continue}break}}c=c+16|0;if((d|0)!=(c|0)){continue}break}}return b}function Jda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(x[a>>2]){zc(a);AN(a);Ht(a);Ih(yb(a),x[a>>2],xg(a));d=yb(a),e=0,x[d>>2]=e;x[a>>2]=0;x[a+4>>2]=0}Wl(a,b);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=x[yb(b)>>2];d=yb(a),e=c,x[d>>2]=e;d=yb(b),e=0,x[d>>2]=e;x[b>>2]=0;x[b+4>>2]=0}function kF(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;Dc(d,a);x[114414]=0;a=R(21,d|0)|0;d=x[114414];x[114414]=0;a:{if((d|0)==1){break a}x[114414]=0;a=O(22,a|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}Ob(c+8|0);hb=c+16|0;return a}a=N()|0;Ob(c+8|0);Q(a|0);p()}function W$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Wg(v[b|0]),e=x[x[a>>2]+52>>2],mb[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=oj(b,1,c,x[a+32>>2])}return c|0}function OV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-32|0;hb=e;x[114414]=0;x[e+24>>2]=d;x[e+28>>2]=c;X(250,e+8|0,b|0,e+28|0,e+24|0);c=x[114414];x[114414]=0;if((c|0)!=1){c=e+16|0;d=e+8|0;QC(c,d);zm(a,c);Ab(c);Ab(d);Ab(b);hb=e+32|0;return}a=N()|0;Ab(b);Q(a|0);p()}function L6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=ud(b);f=jf(b);e=ud(b);c=hb-32|0;hb=c;x[c+16>>2]=f;x[c+24>>2]=d;x[c+8>>2]=e;if(Hb(c+24|0,c+16|0)){while(1){d=c+24|0;f=mn(v[x[d>>2]]);e=c+8|0;v[x[e>>2]]=f;bg(d);bg(e);if(Hb(d,c+16|0)){continue}break}}hb=c+32|0;Jd(a,b)}function $o(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function lda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Cb(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=Cb(y[c|0])^128,v[f|0]=g;a=a+1|0;c=c+1|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e|0}function VE(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;c=je(d,a,b);b=x[c+4>>2];f=x[c+8>>2];a:{while(1){if((b|0)==(f|0)){break a}e=rl(a);x[114414]=0;Yv(e,b);e=x[114414];x[114414]=0;if((e|0)!=1){b=b+4|0;x[c+4>>2]=b;continue}break}a=N()|0;Jb(c);Q(a|0);p()}Jb(c);hb=d+16|0}function zb(){var a=0;a=x[20991];x[114414]=0;V(a|0);a=x[114414];x[114414]=0;a:{if((a|0)!=1){x[114414]=0;P(2910,8438,0);a=x[114414];x[114414]=0;if((a|0)!=1){break a}}Y(S(0)|0)|0;x[114414]=0;P(2910,5772,0);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb()}p()}function mQ(a){var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;x[c+12>>2]=-1;b=hb-16|0;hb=b;d=2;e=x[a>>2];if((e|0)!=1){x[b+12>>2]=e>>>1;x[b+8>>2]=-1-x[a>>2];d=Mb(b+12|0,b+8|0);x[b+12>>2]=x[a>>2]+x[d>>2];x[b+8>>2]=x[c+12>>2];d=x[Mb(b+12|0,b+8|0)>>2]}hb=b+16|0;hb=c+16|0;return d}function i3(a,b){a=a|0;b=b|0;var c=E(0),d=E(0);a:{if((b|0)<0){break a}a=a+24|0;if(z[x[a>>2]+480188>>1]<=b>>>0){break a}b=D(b,896);c=E(E(y[(b+x[a>>2]|0)+1075847|0])*E(.0078125));d=E(c*c);c=E(E(y[(b+x[a>>2]|0)+1075846|0])*E(.0078125));c=E(M(E(d+E(c*c))))}return E(c)}function MJ(a){var b=0,c=0,d=0;Ye(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-4|0;P(1797,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;Xe(yb(a),x[a>>2],vd(a))}return a}function ut(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-32|0;x[a+8>>2]=c;x[114414]=0;P(1183,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){_g(x[a+16>>2],x[a>>2],tv(a))}}function tN(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-12|0;x[a+8>>2]=c;x[114414]=0;P(1226,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Ih(x[a+16>>2],x[a>>2],To(a))}}function oX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(tg(a,x[b+8>>2],0)){Sv(b,c,d);return}e=x[a+12>>2];f=a+16|0;_D(f,b,c,d);a=a+24|0;e=(e<<3)+f|0;a:{if(a>>>0>=e>>>0){break a}while(1){_D(a,b,c,d);if(y[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function gI(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-16|0;x[a+8>>2]=c;x[114414]=0;P(2239,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){di(x[a+16>>2],x[a>>2],Hv(a))}}function fI(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-24|0;x[a+8>>2]=c;x[114414]=0;P(2240,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){xp(x[a+16>>2],x[a>>2],em(a))}}function cL(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-24|0;x[a+8>>2]=c;x[114414]=0;P(1573,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Hf(x[a+16>>2],x[a>>2],em(a))}}function bP(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-12|0;x[a+8>>2]=c;x[114414]=0;P(1004,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Ih(x[a+16>>2],x[a>>2],To(a))}}function Nr(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=x[b+76>>2]>=0;b:{c=x[b+4>>2];c:{if(!c){Iw(b);c=x[b+4>>2];if(!c){break c}}if(x[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;x[b+4>>2]=c;v[c|0]=a;x[b>>2]=x[b>>2]&-17;d=a&255}return d}function Gt(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-12|0;x[a+8>>2]=c;x[114414]=0;P(1005,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Ih(x[a+16>>2],x[a>>2],To(a))}}function zC(a,b,c,d){var e=0,f=0;b=x[a+1072>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1072>>2]=b;c=b+x[a+1076>>2]|0;x[a+1076>>2]=c;v[x[a+1064>>2]+d|0]=y[a+1080|0]?c:b;x[a+1060>>2]=x[a+1060>>2]+1;e=a,f=Je(x[a+1056>>2])+x[a+1064>>2]|0,x[e+1064>>2]=f;x[a+1068>>2]=x[a+1068>>2]-1}function uM(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-32|0;x[a+8>>2]=c;x[114414]=0;P(868,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Qt(x[a+16>>2],x[a>>2],tv(a))}}function qK(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114414]=0;P(1450,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Xe(x[a+16>>2],x[a>>2],Dg(a))}}function pL(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114414]=0;P(1539,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Xe(x[a+16>>2],x[a>>2],Dg(a))}}function mu(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-16|0;x[a+8>>2]=c;x[114414]=0;P(375,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){di(x[a+16>>2],x[a>>2],Hv(a))}}function mt(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-12|0;x[a+8>>2]=c;x[114414]=0;P(313,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Ih(x[a+16>>2],x[a>>2],To(a))}}function mT(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-24|0;x[a+8>>2]=c;x[114414]=0;P(534,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Hf(x[a+16>>2],x[a>>2],em(a))}}function dT(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-24|0;x[a+8>>2]=c;x[114414]=0;P(572,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Hf(x[a+16>>2],x[a>>2],em(a))}}function cR(a){var b=0,c=0,d=0;$p(a);$p(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-20|0;P(857,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;aq(yb(a),x[a>>2],$p(a))}}function br(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-32|0;x[a+8>>2]=c;x[114414]=0;P(238,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){_g(x[a+16>>2],x[a>>2],tv(a))}}function PO(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114414]=0;P(1045,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Ij(x[a+16>>2],x[a>>2],Dg(a))}}function OT(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-24|0;x[a+8>>2]=c;x[114414]=0;P(486,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Hf(x[a+16>>2],x[a>>2],em(a))}}function ND(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-16|0;x[a+8>>2]=c;x[114414]=0;P(185,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){di(x[a+16>>2],x[a>>2],Hv(a))}}function MP(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-24|0;x[a+8>>2]=c;x[114414]=0;P(954,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Hf(x[a+16>>2],x[a>>2],em(a))}}function LL(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114414]=0;P(1456,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Xe(x[a+16>>2],x[a>>2],Dg(a))}}function Ks(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114414]=0;P(1687,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Xe(x[a+16>>2],x[a>>2],Dg(a))}}function IR(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-24|0;x[a+8>>2]=c;x[114414]=0;P(742,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Hf(x[a+16>>2],x[a>>2],em(a))}}function Es(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114414]=0;P(1797,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Xe(x[a+16>>2],x[a>>2],Dg(a))}}function Ar(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-12|0;x[a+8>>2]=c;x[114414]=0;P(175,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Ih(x[a+16>>2],x[a>>2],To(a))}}function xk(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114414]=0;P(105,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Xe(x[a+16>>2],x[a>>2],Dg(a))}}function wC(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-2|0;x[a+8>>2]=c;x[114414]=0;P(326,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){vo(x[a+16>>2],x[a>>2],so(a))}}function uj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(x[a+480180>>2]&1|b){e=x[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;w[c+480286>>1]=64;d=c+480280|0;x[d>>2]=x[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;w[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function qR(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114414]=0;P(798,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Ij(x[a+16>>2],x[a>>2],Dg(a))}}function pn(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114414]=0;P(707,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Xe(x[a+16>>2],x[a>>2],Dg(a))}}function mda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+8>>2]=x[a>>2];e=x[Mb(d+12|0,d+8|0)>>2];c=Cb(b);if(e){a=x[a+20>>2];b=e;while(1){f=a,g=bl(y[c|0]),v[f|0]=g;a=a+1|0;c=c+1|0;b=b-1|0;if(b){continue}break}}hb=d+16|0;return e|0}function kda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;x[e+12>>2]=c;x[e+8>>2]=x[a>>2];f=x[Mb(e+12|0,e+8|0)>>2];c=Cb(b);if(f){a=x[a+20>>2];b=f;while(1){d=Cb(y[c|0])+d|0;v[a|0]=d;a=a+1|0;c=c+1|0;b=b-1|0;if(b){continue}break}}hb=e+16|0;return f|0}function iR(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-2|0;x[a+8>>2]=c;x[114414]=0;P(804,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){hm(x[a+16>>2],x[a>>2],so(a))}}function eS(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114414]=0;P(709,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Ij(x[a+16>>2],x[a>>2],Dg(a))}}function _i(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114414]=0;P(337,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){av(x[a+16>>2],x[a>>2],Dg(a))}}function YP(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114414]=0;P(919,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Ij(x[a+16>>2],x[a>>2],Dg(a))}}function Tq(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-4|0;x[a+8>>2]=c;x[114414]=0;P(314,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){Xe(x[a+16>>2],x[a>>2],Dg(a))}}function Oj(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-2|0;x[a+8>>2]=c;x[114414]=0;P(347,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){vo(x[a+16>>2],x[a>>2],so(a))}}function Km(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-1|0;x[a+8>>2]=c;x[114414]=0;P(183,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){ag(x[a+16>>2],x[a>>2],vA(a))}}function Cu(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-2|0;x[a+8>>2]=c;x[114414]=0;P(494,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){hm(x[a+16>>2],x[a>>2],so(a))}}function Ah(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-1|0;x[a+8>>2]=c;x[114414]=0;P(325,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){ag(x[a+16>>2],x[a>>2],vA(a))}}function AB(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-2|0;x[a+8>>2]=c;x[114414]=0;P(371,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){hm(x[a+16>>2],x[a>>2],so(a))}}function uu(a){var b=0,c=0,d=0;d=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(d|0)){break a}b=x[a+16>>2];c=x[a+8>>2]-1|0;x[a+8>>2]=c;x[114414]=0;P(36,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){ag(x[a+16>>2],x[a>>2],vA(a))}}function pk(a){var b=0,c=0;a:{b=x[a+1396>>2];if((b|0)>24){break a}if(!b){x[a+1392>>2]=0}while(1){if(y[a+1376|0]?0:x[a+1384>>2]){break a}c=js(a);if((c|0)==-1){break a}b=x[a+1396>>2];x[a+1396>>2]=b+8;x[a+1392>>2]=x[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function Nf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;Qe(a+12|0,d);if(b){Lx(e,x[a+16>>2],b);f=x[e>>2];b=x[e+4>>2]}else{b=0}x[a>>2]=f;c=(c<<2)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=ic(a),h=(b<<2)+f|0,x[g>>2]=h;hb=e+16|0;return a|0}function kaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+8>>2]=c;x[d+16>>2]=b;b=x[a>>2];e=d,f=bc(a),x[e>>2]=f;c=d+16|0;b=b+D(Rs(c,d),6)|0;if(Hb(c,d+8|0)){rA(a,UK(b+D(Rs(d+8|0,d+16|0),6)|0,x[a+4>>2],b))}a=x[Fb(d+24|0,b)>>2];hb=d+32|0;return a|0}function an(a,b,c){var d=0,e=0,f=0,g=0;if(b){while(1){c=c-1|0;e=a;a=Bna(a,b,10,0);d=lb;f=c,g=e-yna(a,d,10,0)|48,v[f|0]=g;e=b>>>0>9;b=d;if(e){continue}break}}if(a){while(1){c=c-1|0;b=(a>>>0)/10|0;v[c|0]=a-D(b,10)|48;d=a>>>0>9;a=b;if(d){continue}break}}return c}function Wm(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{if(!b){b=0;break a}d=b;b=G(b);gf(c,d,0,0,0,b+81|0);d=0+x[c+8>>2]|0;b=(x[c+12>>2]^65536)+(16414-b<<16)|0;f=e>>>0>d>>>0?b+1|0:b;e=x[c+4>>2];b=x[c>>2]}x[a>>2]=b;x[a+4>>2]=e;x[a+8>>2]=d;x[a+12>>2]=f;hb=c+16|0}function RD(a,b){var c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;x[b>>2]=0;v[c+15|0]=0;f=bh(a,c+15|0);d=y[c+15|0];x[b>>2]=d>>>2;d=d&3;if(d){while(1){v[c+15|0]=0;g=bh(a,c+15|0);e=e+1|0;x[b>>2]=x[b>>2]|y[c+15|0]<<(e<<3)-2;f=f&g;if((d|0)!=(e|0)){continue}break}}hb=c+16|0}function NI(a){a=a|0;var b=0,c=0,d=0;d=hb-16|0;hb=d;b=FI(Me(8));x[b+4>>2]=a;x[b>>2]=82808;c=hb-16|0;hb=c;x[114414]=0;x[c+12>>2]=b;a=U(2170,d+8|0,c+12|0,c+8|0)|0;b=x[114414];x[114414]=0;a:{if((b|0)!=1){hb=c+16|0;break a}S(0)|0;zb();p()}hb=d+16|0;return x[a>>2]}function Eea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+8>>2]=c;x[d+16>>2]=b;b=x[a>>2];e=d,f=bc(a),x[e>>2]=f;c=d+16|0;b=b+(vq(c,d)<<1)|0;if(Hb(c,d+8|0)){ko(a,Yt(b+(vq(d+8|0,d+16|0)<<1)|0,x[a+4>>2],b))}a=x[Fb(d+24|0,b)>>2];hb=d+32|0;return a|0}function v7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=LJ(a,b,c,d);x[a+4208>>2]=1056964608;x[a+4212>>2]=1065353216;x[a+4232>>2]=1056964608;b=a+4224|0;x[b>>2]=1056964608;x[b+4>>2]=1048406533;b=a+4216|0;x[b>>2]=1020054733;x[b+4>>2]=1065353216;x[a>>2]=80012;return a|0}function rx(a){var b=0,c=0,d=0;ml(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-16|0;P(2239,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;di(yb(a),x[a>>2],ei(a))}}function BX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;d=Om(a);e=Bb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Rb(a);Kh(d+(e<<2)|0,b,c);b=c+e|0;Zg(a,b);x[f+12>>2]=0;ug(d+(b<<2)|0,f+12|0);break a}gE(a,d,(c+e|0)-d|0,e,e,0,c,b)}hb=f+16|0;return a|0}function vl(a){var b=0,c=0,d=0;mi(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-12|0;P(175,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;Ih(yb(a),x[a>>2],xg(a))}}function qd(a){var b=0,c=0,d=0;mi(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-12|0;P(313,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;Ih(yb(a),x[a>>2],xg(a))}}function fy(a){var b=0,c=0,d=0;Ye(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-4|0;P(1539,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;Xe(yb(a),x[a>>2],vd(a))}}function eA(a){var b=0,c=0,d=0;ig(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-24|0;P(742,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;Hf(yb(a),x[a>>2],af(a))}}function aM(a){var b=0,c=0,d=0;Ye(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-4|0;P(1456,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;Xe(yb(a),x[a>>2],vd(a))}}function _l(a){var b=0,c=0,d=0;wm(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-32|0;P(868,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;Qt(yb(a),x[a>>2],Dh(a))}}function Uv(a,b){var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(pf(a)>>>0<b>>>0){if(Au(a)>>>0<b>>>0){break b}d=yb(a);b=Yh(c+8|0,b,wc(a),d);x[114414]=0;P(178,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}Km(b)}hb=c+32|0;return}Vc();p()}a=N()|0;Km(b);Q(a|0);p()}function TP(a){var b=0,c=0,d=0;OP(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-56|0;P(962,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;It(yb(a),x[a>>2],Kn(a))}}function TA(a){var b=0,c=0,d=0;ig(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-24|0;P(486,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;Hf(yb(a),x[a>>2],af(a))}}function ET(a){var b=0,c=0,d=0;ig(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-24|0;P(534,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;Hf(yb(a),x[a>>2],af(a))}}function BA(a){var b=0,c=0,d=0;ig(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-24|0;P(572,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;Hf(yb(a),x[a>>2],af(a))}}function yea(a){a=a|0;var b=0,c=0,d=0;c=hb-32|0;hb=c;b=255;a:{if(Vh(a)>>>0<=49){b=hz(c,x[a+12>>2]);x[114414]=0;P(1165,a|0,b|0);d=x[114414];x[114414]=0;if((d|0)==1){break a}Kk(b);Qp(a,Vh(a)-1&255);b=Vh(a)-1|0}hb=c+32|0;return b&255}a=N()|0;Kk(b);Q(a|0);p()}function xT(a){var b=0,c=0,d=0;tu(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-6|0;P(533,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;su(yb(a),x[a>>2],Vi(a))}}function ps(a){var b=0,c=0,d=0,e=0;b=hb-16|0;hb=b;x[b+12>>2]=12;x[b+8>>2]=32;if(x[Mb(b+12|0,b+8|0)>>2]){while(1){e=Ap(a);x[b+8>>2]=32;c=c<<15^e;d=d+15|0;if(d>>>0<A[Mb(b+12|0,b+8|0)>>2]){continue}break}}hb=b+16|0;a=x[b+12>>2];return(a>>>0>31?-1:-1<<a^-1)&c}function fba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=hb-2496|0;hb=c;kK(b,c,c+2496|0);b=sc(a,c,2496);x[b+2496>>2]=0;a:{if(x[b>>2]<0){break a}d=1;while(1){if(x[b+(d<<2)>>2]){break a}d=d+1|0;if((d|0)!=624){continue}break}x[b>>2]=-2147483648}hb=c+2496|0;return a|0}function bR(a){var b=0,c=0,d=0;Ye(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-4|0;P(856,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;Ij(yb(a),x[a>>2],vd(a))}}function Pq(a){var b=0,c=0,d=0;Rj(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-2|0;P(326,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;vo(yb(a),x[a>>2],Vf(a))}}function Oq(a){var b=0,c=0,d=0;Xn(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-1|0;P(324,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;ag(yb(a),x[a>>2],pf(a))}}function IC(a){var b=0,c=0,d=0;Ye(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-4|0;P(314,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;Xe(yb(a),x[a>>2],vd(a))}}function D$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=x[b>>2];g=x[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function CN(a,b){var c=0,d=0;c=hb-32|0;hb=c;a:{b:{if(vd(a)>>>0<b>>>0){if(wk(a)>>>0<b>>>0){break b}d=yb(a);b=Nf(c+8|0,b,Lb(a),d);x[114414]=0;P(98,a|0,b|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}xk(b)}hb=c+32|0;return}Vc();p()}a=N()|0;xk(b);Q(a|0);p()}function Av(a){var b=0,c=0,d=0;er(a);if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-8|0;P(248,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d;wv(yb(a),x[a>>2],dj(a))}}function XE(a){a=a|0;var b=0,c=0,d=0;x[a>>2]=66280;b=x[a+8>>2];x[114414]=0;c=$(2507)|0;d=x[114414];x[114414]=0;a:{if((d|0)==1){break a}if((b|0)!=(c|0)){b=x[a+8>>2];x[114414]=0;lw(b);b=x[114414];x[114414]=0;if((b|0)==1){break a}}return a|0}S(0)|0;zb();p()}function Tda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=C[b>>3];d=C[b+8>>3];if(d==0){d=C[b+8>>3];e=a;c=gs(c);o(0);a=j(1)|0;f=j(0)|0;o(+d);b=j(1)|0;j(0)|0;l(0,f|0);l(1,a&2147483647|b&-2147483648);Vl(e,c,+n());return}c=gs(C[b>>3]);g=oi(d);Vl(a,c*xe(d),c*g)}function p2(a){a=a|0;var b=0,c=0,d=0;c=hb-16|0;hb=c;b=Fb(c+8|0,x[x[a+8>>2]>>2]);d=Fb(c,x[x[a+4>>2]>>2]);b=x[b>>2];a=hb-16|0;hb=a;x[a>>2]=x[d>>2];x[a+8>>2]=b;if(bd(a+8|0,a)){while(1){b=a+8|0;Pi(hI(b));mq(b);if(bd(b,a)){continue}break}}hb=a+16|0;hb=c+16|0}function dI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{e=Uh(E(d*E(65536)));if((e|0)==65536){break a}f=D(b,c);if(!f){break a}g=e>>31;b=0;while(1){c=x[a>>2];h=a,i=Cc(zna(yna(c,c>>31,e,g),lb,65536,0),lb),x[h>>2]=i;a=a+4|0;b=b+1|0;if((f|0)!=(b|0)){continue}break}}}function Iw(a){var b=0,c=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;if(x[a+20>>2]!=x[a+28>>2]){mb[x[a+36>>2]](a,0,0)|0}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;b=x[a>>2];if(b&4){x[a>>2]=b|32;return-1}c=x[a+44>>2]+x[a+48>>2]|0;x[a+8>>2]=c;x[a+4>>2]=c;return b<<27>>31}function ima(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=Qb(a,64);a:{if(e){c=d+8|0;LA(c,b);Dd(a,c);break a}a=0;c=hb-16|0;hb=c;f=hb-16|0;hb=f;while(1){Ou((a<<1)+b|0);a=a+1|0;if((a|0)!=32){continue}break}hb=f+16|0;hb=c+16|0}hb=d+16|0;return e|0}function _da(a){a=a|0;var b=0,c=0,d=0,e=0;x[a>>2]=0;if(!(v[86180]&1)){while(1){d=0;c=(b&255)<<24;while(1){e=c<<1;c=(c|0)<0?e^79764919:e;d=d+1|0;if((d|0)!=8){continue}break}x[(b<<2)+86192>>2]=c;b=b+1|0;if((b|0)!=256){continue}break}v[86180]=1}return a|0}function Uaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=hb-16|0;hb=b;c=rd(a);e=b,f=bc(a),x[e+8>>2]=f;e=b,f=dc(a),x[e>>2]=f;if(Hb(b+8|0,b)){d=+(c>>>0);while(1){c=b+8|0;a=x[c>>2];C[a>>3]=C[a>>3]/d;C[a+8>>3]=C[a+8>>3]/d;of(c);if(Hb(c,b)){continue}break}}hb=b+16|0}function x9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(!((c|0)!=4&(c|0)!=-1)){c=hb-16|0;hb=c;x[c+8>>2]=0;lp(a,c+8|0);B[b>>2]=B[c+8>>2];hb=c+16|0;return}d=hb-16|0;hb=d;x[d+12>>2]=0;x[d+8>>2]=c;x[d+4>>2]=4;nl(a,d+12|0,x[Mb(d+8|0,d+4|0)>>2]);x[b>>2]=0;hb=d+16|0}function t_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+8>>2]=b;Dc(g,d);x[114414]=0;b=R(2510,g|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){Ob(g);oF(a,f+24|0,g+8|0,c,e,b);hb=g+16|0;return x[g+8>>2]}a=N()|0;Ob(g);Q(a|0);p()}function s_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+8>>2]=b;Dc(g,d);x[114414]=0;b=R(2510,g|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){Ob(g);nF(a,f+16|0,g+8|0,c,e,b);hb=g+16|0;return x[g+8>>2]}a=N()|0;Ob(g);Q(a|0);p()}function Zv(a){a=a|0;var b=0,c=0,d=0;b=x[a+8>>2];x[114414]=0;c=$(2507)|0;d=x[114414];x[114414]=0;a:{b:{if((d|0)==1){break b}if((b|0)!=(c|0)){b=x[a+8>>2];x[114414]=0;lw(b);b=x[114414];x[114414]=0;if((b|0)==1){break b}}break a}S(0)|0;zb();p()}return a|0}function TM(a,b,c){var d=0,e=0;d=x[(D(b,896)+a|0)+1075072>>2];a:{if(!(!(d&134218752)|(c|0)!=1)|d&67108864){break a}if(z[a+480188>>1]<=b>>>0){c=z[(D(b,896)+a|0)+1075792>>1];b=c?c-1|0:b}b=b&65535;if(b>>>0>126){break a}e=y[((b<<5)+a|0)+480288|0]}return e}function wf(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!y[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=x[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(y[b|0]){continue}break}}return b-a|0}function Yh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;Qe(a+12|0,d);if(b){Gh(e,x[a+16>>2],b);f=x[e>>2];b=x[e+4>>2]}else{b=0}x[a>>2]=f;c=c+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=ic(a),h=b+f|0,x[g>>2]=h;hb=e+16|0;return a|0}function Wma(a){a=a|0;var b=0,c=0,d=0;c=hb-16|0;hb=c;b=Fb(c+8|0,x[x[a+8>>2]>>2]);d=Fb(c,x[x[a+4>>2]>>2]);b=x[b>>2];a=hb-16|0;hb=a;x[a>>2]=x[d>>2];x[a+8>>2]=b;if(bd(a+8|0,a)){while(1){b=a+8|0;MT(b);dm(b);if(bd(b,a)){continue}break}}hb=a+16|0;hb=c+16|0}function Ke(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;uD(d+24|0,a,b);kl(d+16|0,x[d+24>>2],x[d+28>>2],c);f=d,g=tD(a,x[d+16>>2]),x[f+12>>2]=g;f=d,g=rg(c,x[d+20>>2]),x[f+8>>2]=g;gd(e+8|0,d+12|0,d+8|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function z_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+8>>2]=b;Dc(g,d);x[114414]=0;b=R(21,g|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){Ob(g);rF(a,f+24|0,g+8|0,c,e,b);hb=g+16|0;return x[g+8>>2]}a=N()|0;Ob(g);Q(a|0);p()}function y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+8>>2]=b;Dc(g,d);x[114414]=0;b=R(21,g|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){Ob(g);qF(a,f+16|0,g+8|0,c,e,b);hb=g+16|0;return x[g+8>>2]}a=N()|0;Ob(g);Q(a|0);p()}function FN(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(sv(a)>>>0<b>>>0){Vc();p()}yb(a);if(b>>>0>536870911){ve();p()}d=Vd(b<<3,8);x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+(d<<3)|0,x[e>>2]=f;rv(a,0);hb=c+16|0}function hia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-160|0;hb=b;e=-1;d=hb-16|0;hb=d;c=d+8|0;f=b+8|0;yP(c,f);g=Eb(c);c=nd(a,ac(d,c));if((g|0)==(c|0)){Yc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(g|0);if(!a){zP(f)}if(a){e=NP(b+8|0)}hb=b+160|0;return e|0}function gT(a){a=a|0;var b=0,c=0,d=0,e=0;b=x[a>>2];c=fT(a);d=hb-16|0;hb=d;e=hb-16|0;hb=e;a:{if((b|0)==(c|0)){break a}a=b+4|0;if((c|0)==(a|0)){break a}while(1){b=ro(a,b)?a:b;a=a+4|0;if((c|0)!=(a|0)){continue}break}}hb=e+16|0;hb=d+16|0;return x[b>>2]}function _E(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;rE(d+24|0,a,b);kl(d+16|0,x[d+24>>2],x[d+28>>2],c);f=d,g=GO(a,x[d+16>>2]),x[f+8>>2]=g;f=d,g=rg(c,x[d+20>>2]),x[f+4>>2]=g;gd(e+8|0,d+8|0,d+4|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function ZE(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;rE(d+24|0,a,b);kl(d+16|0,x[d+24>>2],x[d+28>>2],c);f=d,g=Kx(a,x[d+16>>2]),x[f+8>>2]=g;f=d,g=rg(c,x[d+20>>2]),x[f+4>>2]=g;gd(e+8|0,d+8|0,d+4|0);hb=d+32|0;hb=e+16|0;return x[e+12>>2]}function Tma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-624|0;hb=b;e=-1;d=hb-16|0;hb=d;c=d+8|0;f=b+8|0;IT(c,f);g=Eb(c);c=nd(a,ac(d,c));if((g|0)==(c|0)){Yc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(g|0);if(!a){JT(f)}if(a){e=LT(b+8|0)}hb=b+624|0;return e|0}function rj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=hb-16|0;hb=d;b:{c:{if(!b){b=a;a=Rb(c);yi(b,a,Bb(c)+a|0);break c}GJ(d,c);x[114414]=0;T(112,a|0,b|0,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}Nc(d)}hb=d+16|0;break a}a=N()|0;Nc(d);Q(a|0);p()}}function eo(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;Qe(a+12|0,d);if(b){d=lD(b);x[e+4>>2]=b;x[e>>2]=d;f=x[e>>2];b=x[e+4>>2]}else{b=0}x[a>>2]=f;c=D(c,24)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=ic(a),h=D(b,24)+f|0,x[g>>2]=h;hb=e+16|0;return a}function _ka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+24>>2]=d;d=Vj(a,c);vf(e,x[a+28>>2]);f=x[e+12>>2];x[e+16>>2]=x[e+8>>2];x[e+20>>2]=f;a:{if(!d){if(Cd(a,5)){break a}}wS(x[a+28>>2],b,x[e+24>>2],0)}hj(a,d,c,e+16|0);hb=e+32|0}function Zda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=Qb(a,27);a:{if(e){c=d+8|0;NN(c,b);Dd(a,c);break a}a=0;c=hb-16|0;hb=c;f=hb-16|0;hb=f;while(1){mf(a+b|0);a=a+1|0;if((a|0)!=27){continue}break}hb=f+16|0;hb=c+16|0}hb=d+16|0;return e|0}function Pma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=Qb(a,64);a:{if(e){c=d+8|0;LA(c,b);Dd(a,c);break a}a=0;c=hb-16|0;hb=c;f=hb-16|0;hb=f;while(1){mf(a+b|0);a=a+1|0;if((a|0)!=64){continue}break}hb=f+16|0;hb=c+16|0}hb=d+16|0;return e|0}function rB(a){var b=0,c=0,d=0,e=0;b=a+5|0;c=y[b|0]|y[b+1|0]<<8;b=c+y[a+2|0]|0;c=(b>>>0<c>>>0?1:d)<<1|b>>>31;d=b<<1;b=c;a=a+3|0;a=y[a|0]|y[a+1|0]<<8;c=a>>>30|0;e=d;d=a<<2;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e+47|0;lb=b>>>0<47?a+1|0:a;return b}function lma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-32|0;hb=b;e=-1;d=hb-16|0;hb=d;c=d+8|0;f=b+8|0;nu(c,f);g=Eb(c);c=nd(a,ac(d,c));if((g|0)==(c|0)){Yc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(g|0);if(!a){eT(f)}if(a){e=iT(b+8|0)}hb=b+32|0;return e|0}function YM(a,b,c,d){var e=0;e=-2147483648;e=!c|!(v[c+15|0]&1)?e:x[c+8>>2];a:{b:{if(!(!d|!(y[d+34|0]&32))){e=z[d+28>>1];break b}if((e|0)==-2147483648){break a}}Bt(b,e,a);if(!$b(a+1074312|0,10)|y[a+480209|0]&64){break a}x[b+88>>2]=x[b+88>>2]&-257}}function X0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;a=Zr(a);x[a>>2]=59432;e=vG(a+32|0,d+8|0);x[a+48>>2]=c;x[a+44>>2]=0;x[114414]=0;P(157,a|0,b|0);b=x[114414];x[114414]=0;if((b|0)!=1){hb=d+16|0;return a|0}b=N()|0;xb(e);zl(a);Q(b|0);p()}function VL(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)!=(c|0)){while(1){f=Cb(y[b|0]);d=x[a>>2];e=x[a+4>>2];g=e>>>8|0;e=(e&255)<<24|d>>>8;d=(((d^f)&255)<<3)+84128|0;f=x[d>>2];d=x[d+4>>2]^g;x[a>>2]=f^e;x[a+4>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function Uq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;d=Fc(a);e=Bb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Rb(a);Le(d+e|0,b,c);b=c+e|0;Zg(a,b);v[f+15|0]=0;Wd(b+d|0,f+15|0);break a}wo(a,d,(c+e|0)-d|0,e,e,0,c,b)}hb=f+16|0;return a|0}function QB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=Qb(a,16);a:{if(e){c=d+8|0;FB(c,b);Dd(a,c);break a}a=0;c=hb-16|0;hb=c;f=hb-16|0;hb=f;while(1){mf(a+b|0);a=a+1|0;if((a|0)!=16){continue}break}hb=f+16|0;hb=c+16|0}hb=d+16|0;return e|0}function JG(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=JG(a*0x10000000000000000,b);c=x[b>>2]+-64|0}x[b>>2]=c;return a}x[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function Hka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;e=-1;d=hb-16|0;hb=d;c=d+8|0;f=b+8|0;Gu(c,f);g=Eb(c);c=nd(a,ac(d,c));if((g|0)==(c|0)){Yc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(g|0);if(!a){lB(f)}if(a){e=UR(b+8|0)}hb=b+16|0;return e|0}function bN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=hb-16|0;hb=a;d=x[b+104>>2];if(!(!d|!x[b+76>>2])){x[b+88>>2]=x[b+88>>2]&-131|128;d=x[d>>2];x[b+76>>2]=d;x[a+12>>2]=c<<8;x[a+8>>2]=d-1;c=d+(x[Mb(a+12|0,a+8|0)>>2]^-1)|0;x[b>>2]=0;x[b+4>>2]=c}hb=a+16|0}function Sia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=Qb(a,6);a:{if(e){c=d+8|0;AA(c,b);Dd(a,c);break a}a=0;c=hb-16|0;hb=c;f=hb-16|0;hb=f;while(1){mf(a+b|0);a=a+1|0;if((a|0)!=6){continue}break}hb=f+16|0;hb=c+16|0}hb=d+16|0;return e|0}function Pl(a,b,c,d){var e=0;a:{if(b>>>0>255){break a}b:{switch(c|0){case 2:e=UM(a,b,d);if((e+5&255)>>>0>5){break a}case 0:return TM(a,b,d);case 3:e=TM(a,b,d);if((e+5&255)>>>0>5){break a}break;case 1:break b;default:break a}}e=UM(a,b,d)}return e}function Ija(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=Qb(a,2);a:{if(e){c=d+8|0;hl(c,b);Dd(a,c);break a}a=0;c=hb-16|0;hb=c;f=hb-16|0;hb=f;while(1){mf(a+b|0);a=a+1|0;if((a|0)!=2){continue}break}hb=f+16|0;hb=c+16|0}hb=d+16|0;return e|0}function Ds(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=hb-16|0;hb=d;b:{c:{if(!b){b=a;a=Rb(c);yi(b,a,Bb(c)+a|0);break c}XJ(d,b,c);x[114414]=0;P(113,a|0,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}Nc(d)}hb=d+16|0;break a}a=N()|0;Nc(d);Q(a|0);p()}}function C9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+24>>2]=d;d=Vj(a,c);vf(e,x[a+28>>2]);f=x[e+12>>2];x[e+16>>2]=x[e+8>>2];x[e+20>>2]=f;a:{if(!d){if(Cd(a,5)){break a}}wK(x[a+28>>2],b,x[e+24>>2])}hj(a,d,c,e+16|0);hb=e+32|0}
function qA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Jj(a+8|0);x[114414]=0;d=R(296,b|0)|0;e=x[114414];x[114414]=0;b:{if((e|0)==1){break b}x[114414]=0;T(424,a|0,b|0,d|0);a=x[114414];x[114414]=0;if((a|0)==1){break b}break a}a=N()|0;uh(c);Q(a|0);p()}}function UT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;e=Qb(a,8);a:{if(e){c=d+8|0;pv(c,b);Dd(a,c);break a}a=0;c=hb-16|0;hb=c;f=hb-16|0;hb=f;while(1){mf(a+b|0);a=a+1|0;if((a|0)!=8){continue}break}hb=f+16|0;hb=c+16|0}hb=d+16|0;return e|0}function Tia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,1030);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,1030);hb=c+16|0}return a|0}function pma(a,b){a=a|0;b=b|0;var c=0;b=hb-32|0;hb=b;c=-1;a:{if(!EA(a,b+16|0)){break a}c=0;if(!lT(b+16|0)){break a}if(x[b+16>>2]==1179472708){c=-1;if(!Yc(a,4)){break a}}c=-1;if(!Tj(a,b+8|0)){break a}c=x[b+8>>2]==1196314451}hb=b+32|0;return c|0}function WN(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;if(y[a+530|0]){while(1){d=c&65535;Ji(a,d,1);c=c+1|0;if(d>>>0<255){continue}break}v[a+530|0]=0}v[b+15|0]=0;Th(a+4|0,18,b+15|0);$z(a+22|0,18,25738);v[b+14|0]=255;Th(a+58|0,256,b+14|0);hb=b+16|0}function yj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=z[a+20>>1];if(c){d=z[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=z[e+28>>1]+b|0;w[e+28>>1]=f;if((f&65535)>>>0>=2048){w[a+20>>1]=c-d;return}c=c+1|0;if((g|0)!=(c|0)){continue}break}}}function xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,326);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,326);hb=c+16|0}return a|0}function dna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,136);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,136);hb=c+16|0}return a|0}function aja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,274);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,274);hb=c+16|0}return a|0}function Yia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,106);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,106);hb=c+16|0}return a|0}function Uba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;if(!(!a|!b)){f=at(a);e=hb-16|0;hb=e;a=at(a);c=at(b);if(c){while(1){g=a;a=c;c=(g>>>0)%(a>>>0)|0;if(c){continue}break}}hb=e+16|0;c=D(at(b),(f|0)/(a|0)|0)}hb=d+16|0;return c|0}
function Kja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,422);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,422);hb=c+16|0}return a|0}function Gja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,826);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,826);hb=c+16|0}return a|0}function Baa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,225);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,225);hb=c+16|0}return a|0}function zda(){var a=0,b=0,c=0,d=0;b=hb-16|0;hb=b;c=Sb(Me(6668),0,6668);a=hb-16|0;hb=a;x[114414]=0;x[a+12>>2]=c;c=U(1245,b+8|0,a+12|0,a+8|0)|0;d=x[114414];x[114414]=0;a:{if((d|0)!=1){hb=a+16|0;break a}S(0)|0;zb();p()}hb=b+16|0;return x[c>>2]}function q_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=hb-16|0;hb=a;x[a+8>>2]=b;Dc(a,d);x[114414]=0;b=R(2510,a|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){Ob(a);mF(f+20|0,a+8|0,c,e,b);hb=a+16|0;return x[a+8>>2]}b=N()|0;Ob(a);Q(b|0);p()}function ap(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function Lp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=z[a+24>>1]<<17;e=z[a+20>>1];if(e){d=z[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-D(x[$e(b,z[c+28>>1])>>2],w[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function CR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,284);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,284);hb=c+16|0}return a|0}function vaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,60);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,60);hb=c+16|0}return a|0}function iN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{if(!c){break a}x[b+40>>2]=c;if(x[a+480180>>2]!=256){break a}x[d+12>>2]=c>>>4;x[d+8>>2]=1;e=b,f=x[_c(d+12|0,d+8|0)>>2],x[e+40>>2]=f;e=b,f=ZM(c&255),x[e+44>>2]=f}hb=d+16|0}function fma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,34);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,34);hb=c+16|0}return a|0}function Xja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,42);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,42);hb=c+16|0}return a|0}function Xia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,72);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,72);hb=c+16|0}return a|0}function Iga(a){a=a|0;var b=0,c=0,d=0;b=a;c=LO(a);if((c|0)!=(a|0)){while(1){a=0;uS(b);a:{while(1){d=a+b|0;if(y[d|0]){a=a+1|0;if((a|0)!=32){continue}break a}break}if(a>>>0>31){break a}Sb(d,0,32-a|0)}b=b+32|0;if((c|0)!=(b|0)){continue}break}}}function Eaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,73);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,73);hb=c+16|0}return a|0}function Dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,91);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,91);hb=c+16|0}return a|0}function Dia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,71);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,71);hb=c+16|0}return a|0}function x_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=hb-16|0;hb=a;x[a+8>>2]=b;Dc(a,d);x[114414]=0;b=R(21,a|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){Ob(a);pF(f+20|0,a+8|0,c,e,b);hb=a+16|0;return x[a+8>>2]}b=N()|0;Ob(a);Q(b|0);p()}function wE(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+8>>2]=0;x[d>>2]=4;nl(a,d+8|0,x[Mb(d+12|0,d)>>2]);a=lb;if((a|0)>0|(a|0)>=0){x[d>>2]=4;Mb(d+12|0,d)}x[d>>2]=x[d+8>>2];x[b>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);hb=d+16|0}function ZT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,50);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,50);hb=c+16|0}return a|0}function QV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;b=Jd(b,c);vm(b+12|0,c+12|0);a=hb-16|0;hb=a;c=c+28|0;d=a,e=ke(c),x[d+12>>2]=e;x[114414]=0;U(246,b+28|0,a+12|0,c|0)|0;b=x[114414];x[114414]=0;a:{if((b|0)!=1){hb=a+16|0;break a}S(0)|0;zb();p()}}function OU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;d=c+8|0;jc(d,b,59);hb=e+16|0;e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,59);hb=c+16|0}return a|0}function bf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Jj(a+8|0);x[114414]=0;T(424,a|0,b|0,c|0);c=x[114414];x[114414]=0;a:{if((c|0)!=1){a=x[a>>2];x[114414]=0;O(304,b|0,a|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){break a}}a=N()|0;uh(d);Q(a|0);p()}}function P_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;x[e+12>>2]=b;x[e+8>>2]=d;b=Hh(e,e+12|0);x[114414]=0;a=U(2530,a|0,c|0,x[e+8>>2])|0;c=x[114414];x[114414]=0;if((c|0)!=1){Ne(b);hb=e+16|0;return a|0}a=N()|0;Ne(b);Q(a|0);p()}function h4(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;b=b+4|0;d=x[b+48>>2];a:{if(d&16){if(A[b+24>>2]>A[b+44>>2]){x[b+44>>2]=x[b+24>>2]}yi(a,x[b+20>>2],x[b+44>>2]);break a}if(d&8){yi(a,x[b+8>>2],x[b+16>>2]);break a}vG(a,c+8|0)}hb=c+32|0}function oM(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb-16|0;hb=b;c=b+8|0;d=hb-16|0;hb=d;Fb(d+8|0,a+116|0);x[114414]=0;a=Ja(163,a|0)|0;e=x[114414];x[114414]=0;a:{if((e|0)!=1){hb=d+16|0;break a}Q(N()|0);p()}x[c>>2]=a;Ap(c);hb=b+16|0;return x[c>>2]}function ek(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;Qe(a+12|0,d);if(b){dF(e,x[a+16>>2],b);f=x[e>>2];b=x[e+4>>2]}else{b=0}x[a>>2]=f;c=D(c,12)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=ic(a),h=D(b,12)+f|0,x[g>>2]=h;hb=e+16|0;return a}function Np(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=1/(C[x[a+4>>2]-8>>3]-C[x[a>>2]>>3]);while(1){d=-Qd(C[ll(a,c)>>3]*131072*f);a:{if(F(d)<2147483648){e=~~d;break a}e=-2147483648}g=$e(b,c),h=e,x[g>>2]=h;c=c+1|0;if((c|0)!=2048){continue}break}}function HL(a,b){var c=0,d=0;a:{if(!(y[a+89|0]&16)){break a}c=x[a+656>>2];if(!c){break a}c=x[c>>2];b:{if(c){d=a;a=x[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;x[d+696>>2]=a;a=(D(a,x[b>>2])|0)/65536|0;break b}if(x[a+696>>2]){break a}a=0}x[b>>2]=a}}function Jh(a,b,c){var d=0,e=0,f=0,g=0;x[a+112>>2]=b;x[a+116>>2]=c;e=x[a+4>>2];d=x[a+44>>2]-e|0;x[a+120>>2]=d;x[a+124>>2]=d>>31;d=a;a=x[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}x[d+104>>2]=a}function to(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;Qe(a+12|0,d);if(b){uC(e,x[a+16>>2],b);f=x[e>>2];b=x[e+4>>2]}else{b=0}x[a>>2]=f;c=(c<<1)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=ic(a),h=(b<<1)+f|0,x[g>>2]=h;hb=e+16|0;return a}function po(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;Qe(a+12|0,d);if(b){kC(e,x[a+16>>2],b);f=x[e>>2];b=x[e+4>>2]}else{b=0}x[a>>2]=f;c=(c<<2)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=ic(a),h=(b<<2)+f|0,x[g>>2]=h;hb=e+16|0;return a}function kr(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;Qe(a+12|0,d);if(b){KD(e,x[a+16>>2],b);f=x[e>>2];b=x[e+4>>2]}else{b=0}x[a>>2]=f;c=(c<<4)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=ic(a),h=(b<<4)+f|0,x[g>>2]=h;hb=e+16|0;return a}function eu(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;Qe(a+12|0,d);if(b){dS(e,x[a+16>>2],b);f=x[e>>2];b=x[e+4>>2]}else{b=0}x[a>>2]=f;c=(c<<2)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=ic(a),h=(b<<2)+f|0,x[g>>2]=h;hb=e+16|0;return a}function cr(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;Qe(a+12|0,d);if(b){$C(e,x[a+16>>2],b);f=x[e>>2];b=x[e+4>>2]}else{b=0}x[a>>2]=f;c=(c<<5)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=ic(a),h=(b<<5)+f|0,x[g>>2]=h;hb=e+16|0;return a}function Lja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;b=aR(d,b);e=hb-16|0;hb=e;b=aR(e,b);f=hb-16|0;hb=f;g=d+8|0;mr(g,x[b>>2],x[b>>2]+XQ(b)|0);hb=f+16|0;hb=e+16|0;vv(a,g);x[a+12>>2]=c;x[a+8>>2]=0;hb=d+16|0;return a|0}function $R(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=0;Qe(a+12|0,d);if(b){uT(e,x[a+16>>2],b);f=x[e>>2];b=x[e+4>>2]}else{b=0}x[a>>2]=f;c=D(c,6)+f|0;x[a+8>>2]=c;x[a+4>>2]=c;g=ic(a),h=D(b,6)+f|0,x[g>>2]=h;hb=e+16|0;return a}function xL(a,b,c){var d=0,e=0,f=0,g=0,h=0;if(b){g=c;h=c>>31;c=0;while(1){d=x[a>>2];e=x[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Cc(zna(yna(d,d>>31,g,h),lb,256,0),lb);x[a+4>>2]=f-d;x[a>>2]=d+f;a=a+8|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}}}function t0(a){a=a|0;if(A[a+24>>2]>A[a+44>>2]){x[a+44>>2]=x[a+24>>2]}a:{if(!(y[a+48|0]&8)){break a}if(A[a+16>>2]<A[a+44>>2]){Ym(a,x[a+8>>2],x[a+12>>2],x[a+44>>2])}if(A[a+12>>2]>=A[a+16>>2]){break a}return Wg(v[x[a+12>>2]])|0}return-1}function r9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=0;a:{if(!Lb(a)){break a}while(1){Uf(d,x[Pb(a,c)>>2]+40|0);e=jq(d,b);xb(d);if(e){c=x[Pb(a,c)>>2];break a}c=c+1|0;if(Lb(a)>>>0>c>>>0){continue}break}c=0}hb=d+16|0;return c|0}function fk(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[c+12>>2]=a;a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;x[c+8>>2]=b;if(a>>>0>=b>>>0){break a}wh(x[c+12>>2],x[c+8>>2]);a=x[c+12>>2]+1|0;x[c+12>>2]=a;b=x[c+8>>2];continue}}hb=c+16|0}function Y7(a){a=a|0;var b=0;mb[x[x[a>>2]+124>>2]](a);Dx(a);x[a+4236>>2]=0;v[a+4202|0]=1;b=mb[x[x[a>>2]+188>>2]](a)|0;x[a+4272>>2]=0;B[a+4240>>2]=b?E(.5):E(1);b=x[a+4256>>2];x[a+4292>>2]=b;x[a+4288>>2]=b;x[a+4284>>2]=b;x[a+4280>>2]=b}function Vo(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[c+12>>2]=a;a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;x[c+8>>2]=b;if(a>>>0>=b>>>0){break a}Yb(x[c+12>>2],x[c+8>>2]);a=x[c+12>>2]+4|0;x[c+12>>2]=a;b=x[c+8>>2];continue}}hb=c+16|0}function vg(a,b,c){c=x[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=y[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(y[a+1|0]|32)!=120){break a}a=a+2|0}return a}function Qla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-160|0;hb=b;e=-1;d=hb-16|0;hb=d;c=d+8|0;QS(c,b);f=Eb(c);c=nd(a,ac(d,c));if((f|0)==(c|0)){Yc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(f|0);if(!a){RS(b)}if(a){e=TS(b)}hb=b+160|0;return e|0}function Ima(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;Tu(d,b);e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;hb=c+16|0}return a|0}function Bha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-208|0;hb=b;e=-1;d=hb-16|0;hb=d;c=d+8|0;eP(c,b);f=Eb(c);c=nd(a,ac(d,c));if((f|0)==(c|0)){Yc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(f|0);if(!a){fP(b)}if(a){e=kP(b)}hb=b+208|0;return e|0}function P$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((mb[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=oj(b,4,c,x[a+32>>2])}return c|0}function Dla(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;a:{if(b){Ub(c,b);break a}Wb(c)}x[114414]=0;P(642,c+16|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){b=a;a=c+16|0;b=Jd(b,a);xb(a);xb(c);hb=c+32|0;return b|0}a=N()|0;xb(c);Q(a|0);p()}function jz(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(1151,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;a:{if((c|0)!=1){hb=b+16|0;break a}S(0)|0;zb();p()}x[a+12>>2]=0;w[a+16>>1]=65280;return a}function dt(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;if(c>>>0<=2147483631){a:{if(il(c)){Ce(a,c);e=a;break a}Gh(d+8|0,a,cj(c)+1|0);e=x[d+8>>2];Ue(a,e);Ff(a,x[d+12>>2]);ae(a,c)}Le(e,b,c);v[d+7|0]=0;Wd(c+e|0,d+7|0);hb=d+16|0;return}Ef();p()}function NQ(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-32|0;hb=d;Ct(d+24|0,a,b);kl(d+16|0,x[d+24>>2],x[d+28>>2],c);f=d,g=GO(a,x[d+16>>2]),x[f+8>>2]=g;f=d,g=rg(c,x[d+20>>2]),x[f+4>>2]=g;gd(e+8|0,d+8|0,d+4|0);hb=d+32|0;hb=e+16|0}function Ev(){var a=0,b=0,c=0,d=0;b=hb-16|0;hb=b;c=jE(Me(12));a=hb-16|0;hb=a;x[114414]=0;x[a+12>>2]=c;c=U(234,b+8|0,a+12|0,a+8|0)|0;d=x[114414];x[114414]=0;a:{if((d|0)!=1){hb=a+16|0;break a}S(0)|0;zb();p()}hb=b+16|0;return x[c>>2]}function TU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-48|0;hb=b;e=-1;d=hb-16|0;hb=d;c=d+8|0;GB(c,b);f=Eb(c);c=nd(a,ac(d,c));if((f|0)==(c|0)){Yc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(f|0);if(!a){HB(b)}if(a){e=SB(b)}hb=b+48|0;return e|0}function bF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-32|0;hb=d;x[d+16>>2]=b;x[d+24>>2]=a;x[d+8>>2]=c;while(1){a=Hb(d+24|0,d+16|0);if(!(!a|x[x[d+24>>2]>>2]!=x[x[d+8>>2]>>2])){fe(d+24|0);fe(d+8|0);continue}break}hb=d+32|0;return a^1}function GP(a,b){var c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;d=x[a+4>>2];e=x[a>>2];x[c+24>>2]=e;x[c+28>>2]=d;f=x[b+4>>2];a=x[b>>2];x[c+16>>2]=a;x[c+20>>2]=f;x[c+8>>2]=e;x[c+12>>2]=d;x[c>>2]=a;x[c+4>>2]=f;a=gQ(c+8|0,c);hb=c+32|0;return a}function CD(){var a=0,b=0,c=0;b=hb-16|0;hb=b;a=Ub(b,10486);a:{if(!Bb(a)){break a}c=1;if((Zf(a,10181)|0)!=-1){break a}if((Zf(a,12743)|0)!=-1){break a}if((Zf(a,9547)|0)!=-1){break a}c=(Zf(a,9590)|0)!=-1}xb(a);hb=b+16|0;return c|0}function d3(a,b){a=a|0;b=b|0;var c=E(0);a:{if((b|0)<0){break a}a=a+24|0;if(z[x[a>>2]+480188>>1]<=b>>>0){break a}b=D(b,896);if(!(v[(b+x[a>>2]|0)+1075073|0]&1)){break a}c=E(E(y[(b+x[a>>2]|0)+1075847|0])*E(.0078125))}return E(c)}
function zna(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=Bna(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;lb=(g^lb)-((a>>>0<f>>>0)+g|0)|0;return b}function gD(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;hb=b+16|0}function e3(a,b){a=a|0;b=b|0;var c=E(0);a:{if((b|0)<0){break a}a=a+24|0;if(z[x[a>>2]+480188>>1]<=b>>>0){break a}b=D(b,896);if(!(v[(b+x[a>>2]|0)+1075073|0]&1)){break a}c=E(E(y[(b+x[a>>2]|0)+1075846|0])*E(.0078125))}return E(c)}function b7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=12){Ph(d+12|0);c=B[d+12>>2];e=((b<<2)+a|0)+4208|0;if((b|0)==12){c=E(de(E(c*E(3)))*E(.3333333432674408))}B[e>>2]=c;v[a+5046|0]=1}hb=d+16|0}function Qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d>>2]=4896;c=x[Mb(d+12|0,d)>>2];if(!Qb(a,c)){c=uf(a)}jA(d,b);lg(a,x[d>>2],c);jA(d,b);Sb(x[d>>2]+c|0,0,4896-c|0);cc(a,x[d+12>>2]);hb=d+16|0;return c|0}function Ip(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;if(b){e=Fc(a);d=Bb(a);g=d+b|0;if(e-d>>>0<b>>>0){$k(a,e,g-e|0,d,d,0,0)}e=d;d=Rb(a);yn(e+d|0,b,c);Zg(a,g);v[f+15|0]=0;Wd(d+g|0,f+15|0)}hb=f+16|0;return a|0}function Io(a,b){var c=0,d=0;c=b+4|0;c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);a:{if(b>>>0>=wc(a)>>>0){break a}if(wc(a)>>>0<c>>>0){break a}d=c-1>>>0<wc(a)-b>>>0}return d}function AL(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;x[b+12>>2]=7;x[b+8>>2]=32;if(x[Mb(b+12|0,b+8|0)>>2]){while(1){d=Ap(a);x[b+12>>2]=7;x[b+8>>2]=32;c=c+15|0;if(c>>>0<A[Mb(b+12|0,b+8|0)>>2]){continue}break}c=d&127}hb=b+16|0;return c}function nE(a){var b=0,c=0;b=x[a+4>>2];a:{while(1){if(x[a+8>>2]==(b|0)){break a}x[a+8>>2]=x[a+8>>2]-4;x[114414]=0;c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}if(x[a>>2]){NE(x[a+16>>2],x[a>>2],Dg(a))}}function lT(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179011410|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1179472708)){return 1}return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179472708}function Xs(a,b){var c=0;c=78252;a:{b:{c:{switch(b-2|0){default:if((b|0)==16777216){break a}if((b|0)!=32){break b}c=78268;break a;case 2:c=78264;break a;case 1:break b;case 0:break c}}c=78260;break a}c=78256}x[a>>2]=x[c>>2]}function Wga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d>>2]=263;c=x[Mb(d+12|0,d)>>2];if(!Qb(a,c)){c=uf(a)}QO(d,b);lg(a,x[d>>2],c);QO(d,b);Sb(x[d>>2]+c|0,0,263-c|0);cc(a,x[d+12>>2]);hb=d+16|0;return c|0}function L$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d+8>>2]=c;e=-1;c=Ir(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=sd(c);x[f>>2]=a;if(!a){break a}e=Ir(a,c,b,x[d+12>>2])}hb=d+16|0;return e|0}function oba(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[a+480180>>2]=b;eM(c,up(a));d=x[c+12>>2];b=a+1074320|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=d;b=x[c+4>>2];x[a+1074312>>2]=x[c>>2];x[a+1074316>>2]=b;Xs(a+8|0,up(a));hb=c+16|0}function mba(a,b){a=a|0;b=b|0;var c=0;c=65535;a:{if(z[x[a+8>>2]+58>>1]<b>>>0){break a}while(1){if(!x[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if(z[x[a+8>>2]+58>>1]>=(b&65535)>>>0){continue}break}}return c&65535}function h3(a,b){a=a|0;b=b|0;var c=E(0);a:{if((b|0)<0){break a}a=a+24|0;if(z[x[a>>2]+480188>>1]<=b>>>0){break a}b=D(b,896);if(v[(b+x[a>>2]|0)+1075073|0]&1){break a}c=E(E(y[(b+x[a>>2]|0)+1075846|0])*E(.0078125))}return E(c)}function f3(a,b){a=a|0;b=b|0;var c=E(0);a:{if((b|0)<0){break a}a=a+24|0;if(z[x[a>>2]+480188>>1]<=b>>>0){break a}b=D(b,896);if(v[(b+x[a>>2]|0)+1075073|0]&1){break a}c=E(E(y[(b+x[a>>2]|0)+1075847|0])*E(.0078125))}return E(c)}function bB(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;a:{if(Qb(a,512)){c=d+8|0;YA(c,b);Dd(a,c);break a}a=0;c=hb-16|0;hb=c;e=hb-16|0;hb=e;while(1){XA((a<<2)+b|0);a=a+1|0;if((a|0)!=128){continue}break}hb=e+16|0;hb=c+16|0}hb=d+16|0}function Aha(a,b){a=a|0;b=b|0;var c=0;a=fq(a);x[a>>2]=75608;Jj(a+4|0);v[a+20|0]=0;x[a+16>>2]=0;x[a>>2]=75724;c=x[b+4>>2];x[a+24>>2]=x[b>>2];x[a+28>>2]=c;c=x[b+12>>2];x[a+32>>2]=x[b+8>>2];x[a+36>>2]=c;v[a+40|0]=0;return a|0}function hF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-32|0;hb=d;x[d+16>>2]=b;x[d+24>>2]=a;x[d+8>>2]=c;while(1){a=Hb(d+24|0,d+16|0);if(!(!a|y[x[d+24>>2]]!=y[x[d+8>>2]])){bg(d+24|0);bg(d+8|0);continue}break}hb=d+32|0;return a^1}function aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d>>2]=22;c=x[Mb(d+12|0,d)>>2];if(!Qb(a,c)){c=uf(a)}nu(d,b);lg(a,x[d>>2],c);nu(d,b);Sb(x[d>>2]+c|0,0,22-c|0);cc(a,x[d+12>>2]);hb=d+16|0;return c|0}function Zja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d>>2]=40;c=x[Mb(d+12|0,d)>>2];if(!Qb(a,c)){c=uf(a)}Zz(d,b);lg(a,x[d>>2],c);Zz(d,b);Sb(x[d>>2]+c|0,0,40-c|0);cc(a,x[d+12>>2]);hb=d+16|0;return c|0}function Pp(a,b,c,d){var e=0;a:{e=Jk(a,b);if((e|0)==255){break a}if(Aj(a)){break a}b=Oi(a+314|0,e);e=VN(e);if(v[gc(b,10)|0]&1|d){ph(x[a>>2],e- -64|0,UN(c,y[gc(b,2)|0]))}if(d){break a}ph(x[a>>2],e+67|0,UN(c,y[gc(b,3)|0]))}}function r8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d>>2]=33;c=x[Mb(d+12|0,d)>>2];if(!Qb(a,c)){c=uf(a)}dA(d,b);lg(a,x[d>>2],c);dA(d,b);Sb(x[d>>2]+c|0,0,33-c|0);cc(a,x[d+12>>2]);hb=d+16|0;return c|0}function LU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d>>2]=65;c=x[Mb(d+12|0,d)>>2];if(!Qb(a,c)){c=uf(a)}Pu(d,b);lg(a,x[d>>2],c);Pu(d,b);Sb(x[d>>2]+c|0,0,65-c|0);cc(a,x[d+12>>2]);hb=d+16|0;return c|0}function pP(a,b,c){var d=0;d=hb-16|0;hb=d;v[d+15|0]=a;a=0;if(!(c>>>0>108|b>>>0>108|(c>>>0<25|b>>>0<25)|b>>>0>=c>>>0)){v[d+14|0]=(z[(b<<1)+25886>>1]-z[(c<<1)+25886>>1]|0)/5;a=y[rc(d+15|0,d+14|0)|0]}hb=d+16|0;return a&255}function Qba(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=a;a=x[c+28>>2];x[b+24>>2]=x[c+24>>2];x[b+28>>2]=a;a=x[c+20>>2];x[b+16>>2]=x[c+16>>2];x[b+20>>2]=a;a=x[c+12>>2];x[b+8>>2]=x[c+8>>2];x[b+12>>2]=a}function Jl(a,b){var c=E(0),d=0,e=0;e=w[a+28>>1];d=a+4|0;Lb(d);c=E(1);a:{if((b|0)<(e|0)){break a}if((z[a+28>>1]+Lb(d)|0)-1<<16>>16<(b|0)){break a}c=B[Pb(d,b-w[a+28>>1]|0)>>2];c=c>E(10000000036274937e-31)?c:E(1)}return c}function Ey(a,b){var c=0,d=0;c=D(b,896)+a|0;a:{if(x[c+1075072>>2]&134218752){break a}if(!wj(c+1074984|0)){break a}b=y[x[(D(b,896)+a|0)+1075640>>2]+34|0];if((b+5&255)>>>0<6){break a}d=x[(D(b,160)+a|0)+906140>>2]}return d}function AO(a){a=a|0;var b=0;b=w[a+796>>1];if(b){x[a+692>>2]=(b&32767)-1;if((b|0)<0){x[a+88>>2]=x[a+88>>2]|256}w[a+796>>1]=0}b=y[a+817|0];if(b){v[a+817|0]=0;v[a+858|0]=b-1}b=y[a+818|0];if(b){v[a+818|0]=0;v[a+857|0]=b-1}}function js(a){var b=0;a:{b=y[a+1376|0];b:{if(!b){b=-1;if(x[a+1384>>2]){break b}if(!Uw(a)){break b}b=y[a+1376|0];if(!b){break a}}v[a+1376|0]=b-1;x[a+1400>>2]=x[a+1400>>2]+1;b=ye(a)}return b}ea(11708,9049,1578,1915);p()}function eR(a){var b=0,c=0;a:{if(cd(a,10540,3)){break a}b=a+4|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))>>>0<423|(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))>>>0>2147483646){break a}c=y[a+3|0]<6}return c}function YN(a,b){a:{if(y[a+76|0]==(b|0)){break a}v[a+76|0]=b;if(b){b=0;if(z[a+24>>1]==15){w[a+20>>1]=0;b=1}x[a+8>>2]=0;x[a+16>>2]=b;return}b:{switch(x[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}x[a+16>>2]=3}}function KR(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=je(d,a,1);a=yb(a);e=x[c+4>>2];x[114414]=0;T(741,a|0,e|0,b|0);a=x[114414];x[114414]=0;if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+4;Jb(c);hb=d+16|0;return}a=N()|0;Jb(c);Q(a|0);p()}function GG(a){var b=0,c=0,d=0;if(!ih(v[x[a>>2]])){return 0}while(1){d=x[a>>2];b=-1;if(c>>>0<=214748364){b=v[d|0]-48|0;c=D(c,10);b=(c^2147483647)<(b|0)?-1:b+c|0}x[a>>2]=d+1;c=b;if(ih(v[d+1|0])){continue}break}return b}function yna(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=D(e,f);g=c&65535;h=a&65535;i=D(g,h);f=(i>>>16|0)+D(f,g)|0;e=(f&65535)+D(e,h)|0;lb=(D(b,c)+j|0)+D(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function xD(a){var b=0,c=0;b=a+2|0;a:{if(!(y[b|0]|y[b+1|0]<<8)){break a}a=a+4|0;if(!(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))){break a}c=(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))>>>0<2147483649}return c}function iO(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;d=Yg(e,a,d);a=yb(a);f=x[d+4>>2];x[114414]=0;a=Z(1157,a|0,b|0,c|0,f|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function dca(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=(x[a+480208>>2]&32768?28.85390081777927:34.624680981335125)*(Zo(b)+-4.8737671609324025),C[d+8>>3]=e;kN(c+8|0,127);a=Xt(C[c+8>>3]);hb=c+16|0;return a|0}function bha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=Ae(b);c=YO(d+8|0,c);x[114414]=0;ba(1017,a|0,b|0,0,e-1&65535,c|0);a=x[114414];x[114414]=0;if((a|0)!=1){ce(c);hb=d+32|0;return}a=N()|0;ce(c);Q(a|0);p()}function ZJ(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;d=th(e,a,d);a=yb(a);f=x[d+4>>2];x[114414]=0;a=Z(1735,a|0,b|0,c|0,f|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function Wx(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;d=je(e,a,d);a=yb(a);f=x[d+4>>2];x[114414]=0;a=Z(1594,a|0,b|0,c|0,f|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function Ux(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;d=rq(e,a,d);a=yb(a);f=x[d+4>>2];x[114414]=0;a=Z(1598,a|0,b|0,c|0,f|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function Nz(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=hb-1024|0;hb=f;e=hb-16|0;hb=e;d=e+8|0;Iz(d,f);g=Eb(d);d=nc(a,ac(e,d));if((g|0)==(d|0)){cc(a,Eb(e+8|0))}hb=e+16|0;if((d|0)==(g|0)){h=Kz(f,c)>>>0<=b>>>0}hb=f+1024|0;return h}function ML(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;d=th(e,a,d);a=yb(a);f=x[d+4>>2];x[114414]=0;a=Z(1452,a|0,b|0,c|0,f|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function Lg(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;v[a+8|0]=0;x[a>>2]=0;x[a+4>>2]=4194432;c=Ub(b,17386);x[114414]=0;O(343,a+9|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){xb(c);hb=b+16|0;return}a=N()|0;xb(c);Q(a|0);p()}function Dn(a){a=a|0;xc(a+16|0,x[a>>2]);xc(a+8|0,x[a>>2]);if(A[a+12>>2]>=A[a+16>>2]){x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=z[a+34>>1]&65511}if(A[a+4>>2]>=A[a+8>>2]){x[a+4>>2]=0;x[a+8>>2]=0;w[a+34>>1]=z[a+34>>1]&65529}}function oR(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;d=je(e,a,d);a=yb(a);f=x[d+4>>2];x[114414]=0;a=Z(802,a|0,b|0,c|0,f|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){x[d+4>>2]=a;Jb(d);hb=e+16|0;return}a=N()|0;Jb(d);Q(a|0);p()}function Vw(a){var b=0;a:{b:{while(1){if(x[a+1380>>2]!=-1){break b}b=0;if(!is(a)){break a}if(!(v[a+1375|0]&1)){continue}break}fc(a,32);return 0}x[a+1396>>2]=0;x[a+1400>>2]=0;x[a+1384>>2]=0;v[a+1376|0]=0;b=1}return b}function xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;jA(d,b);e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,4896);hb=c+16|0}return a|0}function gP(a){var b=0,c=0,d=0;d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-12|0;P(1005,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d}function gL(a){var b=0,c=0,d=0;d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-24|0;P(1573,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d}function PI(a){var b=0,c=0,d=0;d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-24|0;P(2240,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d}function GN(a,b){var c=0,d=0,e=0,f=0;e=C[a+48>>3];c=C[a+40>>3];C[a+48>>3]=c;f=C[a+64>>3];d=C[a+56>>3];C[a+64>>3]=d;C[a+40>>3]=b;b=c*C[a+8>>3]+C[a>>3]*b+e*C[a+16>>3]-(f*C[a+32>>3]+d*C[a+24>>3]);C[a+56>>3]=b;return b}function sD(a){var b=0,c=0,d=0;d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-32|0;P(238,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d}function jba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-32|0;hb=d;x[d+24>>2]=c;x[d+16>>2]=b;if(Hb(d+16|0,d+24|0)){while(1){b=d+16|0;x[d+12>>2]=x[x[b>>2]>>2];Ay(a,d+12|0);fe(b);if(Hb(b,d+24|0)){continue}break}}hb=d+32|0}function cn(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return E(b?-1/a:a)}function SO(a){var b=0,c=0,d=0;d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-4|0;P(1045,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d}function RP(a){var b=0,c=0,d=0;d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-24|0;P(954,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d}function HX(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(ku(b,6246)){dE(c,13350,b);a=Rb(c);x[114414]=0;P(2893,44,a|0);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;xb(c);Q(a|0);p()}hb=c+16|0;return a|0}p()}function xY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;x[e+12>>2]=d;d=Hh(e+8|0,e+12|0);x[114414]=0;a=DF(a,b,c);b=x[114414];x[114414]=0;if((b|0)!=1){Ne(d);hb=e+16|0;return a|0}a=N()|0;Ne(d);Q(a|0);p()}function tK(a){var b=0,c=0,d=0;b=x[a>>2];x[a>>2]=0;if(b){a:{b:{a=mc(a);if(y[a+4|0]){x[114414]=0;c=R(706,b+16|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break b}Pi(c)}if(b){_g(x[a>>2],b,1)}break a}S(0)|0;zb();p()}}}function oS(a){var b=0,c=0,d=0;b=x[a>>2];x[a>>2]=0;if(b){a:{b:{a=mc(a);if(y[a+4|0]){x[114414]=0;c=R(703,b+16|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break b}Pi(c)}if(b){_g(x[a>>2],b,1)}break a}S(0)|0;zb();p()}}}function iG(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];a:{if(!c){break a}d=x[c+24>>2];b:{if((d|0)==x[c+28>>2]){b=mb[x[x[c>>2]+52>>2]](c,b)|0;break b}x[c+24>>2]=d+4;x[d>>2]=b}if(!ne(b,-1)){break a}x[a>>2]=0}return a|0}function YL(a){var b=0,c=0,d=0;c=hb-544|0;hb=c;if(!(!(y[a+480210|0]&128)|!x[a+24668>>2])){d=a+1304360|0;b=a+1074984|0;a=EN(c,Ze(a));while(1){sc(b+112|0,a,538);b=b+896|0;if((d|0)!=(b|0)){continue}break}}hb=c+544|0}function Tga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;Zz(d,b);e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,40);hb=c+16|0}return a|0}function TB(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;e=hb-16|0;hb=e;c=d+8|0;jc(c,b,37);hb=e+16|0;e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;if((c|0)!=(e|0)){a=hb-16|0;hb=a;Sb(b,0,37);hb=a+16|0}}function PT(a){var b=0,c=0,d=0;d=x[a>>2];b=x[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=yb(a);x[114414]=0;b=b-2|0;P(494,c|0,b|0);c=x[114414];x[114414]=0;if((c|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=d}function Ju(a,b,c){var d=0;a=a+3|0;a=(y[a|0]|y[a+1|0]<<8)>>>D(c,3)|0;d=a>>>2&1|y[b+12|0]&-8;v[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=y[b+13|0]|y[b+14|0]<<8;v[b+15|0]=a;v[b+16|0]=a>>>8;v[b+12|0]=d|4}}function pq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;LA(d,b);e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,64);hb=c+16|0}return a|0}function UO(a){var b=0,c=0,d=0;b=a- -64|0;d=y[b|0]|y[b+1|0]<<8;b=a+70|0;a=a+72|0;c=y[a|0]|y[a+1|0]<<8;a=(y[b|0]|y[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a<<2;d=c+d|0;a=b<<2|a>>>30;lb=d>>>0<c>>>0?a+1|0:a;return d}function QU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;Pu(d,b);e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;Sb(b,0,65);hb=c+16|0}return a|0}function d4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;e=d+8|0;x[e>>2]=82704;x[e>>2]=82660;x[114414]=0;a=Z(2186,a|0,b|0,c|0,e|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){hb=d+16|0;return a|0}Q(N()|0);p()}function _V(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;x[e+12>>2]=d;d=0;f=x[a+8>>2];if(f>>>0>c>>>0){x[e+8>>2]=f-c;d=Mb(e+8|0,e+12|0);a=x[a+4>>2]+c|0;d=x[d>>2];Ke(a,a+d|0,b)}hb=e+16|0;return d|0}function sP(a){var b=0,c=0,d=0;b=a+32|0;d=y[b|0]|y[b+1|0]<<8;b=a+34|0;a=a+36|0;c=y[a|0]|y[a+1|0]<<8;a=(y[b|0]|y[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a<<1;d=c+d|0;a=b<<1|a>>>31;lb=d>>>0<c>>>0?a+1|0:a;return d}function qha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;w[a+34>>1]=0;f=a+43|0;d=hb-16|0;hb=d;e=hb-16|0;hb=e;while(1){mf(c+f|0);c=c+1|0;if((c|0)!=22){continue}break}hb=e+16|0;hb=d+16|0;x[a+20>>2]=0;Ad(a,b);return a|0}function my(a,b){var c=0,d=0;c=x[b+4>>2];x[a+24648>>2]=x[b>>2];x[a+24652>>2]=c;d=x[b+20>>2];c=a+24664|0;x[c>>2]=x[b+16>>2];x[c+4>>2]=d;d=x[b+12>>2];c=a+24656|0;x[c>>2]=x[b+8>>2];x[c+4>>2]=d;JL(a+24648|0);YL(a)}function Gba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-32|0;hb=d;a=x[a+1304560>>2];a:{if(a){mb[x[x[a>>2]+8>>2]](a,b,c);break a}if(x[18880]<(b|0)){break a}a=d+8|0;fM(a,5124,6831,132);_C(d+24|0,a,b,9105,c)}hb=d+32|0}function ny(a,b){var c=0;c=x[b+24>>2];x[a+24628>>2]=c?c>>>0>=512?512:c:1;a:{if(!(x[b+16>>2]!=x[a+24620>>2]|x[b+20>>2]!=x[a+24624>>2])){c=0;if(x[b+12>>2]==x[a+24616>>2]){break a}}c=1}sc(a+24604|0,b,40);KL(a,c)}function Sv(a,b,c){var d=0;d=x[a+16>>2];if(!d){x[a+36>>2]=1;x[a+24>>2]=c;x[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(x[a+24>>2]!=2){break a}x[a+24>>2]=c;return}v[a+54|0]=1;x[a+24>>2]=2;x[a+36>>2]=x[a+36>>2]+1}}function Qh(a){var b=0,c=0,d=0,e=0;b=pe(a);c=b&63;e=b<<24>>24;a:{if(!(b&64)){break a}b=6;while(1){d=pe(a);c=(d&127)<<b|c;if(d<<24>>24>=0){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}return(e|0)<0?0-c|0:c}function Oka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;g=x[x[b>>2]+20>>2];f=x[c+12>>2];x[e+8>>2]=x[c+8>>2];x[e+12>>2]=f;f=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=f;mb[g|0](a,b,e,d);hb=e+16|0}function pka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c+8|0;dA(d,b);e=Eb(d);d=nc(a,ac(c,d));if((e|0)==(d|0)){cc(a,Eb(c+8|0))}hb=c+16|0;a=(d|0)==(e|0);if(!a){c=hb-16|0;hb=c;NR(b);hb=c+16|0}return a|0}function Yt(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-16|0;hb=d;ES(d+8|0,a,b,c);f=d,g=rg(a,x[d+8>>2]),x[f+4>>2]=g;f=d,g=rg(c,x[d+12>>2]),x[f>>2]=g;gd(e+8|0,d+4|0,d);hb=d+16|0;hb=e+16|0;return x[e+12>>2]}function UK(a,b,c){var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=hb-16|0;hb=d;YR(d+8|0,a,b,c);f=d,g=On(a,x[d+8>>2]),x[f+4>>2]=g;f=d,g=On(c,x[d+12>>2]),x[f>>2]=g;gd(e+8|0,d+4|0,d);hb=d+16|0;hb=e+16|0;return x[e+12>>2]}function zj(a,b){a=a|0;b=b|0;var c=0;if(z[a+24>>1]!=(b&65535)){w[a+22>>1]=z[a+22>>1]-1&127;if(z[a+20>>1]<128){w[a+20>>1]=z[a+20>>1]+1}c=(z[a+22>>1]<<2)+a|0;w[c+28>>1]=0;w[c+26>>1]=b-z[a+24>>1];w[a+24>>1]=b}}function h7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;b=Cc(zna(yna(d,d>>31,b,b>>31),lb,1e3,0),lb);x[a+16>>2]=0;x[a+12>>2]=b+c;sJ(a,e);b=x[a+12>>2];x[f+12>>2]=0;AK(a,b,f+12|0);hb=f+16|0}function Paa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=b,h=Qh(a),x[g>>2]=h;Qh(a);if(f>>>0>=60){cc(a,4)}g=e,h=Qh(a),x[g>>2]=h;cc(a,4);b=Qh(a);x[d>>2]=b;if((b|0)>0){g=c,h=Qh(a),x[g>>2]=h}}function Lz(a,b,c){var d=0;d=hb-16|0;hb=d;x[d>>2]=b;x[d+8>>2]=a;a:{if(!Hb(d+8|0,d)){break a}while(1){if(z[x[d+8>>2]>>1]==z[c>>1]){break a}a=d+8|0;ge(a);if(Hb(a,d)){continue}break}}hb=d+16|0;return x[d+8>>2]}function IA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=c;e=d,f=BT(bc(b),dc(b),d+12|0),x[e+8>>2]=f;e=d,f=dc(b),x[e>>2]=f;a:{if(Hb(d+8|0,d)){df(a,yb(x[d+8>>2]));break a}ci(a)}hb=d+16|0}function Ama(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[c+12>>2]=1;x[c+8>>2]=a>>>4;b=Xb(128/(D(x[Bf(c+12|0,c+8|0)>>2],b)|0)|0,1,15);v[c+7|0]=1;v[c+6|0]=a&15;a=y[Xg(c+7|0,c+6|0)|0];hb=c+16|0;return a|b<<4&240}function lF(a,b,c,d,e,f){var g=0,h=0,i=0;g=hb-16|0;hb=g;v[g+15|0]=0;v[g+14|0]=f;v[g+13|0]=e;v[g+12|0]=37;if(f){wh(g+13|0,g+14|0)}h=c,i=(Ma(b|0,hT(b,x[c>>2])|0,g+12|0,d|0,x[a>>2])|0)+b|0,x[h>>2]=i;hb=g+16|0}function _ja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;x[c+16>>2]=b;d=c,e=bc(a),x[d+8>>2]=e;b=Zt(c+16|0,c+8|0);b=x[a>>2]+(b<<2)|0;hv(a,Yt(b+4|0,x[a+4>>2],b));a=x[Fb(c+24|0,b)>>2];hb=c+32|0;return a|0}function Tn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;a:{if(c){Ub(d,c);break a}Wb(d)}x[114414]=0;T(13,a|0,b|0,d|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(d);hb=d+16|0;return}a=N()|0;xb(d);Q(a|0);p()}function pM(a,b){a=kM(a);kM(a+368680|0);if(b){sL(a,1);return}rL();Ke(218336,283872,a+131112|0);Ke(283872,349408,a+196648|0);Ke(349408,414944,a+262184|0);Ke(87248,218336,a+24|0);sc(a+327720|0,414944,40960)}function eK(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-2048|0;P(1685,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function cz(a){var b=0,c=0,d=0;b=z[a+20>>1];w[a+28>>1]=z[a+22>>1]<<1|(y[x[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=x[c>>2];if(d){Bn(d);ZN(x[c>>2])}b=b+1|0;if((b|0)!=4){continue}break}}function Bp(a,b){a=sc(a,b,88);x[a+88>>2]=x[b+88>>2];sc(a+92|0,b+92|0,576);x[a+668>>2]=x[b+668>>2];sc(a+672|0,b+672|0,52);Iy(a+724|0,b+724|0);Iy(a+736|0,b+736|0);Iy(a+748|0,b+748|0);sc(a+760|0,b+760|0,135)}function wk(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=1073741823;x[114414]=0;x[b+8>>2]=2147483647;a=O(35,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}S(0)|0;zb();p()}function jv(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=2147483647;x[114414]=0;x[b+8>>2]=2147483647;a=O(35,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}S(0)|0;zb();p()}function hf(a,b,c,d,e){var f=0;f=hb-256|0;hb=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Sb(f,b&255,c?d:256);if(!c){while(1){We(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}We(a,f,d)}hb=f+256|0}function gh(a){a=a|0;var b=0;x[a>>2]=60544;x[114414]=0;P(2434,a|0,0);b=x[114414];x[114414]=0;if((b|0)!=1){Ob(a+28|0);_b(x[a+32>>2]);_b(x[a+36>>2]);_b(x[a+48>>2]);_b(x[a+60>>2]);return a|0}S(0)|0;zb();p()}function LC(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808603728|(y[a+4|0]-16&255)>>>0<249|((y[a+5|0]-16&255)>>>0<249|(y[a+6|0]-16&255)>>>0<249))){b=(y[a+7|0]-9&255)>>>0<7}return b}function Cc(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;x[c+24>>2]=a;x[c+28>>2]=b;x[c+16>>2]=-2147483648;x[c+20>>2]=-1;x[c+8>>2]=2147483647;x[c+12>>2]=0;a=yQ(c+16|0,Jz(c+24|0,c+8|0));hb=c+32|0;return x[a>>2]}function yr(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=357913941;x[114414]=0;x[b+8>>2]=2147483647;a=O(35,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}S(0)|0;zb();p()}function yM(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-24|0;P(1387,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function vT(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=715827882;x[114414]=0;x[b+8>>2]=2147483647;a=O(35,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}S(0)|0;zb();p()}function vN(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-12|0;P(1226,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function sv(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=536870911;x[114414]=0;x[b+8>>2]=2147483647;a=O(35,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}S(0)|0;zb();p()}function sM(a){var b=0,c=0;b=x[a>>2];x[a>>2]=0;if(b){a:{b:{a=mc(a);if(y[a+4|0]){x[114414]=0;R(1388,b+14|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break b}}if(b){aq(x[a>>2],b,1)}break a}S(0)|0;zb();p()}}}function qM(a){var b=0,c=0;b=x[a>>2];x[a>>2]=0;if(b){a:{b:{a=mc(a);if(y[a+4|0]){x[114414]=0;R(1392,b+16|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break b}}if(b){Qt(x[a>>2],b,1)}break a}S(0)|0;zb();p()}}}function dP(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-12|0;P(1004,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function bO(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-32|0;P(1183,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function aD(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=134217727;x[114414]=0;x[b+8>>2]=2147483647;a=O(35,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}S(0)|0;zb();p()}function Rd(a,b){var c=0,d=0,e=0;b=b+7&-8;x[a+8>>2]=b+x[a+8>>2];d=x[a+80>>2];a:{if(d){c=b;b=x[a+88>>2];e=c+b|0;c=0;if((e|0)>x[a+92>>2]){break a}x[a+88>>2]=e;return b+d|0}if(!b){return 0}c=sd(b)}return c}function PL(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-52|0;P(1449,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function NT(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=178956970;x[114414]=0;x[b+8>>2]=2147483647;a=O(35,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}S(0)|0;zb();p()}function Iv(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=268435455;x[114414]=0;x[b+8>>2]=2147483647;a=O(35,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}S(0)|0;zb();p()}function yB(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-16|0;P(375,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function sT(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-48|0;P(535,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function i2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;dI(b,c,d,B[a+28>>2]);cI(a,b,c,d);b=x[a+24>>2];x[e+8>>2]=x[a+20>>2];x[e+12>>2]=b;b=x[a+16>>2];x[e>>2]=x[a+12>>2];x[e+4>>2]=b;hb=e+16|0}function gR(a){var b=0,c=0;b=x[a>>2];x[a>>2]=0;if(b){a:{b:{a=mc(a);if(y[a+4|0]){x[114414]=0;R(803,b+14|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break b}}if(b){aq(x[a>>2],b,1)}break a}S(0)|0;zb();p()}}}function bK(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-4|0;P(1687,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function Tha(a,b,c){a=a|0;b=b|0;c=c|0;a=CP(b,c);CP(a+12|0,c+12|0);wz(a+24|0,c+24|0);w[a+52>>1]=z[c+52>>1];b=x[c+48>>2];x[a+44>>2]=x[c+44>>2];x[a+48>>2]=b;b=x[c+40>>2];x[a+36>>2]=x[c+36>>2];x[a+40>>2]=b}function OR(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-33|0;P(740,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function MD(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-16|0;P(185,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function JK(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=82595524;x[114414]=0;x[b+8>>2]=2147483647;a=O(35,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}S(0)|0;zb();p()}function $c(a,b){var c=0,d=0,e=0;a:{d=FF(b);c=Om(a);if(d>>>0<=c>>>0){c=Rb(a);e=d<<2;Bg(c,b,e);b=hb-16|0;hb=b;Zg(a,d);x[b+12>>2]=0;ug(c+e|0,b+12|0);hb=b+16|0;break a}e=a;a=Bb(a);gE(e,c,d-c|0,a,0,a,d,b)}}function yC(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-1|0;P(325,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function rR(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-4|0;P(798,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function oQ(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-8|0;P(894,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function lC(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-4|0;P(337,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function kS(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-4|0;P(707,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function jS(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-6|0;P(708,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function jR(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-2|0;P(804,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function fS(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-4|0;P(709,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function aL(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-4|0;P(105,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function ZP(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-4|0;P(919,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function WB(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-2|0;P(347,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function HD(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-1|0;P(183,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function CB(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-2|0;P(371,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function qE(a){var b=0,c=0;b=hb-16|0;hb=b;rl(a);x[b+12>>2]=1073741823;x[114414]=0;x[b+8>>2]=2147483647;a=Mb(b+12|0,b+8|0);c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}S(0)|0;zb();p()}function Lu(a){var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;c=hb-16|0;hb=c;b=c+8|0;Vq(b,d+15|0);e=Eb(b);b=nd(a,ac(c,b));if((e|0)==(b|0)){Yc(a,Eb(c+8|0))}hb=c+16|0;hb=d+16|0;return((b|0)==(e|0)?y[d+15|0]:0)&255}function Jia(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=$u(a);if(d>>>0>=b>>>0){a=Mt(a);if(a>>>0<d>>>1>>>0){x[c+12>>2]=a<<1;x[c+8>>2]=b+31&-32;d=x[_c(c+12|0,c+8|0)>>2]}hb=c+16|0;return d|0}Vc();p()}function Hq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;if($u(a)>>>0<b>>>0){Vc();p()}Lx(c+8|0,yb(a),(b-1>>>5|0)+1|0);b=x[c+8>>2];x[a+4>>2]=0;x[a>>2]=b;b=x[c+12>>2];d=yb(a),e=b,x[d>>2]=e;hb=c+16|0}function $S(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=yb(a);x[114414]=0;c=c-1|0;P(36,d|0,c|0);d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function tP(a){var b=0,c=0;a:{if((y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1297236819|y[a+29|0]!=16){break a}a=a+42|0;b=y[a+1|0]<<8;if((y[a|0]|b)!=1&(b|y[a|0])!=2){break a}c=1}return c}function o4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;a=x[a+24>>2];Ds(d,0,c);x[114414]=0;T(623,a|0,b|0,d|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(d);hb=d+16|0;return}a=N()|0;xb(d);Q(a|0);p()}function kba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=hb-16|0;hb=c;zf(a,c+14|0);cM(b,z[c+14>>1],16777216);if(z[c+14>>1]){while(1){Ri(a,Pb(b,d));d=d+1|0;if(d>>>0<z[c+14>>1]){continue}break}}ty(b);hb=c+16|0}function ZL(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=x[a>>2];a:{if(!b){break a}if(!(mb[x[x[b>>2]+112>>2]](b)|0)){break a}mb[x[x[b>>2]+92>>2]](b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function Dd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;d=x[a>>2];b=(f=d,g=x[a+8>>2],h=ac(c+8|0,b),e=x[x[d>>2]+32>>2],mb[e](f|0,g|0,h|0)|0);x[a+8>>2]=b+x[a+8>>2];hb=c+16|0;return b|0}function Ng(a,b){var c=0;a:{if(A[a+4>>2]<=b>>>0){a=ec(8);x[114414]=0;b=R(317,a|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break a}b=N()|0;hc(a);Q(b|0);p()}return y[x[a>>2]+b|0]}da(b|0,76228,231);p()}function HN(a,b,c,d,e,f){x[a+40>>2]=0;x[a+44>>2]=0;C[a+32>>3]=f;C[a+24>>3]=e;C[a+16>>3]=d;C[a+8>>3]=c;C[a>>3]=b;x[a+48>>2]=0;x[a+52>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;a=a- -64|0;x[a>>2]=0;x[a+4>>2]=0}function yD(a){if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1129474426&(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))==1634291279){a=a+8|0;a=(y[a|0]|y[a+1|0]<<8)==14}else{a=0}return a}function si(a){var b=0;b=32767;a:{if(a>=E(32766.5)){break a}b=32768;if(a<=E(-32767.5)){break a}a=E(a+E(.5));b:{if(E(F(a))<E(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function oN(a){var b=0,c=0;b=x[a>>2];x[a>>2]=0;if(b){a:{b:{if(y[mc(a)+4|0]){x[114414]=0;a=R(1258,b+16|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break b}Ul(a)}if(b){Sy(b)}break a}S(0)|0;zb();p()}}}function hha(a,b){a=a|0;b=b|0;a:{a=hb-16|0;hb=a;x[b>>2]=0;x[b+4>>2]=0;x[114414]=0;x[a+12>>2]=0;U(1010,b+8|0,a+12|0,a+8|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){hb=a+16|0;break a}S(0)|0;zb();p()}}function Yda(a,b){a=a|0;b=b|0;var c=0,d=0;c=bc(b);d=dc(b);b=hb-16|0;hb=b;x[b+8>>2]=d;x[b>>2]=c;if(Hb(b,b+8|0)){while(1){PN(a,y[x[b>>2]]);bg(b);if(Hb(b,b+8|0)){continue}break}}hb=b+16|0;return a|0}function UM(a,b,c){var d=0,e=0;d=x[(D(b,896)+a|0)+1075640>>2];a:{if(!d){break a}b:{if((c|0)!=1){break b}a=x[(D(b,896)+a|0)+1075088>>2];if(!a){break b}if(y[a+35|0]&4){break a}}e=y[d+34|0]}return e}function Qg(a){var b=0;x[114414]=0;a=R(1404,a|0)|0;b=x[114414];x[114414]=0;a:{if((b|0)==1){Y(S(0)|0)|0;x[114414]=0;V(20);b=x[114414];x[114414]=0;a=0;if((b|0)==1){break a}}return a}S(0)|0;zb();p()}function Au(a){var b=0,c=0;b=hb-16|0;hb=b;yb(a);x[b+12>>2]=-1;x[114414]=0;x[b+8>>2]=2147483647;a=O(35,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return x[a>>2]}S(0)|0;zb();p()}function sq(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(vT(a)>>>0<b>>>0){Vc();p()}uT(c+8|0,yb(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+D(d,6)|0,x[e>>2]=f;FA(a,0);hb=c+16|0}function ho(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(wk(a)>>>0<b>>>0){Vc();p()}Lx(c+8|0,yb(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+(d<<2)|0,x[e>>2]=f;vk(a,0);hb=c+16|0}function _Q(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(wk(a)>>>0<b>>>0){Vc();p()}dS(c+8|0,yb(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+(d<<2)|0,x[e>>2]=f;vk(a,0);hb=c+16|0}function XD(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;b=x[a+8>>2];d=x[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;b=b-c|0;x[a+8>>2]=b;x[a+12>>2]=d}function OS(a){var b=0,c=0;b=a+36|0;b=yna(y[b|0]|y[b+1|0]<<8,0,384,0);a=a+34|0;a=y[a|0]|y[a+1|0]<<8;c=a<<2;b=b+c|0;a=lb+(a>>>30|0)|0;a=b>>>0<c>>>0?a+1|0:a;b=b+256|0;lb=b>>>0<256?a+1|0:a;return b}function NB(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(Iv(a)>>>0<b>>>0){Vc();p()}KD(c+8|0,yb(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+(d<<4)|0,x[e>>2]=f;Jo(a,0);hb=c+16|0}function Ln(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(jv(a)>>>0<b>>>0){Vc();p()}uC(c+8|0,yb(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+(d<<1)|0,x[e>>2]=f;Mq(a,0);hb=c+16|0}function nB(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;x[d>>2]=192;c=x[Mb(d+12|0,d)>>2];if(!Qb(a,c)){c=uf(a)}xq(d,b);lg(a,x[d>>2],c);xq(d,b);Sb(x[d>>2]+c|0,0,192-c|0);cc(a,x[d+12>>2]);hb=d+16|0}function l3(a){a=a|0;var b=0;a=a+24|0;b=tI(x[a>>2]);if(Bj(Vb(x[a>>2]+484360|0))>>>0<=b>>>0){return z[x[a>>2]+1074436>>1]}b=z[uc(Vb(x[a>>2]+484360|0),b)>>1];return(go(x[a>>2]+484344|0,b)?b:-1)|0}function fO(a){a=a|0;var b=0,c=0;b=hb-32|0;hb=b;v[a+16|0]=0;c=hz(b,x[a+12>>2]);x[114414]=0;T(1163,a|0,1,c|0);a=x[114414];x[114414]=0;if((a|0)!=1){Kk(c);hb=b+32|0;return}a=N()|0;Kk(c);Q(a|0);p()}function pC(a,b,c){var d=0,e=0,f=0;f=hb-16|0;hb=f;e=x[a+4>>2];d=e+b|0;x[a+4>>2]=d;if(!((d-1^e-1)>>>0<32?e:0)){x[x[a>>2]+((d>>>0>=33?d-1>>>5|0:0)<<2)>>2]=0}d=f+8|0;oo(d,a,e);Gq(d,b,c);hb=f+16|0}function n9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;e=1;a=a+32|0;if(A[x[b>>2]>>2]<wc(a)>>>0){a=Jm(d,Bc(a,x[x[b>>2]>>2]),z[x[b>>2]+12>>1]);b=Nv(c,a);Gb(a);e=b^1}hb=d+16|0;return e|0}function Fx(a){var b=0,c=0,d=0,e=0;C[a+4272>>3]=C[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){a=Ap(d)^a<<15;e=b>>>0<17;b=b+15|0;if(e){continue}break}C[c+4280>>3]=E(E(a|0)*E(-4.656612873077393e-10))}function xH(a,b){var c=0,d=0,e=0,f=E(0),g=E(0),h=0;if((b|0)>0){h=a+2304|0;while(1){c=d<<2;e=c+a|0;c=c+h|0;f=B[c>>2];g=B[e>>2];B[e>>2]=f+g;B[c>>2]=g-f;d=d+1|0;if((d|0)!=(b|0)){continue}break}}}function wY(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;x[b+12>>2]=a;a=Hh(b+8|0,b+12|0);x[114414]=0;c=CF();d=x[114414];x[114414]=0;if((d|0)!=1){Ne(a);hb=b+16|0;return c|0}b=N()|0;Ne(a);Q(b|0);p()}function Fg(a){var b=0,c=0,d=0,e=0;b=hb-32|0;hb=b;C[b+16>>3]=1;C[b+24>>3]=-1;C[b+8>>3]=a;e=hb-16|0;hb=e;d=b+8|0;c=b+24|0;if(!Ft(d,c)){c=b+16|0;c=Ft(c,d)?c:d}hb=e+16|0;hb=b+32|0;return C[c>>3]}function jna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>0){while(1){d=x[c>>2];v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;a=a+4|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function hA(a,b,c){a=a|0;b=b|0;c=c|0;a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[b|0]=a;v[b+1|0]=a>>>8;v[b+2|0]=a>>>16;v[b+3|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8;v[b+4|0]=a;v[b+5|0]=a>>>8}function Ri(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=0;a=nl(a,c+12|0,4);x[c+8>>2]=x[c+12>>2];d=b;b=c+8|0;x[d>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);hb=c+16|0;return!lb&(a|0)==4}function Ji(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=Jk(a,b);if((d|0)==255){break a}Ik(a,b);Pp(a,b,0,0);if(!c){break a}e=fd(a+22|0,d),f=65535,w[e>>1]=f;a=gc(a+58|0,b);v[a|0]=y[a|0]|128}}function FE(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;x[f+12>>2]=e;e=Hh(f+8|0,f+12|0);x[114414]=0;a=Wo(a,b,c,d);b=x[114414];x[114414]=0;if((b|0)!=1){Ne(e);hb=f+16|0;return a}a=N()|0;Ne(e);Q(a|0);p()}function yk(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(1621,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function sx(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(2161,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function oh(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(1255,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function nA(a,b){var c=0,d=0;a:{if(b){nA(a,x[b>>2]);nA(a,x[b+4>>2]);a=mc(a);x[114414]=0;c=R(706,b+16|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}Pi(c);_g(a,b,1)}return}S(0)|0;zb();p()}function lA(a,b){var c=0,d=0;a:{if(b){lA(a,x[b>>2]);lA(a,x[b+4>>2]);a=mc(a);x[114414]=0;c=R(703,b+16|0)|0;d=x[114414];x[114414]=0;if((d|0)==1){break a}Pi(c);_g(a,b,1)}return}S(0)|0;zb();p()}function jy(a,b,c){var d=0,e=0;d=x[b+656>>2];if(!d){return 0}d=Xu(d,c);a=a+1074312|0;if(!$b(a,31)){e=$b(a,93)^1}a:{if(!(v[zL(b,c)|0]&1)){a=0;if(!(v[d+12|0]&1)|e){break a}}a=od(d)^1}return a}function cg(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb+-64|0;hb=c;d=Tx(c+8|0,a);x[114414]=0;T(1605,a|0,b|0,d|0);a=x[114414];x[114414]=0;if((a|0)!=1){Ck(d);hb=c- -64|0;return}a=N()|0;Ck(d);Q(a|0);p()}function UJ(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(1773,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function TJ(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(1774,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function Pk(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(Au(a)>>>0<b>>>0){Vc();p()}Gh(c+8|0,yb(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=x[c+12>>2];e=yb(a),f=b+d|0,x[e>>2]=f;wA(a,0);hb=c+16|0}function $x(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(1569,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function yz(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(946,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function qw(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(168,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function p4(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a=x[a+24>>2];Ds(c,0,b);x[114414]=0;T(623,a|0,1,c|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(c);hb=c+16|0;return}a=N()|0;xb(c);Q(a|0);p()}function nq(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(569,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function kq(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(643,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function jm(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(365,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function jE(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(176,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function fA(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(732,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function Qq(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(319,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function Ot(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(903,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function KG(a){var b=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;b=x[a>>2];if(b&8){x[a>>2]=b|32;return-1}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];return 0}function KF(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:v[a|0]=c;return;case 1:w[a>>1]=c;return;case 2:case 3:x[a>>2]=c;return;case 5:break b;default:break a}}x[a>>2]=c;x[a+4>>2]=d}}function Jaa(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;a:{if(!Tj(a,b+8|0)){break a}c=0;if(!jL(b+8|0)){break a}a=oP(a,b);if(!a){gS(b)}c=-1;if(!a){break a}c=iL(b)}a=c;hb=b+16|0;return a|0}function Cz(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[b+12>>2]=0;x[114414]=0;U(907,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function Cq(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(366,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function pw(a,b,c,d,e,f,g,h,i){var j=0;j=hb-16|0;hb=j;$f(j,b,c,d,e,f,g,h,i^-2147483648);d=x[j>>2];c=x[j+4>>2];b=x[j+12>>2];x[a+8>>2]=x[j+8>>2];x[a+12>>2]=b;x[a>>2]=d;x[a+4>>2]=c;hb=j+16|0}function Jj(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(34,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function Dk(a){var b=0,c=0;b=hb-16|0;hb=b;x[a>>2]=0;x[a+4>>2]=0;x[114414]=0;x[b+12>>2]=0;U(93,a+8|0,b+12|0,b+8|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function z7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=4){Ph(d+12|0);c=B[d+12>>2];if((b|0)==4){c=de(c);B[d+12>>2]=c}B[((b<<2)+a|0)+4220>>2]=c;vJ(a)}hb=d+16|0}function ys(a){var b=0,c=0;c=a+24|0;b=x[c>>2];x[114414]=0;R(1410,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){qd(a+68|0);Mf(a+36|0);dg(a+32|0);ui(c);pd(a+4|0);return pd(a)}S(0)|0;zb();p()}function l7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=1){Ph(d+12|0);c=B[d+12>>2];if((b|0)==1){c=de(c);B[d+12>>2]=c}B[((b<<2)+a|0)+4208>>2]=c;tJ(a)}hb=d+16|0}function Uh(a){var b=0;a=de(a);b=2147483647;a:{if(!(a<E(2147483648))){break a}b=-2147483648;if(!(a>E(-2147483648))){break a}b=~~a;if(E(F(a))<E(2147483648)){break a}b=-2147483648}return b}function Qz(a){var b=0,c=0;c=(y[a+24|0]>15)+(y[a+25|0]>64)|0;b=a+26|0;b=y[b|0]|y[b+1|0]<<8;a=a+22|0;a=y[a|0]|y[a+1|0]<<8;return c+(((b<<8|b>>>8)&65535)>>>0>((a<<8|a>>>8)&65535)<<1>>>0)|0}function OO(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function $v(a,b,c,d){var e=0;e=hb-16|0;hb=e;x[e+12>>2]=d;d=Hh(e+8|0,e+12|0);x[114414]=0;a=as(a,b,c);b=x[114414];x[114414]=0;if((b|0)!=1){Ne(d);hb=e+16|0;return a}a=N()|0;Ne(d);Q(a|0);p()}function pj(a,b){var c=0,d=0;c=y[a|0];d=y[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=y[b+1|0];c=y[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function eJ(a,b){var c=0,d=0,e=0;if(a>E(.9999989867210388)){d=0}else{a=E(a*a);e=+a;c=xe(31415.926535897932/+b);d=Cn((32768-(M((1-c)*+E(a+a)+(c*c+-1)*+E(a*a))+c*e)*32768)/(1-e))}return d}function R6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Qg(86224);if(d){x[114414]=0;Z(1999,d|0,a|0,b|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function N$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a+84>>2];d=c+256|0;f=fs(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;sc(b,e,c);b=e+d|0;x[a+84>>2]=b;x[a+8>>2]=b;x[a+4>>2]=c+e;return c|0}function w7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Qg(4296);if(d){x[114414]=0;Z(1913,d|0,a|0,b|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function v6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=hb-16|0;hb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;a=YI(f,b,c,d,0,0,0,0,e);hb=f+16|0;return a|0}function p7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Qg(4228);if(d){x[114414]=0;Z(1926,d|0,a|0,b|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function g7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Qg(5048);if(d){x[114414]=0;Z(1949,d|0,a|0,b|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function c9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Qg(4268);if(d){x[114414]=0;Z(1671,d|0,a|0,b|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function a8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Qg(4296);if(d){x[114414]=0;Z(1809,d|0,a|0,b|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function Y6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Qg(4276);if(d){x[114414]=0;Z(1976,d|0,a|0,b|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function S7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Qg(4280);if(d){x[114414]=0;Z(1842,d|0,a|0,b|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function Rba(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;c=Ub(b,6246);x[114414]=0;a=O(91,a|0,c|0)|0;d=x[114414];x[114414]=0;if((d|0)!=1){xb(c);hb=b+16|0;return a|0}a=N()|0;xb(c);Q(a|0);p()}function K7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Qg(4276);if(d){x[114414]=0;Z(1866,d|0,a|0,b|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function H8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Qg(4304);if(d){x[114414]=0;Z(1734,d|0,a|0,b|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function D7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Qg(4268);if(d){x[114414]=0;Z(1889,d|0,a|0,b|0,c|0)|0;a=x[114414];x[114414]=0;if((a|0)==1){break a}}return d|0}a=N()|0;_b(d);Q(a|0);p()}function Bda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(y[b+30|0]!=4){break a}d=b+31|0;if(y[d|0]&4|y[d|0]&2){break a}ad(a,8,1,0,11);return}d=a;a=b+31|0;ad(d,y[a|0]&4?16:8,y[a|0]&2|1,0,c^1)}function B_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-16|0;hb=g;x[g+8>>2]=624576549;x[g+12>>2]=1394948685;h=a;a=g+16|0;b=kj(h,b,c,d,e,f,g+8|0,a);hb=a;return b|0}function oE(a,b){var c=0,d=0;c=x[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}rl(a);x[114414]=0;c=c-4|0;d=x[114414];x[114414]=0;if((d|0)!=1){continue}break}S(0)|0;zb();p()}x[a+4>>2]=b}function ip(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=ke(b),x[d+12>>2]=e;x[114414]=0;a=U(2036,a|0,c+12|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){hb=c+16|0;return a}S(0)|0;zb();p()}function hp(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=ke(b),x[d+12>>2]=e;x[114414]=0;a=U(2194,a|0,c+12|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){hb=c+16|0;return a}S(0)|0;zb();p()}function Bv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];b=(f=d,g=Cb(b),h=x[a+8>>2],i=c,e=x[x[d>>2]+28>>2],mb[e](f|0,g|0,h|0,i|0)|0);x[a+8>>2]=b+x[a+8>>2];return b|0}function iq(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=ke(b),x[d+12>>2]=e;x[114414]=0;a=U(699,a|0,c+12|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){hb=c+16|0;return a}S(0)|0;zb();p()}function P8(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);d=hb-16|0;hb=d;e=d,f=E(E(mb[x[x[a>>2]+48>>2]](a,b))+c),B[e+12>>2]=f;Ph(d+12|0);mb[x[x[a>>2]+44>>2]](a,b,B[d+12>>2]);hb=d+16|0}function Lba(a){a=a|0;var b=0,c=0,d=0,e=0;x[a>>2]=0;e=a+9|0;c=hb-16|0;hb=c;d=hb-16|0;hb=d;while(1){mf(b+e|0);b=b+1|0;if((b|0)!=20){continue}break}hb=d+16|0;hb=c+16|0;Lg(a);return a|0}function ze(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=wk(a);if(d>>>0<=b>>>0){a=vd(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Vc();p()}function xm(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=aD(a);if(d>>>0<=b>>>0){a=Dh(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Vc();p()}function wD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;hD(c,b);e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){iD(b)}return a|0}function vD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;fD(c,b);e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){gD(b)}return a|0}function qB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;Eu(c,b);e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){dB(b)}return a|0}function pu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;CA(c,b);e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){jT(b)}return a|0}function ov(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;Sq(c,b);e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){HC(b)}return a|0}function nba(a){a=a|0;var b=0;b=1;a=x[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function lr(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=Iv(a);if(d>>>0<=b>>>0){a=ei(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Vc();p()}function gA(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=vT(a);if(d>>>0<=b>>>0){a=Vi(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Vc();p()}function f4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;dd(a+12|0,0,0);d=a+20|0;while(1){Xc((c<<2)+d|0);c=c+1|0;if((c|0)!=4){continue}break}e=d,f=oM(b),x[e+16>>2]=f;x[a+40>>2]=1;return a|0}function cQ(a){var b=0,c=0,d=0,e=0;d=y[a+4|0];e=y[a+92|0];c=y[a+93|0];b=a+94|0;b=c+(y[b|0]|y[b+1|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=d;d=b<<2;b=a+d|0;b=b-96|0;lb=0;return b}function aJ(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=hb-16|0;hb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;c=$I(f,b,c,d,e,0,0,0,0);hb=f+16|0;return+c}function Zk(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=NT(a);if(d>>>0<=b>>>0){a=af(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Vc();p()}function Wh(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=Au(a);if(d>>>0<=b>>>0){a=pf(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Vc();p()}function Vn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;bS(c,b);e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){cS(b)}return a|0}function Td(a,b){var c=0;a:{c=wf(b);if((c|0)==(Bb(a)|0)){x[114414]=0;a=aa(311,a|0,0,-1,b|0,c|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}S(0)|0;zb();p()}function Rm(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=yr(a);if(d>>>0<=b>>>0){a=xg(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Vc();p()}function RB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;GB(c,b);e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){HB(b)}return a|0}function Oga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;a=mb[x[x[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Mb(d+12|0,d+8|0)>>2]}hb=d+16|0;return c|0}function Nu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;jB(c,b);e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){kB(b)}return a|0}function NK(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=JK(a);if(d>>>0<=b>>>0){a=tj(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Vc();p()}function Lt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;_P(c,b);e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){$P(b)}return a|0}function Ku(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;Gu(c,b);e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){lB(b)}return a|0}function Dw(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+D(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((D(b,306)+5<<16>>16)/10<<16>>16)|0)-1|0}function $i(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=jv(a);if(d>>>0<=b>>>0){a=Vf(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Vc();p()}function mla(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;x[c>>2]=0;x[c+4>>2]=0;zS(b,c,32);yS(a,c);hb=c+32|0}function iL(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179012417){b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=538987841){break a}}b=1}return b}function Ty(a,b){var c=0;a:{if(b){Ty(a,x[b>>2]);Ty(a,x[b+4>>2]);mc(a);x[114414]=0;a=R(1258,b+16|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}Ul(a);Sy(b)}return}S(0)|0;zb();p()}function Jr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;x[e+12>>2]=d;d=Bb(b);if(d>>>0<c>>>0){om();p()}b=Rb(b);x[e+4>>2]=d-c;dt(a,b+c|0,x[Mb(e+12|0,e+4|0)>>2]);hb=e+16|0}function jT(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;hb=b+16|0}function h0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;e=x[c+4>>2];c=x[c>>2];x[d>>2]=c;x[d+4>>2]=e;x[d+8>>2]=c;x[d+12>>2]=e;a=aE(a,d,b);x[a>>2]=60524;hb=d+16|0;return a|0}function dh(a,b){var c=0;c=x[a>>2];a=Fd(b);b=c+8|0;if(Lb(b)>>>0>a>>>0){b=x[Pb(b,a)>>2]!=0}else{b=0}if(!b){a=ln(ec(4));x[a>>2]=75452;da(a|0,75500,2369);p()}return x[Pb(c+8|0,a)>>2]}function VA(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;if(Zq(a,b+8|0)){a=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);c=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}hb=b+16|0;return c|0}function yx(a){a=a|0;var b=0,c=0;a:{if(!a){a=ec(8);x[114414]=0;b=R(2061,a|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break a}b=N()|0;hc(a);Q(b|0);p()}return}da(b|0,82344,2050);p()}function kB(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;hb=b+16|0}function Ys(a,b){var c=0;a:{if(b){Ys(a,x[b>>2]);Ys(a,x[b+4>>2]);a=mc(a);x[114414]=0;R(1388,b+14|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}aq(a,b,1)}return}S(0)|0;zb();p()}function WI(a){a=a|0;var b=0,c=0;a:{if(!a){a=ec(8);x[114414]=0;b=R(2049,a|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){break a}b=N()|0;hc(a);Q(b|0);p()}return}da(b|0,82332,2050);p()}function Hz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=hb-16|0;hb=c;d=a,e=(g=a,h=x[a+12>>2],i=ac(c+8|0,b),f=x[x[a>>2]+32>>2],mb[f](g|0,h|0,i|0)|0)+x[a+12>>2]|0,x[d+12>>2]=e;hb=c+16|0}function By(a,b){var c=0;a:{if(b){By(a,x[b>>2]);By(a,x[b+4>>2]);a=mc(a);x[114414]=0;R(1392,b+16|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}Qt(a,b,1)}return}S(0)|0;zb();p()}function Xz(a,b){var c=0;a:{if(b){Xz(a,x[b>>2]);Xz(a,x[b+4>>2]);a=mc(a);x[114414]=0;R(803,b+14|0)|0;c=x[114414];x[114414]=0;if((c|0)==1){break a}aq(a,b,1)}return}S(0)|0;zb();p()}function VY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[(a<<2)+65248>>2]}else{a=0}x[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function Gm(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=hb-16|0;hb=b;wx(b,c);x[114414]=0;T(13,a|0,0,b|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(b);hb=b+16|0;break a}a=N()|0;xb(b);Q(a|0);p()}}function BO(a,b){var c=0;c=y[a+822|0];a:{if(c){break a}c=Vk(y[a+819|0]-x[a+772>>2]|0);if(!b|!c|(!x[a+656>>2]|c>>>0>=129)){break a}c=y[gc(x[a+656>>2]+108|0,c-1|0)|0]}return c&255}function $m(a){var b=0,c=0;b=x[20913];c=a+7&-8;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>nb()<<16>>>0){if(!(Sa(a|0)|0)){break a}}x[20913]=a;return b}x[114240]=48;return-1}function yX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;e=d+8|0;mb[x[x[a>>2]+12>>2]](e,a,b);if(ne(x[e+4>>2],x[c+4>>2])){a=x[e>>2]==x[c>>2]}else{a=0}hb=d+16|0;return a|0}function vw(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;if(b>>>0<=2147483631){a:{if(il(b)){Dm(a);Ce(a,b);break a}d=cj(b)+1|0;e=vE(d);Ff(a,d);Ue(a,e);ae(a,b)}hb=c+16|0;return a}Ef();p()}function iP(a){var b=0;if(x[a>>2]){ae(a,x[a>>2]);b=x[a>>2];a=(x[yb(a)>>2]-x[a>>2]|0)/9|0;x[114414]=0;T(27,b|0,D(a,9)|0,1);a=x[114414];x[114414]=0;if((a|0)==1){S(0)|0;zb();p()}}}function dQ(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=441273424|y[a+5|0]!=16){break a}b=a+54|0;if(!y[b|0]|y[b|0]>32){break a}c=y[a+4|0]>95}return c}function _S(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28163770){break a}if(cd(a+44|0,13681,3)){break a}a=a+47|0;b=(y[a|0]|y[a+1|0]<<8)>>>0>97}return b}function Yha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;Az(a,b,c);c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Mb(d+8|0,d+12|0)>>2]}hb=d+16|0;return c|0}function Mv(a,b){var c=0,d=0;c=hb-16|0;hb=c;w[b>>1]=0;v[c+15|0]=0;bh(a,c+15|0);d=y[c+15|0];w[b>>1]=d>>>1;if(d&1){v[c+15|0]=0;bh(a,c+15|0);w[b>>1]=z[b>>1]|y[c+15|0]<<7}hb=c+16|0}function Db(a,b){var c=0,d=0;c=hb-16|0;hb=c;if(re(a)){ag(a,x[a>>2],ti(a))}x[a+8>>2]=x[b+8>>2];d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;Ce(b,0);v[c+15|0]=0;Wd(b,c+15|0);hb=c+16|0}function hi(a,b){var c=0,d=0;c=hb-16|0;hb=c;if(re(a)){Oo(x[a>>2],ti(a))}x[a+8>>2]=x[b+8>>2];d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;Ce(b,0);x[c+12>>2]=0;ug(b,c+12|0);hb=c+16|0}function d2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;dI(b,c,d,B[a+24>>2]);_H(a,b,c,d);x[e+8>>2]=x[a+20>>2];b=x[a+16>>2];x[e>>2]=x[a+12>>2];x[e+4>>2]=b;hb=e+16|0}function Q9(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+12>>2]=0;yb(b);Xc(a+8|0);d=Lb(b);if(d){ho(a,d);Wx(a,x[b>>2],x[b+4>>2],d)}hb=c+16|0;return a|0}function LK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!kg(a,b)){break a}c=Qx(a,x[Re(a,b)+12>>2],c);d=65535;if((c|0)==65535){break a}b=Re(a,b);TK(Re(a,c),b);d=c}return d|0}function zf(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;w[c+14>>1]=0;a=nl(a,c+14|0,2);w[c+8>>1]=z[c+14>>1];d=b;b=c+8|0;w[d>>1]=y[b|0]|y[b+1|0]<<8;hb=c+16|0;return!lb&(a|0)==2}function H9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;e=z[a+28>>1];w[d+8>>1]=e;f=d,g=(Lb(a+4|0)+e|0)-1|0,w[f+10>>1]=g;a=CK(a,b,c,d+8|0);hb=d+16|0;return a|0}function Cla(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;lt(c,b);x[114414]=0;T(623,a|0,4,c|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(c);hb=c+16|0;return}a=N()|0;xb(c);Q(a|0);p()}function _$(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;rj(b,0,a);x[114414]=0;a=R(167,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){xb(b);hb=b+16|0;return a|0}a=N()|0;xb(b);Q(a|0);p()}function T6(a){a=a|0;var b=0,c=E(0);v[a+4202|0]=1;b=a,c=Qy(E(E(E(Ze(x[a+16>>2])>>>0)*E(20938023226335645e-21))+E(-.005025125574320555)),E(0),E(1)),B[b+4272>>2]=c;mJ(a);lJ(a)}function cia(a,b){a=a|0;b=b|0;var c=0,d=0;c=1;d=a;a=b+47|0;b=ad(d,y[a|0]&4?16:8,1,0,0);a:{b:{if(y[a|0]&8){break b}c=2;if(y[a|0]&16){break b}if(y[a|0]&127){break a}}pm(b,c)}}function JQ(a,b){var c=0;c=hb-32|0;hb=c;x[c+24>>2]=a;x[c+28>>2]=b;x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=-1;x[c+12>>2]=0;a=yQ(c+16|0,Jz(c+24|0,c+8|0));hb=c+32|0;return x[a>>2]}function ED(a){var b=0;a:{if(!(A[a>>2]<=18285140|A[a>>2]>=18350592)){b=1;if(x[a>>2]!=18350080){break a}}a=x[a>>2];b=0;if(a>>>0<=18350592){break a}b=(a|0)!=(a&-256)}return b}function hq(a){var b=0,c=0;c=x[a+4>>2];b=x[c>>2];x[a+4>>2]=b;if(b){Pn(b,a)}x[c+8>>2]=x[a+8>>2];a:{if(Gg(a)){b=x[a+8>>2];break a}b=x[a+8>>2]+4|0}x[b>>2]=c;x[c>>2]=a;Pn(a,c)}function gq(a){var b=0,c=0;c=x[a>>2];b=x[c+4>>2];x[a>>2]=b;if(b){Pn(b,a)}x[c+8>>2]=x[a+8>>2];a:{if(Gg(a)){b=x[a+8>>2];break a}b=x[a+8>>2]+4|0}x[b>>2]=c;x[c+4>>2]=a;Pn(a,c)}function Oba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=hb-16|0;hb=a;x[a+8>>2]=x[d>>2];c=x[a+8>>2];c=z[c>>1]|z[c+2>>1]<<16;w[b+4>>1]=0;w[b>>1]=c;w[b+2>>1]=c>>>16;hb=a+16|0}function KE(a){a=a|0;var b=0,c=0;x[a>>2]=65176;b=a+8|0;while(1){if(Lb(b)>>>0>c>>>0){if(x[Pb(b,c)>>2]){Am(x[Pb(b,c)>>2])}c=c+1|0;continue}break}xb(a+152|0);WE(b);return a|0}function Daa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=c,e=BT(bc(a),dc(a),c+12|0),x[d+8>>2]=e;d=c,e=dc(a),x[d>>2]=e;a=Hb(c+8|0,c);hb=c+16|0;return a|0}function wM(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=a;a=x[c+20>>2];x[b+16>>2]=x[c+16>>2];x[b+20>>2]=a;a=x[c+12>>2];x[b+8>>2]=x[c+8>>2];x[b+12>>2]=a}function w0(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;if(Jf(x[x[b>>2]-12>>2]+b|0)){if(x[(x[x[b>>2]-12>>2]+b|0)+72>>2]){mG(x[(x[x[b>>2]-12>>2]+b|0)+72>>2])}v[a|0]=1}return a|0}function Xga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=mb[x[x[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function TY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];if(!(a>>>0>127|!(x[(a<<2)+65248>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function J0(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;if(Jf(x[x[b>>2]-12>>2]+b|0)){if(x[(x[x[b>>2]-12>>2]+b|0)+72>>2]){Wr(x[(x[x[b>>2]-12>>2]+b|0)+72>>2])}v[a|0]=1}return a|0}function Gi(a){a=a|0;var b=0,c=0;while(1){b=c&65535;if(b>>>0<=126){Lg(((b<<5)+a|0)+480280|0);Hn((D(b,896)+a|0)+1074984|0,7,a,b,1024)}c=c+1|0;if(b>>>0<126){continue}break}}function SB(a){var b=0,c=0;a:{if(cd(a,9922,3)){break a}b=a+3|0;if(y[b|0]<=7&y[b|0]!=1|y[b|0]>14){break a}a=a+40|0;if(!(y[a|0]<33?y[a|0]:0)&y[b|0]>8){break a}c=1}return c}function Qr(a,b,c){var d=0;a:{d=hb-16|0;hb=d;nx(d,b,c);x[114414]=0;T(13,a|0,0,d|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(d);hb=d+16|0;break a}a=N()|0;xb(d);Q(a|0);p()}}function QA(a,b,c){var d=0;d=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);b=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a>>2]=d;x[a+4>>2]=b;vm(a+8|0,c);return a}function Iu(a,b,c){var d=0;a:{d=hb-16|0;hb=d;eI(d,b,c);x[114414]=0;T(13,a|0,0,d|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(d);hb=d+16|0;break a}a=N()|0;xb(d);Q(a|0);p()}}function Fw(a,b,c){var d=0;a:{d=hb-16|0;hb=d;vs(d,b,c);x[114414]=0;T(13,a|0,0,d|0);a=x[114414];x[114414]=0;if((a|0)!=1){xb(d);hb=d+16|0;break a}a=N()|0;xb(d);Q(a|0);p()}}function qL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;if((b|0)!=(c|0)){while(1){x[d+12>>2]=x[b>>2];Ay(a,d+12|0);b=b+4|0;if((c|0)!=(b|0)){continue}break}}hb=d+16|0}function gN(a,b,c){var d=0;d=c&15;if(d){v[b+844|0]=d}c=c&240;if(c){v[b+843|0]=c>>>4}x[b+88>>2]=x[b+88>>2]|131072;if(!(!d|!$b(a+1074312|0,80))){v[b+844|0]=y[b+844|0]<<2}}function dM(a,b){var c=0,d=0,e=0;c=Rb(a);a=Bb(a);d=Rb(b);e=Bb(b);a=a+c|0;b=-1;a:{while(1){if((a|0)==(c|0)){break a}a=a-1|0;if(qo(d,e,a)){continue}break}b=a-c|0}return b}function UY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=x[c>>2];if(a>>>0>127|!(x[(a<<2)+65248>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function Cl(a){a=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function yH(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=y[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function yA(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;US(c,b);e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){VS(b)}return a}function nP(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;US(c,b);e=Eb(c);c=nd(a,ac(d,c));if((e|0)==(c|0)){Yc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){VS(b)}return a}function jV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;Id(a+8|0,d+12|0,d+8|0);if(b){Hq(a,b);pC(a,b,y[c|0])}hb=d+16|0;return a|0}function eQ(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;_P(c,b);e=Eb(c);c=nd(a,ac(d,c));if((e|0)==(c|0)){Yc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){$P(b)}return a}function Zia(a,b){a=a|0;b=b|0;var c=0;a:{if(a>>>0>=515){a=Gf(b);Gf(b);break a}a=pg(b);pg(b)}if(a){while(1){if(a&1){cc(b,260)}c=a>>>0>1;a=a>>>1|0;if(c){continue}break}}}function U2(a,b){a=a|0;b=b|0;var c=0;c=-1;a:{if((b|0)<0){break a}a=a+24|0;if(Bj(Vb(x[a>>2]+484360|0))>>>0<=b>>>0){break a}c=z[uc(Vb(x[a>>2]+484360|0),b)>>1]}return c|0}function Tj(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;pv(c,b);e=Eb(c);c=nd(a,ac(d,c));if((e|0)==(c|0)){Yc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){SC(b)}return a}function TQ(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;FQ(c,b);e=Eb(c);c=nd(a,ac(d,c));if((e|0)==(c|0)){Yc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){GQ(b)}return a}function Oz(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;DQ(c,b);e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){EQ(b)}return a}function KA(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;ru(c,b);e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){tT(b)}return a}function JC(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;Sq(c,b);e=Eb(c);c=nd(a,ac(d,c));if((e|0)==(c|0)){Yc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){HC(b)}return a}function HT(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;ru(c,b);e=Eb(c);c=nd(a,ac(d,c));if((e|0)==(c|0)){Yc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){tT(b)}return a}function EA(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;CA(c,b);e=Eb(c);c=nd(a,ac(d,c));if((e|0)==(c|0)){Yc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){jT(b)}return a}function DR(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;sR(c,b);e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;a=(c|0)==(e|0);if(!a){tR(b)}return a}function lna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;if(Xf(a,d+8|0)){x[d+4>>2]=y[d+8|0];c=QT(a,b,x[Mb(d+4|0,d+12|0)>>2])}hb=d+16|0;return c|0}function Fi(a,b,c){var d=0;d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;C[a>>3]=C[a>>3]-C[c>>3];C[a+8>>3]=C[a+8>>3]-C[c+8>>3]}function E9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=Tt(x[b>>2]),x[d+12>>2]=e;x[c+8>>2]=0;d=a,e=x[dl(c+12|0,c+8|0,35976)>>2],x[d+36>>2]=e;mp(a);hb=c+16|0}function yq(a,b){var c=0;c=hb-16|0;hb=c;hb=c+16|0;return(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))>>>0<(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))>>>0?b:a}function wU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;if(Xf(a,d+8|0)){x[d+4>>2]=y[d+8|0];c=iB(a,b,x[Mb(d+4|0,d+12|0)>>2])}hb=d+16|0;return c|0}function vU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;if(Xf(a,d+8|0)){x[d+4>>2]=y[d+8|0];c=fB(a,b,x[Mb(d+4|0,d+12|0)>>2])}hb=d+16|0;return c|0}function v0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;e=Bb(b);d=a;a=Bb(c);d=Rb(vw(d,e+a|0));Le(d,Rb(b),e);b=e+d|0;Le(b,Rb(c),a);yn(a+b|0,1,0);hb=f+16|0}function uU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;if(Xf(a,d+8|0)){x[d+4>>2]=y[d+8|0];c=eB(a,b,x[Mb(d+4|0,d+12|0)>>2])}hb=d+16|0;return c|0}function sy(a,b){var c=0;c=hb-16|0;hb=c;x[114414]=0;x[c+12>>2]=b;a=U(1444,a|0,c+12|0,c+8|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){hb=c+16|0;return a}S(0)|0;zb();p()}function eia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;Az(a,b,c);a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function I6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b){f=x[b+24>>2];g=x[b+8>>2];h=x[b+4>>2];i=x[b>>2];e=x[b+12>>2]}else{e=0}cJ(a,i,h,g,e,f,b,c,d)}function Bt(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(!$b(c+1074312|0,102)){break a}c=z[a+692>>1]+1|0;w[a+796>>1]=c;if(!(v[a+89|0]&1)){break a}w[a+796>>1]=c|32768}x[a+692>>2]=b}function BV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Mb(d+12|0,d+8|0)>>2]}hb=d+16|0;return c|0}function B8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a=sj(a);if(a){a=(e=a,f=fi(c+8|0,b),d=x[x[a>>2]+72>>2],mb[d](e|0,f|0)|0)}else{a=1}hb=c+16|0;return a|0}function j1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a=bs(Ba(x[a+60>>2],b|0,c|0,d&255,e+8|0)|0);hb=e+16|0;lb=a?-1:x[e+12>>2];return(a?-1:x[e+8>>2])|0}function fC(a,b){var c=0,d=0;c=hb-16|0;hb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}v[c+15|0]=0;Xf(a,c+15|0);v[c+8|0]=y[c+15|0];d=y[c+8|0]}hb=c+16|0;return d<<24>>24}function f0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=So(d,a);JE(a,c);x[114414]=0;P(2434,b|0,1);a=x[114414];x[114414]=0;if((a|0)==1){a=N()|0;Ob(d);Q(a|0);p()}}function YV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;a=x[a+8>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Mb(d+12|0,d+8|0)>>2]}hb=d+16|0;return c|0}function XP(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=541938512|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1162627398)){return 1}return 0}function KO(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=y[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function tG(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>2];if((c|0)==x[a+28>>2]){return e=a,f=Wg(b),d=x[x[a>>2]+52>>2],mb[d](e|0,f|0)|0}x[a+24>>2]=c+1;v[c|0]=b;return Wg(b)}function Jea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=a+108|0;c=a+128|0;if((a|0)!=(c|0)){while(1){d=a,e=sO(y[a|0]+b|0),v[d|0]=e;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function zv(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;x[c>>2]=x[b>>2];d=c,e=x[b>>2]+MC(b)|0,x[d+4>>2]=e;b=hb-16|0;hb=b;mr(a,x[c>>2],x[c>>2]+MC(c)|0);hb=b+16|0;hb=c+16|0}function xja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Jj(a+8|0);x[114414]=0;T(424,a|0,b|0,c|0);a=x[114414];x[114414]=0;if((a|0)!=1){break a}a=N()|0;uh(d);Q(a|0);p()}}function nc(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;d=x[a>>2];a=(f=d,g=x[a+8>>2],h=ac(c+8|0,b),e=x[x[d>>2]+32>>2],mb[e](f|0,g|0,h|0)|0);hb=c+16|0;return a}function ms(a,b){a=a|0;b=b|0;x[a+20>>2]=0;x[a+24>>2]=b;x[a+12>>2]=0;x[a+4>>2]=4098;x[a+8>>2]=6;x[a+16>>2]=!b;Sb(a+32|0,0,40);bw(a+28|0);x[a+72>>2]=0;x[a+76>>2]=-1}function lca(a){a=E(a);var b=0;a=de(a);b=65535;a:{if(!(a<E(65535))){break a}b=0;if(!(a>E(0))){break a}b=~~a>>>0;if(a<E(4294967296)&a>=E(0)){break a}b=0}return b|0}function jM(a){x[a>>2]=0;x[a+4>>2]=0;x[a+88>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;EN(a+112|0,48e3);x[a+668>>2]=0;py(a+724|0);py(a+736|0);py(a+748|0);_h(a+810|0);return a}function j8(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;x[d+8>>2]=0;c=d+8|0;v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;a=PJ(a,c);hb=d+16|0;return a|0}function cc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Qb(a,b);if(c){x[a+8>>2]=x[a+8>>2]+b;return c|0}b=a;a=x[a>>2];d=b,e=mb[x[x[a>>2]+24>>2]](a)|0,x[d+8>>2]=e;return c|0}function tw(a,b){var c=0;c=rs(a+4|0);x[a>>2]=59228;x[c>>2]=59248;x[114414]=0;P(2451,c|0,b|0);a=x[114414];x[114414]=0;if((a|0)!=1){return}a=N()|0;gh(c);Q(a|0);p()}function sw(a,b){var c=0;c=YF(a+4|0);x[a>>2]=59388;x[c>>2]=59408;x[114414]=0;P(2453,c|0,b|0);a=x[114414];x[114414]=0;if((a|0)!=1){return}a=N()|0;gh(c);Q(a|0);p()}function ss(a,b,c,d){var e=0;a:{if(d==E(1)){break a}c=D(b,c);if(!c){break a}e=+d;b=0;while(1){C[a>>3]=C[a>>3]*e;a=a+8|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function hX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=x[c>>2];a=mb[x[x[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){x[c>>2]=x[d+12>>2]}hb=d+16|0;return a|0}function dE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;e=wf(b);d=a;a=Bb(c);d=Rb(vw(d,e+a|0));Le(d,b,e);b=e+d|0;Le(b,Rb(c),a);yn(a+b|0,1,0);hb=f+16|0}function Vp(a){x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=128;x[a+4>>2]=256;x[a+32>>2]=363;x[a+36>>2]=952;x[a+16>>2]=48e3;x[a+20>>2]=2;x[a+24>>2]=128;x[a+28>>2]=0;return a}function f$(a){a=a|0;var b=0,c=0;b=x[a+112>>2];if((b|0)>=11){b=378;while(1){wF(a);c=c-!b|0;b=b-1|0;if(c|b){continue}break}b=0}x[a+112>>2]=b+1;a=wF(a);return a|0}function RO(a,b){var c=0;c=x[a+4>>2];a:{if((b|0)>=0){b=b+c|0;c=x[a>>2]+(b>>>3&536870908)|0;break a}b=b+c|0;c=x[a>>2]+((b-31|0)/32<<2)|0}x[a>>2]=c;x[a+4>>2]=b&31}function Pia(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-80|0;hb=d;c=-1;a:{if(!HT(a,d+8|0)){break a}c=0;if(!lQ(d+8|0)){break a}c=kf(a,b,kQ(d+8|0),lb)}hb=d+80|0;return c|0}function we(a,b){var c=0;c=x[a>>2];x[a>>2]=b;a:{if(c){a=x[mc(a)>>2];x[114414]=0;W(a|0,c|0);a=x[114414];x[114414]=0;if((a|0)==1){break a}}return}S(0)|0;zb();p()}function ula(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=Qb(a,12);a:{if(d){e=c+8|0;CA(e,b);Dd(a,e);break a}v[c+7|0]=0;Th(b,12,c+7|0)}hb=c+16|0;return d|0}function lo(a,b,c){a=a|0;b=b|0;c=c|0;v[a+11|0]=c;v[a+10|0]=b;v[a+12|0]=y[a+12|0]&251;w[a+8>>1]=65535;x[a>>2]=0;x[a+4>>2]=0;v[a+12|0]=y[a+12|0]&252|1;return a|0}function is(a){var b=0;a:{if((ye(a)|0)!=79){break a}if((ye(a)|0)!=103){break a}if((ye(a)|0)!=103){break a}b=(ye(a)|0)==83}if(!b){fc(a,30);return 0}return mH(a)}function RJ(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=b;x[c+8>>2]=127;b=Mb(c+12|0,c+8|0);B[x[a+20>>2]+144>>2]=E(E(A[b>>2])*E(-.007874015718698502))+E(1);hb=c+16|0}function $t(a){var b=0,c=0;c=a;a=x[a>>2];b=x[a+4>>2];a:{if(!b){if(!Gg(a)){while(1){a=x[a+8>>2];if(!Gg(a)){continue}break}}a=x[a+8>>2];break a}a=kR(b)}x[c>>2]=a}function yn(a,b,c){var d=0;d=hb-16|0;hb=d;x[114414]=0;v[d+15|0]=c;U(81,a|0,b|0,d+15|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){hb=d+16|0;return}S(0)|0;zb();p()}function ju(a){var b=0,c=0;b=hb-16|0;hb=b;c=b+8|0;dd(c,a,0);x[114414]=0;T(647,c|0,110,0);a=x[114414];x[114414]=0;if((a|0)!=1){hb=b+16|0;return}S(0)|0;zb();p()}function _D(a,b,c,d){var e=0,f=0;f=x[a+4>>2];e=0;a:{if(!c){break a}e=f>>8;if(!(f&1)){break a}e=Rv(x[c>>2],e)}a=x[a>>2];mb[x[x[a>>2]+28>>2]](a,b,c+e|0,f&2?d:2)}function wma(a,b){a=a|0;b=b|0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+4|0]=6;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=8;v[b+3|0]=4}function lJ(a){a=a|0;var b=0;x[a+4240>>2]=0;x[a+4244>>2]=0;b=a+4264|0;x[b>>2]=0;x[b+4>>2]=0;b=a+4256|0;x[b>>2]=0;x[b+4>>2]=0;a=a+4248|0;x[a>>2]=0;x[a+4>>2]=0}function RY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[vr()+(x[b>>2]<<2)>>2]}x[b>>2]=a;b=b+4|0;continue}break}return c|0}function PY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[ur()+(x[b>>2]<<2)>>2]}x[b>>2]=a;b=b+4|0;continue}break}return c|0}function B$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=x[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function u_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=mb[x[x[a+8>>2]+20>>2]](a+8|0)|0;return jj(g,b,c,d,e,f,Rb(a),Rb(a)+(Bb(a)<<2)|0)|0}function md(a,b){var c=0,d=0;c=hb-16|0;hb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}v[c+15|0]=0;Xf(a,c+15|0);v[c+8|0]=y[c+15|0];d=y[c+8|0]}hb=c+16|0;return d}function lg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];return(f=d,g=Cb(b),h=x[a+8>>2],i=c,e=x[x[d>>2]+28>>2],mb[e](f|0,g|0,h|0,i|0)|0)|0}function E$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function Cr(a){a=a|0;var b=0,c=0;b=ec(8);x[114414]=0;a=O(2095,b|0,a|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){da(a|0,75356,231);p()}a=N()|0;hc(b);Q(a|0);p()}function Cg(a){var b=0,c=0;b=hb-16|0;hb=b;x[114414]=0;a=U(111,a|0,b+8|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){Dm(a);hb=b+16|0;return a}S(0)|0;zb();p()}function rba(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[114414]=0;a=O(1438,a|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){hb=c+16|0;return a|0}Q(N()|0);p()}function mz(a,b,c,d,e){var f=0;if(d){while(1){B[b>>2]=E(x[a>>2])*e;B[c>>2]=E(x[a+4>>2])*e;c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;if((f|0)!=(d|0)){continue}break}}}function iD(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;hb=b+16|0}function ev(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[rc(d+15|0,d+14|0)|0]|(c?-128:0),v[e+21|0]=f;hb=d+16|0}function dv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[rc(d+15|0,d+14|0)|0]|(c?-128:0),v[e+22|0]=f;hb=d+16|0}function aY(a){a=a|0;if(y[461184]){return x[115295]}if(!y[462344]){v[462344]=1}$c(462320,71712);$c(462332,71724);v[461184]=1;x[115295]=462320;return 462320}function Wb(a){var b=0,c=0;b=hb-16|0;hb=b;x[114414]=0;a=U(14,a|0,b+8|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){Dm(a);hb=b+16|0;return a}S(0)|0;zb();p()}function R8(a,b,c){a=a|0;b=b|0;c=c|0;c=x[b>>2];if(!((Vg(b)|0)!=8|(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=1869112133)){sc(a+4260|0,c,Vg(b));Ns(a)}}function Pd(a,b,c){var d=0;d=hb-16|0;hb=d;x[114414]=0;x[d+12>>2]=b;a=Uo(a,d+12|0,c);b=x[114414];x[114414]=0;if((b|0)!=1){hb=d+16|0;return a}S(0)|0;zb();p()}function zK(a){a=E(a);var b=0;b=hb-16|0;hb=b;B[b+12>>2]=F(a);x[b+8>>2]=646978941;x[b+4>>2]=1259902592;a=B[oA(b+12|0,b+8|0,b+4|0)>>2];hb=b+16|0;return E(a)}function vG(a,b){var c=0;c=hb-16|0;hb=c;x[114414]=0;a=U(158,a|0,c+8|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){Dm(a);hb=c+16|0;return a}S(0)|0;zb();p()}function hd(a){var b=0,c=0;b=hb-16|0;hb=b;x[114414]=0;a=U(1,a|0,b+8|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){Dm(a);hb=b+16|0;return a}S(0)|0;zb();p()}function hN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(x[a+480180>>2]&2){break a}}x[b+56>>2]=0;d=Gp(a,z[b+60>>1],x[b+48>>2],c,0)}return d|0}function h$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;x[e+12>>2]=b;x[e+8>>2]=d;b=Hh(e,e+12|0);a=JF(a,c,x[e+8>>2]);Ne(b);hb=e+16|0;return a|0}function cka(a,b){a=a|0;b=b|0;var c=0;a=HR(a,b);if(!a){c=hb-16|0;hb=c;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;hb=c+16|0}return a|0}function ax(a,b){var c=0;while(1){c=(b|0)>=120?120:b;a=E(E(B[((c&3)<<2)+40480>>2]*a)*E(1073741824>>>(c>>2)|0));b=b-c|0;if((b|0)>0){continue}break}return a}function Yo(a,b){var c=0,d=0;a:{if(!a){break a}c=yna(a,0,b,0);d=lb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=sd(c);if(!(!a|!(y[a-4|0]&3))){Sb(a,0,c)}return a}function T2(a,b){a=a|0;b=b|0;var c=0;a:{if(!ws(b)){break a}a=a+24|0;if(!kg(x[a>>2]+484344|0,b&65535)){break a}c=x[Zb(x[a>>2]+484344|0,b)+12>>2]}return c|0}function OQ(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+8|0;FQ(c,b);e=Eb(c);c=nc(a,ac(d,c));if((e|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;if((c|0)!=(e|0)){GQ(b)}}function Li(a){var b=0;a=de(a);b=-1;a:{if(!(a<E(4294967296))){break a}b=0;if(!(a>E(0))){break a}b=~~a>>>0;if(a<E(4294967296)&a>=E(0)){break a}b=0}return b}function Lh(a){var b=0,c=0;b=a*a;c=b*a;return E(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function KZ(){var a=0,b=0,c=0;a:{a=Gd(462400);x[a>>2]=66280;x[114414]=0;b=$(2507)|0;c=x[114414];x[114414]=0;if((c|0)!=1){x[a+8>>2]=b;break a}Q(N()|0);p()}}function Ik(a,b){var c=0,d=0;a:{b=Jk(a,b);if((b|0)==255){break a}if(Aj(a)){break a}c=a+4|0;d=gc(c,b);v[d|0]=y[d|0]&223;ph(x[a>>2],tt(b)|176,y[gc(c,b)|0])}}function CV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function tp(a,b){var c=0;x[a>>2]=75840;x[a>>2]=75964;c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;return a}function qs(a){var b=0,c=0,d=0;b=Cna(x[a>>2],1)^270549120;c=x[a+4>>2];d=(b+(c<<2)|0)+2019860093|0;x[a>>2]=d;b=a;a=D(Cna(d,16),5)+c|0;x[b+4>>2]=a;return a}function cY(a){a=a|0;if(y[461176]){return x[115293]}if(!y[462312]){v[462312]=1}Pc(462288,9658);Pc(462300,9637);v[461176]=1;x[115293]=462288;return 462288}function ZV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Ol(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;c=x[a+1074400>>2];d=x[a+1074416>>2];x[b+12>>2]=1;a=x[_c(a+1074396|0,b+12|0)>>2];hb=b+16|0;return D(a,c+d|0)}function Me(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=sd(a);if(b){break a}b=x[115731];if(b){mb[b|0]();continue}break}da(Yj(ec(4))|0,75016,26);p()}return b|0}function en(a,b){var c=0,d=0;b=b+7&-8;d=x[a+80>>2];a:{if(d){b=x[a+92>>2]-b|0;c=0;if((b|0)<x[a+88>>2]){break a}x[a+92>>2]=b;return b+d|0}c=sd(b)}return c}function _p(a,b,c){var d=0;d=b;b=y[a|0]|y[a+1|0]<<8;if((d|0)<=((b<<8|b>>>8)&65535)){a=y[a|0]|y[a+1|0]<<8;a=((a<<8|a>>>8)&65535)<=(c|0)}else{a=0}return a}function Q2(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=Uf(a,b);x[114414]=0;O(117,a+12|0,c|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){break a}b=N()|0;xb(a);Q(b|0);p()}}function JY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=v[b|0];if((a|0)>=0){a=x[vr()+(v[b|0]<<2)>>2]}v[b|0]=a;b=b+1|0;continue}break}return c|0}function HY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=v[b|0];if((a|0)>=0){a=x[ur()+(v[b|0]<<2)>>2]}v[b|0]=a;b=b+1|0;continue}break}return c|0}function zI(a){var b=0,c=0;b=hb-16|0;hb=b;x[114414]=0;a=U(2199,a|0,b+8|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function yI(a){var b=0,c=0;b=hb-16|0;hb=b;x[114414]=0;a=U(2200,a|0,b+8|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function a0(a,b){a=a|0;b=b|0;var c=0,d=0;b=yw(b);x[a+36>>2]=b;c=a,d=sn(b),x[c+44>>2]=d;c=a,d=Xm(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){Cr(2049);p()}}function U$(a,b){a=a|0;b=b|0;var c=0,d=0;b=rw(b);x[a+36>>2]=b;c=a,d=sn(b),x[c+44>>2]=d;c=a,d=Xm(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){Cr(2049);p()}}function TN(a){var b=0,c=0,d=0;b=a+26|0;c=y[b|0]+27|0;if(y[b|0]){while(1){c=y[(a+d|0)+27|0]+c|0;d=d+1|0;if(d>>>0<y[b|0]){continue}break}}return c&65535}function Rc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(A[a+8>>2]<b>>>0){d=x[a>>2];c=0;if(mb[x[x[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}x[a+8>>2]=b;c=1}return c|0}function MY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];v[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function EX(a,b){a=a|0;b=b|0;a=ln(a);x[a>>2]=75068;b=Rb(b);x[114414]=0;O(2894,a+4|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){return a|0}Q(N()|0);p()}function A_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=mb[x[x[a+8>>2]+20>>2]](a+8|0)|0;return kj(g,b,c,d,e,f,Rb(a),Rb(a)+Bb(a)|0)|0}function AI(a){var b=0,c=0;b=hb-16|0;hb=b;x[114414]=0;a=U(2198,a|0,b+8|0,b|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){hb=b+16|0;return a}S(0)|0;zb();p()}function _ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;Xc(a+8|0);if(b){Ln(a,b);Eq(a,b,c)}hb=d+16|0;return a|0}function O2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=hb-32|0;hb=h;i=h+8|0;oI(i,b,c,d,e,f,g);Jd(a,h+20|0);Ul(i);hb=h+32|0}function Nh(a,b,c){x[b+12>>2]=x[b+12>>2]+c;x[b+8>>2]=x[b+8>>2]-c;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function xu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;Xc(a+8|0);if(b){Pk(a,b);qq(a,b,c)}hb=d+16|0;return a|0}function nd(a,b){var c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;a=(e=a,f=x[a+12>>2],g=ac(c+8|0,b),d=x[x[a>>2]+32>>2],mb[d](e|0,f|0,g|0)|0);hb=c+16|0;return a}function gg(a){a=+a;var b=0;a=Qd(a);b=-1;a:{if(!(a<4294967295)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function PU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;Xc(a+8|0);if(b){ho(a,b);OB(a,b,c)}hb=d+16|0;return a|0}function GS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;x[d+12>>2]=0;Xc(a+8|0);if(b){sq(a,b);sA(a,b,c)}hb=d+16|0;return a|0}function FX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=wf(b);d=Me(c+13|0);x[d+8>>2]=0;x[d+4>>2]=c;x[d>>2]=c;e=a,f=sc(d+12|0,b,c+1|0),x[e>>2]=f;return a|0}function B2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<2;a=0;while(1){if(d){Sb(x[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function A2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<3;a=0;while(1){if(d){Sb(x[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function $L(a){if(x[a+480224>>2]==2){return+A[a+1074420>>2]*1e-4}return+A[a+24620>>2]*60/(+A[a+1074404>>2]*+(D(x[a+1074408>>2],x[a+1074416>>2])>>>0))}function uY(a){a=a|0;var b=0;a=x[a+8>>2];if(!a){return 1}x[114414]=0;a=R(2625,a|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){return a|0}S(0)|0;zb();p()}function ica(a){a=+a;var b=0;a=Qd(a);b=65535;a:{if(!(a<65535)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function gn(a,b,c){var d=0;d=x[b+4>>2];x[b+8>>2]=x[b+8>>2]-c;x[b>>2]=x[b>>2]+(D(c,d)<<1);c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2]}function ep(a,b,c){var d=0;d=x[b+4>>2];x[b+8>>2]=x[b+8>>2]-c;x[b>>2]=x[b>>2]+(D(c,d)<<2);c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2]}function dha(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-48|0;hb=d;c=-1;a:{if(!nP(a,d)){break a}c=0;if(!$O(d)){break a}c=kf(a,b,_O(d),lb)}hb=d+48|0;return c|0}function U6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=2){Ph(d+12|0);B[((b<<2)+a|0)+4208>>2]=B[d+12>>2];mJ(a)}hb=d+16|0}function O7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=5){Ph(d+12|0);B[((b<<2)+a|0)+4208>>2]=B[d+12>>2];DJ(a)}hb=d+16|0}function N6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=3){Ph(d+12|0);B[((b<<2)+a|0)+4208>>2]=B[d+12>>2];kJ(a)}hb=d+16|0}function Kw(a,b){var c=0,d=0;c=b&1?a:1;if(b+1>>>0>=3){d=b;while(1){a=a*a;d=(d|0)/2|0;c=c*(d&1?a:1);if(d+1>>>0>2){continue}break}}return(b|0)<0?1/c:c}function Kha(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-96|0;hb=d;c=-1;a:{if(!eQ(a,d)){break a}c=0;if(!tP(d)){break a}c=kf(a,b,sP(d),lb)}hb=d+96|0;return c|0}function He(a){var b=0,c=0;b=hb-16|0;hb=b;a:{if(re(a)){c=x[a>>2];v[b+15|0]=0;Wd(c,b+15|0);ae(a,0);break a}v[b+14|0]=0;Wd(a,b+14|0);Ce(a,0)}hb=b+16|0}function Gia(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-96|0;hb=d;c=-1;a:{if(!eQ(a,d)){break a}c=0;if(!dQ(d)){break a}c=kf(a,b,cQ(d),lb)}hb=d+96|0;return c|0}function G7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;d=hb-16|0;hb=d;B[d+12>>2]=c;if((b|0)<=4){Ph(d+12|0);B[((b<<2)+a|0)+4208>>2]=B[d+12>>2];yJ(a)}hb=d+16|0}function Fba(a,b,c){a=a|0;b=b|0;c=c|0;a=Dk(a);x[114414]=0;T(94,a|0,b|0,c|0);b=x[114414];x[114414]=0;if((b|0)!=1){return a|0}b=N()|0;Ge(a);Q(b|0);p()}function EY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b|0];v[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function Dha(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-48|0;hb=d;c=-1;a:{if(!nP(a,d)){break a}c=0;if(!mP(d)){break a}c=kf(a,b,lP(d),lb)}hb=d+48|0;return c|0}function CM(a){var b=0;a=de(a);b=255;a:{if(!(a<E(255))){break a}b=0;if(!(a>E(0))){break a}b=~~a>>>0;if(a<E(4294967296)&a>=E(0)){break a}b=0}return b}function jX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(tg(a,x[b+8>>2],f)){Qv(b,c,d,e);return}a=x[a+8>>2];mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)}function Zi(a){var b=0,c=0;b=ec(8);x[114414]=0;a=O(29,b|0,a|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){da(a|0,75288,25);p()}a=N()|0;hc(b);Q(a|0);p()}function Jv(a){var b=0,c=0;b=ec(8);x[114414]=0;a=O(24,b|0,a|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){da(a|0,75236,25);p()}a=N()|0;hc(b);Q(a|0);p()}function lp(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;e=c+8|0;Eh(e,b);d=hb-16|0;hb=d;f=d+8|0;vK(f,ac(d,e));aS(a,f);hb=d+16|0;Eh(c,b);Eb(c);hb=c+16|0}function g0(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;mb[x[x[a+32>>2]+d>>2]](b,a,x[d+x[a+36>>2]>>2]);continue}break}}function _m(a,b){var c=0;c=x[x[b>>2]-12>>2];x[114414]=0;b=x[(b+c|0)+24>>2];c=x[114414];x[114414]=0;if((c|0)!=1){x[a>>2]=b;return a}S(0)|0;zb();p()}function YR(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;c=c-b|0;d=Bg(d,b,c);f=b;b=D((c|0)/6|0,6);x[e+12>>2]=f+b;x[e+8>>2]=b+d;gd(a,e+12|0,e+8|0);hb=e+16|0}function SG(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function Kaa(a,b){a=a|0;b=b|0;var c=0;if(!(y[b+14|0]&48|y[b+17|0]!=173)){ad(a,8,1,0,11);return}c=a;a=b+14|0;ad(c,y[a|0]&16?16:8,y[a|0]&32?3:1,0,2)}function IQ(a){return(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))==1279545165&(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1297239878}function Eha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=hb-16|0;hb=d;e=d+8|0;Kq(e,a);Iq(c,e);hb=d+16|0;a=yf(c,b);xb(c);hb=c+16|0;return a|0}function D2(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-32|0;hb=c;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;dt(a,x[c+8>>2],x[c+12>>2]);hb=c+32|0;return a|0}function Ana(a,b,c){var d=0;d=b>>31;a=a^d;wna(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);lb=kb;a=d^jb;b=a-d|0;lb=(d^lb)-((a>>>0<d>>>0)+d|0)|0;return b}function $y(a,b,c){var d=0,e=0,f=0;d=Jk(a,b);if((d|0)!=255){e=fd(a+22|0,d),f=c,w[e>>1]=f;a=a+58|0;e=gc(a,b),f=255,v[e|0]=f;e=gc(a,c),f=d,v[e|0]=f}}function qv(a,b){var c=0,d=0;d=hb-16|0;hb=d;c=d+8|0;pv(c,b);b=Eb(c);c=nc(a,ac(d,c));if((b|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;return(b|0)==(c|0)}function oP(a,b){var c=0,d=0;d=hb-16|0;hb=d;c=d+8|0;Eh(c,b);b=Eb(c);c=nd(a,ac(d,c));if((b|0)==(c|0)){Yc(a,Eb(d+8|0))}hb=d+16|0;return(b|0)==(c|0)}function Zq(a,b){var c=0,d=0;d=hb-16|0;hb=d;c=d+8|0;Eh(c,b);b=Eb(c);c=nc(a,ac(d,c));if((b|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;return(b|0)==(c|0)}function Yaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;Zy(a,C[c>>3])}function Xf(a,b){var c=0,d=0;d=hb-16|0;hb=d;c=d+8|0;Vq(c,b);b=Eb(c);c=nc(a,ac(d,c));if((b|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;return(b|0)==(c|0)}function P2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=hb-32|0;hb=h;i=h+8|0;oI(i,b,c,d,e,f,g);Jd(a,i);Ul(i);hb=h+32|0}function Lq(a,b){var c=0,d=0;d=hb-16|0;hb=d;c=d+8|0;hl(c,b);b=Eb(c);c=nc(a,ac(d,c));if((b|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;return(b|0)==(c|0)}function HR(a,b){var c=0,d=0;d=hb-16|0;hb=d;c=d+8|0;AA(c,b);b=Eb(c);c=nc(a,ac(d,c));if((b|0)==(c|0)){cc(a,Eb(d+8|0))}hb=d+16|0;return(b|0)==(c|0)}function uw(a){var b=0,c=0;b=hb-16|0;hb=b;c=-1;a:{if(Iw(a)){break a}if((mb[x[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=y[b+15|0]}hb=b+16|0;return c}function dp(a,b){var c=0;a:{if(!yH(b)|(y[b+1|0]^y[a+1|0])>>>0>1){break a}b=y[b+2|0];a=y[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function dN(a,b){v[a+860|0]=b;v[a+832|0]=b;v[a+831|0]=b;v[a+829|0]=b;v[a+828|0]=b;w[a+800>>1]=b;v[a+853|0]=b;v[a+846|0]=b>>>4;v[a+847|0]=b<<2&60}function bh(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;v[c+15|0]=0;a=nl(a,c+15|0,1);v[c+8|0]=y[c+15|0];v[b|0]=y[c+8|0];hb=c+16|0;return!lb&(a|0)==1}function Nba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=hb-16|0;hb=a;x[a+8>>2]=x[d>>2];f=C[x[a+8>>2]>>3];x[b+8>>2]=0;C[b>>3]=f;hb=a+16|0}function ry(a){var b=0;b=hb-16|0;hb=b;x[114414]=0;U(1445,a|0,b+8|0,b|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){hb=b+16|0;return}S(0)|0;zb();p()}function pN(a,b,c){var d=0,e=0,f=0;d=Fc(a);if(d>>>0>=c>>>0){d=Rb(a);fl(d,b,c);return Wu(a,d,c)}e=d;f=c-d|0;d=Bb(a);wo(a,e,f,d,0,d,c,b);return a}function oj(a,b,c,d){var e=0;e=D(b,c);a:{if(x[d+76>>2]<0){a=Lw(a,e,d);break a}a=Lw(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function mma(a,b){a=a|0;b=b|0;var c=0;a=ad(a,8,1,0,1);c=2;b=b+13|0;a:{if(!(y[b|0]&64)){c=0;if(!(y[b|0]&2)){break a}}pm(a,c)}if(y[b|0]&4){DA(a)}}function lE(a,b){a=a|0;b=b|0;a=ln(a);x[a>>2]=75068;x[114414]=0;O(2894,a+4|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){return a|0}Q(N()|0);p()}function gp(a){var b=0;b=hb-16|0;hb=b;x[114414]=0;U(2205,a|0,b+8|0,b|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){hb=b+16|0;return}S(0)|0;zb();p()}function el(a,b){var c=0;c=x[x[b>>2]-12>>2];x[114414]=0;b=R(30,b+c|0)|0;c=x[114414];x[114414]=0;if((c|0)!=1){x[a>>2]=b;return a}S(0)|0;zb();p()}function Xt(a){a=+a;var b=0;a=Qd(a);b=255;a:{if(!(a<255)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function Kp(a){var b=0,c=0,d=0;c=y[a+30|0];d=Vh(x[a+24>>2]+484360|0);b=x[a+24>>2]+484360|0;if(c>>>0>=d>>>0){return Vb(b)}return Ni(b,y[a+30|0])}function Jma(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;w[b+14>>1]=1;c=b,d=zu(a),w[c+12>>1]=d;a=z[aj(b+14|0,b+12|0)>>1];hb=b+16|0;return a-1&65535}function Gl(a,b,c){a:{if((a|0)==(b|0)){break a}c=y[c|0];while(1){if((c|0)==y[a|0]){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function $0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b>>2];x[a>>2]=d;x[x[d-12>>2]+a>>2]=x[b+4>>2];x[a+4>>2]=0;ms(x[x[a>>2]-12>>2]+a|0,c);return a|0}function hZ(){var a=0,b=0;a:{a=Gd(462632);x[114414]=0;R(2613,a+8|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){x[a>>2]=69216;break a}Q(N()|0);p()}}function hH(a,b,c,d,e,f){var g=0,h=0;g=x[a+32>>2];if(!y[a+23|0]){x[(c<<2)+g>>2]=b;return}h=g;g=d<<2;x[h+g>>2]=b;v[x[a+8>>2]+d|0]=e;x[f+g>>2]=c}function fZ(){var a=0,b=0;a:{a=Gd(462648);x[114414]=0;R(2613,a+8|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){x[a>>2]=69372;break a}Q(N()|0);p()}}function Mga(a,b,c){a=a|0;b=b|0;c=c|0;a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[b|0]=a;v[b+1|0]=a>>>8;v[b+2|0]=a>>>16;v[b+3|0]=a>>>24}function lQ(a){var b=0;a:{if(cd(a,9626,3)|y[a+3|0]>31|(v[a+27|0]<0|y[a+32|0]>64)){break a}a=a+33|0;if(y[a|0]>32){break a}b=y[a|0]!=0}return b}function Su(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;a:{if(Qb(a,256)){d=hb-16|0;hb=d;e=c+8|0;jc(e,b,256);hb=d+16|0;Dd(a,e);break a}SD(b)}hb=c+16|0}function Mh(a){var b=0;a=a*a;b=a*a;return E(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function tka(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+12>>2]=0;Xc(a+8|0);if(b){Pk(a,b);GR(a,b)}hb=c+16|0;return a|0}function rM(a,b){var c=0,d=0,e=0;d=y[a|0];e=y[b|0];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(d>>>0>e>>>0){break a}c=z[a+2>>1]<z[b+2>>1]}return c}function kl(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;f=c-b|0;if((b|0)!=(c|0)){Bg(d,b,f)}x[e+12>>2]=b+f;x[e+8>>2]=d+f;gd(a,e+12|0,e+8|0);hb=e+16|0}function bw(a){var b=0,c=0;x[114414]=0;c=$(2616)|0;b=x[114414];x[114414]=0;if((b|0)!=1){b=a;a=x[c>>2];x[b>>2]=a;Bm(a);return}S(0)|0;zb();p()}function XO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;return(e=a,f=x[c>>2],g=b,h=Eb(c),d=x[x[a>>2]+28>>2],mb[d](e|0,f|0,g|0,h|0)|0)|0}function R2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-32|0;hb=g;h=g+8|0;pI(h,b,c,d,e,f);Jd(a,g+20|0);Ul(h);hb=g+32|0}function Iq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=x[b+4>>2];d=x[b>>2];v[c+15|0]=0;d=Gl(d,d+e|0,c+15|0);yi(a,x[b>>2],d);hb=c+16|0}function Tba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;if(b>>>0>=250){Zi(7976);p()}e=d+8|0;Kb(e,a,b);he(e,c);hb=d+16|0;return a|0}function Hs(a){var b=0;b=C[a+4248>>3]/+(Ze(x[a+16>>2])>>>0);C[a+4264>>3]=b;if(y[a+4240|0]){C[a+4264>>3]=b*.016666666666666666*C[a+4288>>3]}}function HU(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+12>>2]=0;Xc(a+8|0);if(b){NB(a,b);MB(a,b)}hb=c+16|0;return a|0}function HS(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[a>>2]=0;x[a+4>>2]=0;x[c+12>>2]=0;Xc(a+8|0);if(b){Pk(a,b);xC(a,b)}hb=c+16|0;return a|0}function Cj(a){if(!(a<2147483647)){return 2147483647}if(!(a>-2147483648)){return-2147483648}if(F(a)<2147483648){return~~a}return-2147483648}function xQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=Qb(a,32);a:{if(d){e=c+8|0;qQ(e,b);Dd(a,e);break a}pQ(b)}hb=c+16|0;return d|0}function p9(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;if(!Cd(a,4)){Lv(a)}c=b,d=bc(a+44|0),x[c>>2]=d;a=x[td(b+8|0,b)>>2];hb=b+16|0;return a|0}function o9(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;if(!Cd(a,4)){Lv(a)}c=b,d=dc(a+44|0),x[c>>2]=d;a=x[td(b+8|0,b)>>2];hb=b+16|0;return a|0}function jd(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[c+8>>2]=a;x[c+12>>2]=b;x[c>>2]=-1;x[c+4>>2]=0;a=cv(c+8|0,c);hb=c+16|0;return x[a>>2]}function dma(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;a:{if(Qb(b,6)){d=c+8|0;AA(d,a);Dd(b,d);break a}v[c+7|0]=0;Th(a,6,c+7|0)}hb=c+16|0}function bca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;if(b>>>0>=43){Zi(7976);p()}e=d+8|0;Kb(e,a,b);he(e,c);hb=d+16|0;return a|0}function aca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;if(b>>>0>=16){Zi(7976);p()}e=d+8|0;ol(e,a,b);he(e,c);hb=d+16|0;return a|0}function Nb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;if(b>>>0>=110){Zi(7976);p()}e=d+8|0;Kb(e,a,b);he(e,c);hb=d+16|0;return a|0}function DY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=hb-16|0;hb=a;x[a+12>>2]=e;x[a+8>>2]=d-c;b=Mb(a+12|0,a+8|0);hb=a+16|0;return x[b>>2]}function Cia(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;a:{if(Qb(b,5)){d=c+8|0;Gu(d,a);Dd(b,d);break a}v[c+7|0]=0;Th(a,5,c+7|0)}hb=c+16|0}function wz(a,b){var c=0,d=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[b>>2]=0;x[b+4>>2]=0;c=yb(b),d=0,x[c>>2]=d;return a}function km(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;a:{if(Qb(b,4)){d=c+8|0;Eh(d,a);Dd(b,d);break a}v[c+7|0]=0;Th(a,4,c+7|0)}hb=c+16|0}function ZM(a){a=50-(D(y[(a>>>4|0)+25760|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Cc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function XQ(a){var b=0;b=x[a+4>>2];a=x[a>>2];x[114414]=0;a=O(855,a|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){return a}S(0)|0;zb();p()}function Vk(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=0;x[b+4>>2]=255;a=y[Bf(b+8|0,be(b+12|0,b+4|0))|0];hb=b+16|0;return a|0}function Un(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=Qb(a,4);a:{if(d){e=c+8|0;Eh(e,b);Dd(a,e);break a}XR(b)}hb=c+16|0;return d|0}function Uc(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=-32768;x[b+4>>2]=32767;a=w[Bf(b+8|0,be(b+12|0,b+4|0))>>1];hb=b+16|0;return a}function SD(a){var b=0,c=0,d=0;c=hb-16|0;hb=c;d=hb-16|0;hb=d;while(1){mf(a+b|0);b=b+1|0;if((b|0)!=256){continue}break}hb=d+16|0;hb=c+16|0}function MC(a){var b=0;b=x[a+4>>2];a=x[a>>2];x[114414]=0;a=O(252,a|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){return a}S(0)|0;zb();p()}function Fq(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;a:{if(Qb(b,3)){d=c+8|0;Tu(d,a);Dd(b,d);break a}v[c+7|0]=0;Th(a,3,c+7|0)}hb=c+16|0}function AQ(a){var b=0,c=0,d=0;c=hb-16|0;hb=c;d=hb-16|0;hb=d;while(1){mf(a+b|0);b=b+1|0;if((b|0)!=512){continue}break}hb=d+16|0;hb=c+16|0}function pQ(a){var b=0,c=0,d=0;c=hb-16|0;hb=c;d=hb-16|0;hb=d;while(1){mf(a+b|0);b=b+1|0;if((b|0)!=32){continue}break}hb=d+16|0;hb=c+16|0}function jla(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+16|0]=44;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=1042;x[c+4>>2]=2;Qr(a,b,c);hb=c+32|0}function gna(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+16|0]=44;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=1058;x[c+4>>2]=2;vs(a,b,c);hb=c+32|0}function fJ(a){var b=0,c=E(0);if(!a){return E(1)}if((a|0)>=-99999){b=+(a|0)*.0016609640474436812;c=E(jh(b-L(b+.5)))}else{c=E(0)}return c}function Vg(a){var b=0;b=x[a+4>>2];a=x[a>>2];x[114414]=0;a=O(32,a|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){return a}S(0)|0;zb();p()}function Ud(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=zm(c+8|0,b);oD(d,a);Ab(d);hb=c+16|0;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;return a}function Qja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=hb-16|0;hb=a;x[a+8>>2]=x[d>>2];c=z[x[a+8>>2]>>1];w[b+2>>1]=0;w[b>>1]=c;hb=a+16|0}function Nha(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+16|0]=44;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=1042;x[c+4>>2]=2;Iu(a,b,c);hb=c+32|0}function Lga(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+16|0]=44;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=1058;x[c+4>>2]=3;$Q(a,b,c);hb=c+32|0}function Eb(a){var b=0;b=x[a+4>>2];a=x[a>>2];x[114414]=0;a=O(37,a|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){return a}S(0)|0;zb();p()}function x0(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+16|0]=44;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=1025;x[c+4>>2]=2;Qr(a,b,c);hb=c+32|0}function sna(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+16|0]=44;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=274;x[c+4>>2]=0;Iu(a,b,c);hb=c+32|0}function mU(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+16|0]=44;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=1025;x[c+4>>2]=2;Iu(a,b,c);hb=c+32|0}function g1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=x[b>>2]+7&-8;x[c>>2]=b+16;d=a,e=Jw(x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2]),C[d>>3]=e}function eja(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+16|0]=44;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=257;x[c+4>>2]=0;Fw(a,b,c);hb=c+32|0}function Yd(a,b){a=a|0;b=b|0;return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|0}function Yc(a,b){var c=0,d=0,e=0;c=Yf(a,b);if(c){x[a+12>>2]=x[a+12>>2]+b;return c}d=a,e=mb[x[x[a>>2]+24>>2]](a)|0,x[d+12>>2]=e;return c}function XR(a){var b=0,c=0,d=0;c=hb-16|0;hb=c;d=hb-16|0;hb=d;while(1){mf(a+b|0);b=b+1|0;if((b|0)!=4){continue}break}hb=d+16|0;hb=c+16|0}function Vz(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+16|0]=44;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=1058;x[c+4>>2]=2;$Q(a,b,c);hb=c+32|0}function Ut(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+16|0]=44;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=1058;x[c+4>>2]=2;eI(a,b,c);hb=c+32|0}function S2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-32|0;hb=g;h=g+8|0;pI(h,b,c,d,e,f);Jd(a,h);Ul(h);hb=g+32|0}function Ru(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;a:{if(Qb(b,2)){d=c+8|0;hl(d,a);Dd(b,d);break a}v[c+7|0]=0;EB(a,c+7|0)}hb=c+16|0}function G9(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+16|0]=44;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=1058;x[c+4>>2]=1;Qr(a,b,c);hb=c+32|0}function EO(a){var b=0;b=x[a+16>>2];a=x[a+32>>2];b=yna(b,b>>31,a,a>>31);a=lb;b=b+5e5|0;a=b>>>0<5e5?a+1|0:a;return Cc(zna(b,a,1e6,0),lb)}function DW(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+16|0]=44;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=1058;x[c+4>>2]=2;Fw(a,b,c);hb=c+32|0}function DO(a){var b=0;b=x[a+16>>2];a=x[a+36>>2];b=yna(b,b>>31,a,a>>31);a=lb;b=b+5e5|0;a=b>>>0<5e5?a+1|0:a;return Cc(zna(b,a,1e6,0),lb)}function C0(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+16|0]=44;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=1025;x[c+4>>2]=4;Qr(a,b,c);hb=c+32|0}function Qs(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=(b|0)!=0&(c|0)!=0;if(e){v[d+15|0]=0;UI(a+36|0,b,Gl(b,b+c|0,d+15|0))}hb=d+16|0;return e}function EW(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+16|0]=44;x[c+8>>2]=-1;x[c+12>>2]=0;x[c>>2]=290;x[c+4>>2]=0;Fw(a,b,c);hb=c+32|0}function w8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Zd(c&255))){aK(a,8,E(0))}a=sj(a);if(a){mb[x[x[a>>2]+88>>2]](a,b,c,d,e)}}function iE(a){var b=0,c=0,d=0;c=Rb(a);b=Bb(a);a=hb-16|0;hb=a;v[a+15|0]=0;d=-1;if(b){b=qo(c,b,a+15|0);d=b?b-c|0:-1}hb=a+16|0;return d}function dB(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;hb=b+16|0}function VV(a,b){a=a|0;b=b|0;x[b>>2]=0;x[b+4>>2]=0;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;eD(b)}function Ov(a,b,c,d,e,f){var g=0,h=0;g=x[a+4>>2];h=g>>8;if(g&1){h=Rv(x[d>>2],h)}a=x[a>>2];mb[x[x[a>>2]+20>>2]](a,b,c,d+h|0,g&2?e:2,f)}function Gf(a){var b=0,c=0;b=hb-16|0;hb=b;if(Zq(a,b+8|0)){a=b+8|0;c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24)}hb=b+16|0;return c}function pE(a,b,c){var d=0;d=hb-16|0;hb=d;a:{if(!(y[b+120|0]|c>>>0>30)){v[b+120|0]=1;break a}b=tE(c)}hb=d+16|0;x[a+4>>2]=c;x[a>>2]=b}function gH(a,b){a:{if(y[a+23|0]){a=1;if((b|0)!=255){break a}ea(9933,9049,1180,2220);p()}if((b|0)==255){return 0}a=b>>>0>10}return a}function ff(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;x[f+12>>2]=c;x[f+8>>2]=e;c=Hh(f,f+12|0);a=Ir(a,b,d,x[f+8>>2]);Ne(c);hb=f+16|0;return a}function bC(a){var b=0,c=0;b=yna(y[a+111|0],0,1536,0);c=lb;a=yna(y[a+110|0],0,25,0);b=b+a|0;c=lb+c|0;lb=a>>>0>b>>>0?c+1|0:c;return b}function sW(){var a=0,b=0;a=hb-16|0;hb=a;x[a+8>>2]=19469590;a:{if(ED(a+8|0)){break a}if(DD()){break a}b=CD()^1}hb=a+16|0;return b|0}function e2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b>>2];x[a>>2]=d;x[x[d-12>>2]+a>>2]=x[b+4>>2];ms(x[x[a>>2]-12>>2]+a|0,c);return a|0}function cs(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=x[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=x[c>>2];x[a>>2]=d<<b;x[a+4>>2]=c<<b|d>>>32-b}function Ew(a){a=a|0;var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+1;return Wg(v[b|0])|0}function es(a,b){var c=0,d=0;c=x[a+4>>2];a:{if(b>>>0<=31){d=x[a>>2];break a}b=b-32|0;d=c;c=0}x[a+4>>2]=c>>>b;x[a>>2]=c<<32-b|d>>>b}function XV(a,b,c){a=a|0;b=b|0;c=c|0;if(BD(c)){x[114414]=0;_b(a);a=x[114414];x[114414]=0;if((a|0)==1){S(0)|0;zb();p()}return}_b(a)}function Ko(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;b=fi(c,b);d=hb-16|0;hb=d;mr(a,x[b>>2],x[b>>2]+Vg(b)|0);hb=d+16|0;hb=c+16|0}function Ig(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;if(b>>>0>=110){Zi(7941);p()}d=c+8|0;Kb(d,a,b);he(d,0);hb=c+16|0;return a|0}function pr(a,b,c,d,e){var f=0,g=0;f=x[a+4>>2];g=f>>8;if(f&1){g=Rv(x[c>>2],g)}a=x[a>>2];mb[x[x[a>>2]+24>>2]](a,b,c+g|0,f&2?d:2,e)}function pS(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=hb-16|0;hb=a;x[a+8>>2]=x[d>>2];w[b>>1]=z[x[a+8>>2]>>1];hd(b+4|0);hb=a+16|0}function eV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;return(c=Cna(0-Cna(b^1230262859,25)|0,4)^1247037516,d=b,e=(a&4088)>>>0>=520,e?c:d)|0}function Vv(a,b){a=ln(a);x[a>>2]=75048;x[114414]=0;O(2894,a+4|0,b|0)|0;b=x[114414];x[114414]=0;if((b|0)!=1){return a}Q(N()|0);p()}function AD(a){a=a|0;var b=0;a=hd(a);x[114414]=0;O(206,a|0,9498)|0;b=x[114414];x[114414]=0;if((b|0)==1){b=N()|0;xb(a);Q(b|0);p()}}function XY(a){a=a|0;var b=0,c=0;b=x[x[a>>2]>>2];c=x[b+8>>2];a=x[b+4>>2];b=x[b>>2]+(c>>1)|0;if(c&1){a=x[a+x[b>>2]>>2]}mb[a|0](b)}function Q8(a){a=a|0;a=hb-16|0;hb=a;x[a+8>>2]=1869112133;hb=a+16|0;a=a+8|0;return y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24)}function sj(a){var b=0,c=0;b=Sj(x[a+20>>2]);if(!(b>>>0>249|y[a+4200|0]>=b>>>0)){c=x[(x[a+16>>2]+D(b,160)|0)+906300>>2]}return c}function rE(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;e=d,f=At(b),x[e+12>>2]=f;e=d,f=At(c),x[e+8>>2]=f;ym(a,d+12|0,d+8|0);hb=d+16|0}function qF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=Hr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function nF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=Fr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function Xw(a,b,c){var d=0;d=x[a+32>>2];if(A[a+40>>2]<d+c>>>0){x[a+96>>2]=1;return 0}sc(b,d,c);x[a+32>>2]=x[a+32>>2]+c;return 1}function S1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=mx(a+8|0,b,c,d,2);if(a>>>0<16){a=y[a+35904|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function R1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=mx(a+8|0,b,c,d,3);if(a>>>0<43){a=y[a+35856|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function QN(a,b,c){a=a|0;b=b|0;c=c|0;if((b|0)!=(c|0)){while(1){PN(a,y[b|0]);b=b+1|0;if((c|0)!=(b|0)){continue}break}}return a|0}function OY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){x[d>>2]=v[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function HQ(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=jl(c+8|0,b);oD(d,a);Ab(d);hb=c+16|0;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function ES(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;f=b;b=c-b|0;d=Bg(d,f,b);x[e+12>>2]=c;x[e+8>>2]=b+d;gd(a,e+12|0,e+8|0);hb=e+16|0}function Ct(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;e=d,f=At(b),x[e+12>>2]=f;e=d,f=At(c),x[e+8>>2]=f;gd(a,d+12|0,d+8|0);hb=d+16|0}function Ab(a){var b=0;a=x[a+4>>2];if(a){if(Am(a)){a:{b=a+8|0;if(x[b>>2]){if((uv(b)|0)!=-1){break a}}mb[x[x[a>>2]+16>>2]](a)}}}}function nf(a,b){var c=0;c=hb-16|0;hb=c;B[c+8>>2]=1;B[c+12>>2]=b;B[c+4>>2]=a;a=B[oA(c+4|0,c+12|0,c+8|0)>>2];hb=c+16|0;return a}function GY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function $N(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(b){ae(b,a)}if(c){ae(c,a)}if(d){ae(d,a)}if(e){ae(e,a)}}function pX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(tg(a,x[b+8>>2],0)){Sv(b,c,d);return}a=x[a+8>>2];mb[x[x[a>>2]+28>>2]](a,b,c,d)}function W0(a){a=a|0;var b=0;if((mb[x[x[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=x[a+12>>2];x[b+12>>2]=a+1;return Wg(v[a|0])|0}function QK(a){var b=0,c=0;if(x[a>>2]){hg(a);xS(a);_R(a);su(yb(a),x[a>>2],Vi(a));b=yb(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function Nk(a,b){var c=0;a:{if(A[a+12>>2]<b>>>0){c=0;if(mb[x[x[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}x[a+12>>2]=b;c=1}return c}function Kba(a){a=a|0;x[a>>2]=0;Jj(a+4|0);x[a+152>>2]=0;x[a+156>>2]=0;x[a+144>>2]=0;x[a+148>>2]=0;Sb(a+16|0,0,128);return a|0}function Fk(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=x[b>>2];x[d+8>>2]=x[b+4>>2];dd(a,c,x[Mb(d+12|0,d+8|0)>>2]);hb=d+16|0}function DD(){var a=0,b=0,c=0;a=hb-16|0;hb=a;b=Ub(a,10486);if(Bb(b)){c=(Zf(b,9659)|0)!=-1}else{c=0}xb(b);hb=a+16|0;return c|0}function v1(a){a=a|0;var b=0;if(!a){return-2}b=x[a+28>>2];if(!b){return 0}mb[x[a+36>>2]](x[a+40>>2],b);x[a+28>>2]=0;return 0}function rF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]>>2]](a+8|0)|0;a=Hr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function oF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]>>2]](a+8|0)|0;a=Fr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function nG(a){x[a>>2]=59272;bw(a+4|0);x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function Zr(a){x[a>>2]=59112;bw(a+4|0);x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function Wf(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=Ng(d,a);return((Ng(d,a+1|0)<<8|e<<16|Ng(d,a+2|0))<<(b&7)&16777215)>>>24-c|0}function TV(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;a=Eo(a);x[a>>2]=76028;c=fq(ic(a)),d=76068,x[c>>2]=d;hb=b+16|0;return a|0}function Of(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return zn(a,d)}function Du(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;if(Lq(a,b+8|0)){a=y[b+8|0]|y[b+9|0]<<8;c=a<<8|a>>>8}hb=b+16|0;return c&65535}function oc(a,b){var c=0;a=ln(a);x[a+4>>2]=0;x[a>>2]=82436;c=sd(Bb(b)+1|0);x[a+4>>2]=c;if(c){sc(c,Rb(b),Bb(b)+1|0)}return a}function oJ(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=fg(b-24|0);if((c|0)!=(b|0)){continue}break}return xf(a)|0}function no(a,b){var c=0;a:{if(!b){break a}if(!Qb(a,b)){break a}if(b>>>0<=3){c=eC(a,b);break a}c=Gf(a);cc(a,b-4|0)}return c}function Zu(a,b){var c=0;a:{if(!b){break a}if(!Qb(a,b)){break a}if(b>>>0<=1){c=dC(a,1);break a}c=pg(a);cc(a,b-2|0)}return c}function Tt(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=x[Mb(b+12|0,b+8|0)>>2];hb=b+16|0;return a|0}function Ts(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=c+b;if(b*1e-7<c){continue}break}return+b}function Sj(a){a=a+28|0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))>>>0>=128){a=y[a|0]^-128}else{a=255}return a&255}function KK(a){a=a|0;var b=0,c=0;b=Ae(a);while(1){c=b;if(c&65535){b=c-1|0;if(!kg(a,b&65535)){continue}}break}return c&65535}function dy(a,b){var c=0;if(!(y[a|0]!=y[b|0]|C[a+8>>3]!=C[b+8>>3]|y[a+16|0]!=y[b+16|0])){c=x[a+20>>2]==x[b+20>>2]}return c}function Fz(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function CO(a){a=a|0;x[a+700>>2]=0;w[a+862>>1]=0;x[a+688>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0}function yo(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=x[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}x[a>>2]=b}}function jK(a,b,c){var d=0;b=b-a>>2;if((b|0)>0){while(1){x[a>>2]=x[c>>2];a=a+4|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function cw(a,b,c){c=x[c>>2];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=x[a>>2]){break a}}else{a=b}return a}a=a+4|0;continue}}function _d(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=x[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}x[a>>2]=b}}function J2(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;c=hb-16|0;hb=c;x[c+12>>2]=y[b|0];wx(a,c+12|0);hb=c+16|0;hb=d+16|0}function z4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=hb-16|0;hb=a;x[a+8>>2]=x[d>>2];Wb(Jd(b,x[a+8>>2])+12|0);hb=a+16|0}function z0(a){a=a|0;var b=0;if((mb[x[x[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=x[a+12>>2];x[b+12>>2]=a+4;return x[a>>2]}function nO(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){kO(a,1);kO(a,0)}}function mO(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){jO(a,1);jO(a,0)}}function kG(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+4;return x[b>>2]}function Ne(a){a:{a=x[a>>2];if(a){x[114414]=0;jw(a);a=x[114414];x[114414]=0;if((a|0)==1){break a}}return}S(0)|0;zb();p()}function NU(a){a=a|0;var b=0;a:{if(!ne(-1,x[a+76>>2])){a=x[a+76>>2];break a}b=a;a=kF(a,32);x[b+76>>2]=a}return a<<24>>24}function Ak(a,b,c){var d=0;d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;ay(a,c)}function Ho(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=d+8|0;Ko(e,fi(d,b));vv(a,e);x[a+12>>2]=c;x[a+8>>2]=0;hb=d+16|0;return a}function ye(a){var b=0;b=x[a+32>>2];a:{if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1;a=0;break a}x[a+32>>2]=b+1;a=y[b|0]}return a}function vK(a,b){var c=0,d=0;c=hb-16|0;hb=c;b=ac(c,b);d=hb-16|0;hb=d;mr(a,x[b>>2],x[b>>2]+Eb(b)|0);hb=d+16|0;hb=c+16|0}function VO(a){var b=0,c=0,d=0;b=a+68|0;c=y[b+1|0]<<8;if(!(!(y[b|0]|c)|(c|y[b|0])>>>0>127)){d=!cd(a,13538,17)}return d}function TW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return mb[a|0](h|b,c,d,e,b|f,g)|0}function LT(a){var b=0,c=0;a:{if(cd(a,23460,20)){break a}b=a+25|0;if(!y[b|0]|y[b|0]>8){break a}c=v[a+47|0]>=0}return c}function HA(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=65535;a=z[Mb(b+12|0,b+8|0)>>1];hb=b+16|0;return a|0}function Bs(a,b,c){var d=0;b=b-a|0;if((b|0)>0){while(1){v[a|0]=y[c|0];a=a+1|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function zp(a){var b=0;a:{if(!(y[a+480208|0]&16)){break a}if(!$b(a+1074312|0,7)){break a}b=x[a+480180>>2]!=4}return b}function xp(a,b,c){a:{x[114414]=0;T(27,b|0,D(c,24)|0,8);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function vR(a){a=a|0;var b=0;b=hb-16|0;hb=b;w[b+14>>1]=a;w[b+12>>1]=255;a=y[Cf(b+14|0,b+12|0)|0];hb=b+16|0;return a|0}function oy(a,b,c){a:{x[114414]=0;T(27,b|0,D(c,52)|0,4);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function nT(a,b,c){a:{x[114414]=0;T(27,b|0,D(c,48)|0,4);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function gB(a,b){a=a|0;b=b|0;var c=0;c=x[b+4>>2];if(c){jc(a,c,x[b>>2]);return}b=b+8|0;if(!od(b)){ej(a,b);return}Do(a)}function aq(a,b,c){a:{x[114414]=0;T(27,b|0,D(c,20)|0,4);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function Xj(a,b,c){var d=0,e=0;e=a+24|0;a=hb-16|0;hb=a;if(b>>>0>=12){Zi(7976);p()}d=a+8|0;ol(d,e,b);he(d,c);hb=a+16|0}function RR(a,b,c){a:{x[114414]=0;T(27,b|0,D(c,33)|0,1);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function It(a,b,c){a:{x[114414]=0;T(27,b|0,D(c,56)|0,4);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function Ih(a,b,c){a:{x[114414]=0;T(27,b|0,D(c,12)|0,4);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function Hf(a,b,c){a:{x[114414]=0;T(27,b|0,D(c,24)|0,4);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function su(a,b,c){a:{x[114414]=0;T(27,b|0,D(c,6)|0,1);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function lP(a){var b=0,c=0;b=y[a+33|0];c=b>>>24|0;a=y[a+31|0]?1120:1056;b=a+(b<<8)|0;lb=a>>>0>b>>>0?c+1|0:c;return b}function lI(a,b){a:{x[114414]=0;T(27,a|0,D(b,324)|0,4);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function Tb(a,b){var c=0,d=0;c=x[b>>2];d=c+x[a>>2]|0;b=x[a+4>>2]+x[b+4>>2]|0;x[a>>2]=d;x[a+4>>2]=d>>>0<c>>>0?b+1|0:b}function Jk(a,b){a=a+58|0;if(v[gc(a,b)|0]<0){return 255}if(y[gc(a,b)|0]!=255){a=y[gc(a,b)|0]&127}else{a=255}return a}function gl(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=255;a=y[Mb(b+12|0,b+8|0)|0];hb=b+16|0;return a|0}function RF(a,b,c,d,e,f,g,h,i){x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function p8(a){a=a|0;var b=0,c=0;x[x[a+20>>2]>>2]=a;c=x[a+12>>2];b=x[c>>2];x[a+4>>2]=b;if(b){x[b+8>>2]=a}x[c>>2]=a}function YG(a,b,c){var d=0,e=0,f=0;e=c*c;C[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;C[b>>3]=d*d+((c+c)*d+(c*c-e))}function Th(a,b,c){a=a|0;b=b|0;c=c|0;if(b){while(1){v[a|0]=y[c|0];a=a+1|0;b=b-1|0;if(b){continue}break}}return a|0}function TT(a,b,c,d,e){v[a+4|0]=b;v[a|0]=69;v[a+1|0]=99;v[a+2|0]=104;v[a+3|0]=111;v[a+7|0]=e;v[a+6|0]=d;v[a+5|0]=c}function Cja(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;if(Lq(a,b+8|0)){c=y[b+8|0]|y[b+9|0]<<8}hb=b+16|0;return c<<16>>16}function xJ(a){a=a|0;x[a+4244>>2]=0;x[a+4248>>2]=0;x[a+4228>>2]=0;x[a+4232>>2]=0;a=a+4252|0;x[a>>2]=0;x[a+4>>2]=0}function oG(a,b){a=a|0;b=b|0;var c=0;c=x[a>>2];a:{if(!c){break a}if(!ne(tG(c,b),-1)){break a}x[a>>2]=0}return a|0}function nR(a){var b=0,c=0;if(x[a>>2]){MR(a);av(yb(a),x[a>>2],vd(a));b=yb(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function hO(a){var b=0,c=0;if(x[a>>2]){wq(a);vo(yb(a),x[a>>2],Vf(a));b=yb(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function fN(a,b){var c=0;c=b&15;if(c){v[a+847|0]=c<<2}b=b&240;if(b){v[a+846|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|262144}function cK(a,b,c){a:{x[114414]=0;T(27,b|0,c<<11,4);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function U8(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=CM(E(c*E(255))),v[d|0]=e;Ns(a)}}function Oy(a){var b=0,c=0;if(x[a>>2]){jt(a);ag(yb(a),x[a>>2],pf(a));b=yb(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function Naa(a,b){a=a|0;b=b|0;v[b+38|0]=y[a+202|0];v[b+39|0]=y[a+203|0];v[b+40|0]=y[a+204|0];v[b+41|0]=y[a+205|0]}function Ek(a,b){var c=0;c=b&15;if(c){v[a+844|0]=c<<2}b=b&240;if(b){v[a+843|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|131072}function wv(a,b,c){a:{x[114414]=0;T(27,b|0,c<<3,1);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function vo(a,b,c){a:{x[114414]=0;T(27,b|0,c<<1,2);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function pO(a){var b=0,c=0;b=a+68|0;a=0;while(1){c=(a<<2)+b|0;a=a+1|0;x[c>>2]=a<<11;if((a|0)!=9){continue}break}}function nN(a){var b=0;x[114414]=0;a=R(1262,a|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){S(0)|0;zb();p()}return a}function jL(a){if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179011410){a=zz(a)>>>0>80}else{a=0}return a}function hm(a,b,c){a:{x[114414]=0;T(27,b|0,c<<1,1);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function hI(a){var b=0;x[114414]=0;a=R(2235,a|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){S(0)|0;zb();p()}return a}function di(a,b,c){a:{x[114414]=0;T(27,b|0,c<<4,4);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function cW(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a=Eo(a);x[a>>2]=75924;mD(ic(a),fi(c,b));hb=c+16|0;return a|0}function av(a,b,c){a:{x[114414]=0;T(27,b|0,c<<2,2);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function _g(a,b,c){a:{x[114414]=0;T(27,b|0,c<<5,4);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function Xe(a,b,c){a:{x[114414]=0;T(27,b|0,c<<2,4);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function Qt(a,b,c){a:{x[114414]=0;T(27,b|0,c<<5,8);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function Kh(a,b,c){x[114414]=0;U(2365,b|0,c|0,a|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){return}S(0)|0;zb();p()}function Ij(a,b,c){a:{x[114414]=0;T(27,b|0,c<<2,1);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function C4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=mb[x[x[b>>2]+8>>2]](b)|0;d=c,e=Ld(a?a:17386),x[d>>2]=e}}function q6(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;c=Ub(b,8336);a=oc(a,c);xb(c);x[a>>2]=82396;hb=b+16|0;return a|0}function it(a){var b=0;b=1;a:{switch(y[a+3|0]-4|0){default:b=y[a+2|0]==11;break;case 0:case 2:break a}}return b}function ch(a){a:{a=x[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function ag(a,b,c){a:{x[114414]=0;T(27,b|0,c|0,1);a=x[114414];x[114414]=0;if((a|0)!=1){break a}S(0)|0;zb();p()}}function a6(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;c=Ub(b,4396);a=oc(a,c);xb(c);x[a>>2]=82416;hb=b+16|0;return a|0}function X$(a,b){a=a|0;b=b|0;var c=0,d=0;mb[x[x[a>>2]+24>>2]](a)|0;b=yw(b);x[a+36>>2]=b;c=a,d=Xm(b),v[c+44|0]=d}function Q$(a,b){a=a|0;b=b|0;var c=0,d=0;mb[x[x[a>>2]+24>>2]](a)|0;b=rw(b);x[a+36>>2]=b;c=a,d=Xm(b),v[c+44|0]=d}function MT(a){var b=0;x[114414]=0;a=R(498,a|0)|0;b=x[114414];x[114414]=0;if((b|0)==1){S(0)|0;zb();p()}return a}function Gn(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=x[a>>2];x[c+8>>2]=x[c+8>>2]+(b<<2);hb=c+16|0;return x[c+8>>2]}function EI(a){var b=0;a:{while(1){if(!x[(b<<2)+a>>2]){break a}b=b+1|0;if((b|0)!=4){continue}break}b=4}return b}function wba(a,b){a=a|0;b=b|0;if(b>>>0>255){return 17386}a=x[((b<<2)+a|0)+900380>>2];return(a?a+492|0:17386)|0}function vu(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=(D(a,b)>>>0)/255;_d(c+12|0,0,15);hb=c+16|0;return y[c+12|0]}function tg(a,b,c){if(!c){return x[a+4>>2]==x[b+4>>2]}if((a|0)==(b|0)){return 1}return!pj(x[a+4>>2],x[b+4>>2])}function he(a,b){var c=0;c=x[a+4>>2];if(b){a=x[a>>2];x[a>>2]=x[a>>2]|c;return}a=x[a>>2];x[a>>2]=x[a>>2]&(c^-1)}function Qj(a){a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function Le(a,b,c){x[114414]=0;U(23,b|0,c|0,a|0)|0;a=x[114414];x[114414]=0;if((a|0)!=1){return}S(0)|0;zb();p()}function DK(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=32767;a=w[Mb(b+12|0,b+8|0)>>1];hb=b+16|0;return a}function zL(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+736|0;case 1:break a}}return a+748|0}function rn(a){var b=0;while(1){if(y[b+35920|0]==(a|0)){return b}b=b+1|0;if(b>>>0<43){continue}break}return 0}function eE(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if(b){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}return a|0}function Xd(a){a=a|0;var b=0;b=x[15040];x[a>>2]=b;x[x[b-12>>2]+a>>2]=x[15043];ls(a+4|0);gh(a+56|0);return a|0}function PQ(a,b){v[a+6|0]=255;x[a+16>>2]=0;w[a+4>>1]=0;x[a>>2]=0;if(!(b<0)){C[a+8>>3]=b;x[a+16>>2]=3}return a}function Lf(a){a=a|0;var b=0;b=x[15085];x[a>>2]=b;x[x[b-12>>2]+a>>2]=x[15088];ls(a+8|0);gh(a+60|0);return a|0}function zR(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;w[c+14>>1]=b;if((zu(a)|0)!=65535){pB(a,c+14|0)}hb=c+16|0}function uG(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+36>>2]](a)|0}return Wg(v[b|0])}function pF(a,b,c,d,e){b=ji(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function mF(a,b,c,d,e){b=ii(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function Rp(a,b){a=a|0;b=b|0;if(qc(a)>>>0>b>>>0){a=kg(x[a+24>>2]+484344|0,z[Pj(a,b)>>1])}else{a=0}return a|0}function uH(a,b,c,d){B[d+4>>2]=c+a;a=E(a+E(c*E(-.5)));b=E(b*E(.8660253882408142));B[d+8>>2]=a-b;B[d>>2]=a+b}function oA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;if(!fu(a,b)){b=fu(c,a)?c:a}hb=d+16|0;return b|0}function mh(a,b){var c=0;c=a;b=x[a+16>>2]+b|0;a=x[a+12>>2];b=(b|0)%(a|0)|0;return B[Ec(c,(b>>31&a)+b|0)>>2]}function dl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;if(!Bq(a,b)){b=Bq(c,a)?c:a}hb=d+16|0;return b|0}function bv(a,b){var c=0,d=0;d=x[b>>2];c=x[a+4>>2];b=x[b+4>>2];return(c|0)==(b|0)&A[a>>2]<d>>>0|b>>>0>c>>>0}function UP(a,b){var c=0;c=hb-16|0;hb=c;a=Ib(dd(c+8|0,x[a>>2]+(b>>>3&536870908)|0,1<<b));hb=c+16|0;return a}function wt(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=x[a>>2];x[c>>2]=x[b>>2];a=Hb(c+8|0,c);hb=c+16|0;return a}function vna(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(Tj(a,b+8|0)){c=$T(b+8|0)}hb=b+16|0;return c|0}function kd(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=x[a>>2];x[c>>2]=x[b>>2];a=bd(c+8|0,c);hb=c+16|0;return a}function dx(a,b){var c=0;c=(D(D(bx(a),cx(a)),125)>>>0)/(BH(a)>>>0)|0;a=(y[a+1|0]&6)==6?c&-4:c;return a?a:b}function Xu(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function WQ(a,b){var c=0,d=0;c=hb-16|0;hb=c;a:{if(Yf(a,4)){d=c+8|0;Eh(d,b);Hz(a,d);break a}XR(b)}hb=c+16|0}function Pja(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(Tj(a,b+8|0)){c=eR(b+8|0)}hb=b+16|0;return c|0}function Oma(a,b){a=a|0;b=b|0;var c=0;b=hb-80|0;hb=b;c=-1;if(HT(a,b+8|0)){c=GT(b+8|0)}hb=b+80|0;return c|0}function Fe(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=x[a>>2];x[c+8>>2]=x[c+8>>2]+b;hb=c+16|0;return x[c+8>>2]}function Ap(a){var b=0,c=0,d=0;b=a;a=x[a>>2];c=b,d=Cb(D(a,214013)+2531011|0),x[c>>2]=d;return a>>>16&32767}function sE(a,b){x[114414]=0;T(27,a|0,b<<2,4);a=x[114414];x[114414]=0;if((a|0)!=1){return}S(0)|0;zb();p()}function pg(a){var b=0,c=0;b=hb-16|0;hb=b;if(Lq(a,b+8|0)){a=b+8|0;c=y[a|0]|y[a+1|0]<<8}hb=b+16|0;return c}function lG(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+36>>2]](a)|0}return x[b>>2]}function St(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;km(c+8|0,a);x[c+4>>2]=x[c+8>>2];Rt(c+4|0,b);hb=c+16|0}function Q3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;e=d+8|0;Ko(e,fi(d,b));Ho(a,e,c);hb=d+16|0}function Jd(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];Dm(b);re(a);return a}function GX(a){a=a|0;a=hb-16|0;hb=a;if(La(a+12|0,4)|0){qr(x[114240],8482);p()}hb=a+16|0;return x[a+12>>2]}function GT(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179468868&(y[a+4|0]-1&255)>>>0<10}function GE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;x[e>>2]=c;x[h>>2]=f;return 3}function AV(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(Tj(a,b+8|0)){c=LC(b+8|0)}hb=b+16|0;return c|0}function qg(a,b){var c=0,d=0;c=x[a>>2];d=x[b>>2];lb=x[a+4>>2]-(x[b+4>>2]+(c>>>0<d>>>0)|0)|0;return c-d|0}function jw(a){a=a|0;var b=0;b=x[114284];if(a){x[114284]=(a|0)==-1?457016:a}return((b|0)==457016?-1:b)|0}function ZN(a){w[a+70>>1]=y[((z[x[a+4>>2]+22>>1]<<4|z[x[a+4>>2]+20>>1]>>>6)&65535)+25600|0]>>>z[a+68>>1]}function Rh(a,b,c){var d=0,e=0,f=0,g=0;d=C[c>>3];e=C[b>>3];f=C[c+8>>3];g=C[b+8>>3];Vl(a,d*e-f*g,e*f+d*g)}function ZY(){if(y[461052]){return x[115262]}So(461044,ME());v[461052]=1;x[115262]=461044;return 461044}function T0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return mb[x[x[a>>2]+16>>2]](a,b,c,d,e,f)|0}function R0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return mb[x[x[a>>2]+24>>2]](a,b,c,d,e,f)|0}function O0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return mb[x[x[a>>2]+28>>2]](a,b,c,d,e,f)|0}function L0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return mb[x[x[a>>2]+44>>2]](a,b,c,d,e,f)|0}function Fo(a,b,c){var d=0;d=hb-16|0;hb=d;a=Do(a);x[a+4>>2]=c;x[a>>2]=b;x[d+4>>2]=b;x[d>>2]=b;hb=d+16|0}function F0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0}function vr(){var a=0;x[114414]=0;a=x[114414];x[114414]=0;if((a|0)!=1){return x[15458]}S(0)|0;zb();p()}function ur(){var a=0;x[114414]=0;a=x[114414];x[114414]=0;if((a|0)!=1){return x[15844]}S(0)|0;zb();p()}function nL(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){a=mc(a);if(y[a+4|0]){aw(x[a>>2],b+16|0)}if(b){oL(b)}}}function oL(a){x[114414]=0;T(27,a|0,28,4);a=x[114414];x[114414]=0;if((a|0)!=1){return}S(0)|0;zb();p()}function kN(a,b){var c=0,d=0;a:{if(b<0){break a}c=C[a>>3];if(!(c<0)){d=b;if(b>=c){break a}}C[a>>3]=d}}function cx(a){var b=0;b=y[a+1|0];return y[(D(b>>>1&3,15)+D(b>>>3&1,45)+(y[a+2|0]>>>4)|0)+39377|0]<<1}function Xy(a,b){if(kg(x[a+24>>2]+484344|0,b)){a=x[Zb(x[a+24>>2]+484344|0,b)+12>>2]}else{a=1}return a}function Sy(a){x[114414]=0;T(27,a|0,40,4);a=x[114414];x[114414]=0;if((a|0)!=1){return}S(0)|0;zb();p()}function um(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function sS(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){mS(c+52|0);xb(c+40|0);fg(c+16|0);fg(c+4|0);_b(c)}}function lB(a){var b=0;b=hb-16|0;hb=b;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;hb=b+16|0}function kV(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;Kq(d,a);Jq(d,b);hb=c+16|0;return a|0}function kM(a){x[a+20>>2]=0;v[a+16|0]=7;x[a+8>>2]=1889785610;x[a+12>>2]=1072630333;v[a|0]=3;return a}function hV(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;nC(d,a);Jq(d,b);hb=c+16|0;return a|0}function YU(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;_B(d,a);Jq(d,b);hb=c+16|0;return a|0}function VQ(a){w[a+10>>1]=0;w[a+12>>1]=0;w[a+8>>1]=1084;x[a>>2]=0;x[a+4>>2]=40;w[a+14>>1]=0;return a}function NE(a,b,c){var d=0;d=hb-16|0;hb=d;a:{if((a|0)==(b|0)){v[b+120|0]=0;break a}sE(b,c)}hb=d+16|0}function qO(a,b){var c=0,d=0;c=x[a+4>>2];d=x[b+4>>2];return(c|0)<=(d|0)&A[b>>2]>A[a>>2]|(c|0)<(d|0)}function Vma(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];a=NA(ge(b+8|0));hb=b+16|0;return a|0}function V8(a,b){a=a|0;b=b|0;return E((b|0)<=3?E(E(y[(a+b|0)+4264|0])*E(.003921568859368563)):E(0))}function Rk(a,b,c){a=a|0;b=b|0;c=c|0;a=td(a,b);b=x[c+4>>2];x[a+4>>2]=x[c>>2];x[a+8>>2]=b;return a|0}function Qha(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];a=xz(BP(b+8|0));hb=b+16|0;return a|0}function Hd(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=82480;x[b+8>>2]=82584;gd(a,b+12|0,b+8|0);hb=b+16|0}function BH(a){var b=0;b=x[(y[a+2|0]&12)+39380>>2];a=y[a+1|0]^-1;return b>>>(a>>>3&1)>>>(a>>>4&1)|0}function sr(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];a=Mm(_j(b+8|0));hb=b+16|0;return a|0}function ija(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(EA(a,b)){c=IQ(b)}hb=b+16|0;return c|0}function d9(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];a=Vx(fe(b+8|0));hb=b+16|0;return a|0}function bka(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;w[c+14>>1]=b;$z(a+236|0,128,c+14|0);hb=c+16|0}function ao(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];a=Xk(Xi(b+8|0));hb=b+16|0;return a|0}function aT(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];a=lu(of(b+8|0));hb=b+16|0;return a|0}function a2(a,b){a=a|0;b=b|0;a=Zr(a);x[a>>2]=59432;Wb(a+32|0);x[a+48>>2]=b;x[a+44>>2]=0;return a|0}function Yu(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=Xf(a,b+15|0);hb=b+16|0;return(a?v[b+15|0]:0)<<24>>24}function Y9(a,b){a=a|0;b=b|0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;_h(b)}function WC(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];a=$q(Ao(b+8|0));hb=b+16|0;return a|0}function Ph(a){var b=E(0),c=E(0);a:{b=B[a>>2];if(!(b<E(0))){c=E(1);if(b<=E(1)){break a}}B[a>>2]=c}}function MW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return mb[a|0](b,c,d,e,f,g)|0}function K9(a){a=a|0;var b=0;b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];a=Px(Zl(b+8|0));hb=b+16|0;return a|0}function Hg(a){var b=0;b=a+44|0;ml(b);if(x[b>>2]){MD(b,x[b>>2]);di(yb(b),x[b>>2],ei(b))}VC(a+32|0)}function A4(a,b){a=a|0;b=b|0;var c=0;c=x[a+4>>2];b=Rb(b);if(c){mb[c|0](b,x[a+8>>2]);return}Cs(b,a)}function uK(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=a;a=c+8|0;a=Gn(a,b-zt(a)>>2);hb=c+16|0;return a}function u8(a,b,c){a=a|0;b=b|0;c=c|0;a=sj(a);if(!a){return 0}return mb[x[x[a>>2]+96>>2]](a,b,c)|0}function qla(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;CS(c,b);a=Jd(a,c);xb(c);hb=c+16|0;return a|0}function kla(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;oC(c,a);a=yf(c,b);xb(c);hb=c+16|0;return a|0}function eha(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=a;x[b+8>>2]=x[c+8>>2]}function aj(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=xo(c+8|0,a,b);hb=c+16|0;return(d?b:a)|0}function Wu(a,b,c){var d=0;d=hb-16|0;hb=d;Zg(a,c);v[d+15|0]=0;Wd(b+c|0,d+15|0);hb=d+16|0;return a}function W1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;mb[x[x[b>>2]+8>>2]](b,c);d=a;a=b+4|0;So(d,a);JE(a,c)}function NJ(a){a=a|0;var b=0;b=x[a>>2];if(b){mb[x[x[b>>2]+8>>2]](b);x[a>>2]=0}a=a+4|0;jt(a);wR(a)}function Cf(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=xo(c+8|0,b,a);hb=c+16|0;return(d?b:a)|0}function nl(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=d+8|0;jc(e,Cb(b),c);a=aS(a,e);hb=d+16|0;return a}function VK(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=x[a>>2];FS(c+8|0,b);hb=c+16|0;return x[c+8>>2]}function GO(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=a;a=c+8|0;a=Fe(a,b-zt(a)|0);hb=c+16|0;return a}function xw(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+12>>2]=b;x[d+8>>2]=c;ym(a,d+12|0,d+8|0);hb=d+16|0}function vQ(a){var b=0,c=0;b=1;c=x[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}x[a>>2]=b}}function uD(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+12>>2]=b;x[d+8>>2]=c;gd(a,d+12|0,d+8|0);hb=d+16|0}function o0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mb[x[x[b>>2]+16>>2]](a,b,x[c+8>>2],x[c+12>>2],0,d)}function iX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(tg(a,x[b+8>>2],f)){Qv(b,c,d,e)}}function bV(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;if(Xf(a,b+8|0)){c=y[b+8|0]}hb=b+16|0;return c|0}function Uka(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=Zq(a,b+8|0);hb=b+16|0;return E(a?B[b+8>>2]:E(0))}function Qka(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[x[x[b>>2]+16>>2]](a,b,c,d,e,f)}function Qaa(a,b){a=a|0;b=b|0;Qh(a);Qh(a);a:{if(b>>>0>=60){cc(a,4);break a}Qh(a)}return Qh(a)|0}function Mu(a,b){a=a|0;b=b|0;var c=0;a=Lq(a,b);if(!a){c=hb-16|0;hb=c;Ou(b);hb=c+16|0}return a|0}function Bk(a,b,c){a=x[a>>2]+1074984|0;return x[(a+D(b,896)|0)+680>>2]>x[(a+D(c,896)|0)+680>>2]}function y7(a){a=a|0;var b=0,c=0;v[a+4202|0]=1;b=a,c=Ze(x[a+16>>2]),x[b+4256>>2]=c;vJ(a);uJ(a)}function xt(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=x[a+24>>2];d=a,e=gg(jh(b)*+(c>>>0)),x[d+24>>2]=e}function s8(a,b){a=a|0;b=b|0;b=hb-16|0;hb=b;ej(b,x[a+20>>2]+4|0);YJ(a,Ed(b+8|0,b),0);hb=b+16|0}function pH(a){var b=0;b=+((a&2097151)>>>0);return E(ok(+E((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function oea(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=a;a=Jd(c,b);st(d,a);xb(a);hb=c+16|0}function _v(a,b){a=a|0;b=b|0;var c=0;a:{c=Bb(a);if(c>>>0<b>>>0){Ip(a,b-c|0,0);break a}jC(a,b)}}function T8(a){a=a|0;var b=0,c=0;v[a+4202|0]=1;b=a,c=Ze(x[a+16>>2]),x[b+4232>>2]=c;Ns(a);lK(a)}function OA(a,b){var c=0;c=hb-16|0;hb=c;x[c>>2]=b;x[c+8>>2]=a;a=vq(c,c+8|0);hb=c+16|0;return a}function Cs(a,b){a=a|0;b=b|0;b=hb-16|0;hb=b;x[b>>2]=a;a=x[14652];ZG(a,13689,b);dn(a);hb=b+16|0}function AT(a,b){return(Xb((D(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Xb((D(a&15,b)>>>0)/15|0,1,15))&255}function xX(a,b,c){a=a|0;b=b|0;c=c|0;if(ne(a,x[b+4>>2])){a=x[b>>2]==(c|0)}else{a=0}return a|0}function x6(a,b,c){a=a|0;b=b|0;c=c|0;a=ux(a);x[a+8>>2]=c;x[a+4>>2]=b;x[a>>2]=82364;return a|0}function gk(a){var b=0;b=hb-16|0;hb=b;a=x[Fb(b+8|0,Rb(a)+(Bb(a)<<2)|0)>>2];hb=b+16|0;return a}function aP(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=D(c,12)+d;return a}function UR(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1279544644&y[a+4|0]<32}function UB(a){var b=0;a=y[a+35|0];b=(a<<11)+2624|0;a=a>>>21|0;lb=b>>>0<2624?a+1|0:a;return b}function UA(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=a;a=Ub(c,b);st(d,a);xb(a);hb=c+16|0}function H0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return mb[x[x[a>>2]+16>>2]](a,b,c,d,e)|0}function G0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return mb[x[x[a>>2]+24>>2]](a,b,c,d,e)|0}function Ff(a,b){x[a+8>>2]=x[a+8>>2]&-2147483648|b&2147483647;x[a+8>>2]=x[a+8>>2]|-2147483648}function Cd(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;PD(d,a+24|0,b);a=Ib(d);hb=c+16|0;return a}function yp(a,b,c){a=Ol(a)-x[a+1074392>>2]|0;if(a>>>0>=2){c=E(E(E(c-b)/E(a>>>0))+b)}return c}function uq(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=a;vm(b+8|0,c+8|0)}function rm(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=(c<<1)+d;return a}function qja(a,b){a=a|0;b=b|0;var c=0;a=hb-16|0;hb=a;c=b;b=ci(a);dR(c,b,0,0);Ab(b);hb=a+16|0}function mD(a,b){var c=0,d=0;a=fq(a);x[a>>2]=75964;x[a+4>>2]=x[b>>2];c=a,d=Vg(b),x[c+8>>2]=d}function bi(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=(c<<2)+d;return a}function JD(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=(c<<4)+d;return a}function HE(a){a=a|0;var b=0;x[a>>2]=65196;b=x[a+8>>2];if(!(!b|!y[a+12|0])){_b(b)}return a|0}function FF(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(x[b>>2]){continue}break}return b-a>>2}function E0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return mb[x[x[a>>2]+32>>2]](a,b,c,d,e)|0}function rc(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=QD(b,a);hb=c+16|0;return(d?b:a)|0}function jq(a,b){var c=0;c=Bb(a);if((c|0)==(Bb(b)|0)){a=on(Rb(a),Rb(b),c)}else{a=1}return!a}function ina(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;Kg(c,1,a);tC(c,b);hb=c+16|0;return a|0}function hna(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;Bu(c,1,a);tC(c,b);hb=c+16|0;return a|0}function cv(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=bv(b,a);hb=c+16|0;return(d?b:a)|0}function be(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Bq(b,a);hb=c+16|0;return(d?b:a)|0}function _c(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=ro(a,b);hb=c+16|0;return(d?b:a)|0}function Xg(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=QD(a,b);hb=c+16|0;return(d?b:a)|0}function Uia(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=qv(a,b+8|0);hb=b+16|0;return+(a?C[b+8>>3]:0)}function Qu(a,b,c){a=a|0;b=b|0;c=c|0;b=hb-16|0;hb=b;v[b+15|0]=y[c|0];sI(a,b+15|0);hb=b+16|0}function Qb(a,b){a=a|0;b=b|0;var c=0;c=x[a>>2];return mb[x[x[c>>2]+36>>2]](c,x[a+8>>2],b)|0}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;dt(a,b,c);hb=d+16|0;return a|0}function Mb(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=ro(b,a);hb=c+16|0;return(d?b:a)|0}function Ly(a){var b=0;x[a+72>>2]=0;x[a+76>>2]=0;b=x[a+68>>2];x[a+80>>2]=b;x[a+84>>2]=b<<12}function KC(a){a=a|0;var b=0;b=x[a>>2];return Cb((mb[x[x[b>>2]+20>>2]](b)|0)+x[a+8>>2]|0)|0}function Bf(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Bq(a,b);hb=c+16|0;return(d?b:a)|0}function $T(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==810369604&y[a+4|0]<4}function yi(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;VI(a,b,c);hb=d+16|0;return a|0}function yaa(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+38|0;ad(c,(y[a|0]|y[a+1|0]<<8)&4?16:8,1,0,0)}function y6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;cJ(a,b,c,d,e,0,0,f,g)}function taa(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+40|0;ad(c,(y[a|0]|y[a+1|0]<<8)&4?16:8,1,0,0)}function sJ(a,b){var c=0;c=x[a+12>>2];if((c|0)>0){x[a+20>>2]=(x[a+16>>2]+(b+c|0)|0)%(c|0)}}function ej(a,b){a=a|0;b=b|0;var c=0,d=0;x[a>>2]=x[b>>2];c=a,d=x[b>>2]+wc(b)|0,x[c+4>>2]=d}function eG(a){var b=0;b=x[a>>2];if(b){if(!ne(uG(b),-1)){return!x[a>>2]}x[a>>2]=0}return 1}function dG(a){var b=0;b=x[a>>2];if(b){if(!ne(lG(b),-1)){return!x[a>>2]}x[a>>2]=0}return 1}function cj(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function _O(a){var b=0;a=y[a+47|0];b=(a<<5)+259|0;a=a>>>27|0;lb=b>>>0<259?a+1|0:a;return b}function UW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=mb[a|0](b,c,d,e)|0;ib=lb;return a|0}function z8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=sj(a);if(a){mb[x[x[a>>2]+80>>2]](a,b,c,d)}}function x8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=sj(a);if(a){mb[x[x[a>>2]+84>>2]](a,b,c,d)}}function tf(a,b){var c=0;c=x[b+4>>2]+x[a+4>>2]|0;a=x[a>>2];lb=a+x[b>>2]>>>0<a>>>0?c+1|0:c}function mw(a,b,c,d){var e=0;e=hb-16|0;hb=e;x[e+12>>2]=d;a=Ir(a,b,c,d);hb=e+16|0;return a}function lv(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0>4){b=5654}else{b=x[(b<<2)+75524>>2]}Ub(a,b)}function lka(a,b,c){a=a|0;b=b|0;c=c|0;x[b>>2]=x[c>>2];w[b+4>>1]=z[c+4>>1];vm(b+8|0,c+8|0)}function k8(a,b,c){a=a|0;b=b|0;c=c|0;a=Ed(a,b);b=x[c+4>>2];x[a+8>>2]=x[c>>2];x[a+12>>2]=b}function df(a,b){var c=0;a=jl(a,b);c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;return a}function dH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;x[a>>2]=d;x[a+4>>2]=b-D(c,d)}function Z2(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;_B(d,b);Iq(a,d);hb=c+16|0}function SI(a){a=a|0;var b=0;x[a>>2]=82436;b=x[a+4>>2];if(b){_b(b);x[a+4>>2]=0}return a|0}function NW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;mb[a|0](b,c,d,e,f,g)}function Cna(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function A8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=sj(a);if(a){mb[x[x[a>>2]+76>>2]](a,b,c,d)}}function $J(a){a=a|0;var b=0;b=C[a+4264>>3]*+A[x[a+16>>2]+1074376>>2];C[a+4256>>3]=b-L(b)}function pe(a){var b=0;b=hb-16|0;hb=b;a=Xf(a,b+15|0);hb=b+16|0;return(a?y[b+15|0]:0)&255}function nM(a){a=hd(a);hd(a+12|0);hd(a+24|0);hd(a+36|0);hd(a+48|0);x[a+60>>2]=0;return a}function jf(a){var b=0;b=hb-16|0;hb=b;a=x[Fb(b+8|0,Rb(a)+Bb(a)|0)>>2];hb=b+16|0;return a}function fU(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;c=b+8|0;hB(c,a);hb=b+16|0;return x[c>>2]}function caa(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=4&(c|0)!=-1)){Ri(a,b);return}wE(a,b,c)}function JM(a,b){var c=0;c=y[a+872|0];if(c&1){v[a+872|0]=c|16;x[a+876>>2]=x[a+876>>2]+b}}function IE(){var a=0;a=Gd(462368);v[a+12|0]=0;x[a+8>>2]=0;x[a>>2]=65196;x[a+8>>2]=65248}function $z(a,b,c){if(b){while(1){w[a>>1]=z[c>>1];a=a+2|0;b=b-1|0;if(b){continue}break}}}function $b(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;EC(d,a,b);a=Ib(d);hb=c+16|0;return a}function zg(a,b,c){a=a|0;b=b|0;c=c|0;return(x[x[a+8>>2]+((c&255)<<2)>>2]&b)!=0&(c|0)>=0}function fi(a,b){var c=0,d=0;x[a>>2]=x[b>>2];c=a,d=x[b>>2]+Vg(b)|0,x[c+4>>2]=d;return a}function ac(a,b){var c=0,d=0;x[a>>2]=x[b>>2];c=a,d=x[b>>2]+Eb(b)|0,x[c+4>>2]=d;return a}function aR(a,b){var c=0,d=0;x[a>>2]=x[b>>2];c=a,d=x[b>>2]+XQ(b)|0,x[c+4>>2]=d;return a}function _h(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;return a}function PN(a,b){var c=0;b=Cb(b);c=a;a=x[a>>2];x[c>>2]=a<<8^x[((b^a>>>24)<<2)+86192>>2]}function JR(a,b,c){a=a|0;b=b|0;c=c|0;a=z[c>>1]|z[c+2>>1]<<16;w[b>>1]=a;w[b+2>>1]=a>>>16}function FV(a){a=a|0;var b=0;b=x[a+4>>2];return(mb[x[x[b>>2]+20>>2]](b)|0)+x[a+12>>2]|0}function Dt(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=c+d;return a}function C8(a,b){a=a|0;b=b|0;a=sj(a);if(!a){return 1}return mb[x[x[a>>2]+68>>2]](a,b)|0}function Am(a){var b=0;b=uv(a+4|0);if((b|0)==-1){mb[x[x[a>>2]+8>>2]](a)}return(b|0)==-1}function lf(a){var b=0;b=a+24|0;while(1){b=xb(b-12|0);if((b|0)!=(a|0)){continue}break}}function j_(a,b,c){a=a|0;b=b|0;c=c|0;c=Ew(x[b>>2]);x[a+4>>2]=x[b>>2];v[a|0]=c<<24>>24}
function Ub(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;dt(a,b,wf(b));hb=c+16|0;return a|0}function UN(a,b){return(a>>>0<=62?63-(D((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function GF(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=b;a=JF(a,7037,b);hb=c+16|0;return a}function Fm(a){var b=0;b=a+36|0;while(1){b=xb(b-12|0);if((b|0)!=(a|0)){continue}break}}function FD(a){var b=0;b=a+48|0;while(1){b=xb(b-12|0);if((b|0)!=(a|0)){continue}break}}function CZ(){var a=0;a=Gd(462472);x[a+8>>2]=46;x[a+12>>2]=44;x[a>>2]=66368;Wb(a+16|0)}function $A(a,b,c){v[a+2|0]=1;b=b&15;if(c){b=y[b+23408|0]}else{b=(b<<2)+4|0}v[a+4|0]=b}function vM(a,b,c){if(c>>>0>178956970){ve();p()}b=Vd(D(c,24),8);x[a+4>>2]=c;x[a>>2]=b}function ql(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function o1(a,b){a=a|0;b=b|0;a=z[a>>1];b=z[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function m1(a,b){a=a|0;b=b|0;a=x[a>>2];b=x[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function jY(a){a=a|0;a=461496;while(1){a=xb(a-12|0);if((a|0)!=461328){continue}break}}function hY(a){a=a|0;a=461672;while(1){a=Nc(a-12|0);if((a|0)!=461504){continue}break}}function fY(a){a=a|0;a=461968;while(1){a=xb(a-12|0);if((a|0)!=461680){continue}break}}function dY(a){a=a|0;a=462272;while(1){a=Nc(a-12|0);if((a|0)!=461984){continue}break}}function dF(a,b,c){if(c>>>0>357913941){ve();p()}b=Vd(D(c,12),4);x[a+4>>2]=c;x[a>>2]=b}function bq(a,b,c){var d=0;d=b;b=c;if((a|0)!=(d|0)){d=d-a|0;b=b-d|0;Bg(b,a,d)}rg(c,b)}function bY(a){a=a|0;a=462312;while(1){a=xb(a-12|0);if((a|0)!=462288){continue}break}}function Us(a,b){if(!(v[b+872|0]&1&x[a+480180>>2]==8)){iy(a,b,0);iy(a,b,1);iy(a,b,2)}}function RG(a){var b=0;b=PG(x[a>>2]-1|0);if(!b){a=PG(x[a+4>>2]);b=a?a+32|0:0}return b}function Jt(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function $X(a){a=a|0;a=462344;while(1){a=Nc(a-12|0);if((a|0)!=462320){continue}break}}function uf(a){a=a|0;var b=0;b=x[a>>2];return(mb[x[x[b>>2]+24>>2]](b)|0)-x[a+8>>2]|0}function uT(a,b,c){if(c>>>0>715827882){ve();p()}b=Vd(D(c,6),1);x[a+4>>2]=c;x[a>>2]=b}function dc(a){var b=0;b=hb-16|0;hb=b;a=x[Fb(b+8|0,x[a+4>>2])>>2];hb=b+16|0;return a}function Zh(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;_h(a)}function KY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[vr()+((b&255)<<2)>>2]}return b<<24>>24}function IY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[ur()+((b&255)<<2)>>2]}return b<<24>>24}function IK(a,b,c){if(c>>>0>82595524){ve();p()}b=Vd(D(c,52),4);x[a+4>>2]=c;x[a>>2]=b}function zm(a,b){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[b>>2]=0;x[b+4>>2]=0;return a}function xF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return mb[x[x[a>>2]+32>>2]](a,b,c,d)|0}function vF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return mb[x[x[a>>2]+48>>2]](a,b,c,d)|0}function uC(a,b,c){if(c>>>0>2147483647){ve();p()}b=Vd(c<<1,2);x[a+4>>2]=c;x[a>>2]=b}function s6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return XI(a,b,c,d,0,0,0,0,e)|0}function kC(a,b,c){if(c>>>0>1073741823){ve();p()}b=Vd(c<<2,2);x[a+4>>2]=c;x[a>>2]=b}function dS(a,b,c){if(c>>>0>1073741823){ve();p()}b=Vd(c<<2,1);x[a+4>>2]=c;x[a>>2]=b}function Lx(a,b,c){if(c>>>0>1073741823){ve();p()}b=Vd(c<<2,4);x[a+4>>2]=c;x[a>>2]=b}function HF(a){return(a|0)!=0&(a|0)!=61704&(a|0)!=61728&(a|0)!=460808&(a|0)!=460832}function zt(a){var b=0;b=hb-16|0;hb=b;x[b+8>>2]=x[a>>2];hb=b+16|0;return x[b+8>>2]}function qH(a,b){b=x[a+32>>2]+b|0;x[a+32>>2]=b;if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1}}function eN(a,b){var c=0;c=b&15;if(c){v[a+850|0]=c}b=b&240;if(b){v[a+849|0]=b>>>4}}function bc(a){var b=0;b=hb-16|0;hb=b;a=x[Fb(b+8|0,x[a>>2])>>2];hb=b+16|0;return a}function UC(a,b,c){if(c>>>0>536870911){ve();p()}b=Vd(c<<3,1);x[a+4>>2]=c;x[a>>2]=b}function Pj(a,b){a=a|0;b=b|0;if(qc(a)>>>0<=b>>>0){XB();p()}return x[a>>2]+(b<<1)|0}function Iy(a,b){var c=0;v[a|0]=y[b|0];c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c}function tz(a,b){a=sc(a,b,34);w[a+34>>1]=z[b+34>>1];sc(a+36|0,b+36|0,68);return a}function sl(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,12);return a}function rT(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,48);return a}function _k(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,24);return a}function QC(a,b){var c=0;x[a>>2]=x[b>>2];c=a;a=x[b+4>>2];x[c+4>>2]=a;if(a){Bm(a)}}function PA(a,b,c){a=a|0;b=b|0;c=c|0;a=y[c|0]|y[c+1|0]<<8;v[b|0]=a;v[b+1|0]=a>>>8}function $O(a){if((y[a+14|0]-53&255)>>>0>=252){a=cd(a,11614,14)}else{a=1}return!a}function xx(a,b){if(Rb(a)>>>0<=b>>>0){a=Rb(a)+Bb(a)>>>0>=b>>>0}else{a=0}return a}function vm(a,b){var c=0;a=zm(a,b);c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function ud(a){var b=0;b=hb-16|0;hb=b;a=x[Fb(b+8|0,Rb(a))>>2];hb=b+16|0;return a}function rq(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,6);return a}function rO(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){a=mc(a);if(b){di(x[a>>2],b,1)}}}function je(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<2);return a}function gO(a){var b=0;b=hb-16|0;hb=b;a=x[Fb(b+8|0,dc(a))>>2];hb=b+16|0;return a}function Yq(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<3);return a}function Yg(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<1);return a}function Ti(a){var b=0;b=hb-16|0;hb=b;a=x[Fb(b+8|0,Hj(a))>>2];hb=b+16|0;return a}function QW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=mb[a|0](b,c,d)|0;ib=lb;return a|0}function Hm(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<4);return a}function Hj(a){var b=0;b=hb-16|0;hb=b;a=x[Fb(b+8|0,mc(a))>>2];hb=b+16|0;return a}function Gj(a){var b=0;b=hb-16|0;hb=b;a=x[Fb(b+8|0,bc(a))>>2];hb=b+16|0;return a}function Bo(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<5);return a}function At(a){var b=0;b=hb-16|0;hb=b;x[b+8>>2]=a;a=zt(b+8|0);hb=b+16|0;return a}function nS(a,b){a=a|0;b=b|0;return x[b+8>>2]==x[a+8>>2]&x[a+12>>2]==x[b+12>>2]}function aH(){var a=0;a=hb-16|0;x[a+8>>2]=0;x[a+12>>2]=1048576;return C[a+8>>3]}function WY(a,b,c){a=a|0;b=b|0;c=c|0;return(x[(c<<2)+65248>>2]&b)!=0&c>>>0<=127}function VC(a){Xn(a);if(x[a>>2]){HD(a,x[a>>2]);ag(yb(a),x[a>>2],pf(a))}return a}function PW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[a|0](b,c,d,e,f)}function C$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=hb-16|0;hb=b;zF(a,c,d);hb=b+16|0}function yt(a,b){return gg(jh((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function xba(a,b){a=a|0;b=b|0;return(b>>>0>=4e3?17386:((b<<5)+a|0)+946304|0)|0}function ZG(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;IG(a,b,c,0,0);hb=d+16|0}function YX(a){a=a|0;if(!y[461216]){Lm(461204,66444);v[461216]=1}return 461204}function UX(a){a=a|0;if(!y[461248]){Lm(461236,66480);v[461248]=1}return 461236}function SW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return mb[a|0](b,c,d,e)|0}function QX(a){a=a|0;if(!y[461280]){Lm(461268,66516);v[461280]=1}return 461268}function Nt(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0}function MX(a){a=a|0;if(!y[461312]){Lm(461300,66600);v[461312]=1}return 461300}function C1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return EH(a-88|0,b,c,d,e)|0}function uX(a,b,c){a=a|0;b=b|0;c=c|0;if(!y[462920]){v[462920]=1}dd(a,c,83956)}function qi(a,b,c){if(x[a+80>>2]){x[a+92>>2]=x[a+92>>2]+(c+7&-8);return}_b(b)}function qX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(tg(a,x[b+8>>2],0)){Sv(b,c,d)}}function oC(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;nC(d,b);Iq(a,d);hb=c+16|0}function jl(a,b){x[a>>2]=x[b>>2];b=x[b+4>>2];x[a+4>>2]=b;if(b){Bm(b)}return a}function h2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ss(b,c,d,B[a+28>>2]);bI(a,b,c,d)}function f2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ss(b,c,d,B[a+28>>2]);$H(a,b,c,d)}function cP(a,b){a=a|0;b=b|0;mi(b);if(x[b>>2]){gP(b);Ih(yb(b),x[b>>2],xg(b))}}function c7(a,b){a=a|0;b=b|0;return E((b|0)<=12?B[((b<<2)+a|0)+4208>>2]:E(0))}function c2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ss(b,c,d,B[a+24>>2]);ZH(a,b,c,d)}function _X(a){a=a|0;if(!y[461200]){Ub(461188,1755);v[461200]=1}return 461188}function YO(a,b){a=JP(a,b);v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function WX(a){a=a|0;if(!y[461232]){Ub(461220,9540);v[461232]=1}return 461220}function SX(a){a=a|0;if(!y[461264]){Ub(461252,9340);v[461264]=1}return 461252}function OX(a){a=a|0;if(!y[461296]){Ub(461284,5224);v[461296]=1}return 461284}function $1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ss(b,c,d,B[a+24>>2]);XH(a,b,c,d)}function zz(a){a=a+4|0;return y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24)}function yQ(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=qO(a,b);hb=c+16|0;return d?b:a}function m7(a,b){a=a|0;b=b|0;return E((b|0)<=1?B[((b<<2)+a|0)+4208>>2]:E(0))}function cy(a,b){if(b){cy(a,x[b>>2]);cy(a,x[b+4>>2]);aw(mc(a),b+16|0);oL(b)}}function cF(a,b){var c=0,d=0;we(a,ke(b));b=x[mc(b)>>2];c=mc(a),d=b,x[c>>2]=d}function _7(a,b){a=a|0;b=b|0;return E((b|0)<=6?B[((b<<2)+a|0)+4208>>2]:E(0))}function Zw(a){var b=0;b=hb-16|0;hb=b;a=x[Fb(b+8|0,a)>>2];hb=b+16|0;return a}function V6(a,b){a=a|0;b=b|0;return E((b|0)<=2?B[((b<<2)+a|0)+4208>>2]:E(0))}function Rn(a){var b=0;b=hb-16|0;hb=b;a=x[qS(b+8|0,a)>>2];hb=b+16|0;return a}function P7(a,b){a=a|0;b=b|0;return E((b|0)<=5?B[((b<<2)+a|0)+4208>>2]:E(0))}function O6(a,b){a=a|0;b=b|0;return E((b|0)<=3?B[((b<<2)+a|0)+4208>>2]:E(0))}function Jz(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=qO(b,a);hb=c+16|0;return d?b:a}function Hl(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=fu(b,a);hb=c+16|0;return d?b:a}function H7(a,b){a=a|0;b=b|0;return E((b|0)<=4?B[((b<<2)+a|0)+4208>>2]:E(0))}function Ex(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=fu(a,b);hb=c+16|0;return d?b:a}function DI(a,b,c,d){x[a+12>>2]=0;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;return a}function Bd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b+8>>2];cc(b,c);xv(a,b,d,c)}function A7(a,b){a=a|0;b=b|0;return E((b|0)<=4?B[((b<<2)+a|0)+4220>>2]:E(0))}function zD(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;Ii(a,c+8|0,b);hb=c+16|0}function uW(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;Gm(a,c+8|0,b);hb=c+16|0}function th(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+c;return a}function ng(a,b){var c=0;c=a;a=x[a+8>>2];b=a-b|0;x[c+8>>2]=a>>>0>=b>>>0?b:0}function kR(a){var b=0;while(1){b=a;a=x[a>>2];if(a){continue}break}return b}function i0(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){cE(a,c);return}Ub(a,4152)}function hG(a,b,c,d,e,f,g,h){return mb[x[x[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function aB(a,b){a=a|0;b=b|0;a=x[a>>2];return mb[x[x[a>>2]+36>>2]](a,0,b)|0}function Rr(a,b,c,d,e,f,g,h){return mb[x[x[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function EZ(){var a=0;a=Gd(462448);w[a+8>>1]=11310;x[a>>2]=66328;Wb(a+12|0)}function sN(a,b,c){var d=0;d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;RO(a,c)}function nn(a,b){a=x[a+4276>>2];return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function kg(a,b){a=a|0;b=b|0;if(go(a,b)){a=xh(Re(a,b))}else{a=0}return a|0}function ZK(a,b){a=a|0;b=b|0;return(b>>>0>15?63:y[x[a+88>>2]+b|0])<<24>>24}function ZI(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){mb[x[x[c>>2]+4>>2]](c)}}function YK(a,b){a=a|0;b=b|0;return(b>>>0>42?63:y[x[a+84>>2]+b|0])<<24>>24}function Ug(a,b,c){x[a+8>>2]=b;x[a+12>>2]=c;x[a>>2]=0;x[a+4>>2]=0;return a}function SY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[vr()+(b<<2)>>2]}return b|0}function QY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[ur()+(b<<2)>>2]}return b|0}function t2(a){a=a|0;var b=0;b=hb-16|0;hb=b;ic(a);It(b+8|0,a,1);hb=b+16|0}function lk(a,b,c){a=a|0;b=b|0;c=c|0;return mb[x[x[a>>2]+12>>2]](a,b,c)|0}function gm(a,b,c){a=a|0;b=b|0;c=c|0;return mb[x[x[a>>2]+48>>2]](a,b,c)|0}function gla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=no(a,b),x[d>>2]=e}function dla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Zu(a,b),w[d>>1]=e}function ad(a,b,c,d,e){v[a+3|0]=e;v[a+2|0]=d;v[a+1|0]=c;v[a|0]=b;return a}function aW(a){a=a|0;var b=0;b=hb-16|0;hb=b;ic(a);Hf(b+8|0,a,1);hb=b+16|0}function RV(a){a=a|0;var b=0;b=hb-16|0;hb=b;ic(a);di(b+8|0,a,1);hb=b+16|0}function QQ(a,b){v[a+6|0]=255;x[a+16>>2]=b;w[a+4>>1]=0;x[a>>2]=0;return a}function KV(a){a=a|0;var b=0;b=hb-16|0;hb=b;ic(a);_g(b+8|0,a,1);hb=b+16|0}function K0(a,b,c){a=a|0;b=b|0;c=c|0;return mb[x[x[a>>2]+32>>2]](a,b,c)|0}function Ei(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;return a}function n8(a,b){a=a|0;b=b|0;a=x[a+20>>2]+24|0;v[a|0]=y[a|0]&253|(b?2:0)}function kA(a,b){var c=0;c=hb-16|0;hb=c;jc(a,x[b>>2],Lb(b)<<2);hb=c+16|0}function ela(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=tS(a,b),v[d|0]=e}function KB(a,b){return(y[a|0]|y[a+1|0]<<8)>>>0<(y[b|0]|y[b+1|0]<<8)>>>0}function BB(a,b){var c=0;c=hb-16|0;hb=c;jc(a,x[b>>2],qc(b)<<1);hb=c+16|0}function AS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=tS(a,b),x[d>>2]=e}function AG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Ug(a,-1,-1)}function uR(a){Ye(a);if(x[a>>2]){rR(a,x[a>>2]);Ij(yb(a),x[a>>2],vd(a))}}function uQ(a){er(a);if(x[a>>2]){oQ(a,x[a>>2]);wv(yb(a),x[a>>2],dj(a))}}function tc(a,b){var c=0,d=0;x[a>>2]=b;c=a,d=wf(b),x[c+4>>2]=d;return a}function id(a){ml(a);if(x[a>>2]){yB(a,x[a>>2]);di(yb(a),x[a>>2],ei(a))}}function hP(a){mi(a);if(x[a>>2]){dP(a,x[a>>2]);Ih(yb(a),x[a>>2],xg(a))}}function fg(a){Ye(a);if(x[a>>2]){lS(a);Xe(yb(a),x[a>>2],vd(a))}return a}function bQ(a){Ye(a);if(x[a>>2]){ZP(a,x[a>>2]);Ij(yb(a),x[a>>2],vd(a))}}function bA(a){Rj(a);if(x[a>>2]){jR(a,x[a>>2]);hm(yb(a),x[a>>2],Vf(a))}}function _N(a,b){x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=b?b:49716;x[a+12>>2]=0}function VN(a){if(a>>>0<=8){return y[a+25728|0]}return y[a+25719|0]|256}function Ui(a){Ye(a);if(x[a>>2]){fS(a,x[a>>2]);Ij(yb(a),x[a>>2],vd(a))}}function Tw(a){return((Rg(a)+(Rg(a)<<8)|0)+(Rg(a)<<16)|0)+(Rg(a)<<24)|0}function TD(a){w[a+12>>1]=0;x[a+8>>2]=-1;x[a>>2]=0;x[a+4>>2]=0;return a}function Qo(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;x[e>>2]=c;return 3}function Nn(a){SR(a);if(x[a>>2]){OR(a,x[a>>2]);RR(yb(a),x[a>>2],am(a))}}function NH(a){a=a|0;return+(+A[x[a+32>>2]+480240>>2]*152587890625e-16)}function Mj(a){Rj(a);if(x[a>>2]){CB(a,x[a>>2]);hm(yb(a),x[a>>2],Vf(a))}}function Mf(a){ig(a);if(x[a>>2]){PI(a);xp(yb(a),x[a>>2],af(a))}return a}function $w(a,b){a=a|0;b=b|0;mb[b|0](x[x[a>>2]-12>>2]+a|0)|0;return a|0}function hz(a,b){a=jm(a);hd(a+12|0);w[a+28>>1]=0;x[a+24>>2]=b;return a}function d0(a){a=a|0;x[a+16>>2]=x[a+16>>2]|1;if(v[a+20|0]&1){xa();p()}}function ck(a,b){a=a|0;b=b|0;v[a|0]=2;v[a+1|0]=3;v[a+2|0]=0;v[a+3|0]=4}function bl(a){a=a|0;var b=0;b=hb-16|0;hb=b;hb=b+16|0;return a<<24>>24}function ay(a,b){C[a>>3]=C[b>>3]+C[a>>3];C[a+8>>3]=C[b+8>>3]+C[a+8>>3]}function aS(a,b){mk(a,Cb(x[b>>2]),Eb(b));a=x[a+4>>2];lb=a>>31;return a}function Wq(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function Pv(a,b,c){if(!(x[a+28>>2]==1|x[a+4>>2]!=(b|0))){x[a+28>>2]=c}}function Ec(a,b){if(Lb(a)>>>0<=b>>>0){XB();p()}return x[a>>2]+(b<<2)|0}function oW(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;GD(a,b);hb=c+16|0}function gX(a){a=a|0;if(!a){return 0}return(Tv(a,74512,74656)|0)!=0|0}function Uo(a,b,c){a=a|0;b=b|0;c=c|0;a=td(a,b);td(a+4|0,c);return a|0}function Mi(a,b){return(x[a+4>>2]-x[b+4>>2]|0)+(x[a>>2]-x[b>>2]<<3)|0}function As(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;tQ(a,b);hb=c+16|0}function ve(){var a=0;a=Yj(ec(4));x[a>>2]=74920;da(a|0,75028,26);p()}function q2(a,b,c){a=a|0;b=b|0;c=c|0;x[b>>2]=x[c>>2];Uf(b+4|0,c+4|0)}function naa(a,b){a=a|0;b=b|0;return y[x[a+84>>2]+b|0]!=63&b>>>0<=42}function n2(a,b,c){a=a|0;b=b|0;c=c|0;x[b>>2]=x[c>>2];Jd(b+4|0,c+4|0)}function e1(a,b){a=a|0;b=b|0;if(!x[114414]){x[114414]=a;x[114415]=b}}function YY(a){a=a|0;var b=0;b=x[115264]+1|0;x[115264]=b;x[a+4>>2]=b}function WO(a,b){a=wz(a,b);v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2]}function TZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Uf(a,f)}function RW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return mb[a|0](b,c,d)|0}function EM(a,b){return x[(b<<2)+($b(a+1074312|0,7)?30272:30336)>>2]}function Dy(a,b){return x[(b<<2)+($b(a+1074312|0,7)?30400:31424)>>2]}function DM(a,b){return x[(b<<2)+($b(a+1074312|0,7)?30336:30272)>>2]}function Cy(a,b){return x[(b<<2)+($b(a+1074312|0,7)?31424:30400)>>2]}function Bz(a,b){Yb(a,b);Yb(a+4|0,b+4|0);Yb(yb(a),yb(b));yb(a);yb(b)}function w2(a){a=a|0;var b=0;b=hb-16|0;hb=b;ic(a);lI(a,1);hb=b+16|0}function tl(a,b){return b?a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24):a}function s1(a){a=a|0;var b=0;b=x[a+100>>2];x[a+100>>2]=0;return b|0}function fM(a,b,c,d){x[a+12>>2]=0;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b}function _K(a,b){a=a|0;b=b|0;return y[x[a+88>>2]+b|0]!=63&b>>>0<=15}function Yz(a,b){if(b){Yz(a,x[b>>2]);Yz(a,x[b+4>>2]);di(mc(a),b,1)}}function WD(a,b,c,d,e,f,g){return Ga(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function NO(a){a=a|0;x[a>>2]=75552;uh(a+28|0);uh(a+12|0);return a|0}function IM(a,b){x[a+876>>2]=x[a+876>>2]+b;v[a+872|0]=y[a+872|0]|16}function xma(a){a=a|0;return x[a+16>>2]+(x[a+8>>2]-x[a+20>>2]|0)|0}function tO(a,b){var c=0,d=0;c=Fb(a,x[b>>2]),d=y[b+4|0],v[c+4|0]=d}function hn(a,b,c){return x[x[a>>2]+(b<<2)>>2]+(x[a+12>>2]+c<<1)|0}function fR(a,b){if(b>>>0>214748364){ve();p()}return Vd(D(b,20),4)}function Zj(a,b,c){a=a|0;b=b|0;c=c|0;b=tE(c);x[a+4>>2]=c;x[a>>2]=b}function NY(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function In(a,b,c){return x[x[a>>2]+(b<<2)>>2]+(x[a+12>>2]+c<<2)|0}function Gh(a,b,c){a=a|0;b=b|0;c=c|0;b=vE(c);x[a+4>>2]=c;x[a>>2]=b}function En(a){var b=0;b=x[a+20>>2];if(b){_b(b+-64|0)}x[a+20>>2]=0}function Df(a,b,c){a=a|0;b=b|0;c=c|0;return Qc(a,D(zk(a),b)+c|0)|0}function Ce(a,b){v[a+11|0]=y[a+11|0]&128|b;v[a+11|0]=y[a+11|0]&127}function BF(a,b,c){a=a|0;b=b|0;c=c|0;return Wo(0,a,b,c?c:460860)|0}function wP(a){a=a+34|0;a=yna(y[a|0]|y[a+1|0]<<8,0,80,0);return a}function dR(a,b,c,d){a=df(a,b);w[a+18>>1]=d;w[a+16>>1]=c;return a}function bx(a){a=y[a+1|0];return(a&6)==6?384:1152>>>((a&14)==2)|0}function ZS(a){a=a+47|0;a=(y[a|0]|y[a+1|0]<<8)-98|0;lb=0;return a}function Lo(a,b,c,d,e){b=Ha(a|0,b|0,c|0,d|0,e|0)|0;lb=ib;return b}function LH(a){a=a|0;return+(+x[x[a+32>>2]+1074444>>2]*.00390625)}function Hh(a,b){var c=0,d=0;c=a,d=jw(x[b>>2]),x[c>>2]=d;return a}function HV(a){a=a|0;a=x[a+4>>2];return mb[x[x[a>>2]+12>>2]](a)|0}function GV(a){a=a|0;a=x[a+4>>2];return mb[x[x[a>>2]+16>>2]](a)|0}function Dj(a){a=x[a+656>>2];if(!a){return 0}return x[a+44>>2]!=0}function zy(a){xb(a+48|0);xb(a+36|0);xb(a+24|0);xb(a+12|0);xb(a)}function lD(a){if(a>>>0>178956970){ve();p()}return Vd(D(a,24),4)}function Xda(a,b){a=a|0;b=b|0;QN(a,x[b>>2],x[b+4>>2]);return a|0}function IX(a){a=a|0;var b=0,c=0;b=a,c=ie(),x[b>>2]=c;return a|0}function IV(a){a=a|0;a=x[a+4>>2];return mb[x[x[a>>2]+8>>2]](a)|0}function Eba(a,b){a=a|0;b=b|0;a=Vv(a,b);x[a>>2]=75148;return a|0}function Cb(a){a=a|0;var b=0;b=hb-16|0;hb=b;hb=b+16|0;return a|0}function z6(a,b){a=a|0;b=b|0;if(!b){return 3}x[b>>2]=a;return 0}function uy(a){wm(a);if(x[a>>2]){sD(a);_g(yb(a),x[a>>2],Dh(a))}}function uh(a){Xn(a);if(x[a>>2]){kT(a);ag(yb(a),x[a>>2],pf(a))}}function tM(a,b){if(b>>>0>134217727){ve();p()}return Vd(b<<5,8)}function qf(a){Rj(a);if(x[a>>2]){LB(a);vo(yb(a),x[a>>2],Vf(a))}}function nw(a,b){a=a|0;b=b|0;return(ih(a)|0)!=0|(a|32)-97>>>0<6}function mn(a){a=a|0;return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function lR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ke(b,c,d)|0}function lM(a){oT(a);if(x[a>>2]){DT(a);nT(yb(a),x[a>>2],cm(a))}}function gw(a,b){a=a|0;b=b|0;return mb[x[x[a>>2]+12>>2]](a,b)|0}function gM(a){RL(a);if(x[a>>2]){QL(a);oy(yb(a),x[a>>2],tj(a))}}function fz(a){wm(a);if(x[a>>2]){eO(a);_g(yb(a),x[a>>2],Dh(a))}}function fj(a){a=a|0;a=x[a>>2];return mb[x[x[a>>2]+24>>2]](a)|0}function bm(a){tu(a);if(x[a>>2]){xS(a);su(yb(a),x[a>>2],Vi(a))}}function al(a,b){a=a|0;b=b|0;return mb[x[x[a>>2]+28>>2]](a,b)|0}function Yl(a){ig(a);if(x[a>>2]){RP(a);Hf(yb(a),x[a>>2],af(a))}}function WU(a,b){a=a|0;b=b|0;a=Vv(a,b);x[a>>2]=75256;return a|0}function WE(a){Ye(a);if(x[a>>2]){UE(a);NE(rl(a),x[a>>2],vd(a))}}function VT(a){Rj(a);if(x[a>>2]){PT(a);hm(yb(a),x[a>>2],Vf(a))}}function TO(a){Ye(a);if(x[a>>2]){SO(a);Ij(yb(a),x[a>>2],vd(a))}}function Pw(a){var b=0;b=hb-16|0;B[b+12>>2]=a;return B[b+12>>2]}function Pr(a,b){a=a|0;b=b|0;return mb[x[x[a>>2]+44>>2]](a,b)|0}function Mn(a){Ye(a);if(x[a>>2]){LR(a);av(yb(a),x[a>>2],vd(a))}}function Ml(a){ig(a);if(x[a>>2]){gL(a);Hf(yb(a),x[a>>2],af(a))}}function Mc(a,b,c,d){x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;return a}function LN(a,b){b=1/(564505.8718779281/b+1);HN(a,b,0,0,b+-1,0)}function HJ(a){a=a|0;return E(E(E(B[a+4228>>2]*E(198))+E(-99)))}function Gs(a){Ye(a);if(x[a>>2]){fK(a);Xe(yb(a),x[a>>2],vd(a))}}function Ge(a){Ye(a);if(x[a>>2]){BL(a);Xe(yb(a),x[a>>2],vd(a))}}function GW(a,b){a=a|0;b=b|0;a=Vv(a,b);x[a>>2]=75204;return a|0}function Fs(a){dK(a);if(x[a>>2]){iK(a);cK(yb(a),x[a>>2],uk(a))}}function EP(a){if(a>>>0>76695844){ve();p()}return Vd(D(a,56),4)}function DN(a){mi(a);if(x[a>>2]){AN(a);Ih(yb(a),x[a>>2],xg(a))}}function $d(a){Xn(a);if(x[a>>2]){CC(a);ag(yb(a),x[a>>2],pf(a))}}function $M(a){ig(a);if(x[a>>2]){AM(a);xp(yb(a),x[a>>2],af(a))}}function tE(a){if(a>>>0>1073741823){ve();p()}return Vd(a<<2,4)}function nv(a){a=a|0;a=x[a>>2];return mb[x[x[a>>2]+8>>2]](a)|0}function jA(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,4896);hb=c+16|0}function iu(a,b){a=a|0;b=b|0;a=Zq(a,b);if(!a){gS(b)}return a|0}function c_(a,b,c){a=a|0;b=b|0;c=c|0;dd(a,kG(x[b>>2]),x[b>>2])}function ZA(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,1954);hb=c+16|0}function Yf(a,b){return mb[x[x[a>>2]+36>>2]](a,x[a+12>>2],b)|0}function SS(a){a=a|0;a=y[a|0];return Zd(a)^1|(a-49&255)>>>0<36}function QI(a,b,c,d){w[a+4>>1]=c;v[a+6|0]=b;x[a>>2]=d;return a}function Nq(a,b){var c=0;c=b+1|0;x[a>>2]=x[a>>2]>(c|0)?c:b+2|0}function KJ(a){a=a|0;x[a>>2]=79168;fg(a+4260|0);return xf(a)|0}function Iz(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,1024);hb=c+16|0}function If(a,b){a=a|0;b=b|0;a=qv(a,b);if(!a){SC(b)}return a|0}function yP(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,146);hb=c+16|0}function xq(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,192);hb=c+16|0}function wN(a,b){return x[a>>2]==x[b>>2]&x[a+4>>2]==x[b+4>>2]}function uea(a,b,c){a=a|0;b=b|0;c=c|0;return sh(a,b,c,1172)|0}function uP(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,608);hb=c+16|0}function tea(a,b,c){a=a|0;b=b|0;c=c|0;return sh(a,b,c,1173)|0}function rQ(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,126);hb=c+16|0}function rD(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){_b(VC(c))}}function qea(a,b,c){a=a|0;b=b|0;c=c|0;return sh(a,b,c,1178)|0}function n4(a,b,c){a=a|0;b=b|0;c=c|0;wJ(a,0,pA(x[b+24>>2]),c)}function iS(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,674);hb=c+16|0}function hM(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){_b(dg(c))}}function hE(a,b){if(Bb(a)>>>0<=b>>>0){om();p()}return pc(a,b)}function eaa(a,b,c){a=a|0;b=b|0;c=c|0;return sh(a,b,c,1592)|0}function eP(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,204);hb=c+16|0}function bH(a){var b=0;b=hb-16|0;C[b+8>>3]=a;return C[b+8>>3]}function ZC(a){if(a>>>0>134217727){ve();p()}return Vd(a<<5,4)}function YB(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,497);hb=c+16|0}function YA(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,512);hb=c+16|0}function WR(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,128);hb=c+16|0}function Uja(a,b,c){a=a|0;b=b|0;c=c|0;Jd(a,kE(c,Rb(b),Bb(b)))}function Qp(a,b){a=a|0;b=b|0;if(ue(a)>>>0>b>>>0){v[a+16|0]=b}}function QS(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,157);hb=c+16|0}function QO(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,263);hb=c+16|0}function LS(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,576);hb=c+16|0}function IT(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,610);hb=c+16|0}function ID(a){if(a>>>0>268435455){ve();p()}return Vd(a<<4,4)}function Gz(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function Ed(a,b){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];return a}function DQ(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,130);hb=c+16|0}function DG(a,b){b=x[b>>2];x[a>>2]=b;x[a+4>>2]=b>>31;return a}function BQ(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,600);hb=c+16|0}function z9(a,b,c){a=a|0;b=b|0;c=c|0;return sh(a,b,c,1643)|0}function y9(a,b,c){a=a|0;b=b|0;c=c|0;return sh(a,b,c,1644)|0}function sR(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,52);hb=c+16|0}function ru(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,66);hb=c+16|0}function qo(a,b,c){if(!b){return 0}return fs(a,Wg(v[c|0]),b)}function qQ(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,32);hb=c+16|0}function pi(a){var b=0;o(+a);b=j(1)|0;j(0)|0;return b>>>20|0}function nu(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,22);hb=c+16|0}function ls(a){a=a|0;x[a>>2]=59432;xb(a+32|0);return zl(a)|0}function jB(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,11);hb=c+16|0}function hD(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,10);hb=c+16|0}function fD(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,14);hb=c+16|0}function dA(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,33);hb=c+16|0}function bla(a,b,c){a=a|0;b=b|0;c=c|0;return sh(a,b,c,684)|0}function bS(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,80);hb=c+16|0}function _P(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,96);hb=c+16|0}function _A(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,1954);hb=b+16|0}function Zz(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,40);hb=c+16|0}function Yb(a,b){var c=0;c=x[a>>2];x[a>>2]=x[b>>2];x[b>>2]=c}function WW(a,b){a=a|0;b=b|0;a=mb[a|0](b)|0;ib=lb;return a|0}function WS(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,98);hb=c+16|0}function US(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,48);hb=c+16|0}function Sq(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,36);hb=c+16|0}function Sc(a){return(a|0)<-32768?-32768:(a|0)>32767?32767:a}function Pu(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,65);hb=c+16|0}function PH(a){a=a|0;return+(65536/+A[x[a+32>>2]+480244>>2])}function PG(a){return v[(D(0-a&a,124511785)>>>27|0)+58576|0]}function NN(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,27);hb=c+16|0}function LA(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,64);hb=c+16|0}function IB(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,38);hb=c+16|0}function Gx(a){a=a|0;x[a+32>>2]=0;x[a+28>>2]=x[a+28>>2]&-7|2}function GB(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,41);hb=c+16|0}function FQ(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,30);hb=c+16|0}function FB(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,16);hb=c+16|0}function CA(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,12);hb=c+16|0}function $K(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,24);hb=c+16|0}function zP(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,146);hb=b+16|0}function vP(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,608);hb=b+16|0}function v8(a){a=a|0;a=sj(a);if(a){mb[x[x[a>>2]+92>>2]](a)}}function uv(a){var b=0;b=a;a=x[a>>2]-1|0;x[b>>2]=a;return a}function sk(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){_b(Mf(b))}}function sQ(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,126);hb=b+16|0}function pv(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,8);hb=c+16|0}function nD(a){var b=0;b=x[a+8>>2];if(b){Hf(a,b,x[a+4>>2])}}function jI(a){var b=0;b=x[a+8>>2];if(b){It(a,b,x[a+4>>2])}}function hl(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,2);hb=c+16|0}function hS(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,192);hb=b+16|0}function fP(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,204);hb=b+16|0}function dD(a){var b=0;b=x[a+8>>2];if(b){di(a,b,x[a+4>>2])}}function ZB(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,497);hb=b+16|0}function Vq(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,1);hb=c+16|0}function Tu(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,3);hb=c+16|0}function RS(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,157);hb=b+16|0}function RC(a,b,c){a=jl(a,b);x[a+12>>2]=c;x[a+8>>2]=0;Ab(b)}function PC(a){var b=0;b=x[a+8>>2];if(b){_g(a,b,x[a+4>>2])}}function MS(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,576);hb=b+16|0}function KW(a,b,c){a=a|0;b=b|0;c=c|0;return Ke(a,a+b|0,c)|0}function JT(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,610);hb=b+16|0}function Gu(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,5);hb=c+16|0}function Eu(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,7);hb=c+16|0}function Eh(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,4);hb=c+16|0}function EQ(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,130);hb=b+16|0}function CQ(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,600);hb=b+16|0}function AA(a,b){var c=0;c=hb-16|0;hb=c;jc(a,b,6);hb=c+16|0}function tT(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,66);hb=b+16|0}function tR(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,52);hb=b+16|0}function pV(a){a=a|0;a=qD(a,9186);x[a>>2]=76248;return a|0}function n3(a){a=a|0;return A[x[a+24>>2]+1074420>>2]/1e4|0}function m4(a){a=a|0;RI(a,2,100);Qp(x[a+24>>2]+484360|0,0)}function dW(a){a=a|0;a=qD(a,4896);x[a>>2]=75904;return a|0}function cS(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,80);hb=b+16|0}function c0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;lb=0;return 0}function Ym(a,b,c,d){x[a+16>>2]=d;x[a+12>>2]=c;x[a+8>>2]=b}function XS(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,98);hb=b+16|0}function VW(a,b,c){a=a|0;b=b|0;c=c|0;return mb[a|0](b,c)|0}function VS(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,48);hb=b+16|0}function VD(a,b,c){b=Da(2111,a|0,b|0,c|0)|0;lb=ib;return b}function Sf(a,b){a=zna(x[a>>2],x[a+4>>2],b,b>>31);return a}function JB(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,38);hb=b+16|0}function HC(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,36);hb=b+16|0}function HB(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,41);hb=b+16|0}function FY(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function Bl(a,b,c){a=a|0;b=b|0;c=c|0;return mb[c|0](a,b)|0}function $P(a){var b=0;b=hb-16|0;hb=b;Sb(a,0,96);hb=b+16|0}function zw(a,b,c){x[a+28>>2]=c;x[a+20>>2]=b;x[a+24>>2]=b}function wj(a){a=x[a+656>>2];if(!a){return 0}return Ki(a)}function oo(a,b,c){dd(a,x[b>>2]+(c>>>3&536870908)|0,c&31)}function oe(a,b,c){dd(a,x[b>>2]+(c>>>3&536870908)|0,1<<c)}function oH(a){while(1){if((js(a)|0)!=-1){continue}break}}function mI(a){var b=0;b=x[a+8>>2];if(b){lI(b,x[a+4>>2])}}function kh(a,b,c){return x[a>>2]+(D(x[a+4>>2],c)+b<<3)|0}function fn(a,b,c){return x[a>>2]+(D(x[a+4>>2],c)+b<<1)|0}function ce(a){if(x[a>>2]){Xe(yb(a),x[a>>2],x[yb(a)>>2])}}function b3(a){a=a|0;return Bj(Vb(x[a+24>>2]+484360|0))|0}function _s(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){_b(c)}}function Yw(a,b){return x[((a>>>24^b)<<2)+455936>>2]^a<<8}function Rf(a,b,c){return x[a>>2]+(D(x[a+4>>2],c)+b<<2)|0}function Eo(a){a=kD(a);x[a+8>>2]=0;x[a>>2]=71872;return a}function zG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Ug(a,-1,-1)}function yE(a){a=a|0;x[a>>2]=66328;xb(a+12|0);return a|0}function y1(a,b,c){a=a|0;b=b|0;c=c|0;return sd(D(b,c))|0}function xE(a){a=a|0;x[a>>2]=66368;xb(a+16|0);return a|0}function wh(a,b){var c=0;c=y[a|0];v[a|0]=y[b|0];v[b|0]=c}function uV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;xv(a,b,c,d)}function u4(a,b,c){a=a|0;b=b|0;c=c|0;Jd(a,kE(c,b,wf(b)))}function tm(a,b,c){a=zna(x[a>>2],x[a+4>>2],b,c);return a}function ri(a){return ye(a)|ye(a)<<8|ye(a)<<16|ye(a)<<24}function lha(a,b){a=a|0;b=b|0;return $F(a,Rb(b),Bb(b))|0}function eW(a,b,c){a=a|0;b=b|0;c=c|0;xv(a,b,x[b+8>>2],c)}function aC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cf(a,c,d,b)}function _t(a){Mn(a+88|0);Mn(a+68|0);Mn(a+48|0);return a}function Zy(a,b){C[a>>3]=C[a>>3]*b;C[a+8>>3]=C[a+8>>3]*b}function YD(a){a=x[a>>2]-12|0;if((uv(a+8|0)|0)<0){_b(a)}}function XA(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function TE(){var a=0,b=0;a=Gd(462536),b=69500,x[a>>2]=b}function SE(){var a=0,b=0;a=Gd(462568),b=69996,x[a>>2]=b}function RE(){var a=0,b=0;a=Gd(462576),b=70160,x[a>>2]=b}function QE(){var a=0,b=0;a=Gd(462584),b=70324,x[a>>2]=b}function PE(){var a=0,b=0;a=Gd(462592),b=70488,x[a>>2]=b}function OE(){var a=0,b=0;a=Gd(462664),b=70652,x[a>>2]=b}function NS(a){a=a|0;if(!y[a|0]){return 1}return Af(a)|0}function JE(a,b){Bm(x[b>>2]);Am(x[a>>2]);x[a>>2]=x[b>>2]}function Fma(a,b,c){a=a|0;b=b|0;c=c|0;return fB(a,b,c)|0}function Cka(a,b,c){a=a|0;b=b|0;c=c|0;return eB(a,b,c)|0}function Bla(a,b,c){a=a|0;b=b|0;c=c|0;return fs(a,b,c)|0}function zs(a){a=a|0;x[a>>2]=82600;rx(a+4|0);return a|0}function zl(a){a=a|0;x[a>>2]=59112;Ob(a+4|0);return a|0}function tA(a,b,c){a=a|0;b=b|0;c=c|0;return iB(a,b,c)|0}function sma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;QA(b,c,d)}function qJ(a){return E(E(B[a+4208>>2]*E(1e4))+E(-1e4))}function pJ(a){return E(E(B[a+4252>>2]*E(19980))+E(20))}function nr(a){a=a|0;x[a>>2]=75068;YD(a+4|0);return a|0}function mE(a,b,c,d){a=AF(a,b,c,0,-2147483648);return a}function lN(a,b,c){a=a|0;b=b|0;c=c|0;return Ip(a,b,c)|0}function k7(a){a=a|0;tJ(a);v[a+4202|0]=1;x[a+4224>>2]=0}function ZD(a){a=a|0;x[a>>2]=75048;YD(a+4|0);return a|0}function Xo(a){a=a|0;x[a>>2]=59272;Ob(a+4|0);return a|0}function WA(a,b,c){a=a|0;b=b|0;c=c|0;return QT(a,b,c)|0}function NC(a){a=a|0;x[a>>2]=76172;Ab(a+4|0);return a|0}function Md(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function LE(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Am(b)}}function Kr(a,b,c){return uF(Rb(a),Bb(a),Rb(b),c,Bb(b))}function JO(a){a=a|0;x[a>>2]=75608;uh(a+4|0);return a|0}function Go(a){var b=0;b=x[a+8>>2];x[a+8>>2]=0;return b}function Fc(a){if(re(a)){a=ti(a)-1|0}else{a=10}return a}function AH(a,b,c){x[a+4>>2]=0;x[a>>2]=b;x[a+8>>2]=c<<3}function $ba(a,b){a=a|0;b=b|0;return A[a+12>>2]>b>>>0|0}function $4(a,b,c){a=a|0;b=b|0;c=c|0;return pN(a,b,c)|0}function z3(a,b){a=a|0;b=b|0;x[x[a+24>>2]+480272>>2]=b}function xG(a){a=a|0;return Xr(x[x[a>>2]-12>>2]+a|0)|0}function wg(a,b){a=a|0;b=b|0;mb[x[x[b>>2]+20>>2]](a,b)}function rG(a){a=a|0;return Vr(x[x[a>>2]-12>>2]+a|0)|0}function n0(a){a=a|0;return Xd(x[x[a>>2]-12>>2]+a|0)|0}function mj(a,b){x[a+16>>2]=!x[a+24>>2]|(x[a+16>>2]|b)}function l0(a){a=a|0;return Lf(x[x[a>>2]-12>>2]+a|0)|0}function fh(a,b){a=a|0;b=b|0;mb[x[x[b>>2]+24>>2]](a,b)}function eh(a,b){a=a|0;b=b|0;mb[x[x[b>>2]+28>>2]](a,b)}function cp(a){return y[a+2|0]&2?(y[a+1|0]&6)==6?4:1:0}function cla(a,b){a=a|0;b=b|0;return Ub(a,b?b:17386)|0}function bd(a,b){a=a|0;b=b|0;return x[a>>2]!=x[b>>2]|0}function Xb(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function Te(a,b){a=yna(x[a>>2],x[a+4>>2],b,0);return a}function Rg(a){var b=0;b=js(a);x[a+1396>>2]=0;return b}function Om(a){if(re(a)){a=ti(a)-1|0}else{a=1}return a}function F$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;yi(a,c,d)}function EJ(a){a=a|0;return Li(E(B[a+4224>>2]*E(4)))|0}function Bb(a){if(re(a)){return x[a+4>>2]}return uo(a)}function zW(a,b){a=a|0;b=b|0;x[a>>2]=b;x[a+4>>2]=b+48}function xb(a){if(re(a)){ag(a,x[a>>2],ti(a))}return a}function sn(a){a=a|0;return mb[x[x[a>>2]+24>>2]](a)|0}function rN(a,b){a=a|0;b=b|0;x[a>>2]=b;x[a+4>>2]=b+24}function rL(){if(!y[455928]){pM(87224,1);v[455928]=1}}function qW(a,b){a=a|0;b=b|0;x[a>>2]=b;x[a+4>>2]=b+36}function li(a){a=a|0;return mb[x[x[a>>2]+12>>2]](a)|0}function ki(a){a=a|0;return mb[x[x[a>>2]+16>>2]](a)|0}function go(a,b){a=a|0;b=b|0;return Ae(a)>>>0>b>>>0|0}function gS(a){var b=0;b=hb-16|0;hb=b;XA(a);hb=b+16|0}function cf(a,b,c,d){v[a+8|0]=d;x[a+4>>2]=c;x[a>>2]=b}function bba(a){a=a|0;B[a+12>>2]=1;vL(a,4);return a|0}function bD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function a3(a){a=a|0;return KK(x[a+24>>2]+484344|0)|0}function _1(a,b){a=a|0;b=b|0;qN(x[a>>2],b);return a|0}function Xla(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function SC(a){var b=0;b=hb-16|0;hb=b;um(a);hb=b+16|0}function S8(a,b,c){a=a|0;b=b|0;c=c|0;$l(a,b+4260|0,8)}function Qm(a,b){return mb[x[x[a>>2]+36>>2]](a,b,0)|0}function Pm(a,b){return mb[x[x[a>>2]+52>>2]](a,b,0)|0}function Oda(a,b,c){a=a|0;b=b|0;c=c|0;C[b>>3]=C[c>>3]}function KN(a,b){a=a|0;b=b|0;x[a>>2]=b;x[a+4>>2]=b+12}function Id(a,b,c){a=a|0;b=b|0;c=c|0;return td(a,b)|0}function Dz(a){var b=0;b=hb-16|0;hb=b;yb(a);hb=b+16|0}function Cm(a,b){a=df(a,b);Sb(a+16|0,0,1040);return a}function ym(a,b,c){x[a>>2]=x[b>>2];x[a+4>>2]=x[c>>2]}function xna(a){if(a){return 31-G(a-1^a)|0}return 32}function t9(a,b,c){a=a|0;b=b|0;c=c|0;B[b>>2]=B[c>>2]}function sO(a){a=(a|0)>=120?120:a;return(a|0)<=1?1:a}function oia(a,b){a=a|0;b=b|0;return $F(a,b,wf(b))|0}function o3(a){a=a|0;return x[x[a+24>>2]+1074416>>2]}function k3(a){a=a|0;return x[x[a+24>>2]+1074424>>2]}function io(a,b,c){a=a|0;b=b|0;c=c|0;w[b>>1]=z[c>>1]}function daa(a,b){a=a|0;b=b|0;a=a+24|0;SK(a,b);ty(a)}function T7(a){a=a|0;return E(E(B[a+4232>>2]*E(20)))}function Lla(a){a=a|0;return WK(y[a+3|0],y[a+5|0])|0}function Kl(a,b,c){a=a|0;b=b|0;c=c|0;x[b>>2]=x[c>>2]}function FJ(a){a=a|0;return E(E(B[a+4216>>2]*E(10)))}function D8(a){a=a|0;v[a+4202|0]=1;Hs(a);Fx(a);$J(a)}function yc(a,b,c){a=a|0;b=b|0;c=c|0;return Xc(a)|0}function y4(a){a=a|0;a=x[a+4>>2];return(a?a:1518)|0}function y3(a){a=a|0;return x[x[a+24>>2]+480272>>2]}function xs(a){a=a|0;return z[x[a+24>>2]+480190>>1]}function q7(a){a=a|0;return E(E(B[a+4232>>2]*E(4)))}function on(a,b,c){if(!c){return 0}return cd(a,b,c)}function ke(a){var b=0;b=x[a>>2];x[a>>2]=0;return b}function j3(a){a=a|0;return z[x[a+24>>2]+480214>>1]}function haa(a,b){a=a|0;b=b|0;gj(a+36|0,b);return 1}function gt(a){a=a|0;return ct(y[a+3|0],y[a+5|0])|0}function fp(a){a=a|0;return z[x[a+24>>2]+480188>>1]}function bs(a){if(!a){return 0}x[114240]=a;return-1}function az(a,b){a=a|0;b=b|0;return Uq(a,b,wf(b))|0}function VG(a){return WG(a,E(15845632502852868e13))}function UG(a){return WG(a,E(2524354896707238e-44))}function So(a,b){b=x[b>>2];x[a>>2]=b;Bm(b);return a}function Rda(a,b){a=a|0;b=b|0;x[b>>2]=0;x[b+4>>2]=0}function Pc(a,b){a=a|0;b=b|0;return pN(a,b,wf(b))|0}function OW(a){a=a|0;a=mb[a|0]()|0;ib=lb;return a|0}function Ny(a){a=a|0;return ct(y[a+2|0],y[a+4|0])|0}function Nc(a){if(re(a)){Oo(x[a>>2],ti(a))}return a}function Iaa(a){a=a|0;dg(83992);Ky(83984);xb(83972)}function IN(a,b){x[a+8>>2]=0;x[a+12>>2]=0;C[a>>3]=b}function G1(a,b,c){a=a|0;b=b|0;c=c|0;IH(a-88|0,b,c)}function Fl(a){a=a|0;return z[x[a+24>>2]+480192>>1]}function EC(a,b,c){dd(a,(c>>>3&536870908)+b|0,1<<c)}function E1(a,b,c){a=a|0;b=b|0;c=c|0;GH(a-88|0,b,c)}function Co(a){a=a|0;a=ic(a);mb[x[x[a>>2]>>2]](a)|0}function $l(a,b,c){x[a>>2]=b;x[a+4>>2]=b+c;return a}function xka(a,b,c){a=a|0;b=b|0;c=c|0;cf(a,c,16,b)}function sz(a,b,c){a=a|0;b=b|0;c=c|0;RO(Ed(a,b),c)}function lq(a){return(x[a+480180>>2]&740327453)!=0}function lia(a,b,c){a=a|0;b=b|0;c=c|0;cf(a,c,33,b)}function lO(a,b,c){a=a|0;b=b|0;c=c|0;Jd(a,az(b,c))}function jP(a){a=a|0;return gg(44325e5/+(a>>>0))|0}function dia(a,b,c){a=a|0;b=b|0;c=c|0;cf(a,c,24,b)}function cN(a){return x[a+16>>2]!=(0-x[a+20>>2]|0)}function _G(a,b){NG(a,74);x[a+4>>2]=x[a+4>>2]|b&74}function Wz(a,b,c){$l(a,x[b+28>>2]+(c<<12)|0,4096)}function Rl(a){Hi(a+724|0);Hi(a+736|0);Hi(a+748|0)}function Qi(a,b,c){x[a>>2]=x[b>>2];v[a+4|0]=y[c|0]}function Im(a,b,c){a=a|0;b=b|0;c=c|0;v[b|0]=y[c|0]}function I1(a,b,c){a=a|0;b=b|0;c=+c;KH(a-88|0,b,c)}function F1(a,b){a=a|0;b=b|0;return HH(a-88|0,b)|0}function D1(a,b){a=a|0;b=b|0;return FH(a-88|0,b)|0}function Aq(a,b,c){a=a|0;b=b|0;c=c|0;Jd(a,ON(b,c))}function xg(a){return(x[yb(a)>>2]-x[a>>2]|0)/12|0}function uka(a,b){a=a|0;b=b|0;return Qs(a,b,17)|0}function uia(a,b,c){a=a|0;b=b|0;c=c|0;cf(a,c,9,b)}function tj(a){return(x[yb(a)>>2]-x[a>>2]|0)/52|0}function sG(a,b,c){x[a>>2]=b;x[a+4>>2]=c;return a}function rH(a,b){Ow(x[x[a>>2]-12>>2]+a|0,x[b>>2])}function qD(a,b){a=lE(a,b);x[a>>2]=75308;return a}function ou(a,b,c){a=a|0;b=b|0;c=c|0;cf(a,c,28,b)}function ne(a,b){a=a|0;b=b|0;return(a|0)==(b|0)|0}function lm(a,b,c){a=a|0;b=b|0;c=c|0;cf(a,c,22,b)}function kD(a){x[a+4>>2]=0;x[a>>2]=71816;return a}function hh(a,b){a=a|0;b=b|0;return dG(a)^dG(b)^1}function gv(a,b,c){a=a|0;b=b|0;c=c|0;cf(a,c,26,b)}function em(a){return(x[ic(a)>>2]-x[a>>2]|0)/24|0}function dd(a,b,c){x[a+4>>2]=c;x[a>>2]=b;return a}function cm(a){return(x[yb(a)>>2]-x[a>>2]|0)/48|0}function am(a){return(x[yb(a)>>2]-x[a>>2]|0)/33|0}function af(a){return(x[yb(a)>>2]-x[a>>2]|0)/24|0}function _n(a,b,c){a=a|0;b=b|0;c=c|0;cf(a,c,20,b)}function Zg(a,b){if(re(a)){ae(a,b);return}Ce(a,b)}function Zf(a,b){return uF(Rb(a),Bb(a),b,0,wf(b))}function YT(a,b,c){a=a|0;b=b|0;c=c|0;cf(a,c,30,b)}function YS(a,b,c){a=a|0;b=b|0;c=c|0;cf(a,c,40,b)}function Wk(a,b,c){a=a|0;b=b|0;c=c|0;cf(a,c,12,b)}function Vl(a,b,c){C[a+8>>3]=c;C[a>>3]=b;return a}function Vfa(a,b){a=a|0;b=b|0;return mb[b|0](a)|0}function VB(a){return!cd(a,23298,25)&y[a+34|0]<65}function To(a){return(x[ic(a)>>2]-x[a>>2]|0)/12|0}function TG(a){return(a<<1)+16777216>>>0<16777217}function Kn(a){return(x[yb(a)>>2]-x[a>>2]|0)/56|0}function Kg(a,b,c){a=a|0;b=b|0;c=c|0;cf(a,c,32,b)}function Ib(a){return(x[a+4>>2]&x[x[a>>2]>>2])!=0}function EG(a,b){if(!a){return 0}return as(a,b,0)}function Bu(a,b,c){a=a|0;b=b|0;c=c|0;cf(a,c,64,b)}function Ag(a,b){a=a|0;b=b|0;return eG(a)^eG(b)^1}function $p(a){return(x[yb(a)>>2]-x[a>>2]|0)/20|0}function yS(a,b){a=a|0;b=b|0;return Qs(a,b,32)|0}function uma(a,b,c){a=a|0;b=b|0;c=c|0;sc(b,c,48)}function sU(a,b){a=a|0;b=b|0;return Qs(a,b,11)|0}function py(a){x[a+4>>2]=0;x[a+8>>2]=-1;v[a|0]=0}function iz(a,b,c){v[a|0]=y[b|0];v[a+1|0]=y[c|0]}function gja(a,b){a=a|0;b=b|0;return nm(a,b,2)|0}function eq(a,b,c){v[a+2|0]=c;w[a>>1]=b;return a}function bz(a){x[a+24>>2]=z[a+20>>1]<<z[a+22>>1]}function WJ(a){a=a|0;uh(a+4208|0);return xf(a)|0}function Vi(a){return(x[yb(a)>>2]-x[a>>2]|0)/6|0}function SA(a,b){v[a|0]=y[b|0];v[a+1|0]=y[b+1|0]}function Rb(a){if(re(a)){return x[a>>2]}return a}function KD(a,b,c){b=ID(c);x[a+4>>2]=c;x[a>>2]=b}function Jx(a){a=a|0;fg(a+4208|0);return xf(a)|0}function H1(a,b){a=a|0;b=b|0;return+JH(a-88|0,b)}function Ela(a,b){a=a|0;b=b|0;return nm(a,b,3)|0}function Dm(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0}function Bh(a){return(sf(a)|0)!=(0-sf(a+12|0)|0)}function BJ(a){a=a|0;fg(a+4256|0);return xf(a)|0}function $C(a,b,c){b=ZC(c);x[a+4>>2]=c;x[a>>2]=b}function zc(a){return(x[a+4>>2]-x[a>>2]|0)/12|0}function zZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460888))}function yh(a,b){a=a|0;b=b|0;return nm(a,b,4)|0}function yZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460896))}function xd(a){return(x[a+4>>2]-x[a>>2]|0)/24|0}function xZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460904))}function vZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460944))}function uZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460952))}function tZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460960))}function sZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460968))}function s7(a){a=a|0;return B[a+4212>>2]<E(1)|0}function qZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460976))}function oZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460984))}function nk(a){a=a|0;return uG(x[a>>2])<<24>>24}function mm(a,b){a=a|0;b=b|0;return Df(a,b,0)|0}function mZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460992))}function kt(a,b){a=a|0;b=b|0;return(b-a|0)/12|0}function jg(a){return(x[a+4>>2]-x[a>>2]|0)/52|0}function jZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460912))}function jQ(a,b){a=a|0;b=b|0;return nm(a,b,8)|0}function iZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460920))}function gZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460928))}function eZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460936))}function bZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(461008))}function aZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(461016))}function aV(a,b){a=a|0;b=b|0;No(a,b);return a|0}function Xv(a,b,c,d){a=AF(a,b,c,-1,-1);return a}function Xm(a){return mb[x[x[a>>2]+28>>2]](a)|0}function Wi(a){return(x[a+4>>2]-x[a>>2]|0)/48|0}function V9(a,b){a=a|0;b=b|0;return Qs(a,b,1)|0}function V7(a){a=a|0;return B[a+4220>>2]<E(1)|0}function Qw(a){var b=0;b=x[a>>2];bg(a);return b}function Qk(a){return(x[a+4>>2]-x[a>>2]|0)/33|0}function QZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460864))}function PZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460872))}function NZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(461068))}function MZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(461060))}function Lk(a){return(x[a+4>>2]-x[a>>2]|0)/56|0}function LZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(461076))}function Jg(a,b){a=a|0;b=b|0;bG(a,x[a+16>>2]|b)}function JZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(461084))}function IZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(461092))}function HZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(461108))}function GZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(461100))}function Fn(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function FZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(461116))}function DZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(461124))}function BZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(461132))}function AZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460880))}function $j(a){return mb[x[x[a>>2]+36>>2]](a)|0}function zX(a,b,c){a=a|0;b=b|0;c=c|0;dd(a,c,b)}function tt(a){return(a>>>0<9?a:a-9|256)&65535}function rk(a){return(x[a+4>>2]+x[a>>2]|0)-1|0}function kZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(461e3))}function jc(a,b,c){a=a|0;b=b|0;c=c|0;$l(a,b,c)}function hg(a){return(x[a+4>>2]-x[a>>2]|0)/6|0}function fT(a){return x[a>>2]+(x[a+4>>2]<<2)|0}function a7(a){a=a|0;rJ(a);Ax(a);v[a+4202|0]=1}function Zp(a,b){return(D(b,104)+a|0)+484380|0}function We(a,b,c){if(!(y[a|0]&32)){Lw(b,c,a)}}function Sk(a,b){v[a+4|0]=0;x[a>>2]=b;return a}function Sh(a){return(x[a+8>>2]|x[a+12>>2])!=0}function SN(a){RN(a);Sb(a+27|0,0,255);return a}function Rs(a,b){return(x[a>>2]-x[b>>2]|0)/6|0}function N7(a){a=a|0;v[a+4202|0]=1;CJ(a);DJ(a)}function F7(a){a=a|0;v[a+4202|0]=1;yJ(a);xJ(a)}function Be(a){return x[a+20>>2]!=0&x[a>>2]!=0}function BS(a){a=a|0;return(y[a+1|0]==1?1:2)|0}function yT(a){v[a+12|0]=y[a+12|0]|2;return a}function xc(a,b){if(A[a>>2]>b>>>0){x[a>>2]=b}}function wG(a){a=a|0;Gw(x[x[a>>2]-12>>2]+a|0)}function vt(a,b){a=a|0;b=b|0;return Uf(a,b)|0}function ux(a){a=a|0;x[a>>2]=82468;return a|0}function uk(a){return x[yb(a)>>2]-x[a>>2]>>11}function sg(a,b){if(z[a>>1]>b>>>0){w[a>>1]=b}}function rs(a){a=SH(a);x[a>>2]=59496;return a}function qt(a,b){a=a|0;b=b|0;return ON(a,b)|0}function qG(a){a=a|0;Cw(x[x[a>>2]-12>>2]+a|0)}function nia(a){a=a|0;iQ(a);return x[a+16>>2]}function mN(a,b){a=a|0;b=b|0;return wd(a,b)|0}function m0(a){a=a|0;gG(x[x[a>>2]-12>>2]+a|0)}function kI(a){a=a|0;x[a>>2]=82728;return a|0}function k0(a){a=a|0;fG(x[x[a>>2]-12>>2]+a|0)}function jN(a,b){if(!(B[a>>2]<=b)){B[a>>2]=b}}function jD(a){a=a|0;x[a>>2]=75924;return a|0}function iI(a){a=a|0;x[a>>2]=82768;return a|0}function hC(a,b){a=a|0;b=b|0;return Xu(a,b)|0}function cD(a){a=a|0;x[a>>2]=76028;return a|0}function aN(a){$M(a+20|0);zM(a+8|0);dg(a+4|0)}function Zla(a,b,c){a=a|0;b=b|0;c=c|0;df(b,c)}function Yj(a){a=ln(a);x[a>>2]=74900;return a}function Yi(a,b){a=a|0;b=b|0;return hT(a,b)|0}function YF(a){a=SH(a);x[a>>2]=59772;return a}function YE(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function Wla(a,b,c){a=a|0;b=b|0;c=c|0;vm(b,c)}function VR(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function Si(a,b){a=a|0;b=b|0;return Hb(a,b)|0}function RA(a,b){a=a|0;b=b|0;return qv(a,b)|0}function OC(a){a=a|0;x[a>>2]=76132;return a|0}function Ki(a){return(y[a+31|0]-1&255)>>>0<17}function Jga(a){a=a|0;qz(a+288|0);Xp(a+800|0)}function Hb(a,b){a=a|0;b=b|0;return Os(a,b)^1}function Gv(a,b){a=a|0;b=b|0;return az(a,b)|0}function Gd(a){a=kD(a);x[a>>2]=66656;return a}function Eda(a,b,c){a=a|0;b=b|0;c=c|0;wz(b,c)}function Do(a){x[a>>2]=0;x[a+4>>2]=0;return a}function Ch(a,b){if(x[a>>2]>(b|0)){x[a>>2]=b}}function Bna(a,b,c,d){a=wna(a,b,c,d);return a}function via(a){a=a|0;iQ(a);return x[a+4>>2]}function vd(a){return x[yb(a)>>2]-x[a>>2]>>2}function uA(a,b,c){a=a|0;b=b|0;c=c|0;xI(a,c)}function tv(a){return x[ic(a)>>2]-x[a>>2]>>5}function tF(a,b,c){a=a|0;b=b|0;c=c|0;Jd(b,c)}function so(a){return x[ic(a)>>2]-x[a>>2]>>1}function mA(a,b,c){a=a|0;b=b|0;c=c|0;Uf(b,c)}function m3(a){a=a|0;return tI(x[a+24>>2])|0}function l1(a){a=a|0;return Ta(x[a+60>>2])|0}function g9(a,b,c){a=a|0;b=b|0;c=c|0;iq(b,c)}function ei(a){return x[yb(a)>>2]-x[a>>2]>>4}function dj(a){return x[yb(a)>>2]-x[a>>2]>>3}function bE(a,b,c){a=a|0;b=b|0;c=c|0;cE(a,c)}function Vf(a){return x[yb(a)>>2]-x[a>>2]>>1}function On(a,b){return D((b-a|0)/6|0,6)+a|0}function Mka(a,b){a=a|0;b=b|0;tq(Sb(b,0,48))}function Ii(a,b,c){a=a|0;b=b|0;c=c|0;lt(a,c)}function Hx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function Hv(a){return x[ic(a)>>2]-x[a>>2]>>4}function Gg(a){return x[x[a+8>>2]>>2]==(a|0)}function Dh(a){return x[yb(a)>>2]-x[a>>2]>>5}function Dg(a){return x[ic(a)>>2]-x[a>>2]>>2}function Bx(a){return E(E(a*E(7900))+E(100))}function yl(a){a=a|0;Ew(x[a>>2]);return a|0}function vA(a){return x[ic(a)>>2]-x[a>>2]|0}function sf(a){return x[a+4>>2]-x[a>>2]>>11}function r7(a){a=a|0;return E(B[a+4220>>2])}function pf(a){return x[yb(a)>>2]-x[a>>2]|0}function p1(a){a=a|0;NG(a,16384);return a|0}function n1(a){a=a|0;Ow(a,16384);return a|0}function i1(a,b){a=a|0;b=b|0;return ih(a)|0}function dJ(a){return Uh(E(fJ(a)*E(32768)))}function _f(a,b,c){return Ia(a|0,b|0,c|0)|0}function _e(a,b){if(y[a|0]>b>>>0){v[a|0]=b}}function Zm(a){a=a|0;kG(x[a>>2]);return a|0}function XL(a){return a>>>0<=255&a>>>0>=251}function U7(a){a=a|0;return E(B[a+4212>>2])}function NG(a,b){x[a+4>>2]=x[a+4>>2]&(b^-1)}function JJ(a){a=a|0;mb[x[x[a>>2]+4>>2]](a)}function IJ(a){a=a|0;return E(B[a+4208>>2])}function Ci(a,b){a=a|0;b=b|0;return E(E(0))}function CF(){return(x[x[114284]>>2]?4:1)|0}function yw(a){a=a|0;return dh(a,461076)|0}function xr(a,b){mb[x[x[b>>2]+40>>2]](a,b)}function ws(a){return(a|0)<=65535&(a|0)>=0}function vq(a,b){return x[a>>2]-x[b>>2]>>1}function vI(a,b){a=a|0;b=b|0;Bw(a,x[b>>2])}function ue(a){return x[a+4>>2]-x[a>>2]>>5}function ti(a){return x[a+8>>2]&2147483647}function sB(a){return y[a+1|0]==2&y[a|0]<3}function rw(a){a=a|0;return dh(a,461084)|0}function rd(a){return x[a+4>>2]-x[a>>2]>>4}function qc(a){return x[a+4>>2]-x[a>>2]>>1}function pna(a,b){a=a|0;b=b|0;gj(a+12|0,b)}function pba(a,b){a=a|0;b=b|0;gj(a+40|0,b)}function p3(a){a=a|0;return+$L(x[a+24>>2])}function of(a){x[a>>2]=x[a>>2]+16;return a}function jJ(a){return E(E(a*E(96))+E(-96))}function i8(a,b,c){a=a|0;b=b|0;c=c|0;Do(a)}function hw(a){a=a|0;return dh(a,461124)|0}function ew(a){a=a|0;return dh(a,461132)|0}function dr(a){fr(a+28|0);Ab(a+12|0);xb(a)}function bk(a,b){mb[x[x[b>>2]+44>>2]](a,b)}function ak(a,b){mb[x[x[b>>2]+32>>2]](a,b)}function _j(a){x[a>>2]=x[a>>2]+12;return a}function Zt(a,b){return x[a>>2]-x[b>>2]>>2}function Zl(a){x[a>>2]=x[a>>2]+52;return a}function Xi(a){x[a>>2]=x[a>>2]+24;return a}function Wv(){da(Yj(ec(4))|0,75016,26);p()}function WG(a,b){return E(Pw(a?E(-b):b)*b)}function U0(a){a=a|0;return dh(a,460880)|0}function Og(a){return x[a+4>>2]-x[a>>2]>>3}function O8(a,b){a=a|0;b=b|0;v[a+4201|0]=b}function M2(a,b){a=a|0;b=b|0;return b-a>>3}function Lb(a){return x[a+4>>2]-x[a>>2]>>2}function Kt(a){ce(a+24|0);$d(a+12|0);$d(a)}function I0(a){a=a|0;return dh(a,460896)|0}function Hu(a){a=a|0;return dh(a,461068)|0}function G3(a,b){a=a|0;b=b|0;Bw(a,z[b>>1])}function Ck(a){xb(a+36|0);Ge(a+24|0);bm(a)}function BP(a){x[a>>2]=x[a>>2]+56;return a}function Aw(a){a=a|0;return dh(a,461060)|0}function Ao(a){x[a>>2]=x[a>>2]+32;return a}function $V(a){a=a|0;return x[a+4>>2]!=0|0}function xo(a,b,c){return z[b>>1]<z[c>>1]}function wl(a){a=a|0;return lG(x[a>>2])|0}function wd(a,b){return x[a>>2]+D(b,12)|0}function wc(a){return x[a+4>>2]-x[a>>2]|0}function td(a,b){x[a>>2]=x[b>>2];return a}function t1(a){a=a|0;if(a){tH(a);ee(a,a)}}function sm(a,b){return x[a>>2]+(b<<11)|0}function rI(a,b){a=a|0;b=b|0;Uf(a,b+12|0)}function qn(a){return x[x[a+48>>2]+12>>2]}function qm(a,b){return x[a>>2]-x[b>>2]|0}function pY(a,b){a=a|0;b=b|0;Uf(a,b+16|0)}function mL(a,b){Vl(a,C[b>>3],-C[b+8>>3])}function iJ(a){a=a|0;Sb(a+4296|0,0,81928)}function ge(a){x[a>>2]=x[a>>2]+2;return a}function fx(a){a=a|0;ys(a+8|0);return a|0}function fe(a){x[a>>2]=x[a>>2]+4;return a}function dm(a){x[a>>2]=x[a>>2]-2;return a}function c4(a,b){a=a|0;b=b|0;Bw(a,y[b|0])}function Xr(a){a=a|0;gh(a+8|0);return a|0}function Xl(a,b){return x[a>>2]+D(b,56)|0}function Wn(a){return z[a+480190>>1]<3999}function Vr(a){a=a|0;gh(a+4|0);return a|0}function Uz(a,b){return x[a>>2]+D(b,20)|0}function UD(a){a=Aa(a|0)|0;lb=ib;return a}function U9(a,b){a=a|0;b=b|0;Uf(a,b+36|0)}function Tc(a,b){return x[a>>2]+D(b,24)|0}function TR(a,b){return x[a>>2]+D(b,33)|0}function Re(a,b){return x[a>>2]+D(b,52)|0}function Qy(a,b,c){return a<b?b:E(H(a,c))}function Q1(a,b){a=a|0;b=b|0;TH(a-88|0,b)}function Ps(a,b,c){return w[b>>1]<w[c>>1]}function P1(a,b){a=a|0;b=b|0;RH(a-88|0,b)}function ON(a,b){return Uq(a,Rb(b),Bb(b))}function Jp(a){x[a>>2]=x[a>>2]-4;return a}function J8(a,b){a=a|0;b=b|0;Sb(b,0,2048)}function Dc(a,b){a=a|0;b=b|0;So(a,b+28|0)}function DC(a){return(y[a+24|0]&16)>>>4|0}function A1(a,b){a=a|0;b=b|0;DH(a-88|0,b)}function zo(a){return D(Rq(a),Je(a))&255}function zk(a){return z[qn(a)+480188>>1]}function xn(a){a=a|0;return _M(y[a|0])|0}function vc(a,b){return x[a>>2]+(b<<4)|0}function uc(a,b){return x[a>>2]+(b<<1)|0}function tia(a,b){a=a|0;b=b|0;dd(a,b,10)}function od(a){return x[a>>2]==x[a+4>>2]}function oD(a,b){Yb(a,b);Yb(a+4|0,b+4|0)}function nY(a,b){a=a|0;b=b|0;Lm(a,66400)}function ll(a,b){return x[a>>2]+(b<<3)|0}function lY(a,b){a=a|0;b=b|0;Lm(a,66420)}function kk(a){return(a|0)==32|a-9>>>0<5}function hka(a,b){a=a|0;b=b|0;dd(a,b,17)}function au(a){a=a|0;return x[a>>2]+14|0}function a9(a){a=a|0;TT(a,80,150,80,255)}function _6(a){a=a|0;return x[a+4260>>2]}function Zma(a,b){a=a|0;b=b|0;dd(a,b,44)}function Vu(a,b){return x[a>>2]+(b<<5)|0}function Ur(a,b){x[a+24>>2]=x[a+24>>2]+b}function U1(a){a=a|0;return fx(a-88|0)|0}function Qc(a,b){return x[a>>2]+D(b,6)|0}function QJ(a){return(y[a+24|0]&8)>>>3|0}function Pb(a,b){return x[a>>2]+(b<<2)|0}function Os(a,b){return x[a>>2]==x[b>>2]}function O1(a,b){a=a|0;b=+b;QH(a-88|0,b)}function Mda(a){a=a|0;return x[a>>2]-8|0}function M1(a,b){a=a|0;b=+b;OH(a-88|0,b)}function LI(a){return(Rb(a)+Bb(a)|0)-1|0}function K1(a,b){a=a|0;b=+b;MH(a-88|0,b)}function Jf(a){a=a|0;return!x[a+16>>2]|0}function Jb(a){x[x[a>>2]+4>>2]=x[a+4>>2]}function Af(a){a=a|0;return Zd(y[a|0])|0}function zu(a){a=a|0;return HA(qc(a))|0}function u1(a){a=a|0;_G(a,8);return a|0}function ro(a,b){return A[a>>2]<A[b>>2]}function pR(a,b){x[a>>2]=x[a>>2]+(b<<2)}function oY(a,b){a=a|0;b=b|0;Ub(a,7160)}function mY(a,b){a=a|0;b=b|0;Ub(a,7277)}function jF(a,b){a=a|0;b=b|0;Lj(a,1,45)}function iF(a,b){a=a|0;b=b|0;sF(a,1,45)}function fu(a,b){return B[a>>2]<B[b>>2]}function ee(a,b){if(!x[a+80>>2]){_b(b)}}function dU(a,b){a=a|0;b=b|0;dd(a,b,11)}function cO(a,b){x[a>>2]=x[a>>2]+(b<<1)}function aia(a,b){a=a|0;b=b|0;dd(a,b,5)}function Z9(a){a=a|0;return x[a>>2]-6|0}function WM(a,b){return(Jk(a,b)|0)!=255}function RT(a,b){a=a|0;b=b|0;return b|0}function Qda(a,b){a=a|0;b=b|0;Vl(b,0,0)}function N8(a){a=a|0;return y[a+4201|0]}function Mw(a){return(q(a),j(2))>>>20|0}function M8(a){a=a|0;return y[a+4202|0]}function Kq(a,b){a=a|0;b=b|0;dd(a,b,32)}function Jm(a,b,c){return yi(a,b,b+c|0)}function Hi(a){x[a+4>>2]=0;x[a+8>>2]=-1}function HP(a){a=a|0;return x[a>>2]-1|0}function Ft(a,b){return C[a>>3]<C[b>>3]}function FS(a,b){x[a>>2]=x[a>>2]+D(b,6)}function D6(a){a=a|0;return(a|0)==277|0}function Bq(a,b){return x[a>>2]<x[b>>2]}function B1(a){a=a|0;_G(a,2);return a|0}function x3(a){a=a|0;return+C[a+16>>3]}function vC(a,b){a=a|0;b=b|0;w[b>>1]=0}function rz(a,b){a=a|0;b=b|0;x[b>>2]=0}function rha(a){a=a|0;return y[a+40|0]}function qj(a,b){return Rb(a)+(b<<2)|0}function nI(a){return a?(a|0)==2?3:2:1}function iU(a){a=a|0;return x[a+24>>2]}function _0(a){a=a|0;return x[a+20>>2]}function Zs(a){a=a|0;return 2147483647}function Zd(a){return(a-1&255)>>>0<120}function QD(a,b){return y[a|0]<y[b|0]}
function Py(a,b,c){return a<b?b:H(a,c)}function Ow(a,b){x[a+4>>2]=x[a+4>>2]|b}function N1(a){a=a|0;return+PH(a-88|0)}function L1(a){a=a|0;return+NH(a-88|0)}function Kj(a){return D(x[a>>2],zo(a))}function Kga(a){a=a|0;MO(a);return a|0}function K6(a){a=a|0;return-2013527448}function Je(a){return y[a+34|0]&64?2:1}function J1(a){a=a|0;return+LH(a-88|0)}function EV(a){a=a|0;return x[a+16>>2]}function CU(a){a=a|0;return x[a+12>>2]}function CS(a,b){a=a|0;b=b|0;Ds(a,0,b)}function Ac(a){x[x[a+8>>2]>>2]=x[a>>2]}function $u(a){yb(a);return 2147483647}function x7(a){a=a|0;return-281111764}function wu(a){return(a|0)>=120?120:a}function vja(a){a=a|0;return y[a+8|0]}function vO(a){a=a|0;pQ(a);return a|0}function ts(a){x[a>>2]=82920;return a}function tI(a){return z[a+1074438>>1]}function t7(a){a=a|0;return-271958638}function re(a){return y[a+11|0]>>>7|0}function qC(a){return y[a+22|0]>>>7|0}function q8(a){a=a|0;return 542066252}function pA(a){return x[a+1304496>>2]}function lw(a){a=a|0;if(HF(a)){_b(a)}}function ln(a){x[a>>2]=74940;return a}function j7(a){a=a|0;return-620920304}function iA(a){a=a|0;return Qb(a,1)^1}function gu(a){return(y[a+16|0]&5)!=0}function fv(a){return y[a+21|0]>>>7|0}function fq(a){x[a>>2]=75840;return a}function fQ(a,b,c){Ke(a,(b<<2)+a|0,c)}function dq(a){a=a|0;$t(a);return a|0}function bu(a){a=a|0;return x[a+4>>2]}function bJ(a,b){a=a|0;b=b|0;return 0}function _z(a){a=a|0;return x[a+8>>2]}function Z$(a){a=a|0;return WF(a,1)|0}function Yr(a,b){a=a|0;b=b|0;return-1}function Yn(a,b){w[a+8>>1]=b;return a}function XG(a){a=E(a-a);return E(a/a)}function WH(a){x[a>>2]=83392;return a}function W7(a){a=a|0;return-270114148}function Vb(a){return Vu(a,y[a+16|0])}function VH(a){x[a>>2]=83416;return a}function Uma(a,b){a=a|0;b=b|0;rr(a,b)}function T$(a){a=a|0;return TF(a,0)|0}function SH(a){x[a>>2]=60544;return a}function S6(a){a=a|0;return 302837129}function S$(a){a=a|0;return TF(a,1)|0}function Rz(a,b,c,d){return Yt(b,c,d)}function Rq(a){return v[a+34|0]&1?2:1}function Oh(a,b,c){Jd(Jd(a,b)+12|0,c)}function M7(a){a=a|0;return-285139079}function Ix(a,b){a=a|0;b=b|0;return 1}function Ie(a,b){x[a+4>>2]=b;return a}function FI(a){x[a>>2]=82640;return a}function E7(a){a=a|0;return-284078960}function B6(a,b){a=a|0;b=b|0;return 3}function A6(a,b){a=a|0;b=b|0;return 2}function $D(a,b){a=a|0;b=b|0;ra();p()}function $6(a){a=a|0;return-275227023}function $$(a){a=a|0;return WF(a,0)|0}function yu(a){return x[a+4>>2]-24|0}function uI(a){return x[a+4>>2]-48|0}function rY(a){a=a|0;return v[a+8|0]}function rA(a,b){hg(a);jS(a,b);_R(a)}function qY(a){a=a|0;return v[a+9|0]}function qI(a){return x[a+4>>2]-12|0}function nna(a){a=a|0;return nv(a)|0}function nda(a){a=a|0;return fj(a)|0}function lt(a,b){a=a|0;b=b|0;Uf(a,b)}function ld(a,b){return sm(a+12|0,b)}function kv(a,b){wc(a);yC(a,b);Wp(a)}function ko(a,b){qc(a);WB(a,b);jo(a)}function hv(a,b){Lb(a);lC(a,b);og(a)}function hB(a,b){a=a|0;b=b|0;gB(a,b)}function h8(a,b,c){a=a|0;b=b|0;c=c|0}function gJ(a){x[a>>2]=0;x[a+4>>2]=0}function ec(a){return TL(sd(a+24|0))}function dO(a,b){ue(a);bO(a,b);yv(a)}function d8(a,b){a=a|0;b=b|0;vt(a,b)}function at(a){return(a|0)<0?0-a|0:a}function ala(a){a=a|0;return pA(a)|0}function aA(a,b){wc(a);$S(a,b);Wp(a)}function _M(a){return(a+5&255)>>>0<2}function VP(a){return x[a+4>>2]-56|0}function Taa(a){a=a|0;return Qh(a)|0}function Ro(a,b){a=a|0;b=b|0;aw(a,b)}function Rha(a){a=a|0;return xz(a)|0}function Ox(a,b){Lb(a);kS(a,b);og(a)}function OL(a,b){Lb(a);aL(a,b);og(a)}function OK(a,b){jg(a);PL(a,b);MK(a)}function Mt(a){return x[yb(a)>>2]<<5}function Bm(a){x[a+4>>2]=x[a+4>>2]+1}function $g(a){return x[a+4>>2]-32|0}function zr(a,b){a=a|0;b=b|0;Cg(a)}
function xj(a){return x[a+4>>2]-4|0}function xR(a){a=a|0;return au(a)|0}function xO(a,b){return Gn(a,0-b|0)}function wr(a){a=a|0;return Mm(a)|0}function wW(a){a=a|0;return LG(a)|0}function uo(a){return y[a+11|0]&127}function sC(a){return y[a+21|0]&127}function rC(a){return y[a+22|0]&127}function pW(a){a=a|0;return Me(a)|0}function nt(a,b,c){return Uy(a,b,c)}function mka(a,b){a=a|0;b=b|0;NR(b)}function jea(a,b){a=a|0;b=b|0;Kk(b)}function iba(a,b){a=a|0;b=b|0;Ck(b)}function iC(a){v[a+2|0]=0;w[a>>1]=0}function i7(a){a=a|0;x[a+4224>>2]=0}function hu(a){a=a|0;return rh(a)|0}function hba(a,b){a=a|0;b=b|0;Tf(b)}function fW(a){a=a|0;return Gf(a)|0}function f1(a){a=a|0;return gu(a)|0}function co(a){a=a|0;return Xk(a)|0}function cT(a){a=a|0;return lu(a)|0}function cG(a){a=a|0;return nr(a)|0}function bt(a){return Ap(a)<<24>>24}function Zha(a,b){a=a|0;b=b|0;Kt(b)}function Ze(a){return x[a+24620>>2]}function YC(a){a=a|0;return $q(a)|0}function Xq(a){a=a|0;return pe(a)|0}function Ww(a){return!cd(a,83492,6)}function Uk(a){a=a|0;return Xc(a)|0}function Tz(a,b){return Fe(a,0-b|0)}function RK(a){a=a|0;return Vx(a)|0}function Qn(a,b,c){return xo(a,b,c)}function Oi(a,b){return D(b,12)+a|0}function OD(a){a=a|0;return x[a>>2]}function MA(a){a=a|0;return NA(a)|0}function L9(a){a=a|0;return Px(a)|0}function Ida(a,b){a=a|0;b=b|0;ce(b)}function Fda(a,b){a=a|0;b=b|0;Ot(b)}function Fb(a,b){x[a>>2]=b;return a}function Bc(a,b){return x[a>>2]+b|0}function BG(a){a=a|0;return gh(a)|0}function BC(a){a=a|0;return pg(a)|0}function zn(a,b){return(b<<13)+a|0}function zB(a,b){a=a|0;b=b|0;Ou(b)}function xz(a){return x[a>>2]-56|0}function xi(a,b){dd(a,Rb(b),Bb(b))}function xB(a,b){a=a|0;b=b|0;Ab(b)}function x1(a,b){a=a|0;b=b|0;_b(b)}function vi(a){return od(a+36|0)^1}function rh(a){return x[a>>2]+16|0}function rg(a,b){return(b-a|0)+a|0}function o2(a,b){a=a|0;b=b|0;Pi(b)}function nz(a,b){a=a|0;b=b|0;mf(b)}function lu(a){return x[a>>2]-16|0}function jn(a,b){x[a+1304560>>2]=b}function fo(a,b){a=a|0;b=b|0;me(b)}function fF(a){return dh(a,460952)}function ex(a){a=a|0;v[a+6152|0]=0}function eF(a){return dh(a,460944)}function du(a,b){a=a|0;b=b|0;XA(b)}function dk(a,b){a=a|0;b=b|0;Wb(a)}function cV(a,b){a=a|0;b=b|0;iC(b)}function aF(a){return dh(a,460968)}function Yv(a,b){a=a|0;b=b|0;Xc(b)}function Xk(a){return x[a>>2]-24|0}function WV(a,b){a=a|0;b=b|0;dr(b)}function TC(a,b){a=a|0;b=b|0;um(b)}function Sr(a){return ne(a,-1)?0:a}function Px(a){return x[a>>2]-52|0}function Pg(a,b){x[a>>2]=x[a>>2]|b}function Ou(a){v[a|0]=0;v[a+1|0]=0}function NL(a,b){x[a>>2]=x[a>>2]+b}function Mm(a){return x[a>>2]-12|0}function Mk(a,b){oo(a,b,x[b+4>>2])}function HW(a,b){a=a|0;b=b|0;TD(b)}function DU(a,b){a=a|0;b=b|0;ci(b)}function Bi(a){a=a|0;v[a+4202|0]=0}function $q(a){return x[a>>2]-32|0}function $G(a){C[(hb-16|0)+8>>3]=a}function $E(a){return dh(a,460960)}function zba(a){a=a|0;mg(a,Bj(a))}function xW(a){a=a|0;Tn(a,1,9299)}function wB(a,b){return Fu(a,b,7)}function vp(a){uh(a+4|0);return a}function vh(a){x[a>>2]=x[a>>2]-24}function vB(a){return y[a+1|0]==1}function un(a){return a+1074328|0}function tx(a,b){return dy(a,b)^1}function tB(a,b){return nm(a,b,7)}function rP(a,b){return Fu(a,b,4)}function qia(a){a=a|0;zR(a,65535)}function pc(a,b){return Rb(a)+b|0}function ox(a){return a+1304500|0}function mv(a){return v[a+24|0]&1}function mq(a){x[a>>2]=x[a>>2]-16}function ku(a,b){return Td(a,b)^1}function ij(a){x[a>>2]=x[a>>2]-12}function ih(a){return a-48>>>0<10}function fd(a,b){return(b<<1)+a|0}function ai(a){x[a>>2]=1;return a}function _q(a){x[a>>2]=x[a>>2]-32}function Zn(a){x[a>>2]=2;return a}function Xc(a){x[a>>2]=0;return a}function Vx(a){return x[a>>2]-4|0}function Tl(a){w[a>>1]=0;return a}function SJ(a){return a+1074332|0}function Rv(a,b){return x[a+b>>2]}function RQ(a,b){return nm(a,b,5)}function Pe(a){return x[mc(a)>>2]}function NA(a){return x[a>>2]-2|0}function KQ(a,b){return(b<<4)+a|0}function FK(a){x[a>>2]=x[a>>2]-52}function DP(a){x[a>>2]=x[a>>2]-56}function Ae(a){return jg(a)&65535}function $e(a,b){return(b<<2)+a|0}function zd(a){return x[a>>2]!=0}function wq(a){qc(a);LB(a);jo(a)}function wm(a){Dh(a);ue(a);Dh(a)}function wX(a){a=a|0;return 9007}function vX(a){a=a|0;return 6267}function ug(a,b){x[a>>2]=x[b>>2]}function tu(a){Vi(a);hg(a);Vi(a)}function tq(a){return Sb(a,0,48)}function tY(a){a=a|0;yE(a);_b(a)}function sY(a){a=a|0;xE(a);_b(a)}function qP(a){return y[a|0]<129}function pt(a){Lb(a);BL(a);og(a)}function pK(a){sf(a);iK(a);hK(a)}function or(a){a=a|0;ZD(a);_b(a)}function oT(a){cm(a);Wi(a);cm(a)}function nK(a){Lb(a);fK(a);og(a)}function ml(a){ei(a);rd(a);ei(a)}function mi(a){xg(a);zc(a);xg(a)}function jt(a){wc(a);kT(a);Wp(a)}function j0(a){a=a|0;return 6387}function ig(a){af(a);xd(a);af(a)}function gr(a){ue(a);sD(a);yv(a)}function fX(a){a=a|0;return 5757}function er(a){dj(a);Og(a);dj(a)}function eX(a){a=a|0;return 8893}function dX(a){a=a|0;return 6749}function dK(a){uk(a);sf(a);uk(a)}function cX(a){a=a|0;return 2206}function bg(a){x[a>>2]=x[a>>2]+1}function _Y(a){a=a|0;KE(a);_b(a)}function Z0(a){a=a|0;zl(a);_b(a)}function Yy(a){x[a>>2]=x[a>>2]+8}function Ye(a){vd(a);Lb(a);vd(a)}function Xn(a){pf(a);wc(a);pf(a)}function XT(a){qc(a);PT(a);jo(a)}function Sx(a){jg(a);QL(a);MK(a)}function Ss(a){return XL(y[a|0])}function SR(a){am(a);Qk(a);am(a)}function Ry(a){v[a|0]=0;return a}function Rj(a){Vf(a);qc(a);Vf(a)}function RL(a){tj(a);jg(a);tj(a)}function Qe(a,b){Fb(Xc(a)+4|0,b)}function Or(a){a=a|0;nr(a);_b(a)}function OP(a){Kn(a);Lk(a);Kn(a)}function Nj(a){x[a>>2]=x[a>>2]+6}function MR(a){Lb(a);LR(a);og(a)}function LY(a){a=a|0;HE(a);_b(a)}function JA(a){Wi(a);DT(a);CT(a)}function IP(a){x[a>>2]=x[a>>2]-1}function Hw(a){a=a|0;gh(a);_b(a)}function Di(a){Lb(a);lS(a);og(a)}function D0(a){a=a|0;Xo(a);_b(a)}function CY(a){a=a|0;XE(a);_b(a)}function AR(a,b){sc(a,b+4|0,256)}function zh(a,b,c){cf(a,c,13,b)}function zga(a){a=a|0;_b(NO(a))}function ww(a,b){return tD(a,b)}function vj(a){return!x[a+4>>2]}function tD(a,b){return rg(a,b)}function st(a,b){return Jd(a,b)}function rp(a){w[a+480214>>1]=0}function qe(a){a=a|0;return a|0}function qS(a,b){return Fb(a,b)}function pd(a){ZI(a,0);return a}function oga(a){a=a|0;_b(JO(a))}function hc(a){a=a|0;_b(a-24|0)}function gi(a,b){return a>>>b&1}function gQ(a,b){return Mi(b,a)}function gC(a,b){return dC(a,b)}function fm(a,b){return df(a,b)}function et(a){Ge(a+12|0);DN(a)}function ef(a){xb(a+20|0);xb(a)}function dg(a){_s(a,0);return a}function _u(a,b){return eC(a,b)}function Zb(a,b){return Re(a,b)}function ZX(a){a=a|0;xb(461188)}function XX(a){a=a|0;Nc(461204)}function Vt(a,b){return mR(a,b)}function Vh(a){return ue(a)&255}function VX(a){a=a|0;xb(461220)}function Ul(a){xb(a+12|0);xb(a)}function TX(a){a=a|0;Nc(461236)}function T1(a){a=a|0;UH(a-88|0)}function RX(a){a=a|0;xb(461252)}function PX(a){a=a|0;Nc(461268)}function PD(a,b,c){dd(a,b,1<<c)}function Oe(a,b){return Xf(a,b)}function Od(a,b){return sm(a,b)}function Nv(a,b){return yf(a,b)}function Ni(a,b){return Vu(a,b)}function NX(a){a=a|0;xb(461284)}function LX(a){a=a|0;Nc(461300)}function Kx(a,b){return uK(a,b)}function Kk(a){xb(a+12|0);qf(a)}function DL(a,b){return zL(a,b)}function Cn(a){return Cj(Qd(a))}function Br(a){a=a|0;return 127}function x2(a){a=a|0;_b(kI(a))}function vx(a){a=a|0;_b(SI(a))}function uE(a){a=a|0;_b(Zv(a))}function u2(a){a=a|0;_b(iI(a))}function tk(a){a=a|0;_b(xf(a))}function pha(a){a=a|0;return 9}function pD(a){a=a|0;_b(nr(a))}function p0(a){a=a|0;_b(ls(a))}function nJ(a){a=a|0;_b(oJ(a))}function mR(a,b){return b-a>>2}function jC(a,b){Wu(a,Rb(a),b)}function il(a){return a>>>0<11}function gG(a){a=a|0;_b(Xd(a))}function fc(a,b){x[a+100>>2]=b}function fG(a){a=a|0;_b(Lf(a))}function ct(a,b){return a<<8|b}function bW(a){a=a|0;_b(jD(a))}function Z6(a){a=a|0;return 13}function XF(a){a=a|0;_b(zl(a))}function Wd(a,b){v[a|0]=y[b|0]}function Vy(a,b){return b-a>>1}function VJ(a){a=a|0;_b(WJ(a))}function UH(a){a=a|0;_b(fx(a))}function UF(a){a=a|0;_b(Xo(a))}function SV(a){a=a|0;_b(cD(a))}function Ms(a){a=a|0;_b(Jx(a))}function LV(a){a=a|0;_b(OC(a))}function LO(a){return a+4896|0}function Js(a){return a>>>27^a}function JV(a){a=a|0;_b(NC(a))}function Gw(a){a=a|0;_b(Xr(a))}function DS(a){return a+2466|0}function Cx(a){a=a|0;_b(KJ(a))}function Cw(a){a=a|0;_b(Vr(a))}function CL(a,b,c){Wy(a,b,c,1)}function CG(){return(Ra()|0)>0}function C2(a){a=a|0;_b(zs(a))}function B4(a){a=a|0;_b(ux(a))}function AJ(a){a=a|0;_b(BJ(a))}function yG(a){a=a|0;return-1}function xh(a){return od(a)^1}function w4(){return 19469590}function vE(a){return Vd(a,1)}function te(a){a=a|0;return 1}function se(a){a=a|0;return 2}function sX(){$D(13238,0);p()}function mo(a){return a>>>0<5}function kc(a){a=a|0;return 0}function iW(a){a=a|0;return 3}function hs(a){return bH(a)*a}function hT(a,b){return b-a|0}function hR(a){return fR(a,1)}function gc(a,b){return a+b|0}function fL(a){a=a|0;return 5}function cl(a){return!x[a>>2]}function Se(a,b){w[a+28>>1]=b}function Po(a){return a>>>0<2}function Nl(a,b){x[a+32>>2]=b}function Lr(a,b){x[a+72>>2]=b}function L7(a){a=a|0;return 6}function FO(a,b){Sb(a,0,b<<2)}function Et(a){return a+256|0}function Em(a){a=a|0;return 4}function BR(a){a=a|0;return 7}function BD(a){return a>>>0>8}function An(a,b){x[a+36>>2]=b}function Aj(a){return zd(a)^1}function xS(a){jS(a,x[a>>2])}function wA(a,b){pf(a);pf(a)}function vk(a,b){vd(a);vd(a)}function rv(a,b){dj(a);dj(a)}function rl(a){return a+16|0}function qp(a,b){B[a+8>>2]=b}function op(a,b){B[a+4>>2]=b}function ol(a,b,c){PD(a,b,c)}function np(a,b){v[a+36|0]=b}function mr(a,b,c){dd(a,b,c)}function lS(a){kS(a,x[a>>2])}function kT(a){$S(a,x[a>>2])}function ic(a){return a+12|0}function iK(a){eK(a,x[a>>2])}function hy(a,b){v[a+37|0]=b}function gy(a,b){v[a+38|0]=b}function gd(a,b,c){ym(a,b,c)}function fl(a,b,c){Bg(a,b,c)}function fK(a){bK(a,x[a>>2])}function eO(a){bO(a,x[a>>2])}function bM(a){return a+80|0}function ar(a,b){Dh(a);Dh(a)}function ah(a){return a+20|0}function ae(a,b){x[a+4>>2]=b}function Yk(a,b){af(a);af(a)}function Wl(a,b){yb(b);yb(a)}function Vs(a,b){_s(a,ke(b))}function UE(a){oE(a,x[a>>2])}function Tr(a,b){So(a,b+4|0)}function TL(a){return a+24|0}function QL(a){PL(a,x[a>>2])}function Pn(a,b){x[a+8>>2]=b}function PP(a,b){cf(a,b,8,2)}function Nm(a,b){xg(a);xg(a)}function Mq(a,b){Vf(a);Vf(a)}function LR(a){lC(a,x[a>>2])}function LB(a){WB(a,x[a>>2])}function Kb(a,b,c){EC(a,b,c)}function Jo(a,b){ei(a);ei(a)}function HK(a,b){tj(a);tj(a)}function Gc(a,b){a=a|0;b=b|0}function FA(a,b){Vi(a);Vi(a)}function Dv(a,b){rD(a,ke(b))}function DT(a){sT(a,x[a>>2])}function CC(a){yC(a,x[a>>2])}function BL(a){aL(a,x[a>>2])}function AN(a){vN(a,x[a>>2])}function AM(a){yM(a,x[a>>2])}function $Q(a,b,c){nx(a,b,c)}function yb(a){return a+8|0}function x4(){return 327702}function wp(a){Sb(a,0,8192)}function vma(){return 65535}function uz(a){x[a+12>>2]=0}function ria(){return 65534}function rf(a){return a+2|0}function pm(a,b){v[a+3|0]=b}function nC(a,b){dd(a,b,22)}function mc(a){return a+4|0}function mM(a){Sb(a,0,1024)}function ed(a){return a+1|0}function _B(a,b){dd(a,b,20)}function Xp(a){Sb(a,0,4096)}function Wg(a){return a&255}function Wc(a){return!Bb(a)}function $h(a){return a+3|0}function zM(a){Ys(a,Pe(a))}function yv(a){Dh(a);ue(a)}function uS(a){v[a+31|0]=0}function tL(a){cy(a,Pe(a))}function rS(a){lA(a,Pe(a))}function qz(a){Sb(a,0,512)}function pp(a,b){B[a>>2]=b}function om(){Zi(6974);p()}function og(a){vd(a);Lb(a)}function mS(a){nA(a,Pe(a))}function jo(a){Vf(a);qc(a)}function ir(a){a=a|0;jr(a)}function hK(a){uk(a);sf(a)}function cq(a){Yz(a,Pe(a))}function _R(a){Vi(a);hg(a)}function Yp(a){af(a);xd(a)}function XM(a){By(a,Pe(a))}function XB(){Zi(3950);p()}function Wt(a){Xz(a,Pe(a))}function Wp(a){pf(a);wc(a)}function Vc(){Jv(3950);p()}function Ue(a,b){x[a>>2]=b}function Oc(a){a=a|0;_b(a)}function Ob(a){Am(x[a>>2])}function MK(a){tj(a);jg(a)}function Lc(a){x[a+8>>2]=0}function LD(a){ei(a);rd(a)}function J$(){return 61832}function I$(){return 63376}function Ht(a){xg(a);zc(a)}function Gk(a){Ty(a,Pe(a))}function Ej(a,b){oo(a,b,0)}function Ef(){Jv(6974);p()}function EB(a,b){Th(a,2,b)}function CT(a){cm(a);Wi(a)}function pG(a){Sb(a,0,44)}function mC(a){v[a+1|0]=3}function d1(a){a=a|0;ib=a}function bX(){return hb|0}function aX(a){a=a|0;hb=a}function _F(a){Ow(a,8192)}function Y3(){return 2048}function NR(a){Sb(a,0,33)}function tQ(a,b){wx(a,b)}function qh(a){a=a|0;p()}function oB(a,b){sI(a,b)}function me(a){Ab(a+8|0)}function aO(a,b){zf(a,b)}function Sn(a,b){bG(a,b)}function Pi(a){xb(a+4|0)}function Oo(a,b){sE(a,b)}function Hc(a){uh(a+8|0)}function Fh(a,b){bh(a,b)}function DA(a){v[a|0]=16}function mf(a){v[a|0]=0}function yy(a){iM(a,0)}function xy(a){hM(a,0)}function ui(a){MI(a,0)}function fr(a){rD(a,0)}function aw(a,b){xb(b)}function Tf(a){sS(a,0)}function Ky(a){_s(a,0)}function Jc(a){we(a,0)}function JL(a){sL(a,0)}function tr(a){_j(a)}function bo(a){Xi(a)}function bT(a){of(a)}function XC(a){Ao(a)}function Gb(a){xb(a)}function Ee(a){a=a|0}function wZ(){TE()}function rZ(){SE()}function pZ(){RE()}function nZ(){QE()}function lZ(){PE()}function dZ(){OE()}function OZ(){IE()}
// EMSCRIPTEN_END_FUNCS
e=y;var mb=c([null,Fn,Ub,Aq,Uf,Mma,Tn,eja,oia,rj,lha,Vfa,Gea,Ds,Fn,J0,NU,im,Jg,d0,_,Hu,al,KW,GW,ZD,qe,XV,ne,WU,iU,gm,Yi,Gh,yc,Mb,Gc,Yi,tka,nz,Yh,GA,Kfa,NO,qh,te,te,vja,sja,bu,pja,XO,Xga,Oga,sX,JO,qh,te,kc,te,via,nia,iia,eia,Yha,zga,Gha,oga,rha,kha,qe,qh,KN,Sda,dda,mN,qt,lN,uN,rN,kt,Th,Xba,xa,Sba,yc,yc,Rba,Ay,Fba,Cba,HX,Id,yc,jba,fba,qL,Kl,nh,Id,GX,Waa,Iaa,Ee,y8,Gc,qL,No,rr,AX,CX,Fn,o8,d7,mn,rna,UI,Uf,Ub,E5,$4,ME,s4,l4,h4,e2,a2,f0,W1,c4,W3,G3,vI,vI,q3,g3,vs,Aq,us,y2,r2,us,B1,u1,p1,n1,us,us,Q0,f1,$0,X0,S0,N0,M0,$w,P0,u0,Fn,C0,qt,x0,v0,f$,Jr,lt,K$,z$,yc,tF,r_,bd,cZ,wr,sr,Ro,yc,yc,GA,Im,JW,IW,FW,Gc,HW,Gc,nz,oea,EW,DW,CW,BW,Ii,zW,e0,_$,yW,DD,CD,xW,Jr,wW,uW,Gv,ir,gj,Pc,rW,Gm,qW,oW,sW,nW,mW,vW,gea,tW,AD,lW,kW,zD,jW,If,fj,Rc,Bv,Qb,eW,Uj,Bv,dW,nr,VV,UV,Id,TC,OD,cW,WV,ci,yc,TV,bd,QV,PV,YC,Id,WC,Gc,OV,NV,MV,Yi,pD,bu,jD,bW,Co,bJ,aW,Oc,$V,te,te,bu,_z,_V,XO,ZV,YV,cD,SV,Co,RV,Oc,kc,te,te,kc,kc,bD,OC,LV,Co,KV,NC,JV,IV,HV,GV,FV,EV,DV,CV,BV,Kv,uf,Mb,wV,Qaa,vV,Paa,uV,nv,cc,Taa,eD,Bd,tV,yc,nh,DX,Kl,Ro,Gc,KC,qV,pV,pD,yc,yc,BC,nV,mV,Gc,Gc,Gc,lV,GA,nz,vC,Im,dV,nh,kV,hV,cV,Gc,BC,hC,bV,Yu,aV,YU,XU,Uu,io,Gc,RU,PB,QU,PU,OU,MU,Kg,Ic,LU,KU,JU,IU,HU,Eg,cg,Tg,GU,yc,yc,FU,Kl,DU,vC,Gc,EU,Uu,zB,xB,zU,yU,xU,wU,vU,Lg,uU,tU,sU,rU,Sw,wJ,Cb,IO,qU,fW,kg,pU,Qu,qB,jd,Nd,gj,uj,mU,lU,aj,Xq,Xg,SL,kU,jU,Ku,rc,Cc,Cv,hU,pB,be,Nu,Sp,Cb,bl,Cb,Cb,fU,Cb,aC,eU,dU,Jq,Df,Ru,tna,_T,wD,Gi,Cf,Nb,Ig,sna,WA,qna,Pc,Du,yea,pna,ona,Qp,nna,ZT,YT,Ad,mna,VA,lna,haa,mm,lo,Ll,Xx,WK,kna,UT,NJ,jna,ina,hna,Ok,UA,gna,fna,Kq,ST,ena,dna,Mg,yc,cna,bna,KN,ana,Zma,PA,Yma,PA,Uma,mN,qt,lN,fo,yc,uq,$ma,bd,_ma,co,ao,Gc,bd,Xma,Wma,MA,Vma,kt,Rma,Qma,Pma,Lma,RA,Kma,IA,Jma,Ima,Hma,zu,Gma,Rp,oz,Fma,Ema,Dma,Cma,Bf,Af,Bma,Ama,zma,uma,tma,yc,sma,rma,wT,xma,wma,Im,Gc,fo,Gc,bd,uq,qma,co,ao,Fj,pq,nma,ou,mma,jma,_T,oq,gg,ima,pu,pz,ZT,hma,lm,gma,fma,gT,ema,dma,dH,km,Rt,cma,Kda,ST,bma,ama,yc,lg,Ula,fo,yc,uq,$la,bd,_la,co,ao,Zla,Yla,bd,Wla,Vla,cT,aT,Tla,SS,_K,naa,XK,NS,Mla,Lla,yh,Ila,Hla,oba,Ela,Dla,Cla,Bla,gv,Ala,zla,yla,If,fV,xla,Iga,Jga,wla,vla,Kla,Vn,iV,ula,Tp,gV,IS,tla,sla,Gba,_c,rla,qla,HS,pla,$U,ola,nla,mla,GS,lla,vz,kla,jla,eV,FT,Jla,ila,CS,yc,hla,uA,rN,Gq,gla,fla,bn,kba,ela,dla,AS,tA,AS,pl,cla,LW,bla,ala,$ka,_ka,sh,wea,sh,S9,Zka,q9,wS,Nka,ej,Dd,Un,Uka,oA,Lka,hB,Ko,yi,hA,Kka,Jka,vS,Yka,Xka,zf,Wka,Si,hu,r9,qba,h9,Vka,Aq,Tka,Ska,Rka,Id,Uk,Id,mA,qe,pS,Rk,qe,Gc,Gc,Gc,Pka,nh,du,Mka,Fka,Eka,Dka,_n,Cka,Bka,vD,Aka,jd,gl,zka,yka,xka,wka,vka,uka,ska,rka,yc,qka,pka,ika,hka,oka,nka,mka,Gc,JR,fo,yc,lka,kka,bd,jka,co,ao,CR,Vn,eka,dka,cka,bka,Jea,If,aka,$ja,_ja,Zja,YS,uO,Hb,au,cA,zA,Yu,Yja,Xja,zR,Wja,Kq,Iq,iu,HA,Vja,yR,Lj,Uja,Aq,If,Mu,If,ov,Fq,Tja,Si,xR,Bea,Qx,vR,dq,yc,yc,Uk,Id,Gc,Sja,nh,du,lR,qe,Gc,Rja,Uu,zB,Qja,Rk,Nja,Mja,ej,Lja,Kja,Vz,Ut,Jja,Ija,Hja,Gja,Fja,Eja,RB,Dja,Cja,Cb,Bja,Aja,zja,yja,Hga,Ada,bD,xja,Cb,Tt,q1,qA,r1,Tt,wja,uja,s1,t1,lba,tja,zS,yS,lz,Ii,rja,du,qja,Im,Yi,Gc,xB,xu,St,Vk,yi,If,pq,gja,fja,nja,iA,Gc,bja,qB,mB,aja,mba,$ia,_ia,LK,Un,Zia,xQ,Yia,Xia,ev,dv,Pt,dca,Wia,Via,xt,Uia,go,Tia,Sia,yc,Gc,Ria,Qia,TC,mm,If,Lia,mg,Kia,Id,Jia,Iia,hQ,Id,Hq,Hia,Eia,Dia,Wk,Dn,Pt,_c,Cia,maa,du,Gc,Bia,nh,yia,xia,IA,jQ,WP,Nu,wia,uia,tia,sia,vma,ria,qia,pia,Lt,mia,lia,Lt,kia,aB,SP,jia,yc,jV,yc,bia,Xha,Wha,pq,fia,dia,cia,fo,aia,uq,$ha,bd,_ha,co,ao,Zha,KP,JP,Vha,Im,Uha,HP,bd,Tha,Sha,Rha,yc,Qha,Nha,Vn,Mha,Iha,MO,xQ,Vn,Cda,Bda,Eha,yha,xha,KT,Cv,wha,vha,uha,tha,sha,jP,Xt,qha,oha,nha,yc,mha,jha,iha,eha,cP,Gc,hha,bd,gha,fha,yc,wr,yc,sr,lO,bha,Ez,aha,$ga,Cea,Yga,Wga,Maa,Vga,Uga,Tga,Kaa,Sga,Laa,Naa,Rga,Qga,Pga,AW,GD,Fea,Mz,yc,vba,tba,sz,Nga,rz,Mga,nh,Gc,Lga,Gga,zj,yj,Lp,Fga,Ega,Dga,Cga,Bga,Aga,yga,xga,wga,vga,uga,tga,sga,rga,qga,pga,nga,mga,lga,kga,jga,iga,hga,gga,fga,ega,dga,cga,bga,aga,$fa,_fa,Zfa,Yfa,Xfa,Wfa,Ufa,Tfa,Sfa,Rfa,Qfa,Pfa,Ofa,Nfa,Mfa,Lfa,Jfa,Ifa,Hfa,Gfa,Ffa,Efa,Dfa,Cfa,Bfa,Afa,zfa,yfa,xfa,wfa,vfa,ufa,tfa,sfa,rfa,qfa,pfa,ofa,nfa,mfa,lfa,kfa,jfa,ifa,hfa,gfa,ffa,efa,dfa,cfa,bfa,afa,$ea,_ea,Zea,Yea,Xea,Wea,Vea,Uea,Tea,Sea,Rea,Qea,Pea,Oea,Nea,Mea,Iea,vO,yc,Lea,Uk,Id,io,Rk,lea,Pj,Dea,Eea,fO,yc,zea,iea,xea,fea,eea,vea,uea,tea,sea,rea,dz,qea,pea,nea,mea,vS,vt,cea,kea,MA,jea,hea,io,yc,bd,dea,YC,WC,XN,yc,bea,Id,$da,_da,Zda,QN,Yda,gB,Xda,OD,MN,Zaa,Wda,Vda,Ts,Xaa,Uda,Vaa,Uaa,Tda,yc,Pda,Rda,Qda,Gc,Gc,Oda,Nda,Mda,Hk,yc,Hda,Gda,Ida,Fda,bd,Eda,Dda,wr,sr,zda,ex,yda,xda,dl,wda,rba,gz,Hea,oO,vda,uda,Id,tda,io,io,sda,MA,qt,zD,Uk,Id,yc,tF,qda,qe,Rk,bd,pda,wr,sr,BS,Yd,QB,oV,bf,jc,gU,oda,nda,yma,mda,lda,kda,jda,ida,hda,gda,fda,eda,cda,bda,ada,$ca,_ca,Zca,Yca,Xca,Wca,Vca,Uca,Tca,Sca,Rca,Qca,Pca,Oca,Nca,Mca,Lca,Kca,Jca,Ica,Hca,Gca,Fca,Eca,Dca,Cca,Bca,Aca,zca,yca,xca,wca,vca,uca,tca,sca,rca,qca,pca,oca,nca,mca,lca,kca,jca,ica,hca,gca,fca,eca,cca,Lda,bca,aca,$ba,yN,xN,_ba,Zba,xn,gt,Ny,Yba,iN,AO,Bt,Gp,hN,Mb,GL,UL,ly,Fp,ft,Ep,Wba,bN,yO,CO,Vba,Uba,Si,hu,dq,WN,_y,Ji,Si,xR,Tba,dq,Jda,yc,yc,Qba,Pba,Uk,Id,Id,Uk,Id,Gc,qe,wM,Oba,Rk,qe,Nba,Rk,Lba,Aea,Kga,Kba,hL,oM,bba,Jba,Iba,Me,yc,yc,yc,yc,yc,Hba,Eba,hW,AV,yV,sV,Bba,rV,zV,gW,xV,Hn,Aba,Kea,cM,sp,zba,g8,yba,wy,Oaa,yc,yc,aea,Kl,nh,Id,uba,sba,F9,J9,pba,H9,E9,Id,yc,az,Ip,wO,iba,hba,gba,eba,Im,dba,HP,Gc,_ga,Zga,Gla,Fla,Kha,Jha,Dha,Cha,gka,fka,Pia,Oia,Hka,Gka,vna,una,Sla,Rla,BU,AU,oU,nU,Nia,Mia,Pha,Oha,dha,cha,Oma,Nma,pma,oma,VU,UU,TU,SU,Aia,zia,hia,gia,dja,cja,Ika,VR,Qla,Pla,Ola,Nla,Tma,Sma,lma,kma,Gia,Fia,Jaa,Haa,raa,qaa,ija,hja,Hha,Fha,Bha,zha,oja,kja,jja,_U,ZU,cU,bU,Pja,Oja,mja,lja,$aa,yc,Kl,nh,_aa,Uk,Id,Gc,mA,Rk,Yaa,by,Ip,Raa,Saa,qN,Gaa,Faa,IA,Eaa,Bu,Daa,WP,Caa,Baa,Aaa,pq,zaa,yaa,If,xaa,waa,vaa,uaa,taa,SP,saa,yc,z1,w1,v1,fo,uq,paa,bd,oaa,co,ao,laa,kaa,jaa,hA,sh,faa,eaa,sh,daa,Jf,bh,xl,caa,Y9,baa,Kl,aaa,RK,$9,hA,_9,Z9,X9,R9,yc,W9,iaa,V9,P9,O9,T9,gaa,Q9,bd,N9,M9,L9,yc,yc,K9,EK,yc,Uk,Id,u9,nh,s9,Nx,Si,hu,G9,L6,t9,C9,B9,sh,A9,z9,y9,zK,CK,I9,mp,dz,x9,zf,BK,v9,Wj,_v,bh,rz,pS,Rk,p9,o9,n9,m9,l9,k9,hj,j9,i9,w9,D9,g9,f9,bd,e9,RK,d9,b9,a9,$8,p8,_8,Z8,gK,L8,Nf,nh,AK,K8,I8,J8,Gc,rz,Gc,Jx,Ms,Ms,Q8,kc,Ee,kc,kc,kc,Gc,Em,U8,V8,X8,W8,Y8,Ci,Ix,Ix,Hx,Hx,Hx,Xla,Ee,VR,P8,O8,N8,M8,T8,Bi,lK,n8,kc,kc,te,Gx,se,se,te,S8,R8,Gc,Ee,Gc,Ee,G8,lR,r8,WJ,VJ,VJ,q8,kc,Ee,kc,kc,kc,Gc,pha,aK,E8,t8,s8,F8,Ci,C8,B8,A8,z8,x8,w8,v8,u8,D8,Bi,$J,kc,kc,te,se,se,te,_J,YJ,yc,yc,k8,j8,PJ,xf,qh,l8,OJ,m8,kc,i8,h8,f8,lt,e8,d8,c8,b8,Id,yc,nh,vt,Kl,Gc,a8,S7,K7,D7,w7,p7,g7,Y6,R6,c9,H8,LJ,KJ,Cx,JJ,W7,kc,Ee,kc,kc,kc,Gc,BR,Z7,_7,$7,Ci,Y7,Bi,X7,kc,kc,te,se,se,Gc,Ee,IJ,V7,U7,HJ,T7,FJ,EJ,R7,BJ,AJ,AJ,M7,kc,Ee,kc,kc,kc,Gc,L7,O7,P7,Q7,Ci,N7,Bi,CJ,kc,kc,te,se,se,J7,tk,tk,E7,kc,Ee,kc,kc,kc,Gc,fL,G7,H7,I7,Ci,F7,Bi,xJ,kc,kc,te,se,se,C7,Jx,Ms,Ms,x7,kc,Ee,kc,kc,kc,Gc,fL,z7,A7,B7,Ci,y7,Bi,uJ,kc,kc,te,se,se,v7,Cx,Cx,t7,BR,u7,IJ,s7,r7,HJ,q7,FJ,EJ,o7,tk,tk,j7,kc,Ee,kc,kc,kc,Gc,se,l7,m7,n7,Ci,k7,Bi,i7,kc,kc,te,se,se,f7,h7,oJ,nJ,nJ,$6,kc,Ee,kc,kc,_6,Gc,Z6,b7,c7,e7,Ci,a7,Bi,Ax,kc,kc,te,se,se,Gc,Ee,X6,tk,tk,S6,kc,Ee,kc,kc,kc,Gc,iW,U6,V6,W6,Ci,T6,Bi,lJ,kc,kc,te,se,se,Q6,tk,tk,K6,kc,Ee,kc,kc,kc,Gc,Em,N6,O6,P6,Ci,M6,Bi,iJ,kc,kc,te,se,se,x4,I6,D4,p4,w4,v4,b4,Gv,$3,Cs,_I,X3,y6,x6,Id,Id,Y3,U3,T3,S3,da,u6,t6,_I,R3,P3,WI,q6,SI,wI,_z,z3,y3,C3,w3,x3,A3,yx,O3,a6,RI,N3,M3,L3,K3,J3,I3,H3,F3,E3,D3,v3,yx,r3,p3,o3,n3,m3,l3,k3,j3,i3,h3,f3,e3,d3,c3,fp,b3,a3,Fl,xs,$2,lE,_2,Y2,X2,W2,V2,U2,T2,mx,S2,R2,P2,O2,N2,L2,K2,I2,G2,E2,g4,JI,II,HI,GI,X1,V1,WI,yx,V4,U4,T4,S4,R4,Q4,P4,O4,N4,M4,L4,K4,J4,I4,H4,G4,F4,E4,C4,z4,ux,B4,A4,vx,y4,vx,vx,_C,As,u4,rda,hr,s2,q4,n2,m2,ht,k4,yc,wM,k2,Mba,f4,dE,lO,Id,Id,Id,J2,D2,H2,F2,Dba,j4,t4,o4,lv,Si,hu,dq,yc,cv,d4,cba,aba,a4,OI,NI,Z3,V3,_3,Id,i4,e4,m4,yc,yc,yc,Cb,jc,Q3,B3,yc,yc,Id,_L,u3,Z1,wba,xba,n4,nba,t3,s3,kn,rI,U9,Z2,Bj,KK,Q2,Df,WL,ZK,YK,M2,z2,v2,Lha,Aha,q2,p2,cT,bd,l2,aT,o2,Gc,_1,mA,Y1,qh,zs,C2,r4,qe,qh,qe,Oc,B2,A2,qh,kI,x2,Co,w2,iI,u2,Co,t2,Oc,j2,qe,Oc,i2,h2,Oc,cI,bI,qh,Oc,g2,f2,Oc,aI,$H,Oc,d2,c2,Oc,_H,ZH,Oc,b2,$1,Oc,YH,XH,fx,UH,S1,R1,TH,RH,QH,PH,OH,NH,MH,LH,KH,JH,IH,HH,GH,FH,EH,DH,U1,T1,Q1,P1,O1,N1,M1,L1,K1,J1,I1,H1,G1,F1,E1,D1,C1,A1,qe,qh,qe,qh,y1,x1,o1,m1,Bl,l1,k1,j1,h1,g1,c1,b1,sn,Dc,U0,R0,_0,T0,O0,F0,L0,Ew,K0,Qka,Oka,nS,I0,H0,G0,F0,E0,oG,A0,w0,sn,Jg,qe,zl,Z0,Gc,Fn,AG,zG,kc,kc,Y0,yG,W0,Yr,V0,Yr,Xr,Gw,xG,wG,Vr,Cw,rG,qG,Xo,D0,Gc,Fn,AG,zG,kc,kc,B0,yG,z0,Yr,y0,Yr,Xr,Gw,xG,wG,Vr,Cw,rG,qG,ls,p0,q0,o0,t0,s0,r0,BG,Hw,BG,Hw,Xd,gG,n0,m0,Lf,fG,l0,k0,Ee,g0,h0,cG,qe,Oc,j0,zX,yX,xX,i0,Or,gh,Hw,a1,kc,c0,Ee,ms,yw,ms,rw,Wr,mG,b0,XF,a0,$$,Z$,Y$,XF,X$,VF,W$,V$,UF,U$,T$,S$,R$,UF,Q$,VF,P$,O$,N$,M$,hw,fh,eh,Hr,_b,Wv,Ag,nk,gw,yl,Uo,jk,x$,De,ki,wg,v$,t$,yF,yF,p$,Gr,n$,xF,li,l$,j$,ie,h$,jw,Aw,ew,fh,eh,Fr,hh,wl,al,Zm,ik,ki,wg,Er,vF,li,U_,fk,P_,O_,Uo,L$,nw,i1,iG,J_,Pr,Vo,gm,E_,Sm,Uo,kw,Ee,l_,Cr,k_,zg,j_,hF,i_,gF,Uo,g_,Uq,e_,d_,lk,c_,bF,gF,a_,BX,_Z,ZZ,WZ,VZ,lw,RZ,QZ,PZ,OZ,NZ,MZ,LZ,KZ,JZ,IZ,HZ,GZ,FZ,EZ,DZ,CZ,BZ,AZ,zZ,yZ,xZ,wZ,vZ,uZ,tZ,sZ,rZ,qZ,pZ,oZ,nZ,mZ,lZ,kZ,jZ,iZ,hZ,gZ,fZ,eZ,dZ,bZ,aZ,Yv,YY,$Y,IX,KX,JX,ZY,XY,J$,I$,H$,as,EF,Wo,xY,wY,DF,CF,BF,jY,hY,fY,dY,bY,$X,ZX,XX,VX,TX,RX,PX,NX,LX,Gc,KE,_Y,JJ,HE,LY,KY,JY,IY,HY,RT,GY,FY,EY,XE,CY,BY,AY,zY,yY,kc,vY,uY,yE,tY,rY,qY,rI,oY,mY,xE,sY,_z,CU,pY,nY,lY,qe,Oc,Oc,WY,VY,UY,TY,SY,RY,QY,PY,RT,OY,NY,MY,Oc,GE,GE,Qo,te,te,DY,te,Oc,EE,DE,Qo,kc,kc,CE,Em,Oc,EE,DE,Qo,kc,kc,CE,Em,Oc,BE,AE,Qo,kc,kc,zE,Em,Oc,BE,AE,Qo,kc,kc,zE,Em,qe,Oc,G$,F$,E$,qe,Oc,D$,C$,B$,Oc,A$,y$,w$,u$,s$,r$,q$,o$,m$,k$,i$,Oc,g$,e$,d$,c$,b$,a$,$_,__,Z_,Y_,X_,Oc,W_,V_,T_,S_,R_,Q_,N_,M_,Oc,L_,K_,I_,H_,G_,F_,D_,C_,qe,Oc,se,B_,A_,z_,y_,x_,w_,kY,gY,cY,SX,OX,_X,WX,qe,Oc,se,v_,u_,t_,s_,q_,p_,iY,eY,aY,QX,MX,YX,UX,Zv,uE,o_,Zv,uE,n_,Oc,Br,Br,dk,dk,dk,jF,kc,ck,ck,Oc,Br,Br,dk,dk,dk,jF,kc,ck,ck,Oc,Zs,Zs,dk,zr,zr,iF,kc,ck,ck,Oc,Zs,Zs,dk,zr,zr,iF,kc,ck,ck,Oc,m_,h_,Oc,f_,b_,Oc,$Z,YZ,Oc,XZ,UZ,Oc,YE,TZ,Gc,Oc,YE,SZ,Gc,qe,qh,qh,kc,kc,kc,pW,Oc,qr,FX,eE,Zj,tX,EX,aE,cG,Oc,wX,bE,Oc,vX,uX,bE,Or,ra,$D,qe,Oc,Ee,Ee,rX,iX,lX,qX,Oc,jX,mX,pX,Oc,kX,nX,oX,Oc,eX,Oc,dX,Oc,fX,or,bu,Or,or,or,or,Or,Oc,cX]);function nb(){return u.byteLength/65536|0}function sb(tb){tb=tb|0;var ob=nb()|0;var pb=ob+tb|0;if(ob<pb&&pb<65536){var qb=new ArrayBuffer(D(pb,65536));var rb=new Int8Array(qb);rb.set(v);v=new Int8Array(qb);w=new Int16Array(qb);x=new Int32Array(qb);y=new Uint8Array(qb);z=new Uint16Array(qb);A=new Uint32Array(qb);B=new Float32Array(qb);C=new Float64Array(qb);u=qb;t.buffer=u;e=y}return ob}return{"xa":aU,"ya":mb,"za":hc,"Aa":J6,"Ba":H6,"Ca":Oc,"Da":G6,"Ea":F6,"Fa":E6,"Ga":Cs,"Ha":Gc,"Ia":D6,"Ja":C6,"Ka":B6,"La":Ix,"Ma":A6,"Na":bJ,"Oa":z6,"Pa":qe,"Qa":aJ,"Ra":$I,"Sa":aJ,"Ta":w6,"Ua":$W,"Va":_W,"Wa":ZW,"Xa":v6,"Ya":YI,"Za":s6,"_a":XI,"$a":r6,"ab":p6,"bb":o6,"cb":n6,"db":m6,"eb":l6,"fb":k6,"gb":j6,"hb":i6,"ib":h6,"jb":g6,"kb":f6,"lb":e6,"mb":d6,"nb":c6,"ob":b6,"pb":$5,"qb":_5,"rb":Z5,"sb":Y5,"tb":X5,"ub":W5,"vb":V5,"wb":U5,"xb":T5,"yb":S5,"zb":R5,"Ab":Q5,"Bb":P5,"Cb":O5,"Db":N5,"Eb":M5,"Fb":L5,"Gb":K5,"Hb":J5,"Ib":I5,"Jb":H5,"Kb":G5,"Lb":F5,"Mb":D5,"Nb":C5,"Ob":B5,"Pb":A5,"Qb":z5,"Rb":y5,"Sb":x5,"Tb":w5,"Ub":v5,"Vb":u5,"Wb":t5,"Xb":s5,"Yb":r5,"Zb":q5,"_b":p5,"$b":o5,"ac":n5,"bc":m5,"cc":l5,"dc":k5,"ec":j5,"fc":i5,"gc":h5,"hc":g5,"ic":YW,"jc":f5,"kc":e5,"lc":d5,"mc":c5,"nc":XW,"oc":b5,"pc":a5,"qc":_4,"rc":Z4,"sc":Y4,"tc":X4,"uc":W4,"vc":e1,"wc":d1,"xc":bX,"yc":aX,"zc":hX,"Ac":gX,"Bc":WW,"Cc":VW,"Dc":UW,"Ec":TW,"Fc":SW,"Gc":RW,"Hc":QW,"Ic":PW,"Jc":OW,"Kc":NW,"Lc":MW}}return ub(wb)}
// EMSCRIPTEN_END_ASM


)(info);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module, info)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


